// Copyright 2014, ARM Limited
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are met:
//
//   * Redistributions of source code must retain the above copyright notice,
//     this list of conditions and the following disclaimer.
//   * Redistributions in binary form must reproduce the above copyright notice,
//     this list of conditions and the following disclaimer in the documentation
//     and/or other materials provided with the distribution.
//   * Neither the name of ARM Limited nor the names of its contributors may be
//     used to endorse or promote products derived from this software without
//     specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS CONTRIBUTORS "AS IS" AND
// ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
// WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
// DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE
// FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
// DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
// SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
// CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
// OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

// This file holds the expected results for the instructions tested by
// test-simulator-a64.
//
// If the input lists (in test-simulator-inputs-a64.h) are updated, please run
// tools/generate_simulator_traces.py on a reference platform to regenerate this
// file.

#include <stdint.h>

// This header should only be used by test/test-simulator-a64.cc, so it
// doesn't need the usual header guard. This simplifies the script that
// generates it; a closing #endif isn't required.
#ifdef VIXL_A64_TEST_SIMULATOR_TRACES_A64_H_
#error This header should be inluded only once.
#endif
#define VIXL_A64_TEST_SIMULATOR_TRACES_A64_H_

// These dummy output lists are useful when developing new tests.
const uint64_t kExpected_dummy_64[] = { 0 };
const size_t kExpectedCount_dummy_64 = 0;

const uint32_t kExpected_dummy_32[] = { 0 };
const size_t kExpectedCount_dummy_32 = 0;

// ---------------------------------------------------------------------
// Expected outputs.
// Everything below this point is automatically generated.
//
// PLEASE DO NOT EDIT ANYTHING BELOW THIS COMMENT.
// ---------------------------------------------------------------------


const uint64_t kExpected_fabs_d[] = {
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff123456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff123456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
};
const unsigned kExpectedCount_fabs_d = 38;

const uint32_t kExpected_fabs_s[] = {
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7f8fffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7f923456,
  0x7f800001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7f8fffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7f923456,
  0x7f800001,
  0x00123456,
  0x007fffff,
  0x00000001,
};
const unsigned kExpectedCount_fabs_s = 38;

const uint64_t kExpected_fadd_d[] = {
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0010000000000000,
  0x0020000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x001123456789abcd,
  0x001fffffffffffff,
  0x0010000000000001,
  0x0010000000000000,
  0x0000000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x000edcba98765433,
  0x0000000000000001,
  0x000fffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff7ffffffffffff,
  0x3ff8000000000000,
  0x3ff8000000000001,
  0x4000000000000000,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x0000000000000000,
  0xbc90000000000000,
  0xbca8000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000002,
  0xbff0000000000000,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000001,
  0x4000000000000000,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3c90000000000000,
  0x0000000000000000,
  0xbca0000000000000,
  0xbfdffffffffffffe,
  0xbfe0000000000000,
  0xbfe0000000000002,
  0xbff0000000000000,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000002,
  0x4000000000000000,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3ca8000000000000,
  0x3ca0000000000000,
  0x0000000000000000,
  0xbfdffffffffffffc,
  0xbfdffffffffffffe,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3ff7ffffffffffff,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3fffffffffffffff,
  0x4000000000000000,
  0x4000000000000000,
  0x4004000000000000,
  0x4026000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fdfffffffffffff,
  0x3fdffffffffffffe,
  0x3fdffffffffffffc,
  0x0000000000000000,
  0xbca0000000000000,
  0xbcb8000000000000,
  0xbfe0000000000001,
  0xc022000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x4000000000000000,
  0x4000000000000000,
  0x4000000000000000,
  0x4004000000000000,
  0x4026000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fdffffffffffffe,
  0x3ca0000000000000,
  0x0000000000000000,
  0xbcb0000000000000,
  0xbfe0000000000000,
  0xc022000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff8000000000001,
  0x3ff8000000000001,
  0x3ff8000000000002,
  0x4000000000000000,
  0x4000000000000000,
  0x4000000000000001,
  0x4004000000000000,
  0x4026000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3fe0000000000002,
  0x3fe0000000000002,
  0x3fe0000000000001,
  0x3cb8000000000000,
  0x3cb0000000000000,
  0x0000000000000000,
  0xbfdffffffffffffc,
  0xc022000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x4000000000000000,
  0x4000000000000000,
  0x4000000000000000,
  0x4004000000000000,
  0x4004000000000000,
  0x4004000000000000,
  0x4008000000000000,
  0x4027000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3fefffffffffffff,
  0x3fe0000000000001,
  0x3fe0000000000000,
  0x3fdffffffffffffc,
  0x0000000000000000,
  0xc021000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4025000000000000,
  0x4025000000000000,
  0x4025000000000000,
  0x4026000000000000,
  0x4026000000000000,
  0x4026000000000000,
  0x4027000000000000,
  0x4034000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4023000000000000,
  0x4023000000000000,
  0x4023000000000000,
  0x4022000000000000,
  0x4022000000000000,
  0x4022000000000000,
  0x4021000000000000,
  0x0000000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x0000000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x001123456789abcd,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0002468acf13579a,
  0x001123456789abcc,
  0x000123456789abce,
  0x000123456789abcd,
  0x800edcba98765433,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0000000000000000,
  0x800edcba98765432,
  0x000123456789abcc,
  0x000fffffffffffff,
  0x001fffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x001123456789abcc,
  0x001ffffffffffffe,
  0x0010000000000000,
  0x000fffffffffffff,
  0x8000000000000001,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x000edcba98765432,
  0x0000000000000000,
  0x000ffffffffffffe,
  0x0000000000000001,
  0x0010000000000001,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abce,
  0x0010000000000000,
  0x0000000000000002,
  0x0000000000000001,
  0x800fffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcc,
  0x800ffffffffffffe,
  0x0000000000000000,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8010000000000000,
  0x0000000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x800edcba98765433,
  0x8000000000000001,
  0x800fffffffffffff,
  0x8010000000000000,
  0x8020000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x801123456789abcd,
  0x801fffffffffffff,
  0x8010000000000001,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0x0000000000000000,
  0x3c90000000000000,
  0x3ca8000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000002,
  0x3ff0000000000000,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff7ffffffffffff,
  0xbff8000000000000,
  0xbff8000000000001,
  0xc000000000000000,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbc90000000000000,
  0x0000000000000000,
  0x3ca0000000000000,
  0x3fdffffffffffffe,
  0x3fe0000000000000,
  0x3fe0000000000002,
  0x3ff0000000000000,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000001,
  0xc000000000000000,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbca8000000000000,
  0xbca0000000000000,
  0x0000000000000000,
  0x3fdffffffffffffc,
  0x3fdffffffffffffe,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000002,
  0xc000000000000000,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfdfffffffffffff,
  0xbfdffffffffffffe,
  0xbfdffffffffffffc,
  0x0000000000000000,
  0x3ca0000000000000,
  0x3cb8000000000000,
  0x3fe0000000000001,
  0x4022000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbff7ffffffffffff,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbfffffffffffffff,
  0xc000000000000000,
  0xc000000000000000,
  0xc004000000000000,
  0xc026000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfdffffffffffffe,
  0xbca0000000000000,
  0x0000000000000000,
  0x3cb0000000000000,
  0x3fe0000000000000,
  0x4022000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xc000000000000000,
  0xc000000000000000,
  0xc000000000000000,
  0xc004000000000000,
  0xc026000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbfe0000000000002,
  0xbfe0000000000002,
  0xbfe0000000000001,
  0xbcb8000000000000,
  0xbcb0000000000000,
  0x0000000000000000,
  0x3fdffffffffffffc,
  0x4022000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff8000000000001,
  0xbff8000000000001,
  0xbff8000000000002,
  0xc000000000000000,
  0xc000000000000000,
  0xc000000000000001,
  0xc004000000000000,
  0xc026000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbfefffffffffffff,
  0xbfe0000000000001,
  0xbfe0000000000000,
  0xbfdffffffffffffc,
  0x0000000000000000,
  0x4021000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xc000000000000000,
  0xc000000000000000,
  0xc000000000000000,
  0xc004000000000000,
  0xc004000000000000,
  0xc004000000000000,
  0xc008000000000000,
  0xc027000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc023000000000000,
  0xc023000000000000,
  0xc023000000000000,
  0xc022000000000000,
  0xc022000000000000,
  0xc022000000000000,
  0xc021000000000000,
  0x0000000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc025000000000000,
  0xc025000000000000,
  0xc025000000000000,
  0xc026000000000000,
  0xc026000000000000,
  0xc026000000000000,
  0xc027000000000000,
  0xc034000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0x0000000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x800123456789abcd,
  0x000edcba98765433,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0000000000000000,
  0x000edcba98765432,
  0x800123456789abcc,
  0x800123456789abcd,
  0x801123456789abcd,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x8002468acf13579a,
  0x801123456789abcc,
  0x800123456789abce,
  0x800fffffffffffff,
  0x0000000000000001,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x800edcba98765432,
  0x0000000000000000,
  0x800ffffffffffffe,
  0x800fffffffffffff,
  0x801fffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x801123456789abcc,
  0x801ffffffffffffe,
  0x8010000000000000,
  0x8000000000000001,
  0x000fffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcc,
  0x000ffffffffffffe,
  0x0000000000000000,
  0x8000000000000001,
  0x8010000000000001,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abce,
  0x8010000000000000,
  0x8000000000000002,
};
const unsigned kExpectedCount_fadd_d = 1444;

const uint32_t kExpected_fadd_s[] = {
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00800000,
  0x01000000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00923456,
  0x00ffffff,
  0x00800001,
  0x00800000,
  0x00000000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x006dcbaa,
  0x00000001,
  0x007fffff,
  0x3effffff,
  0x3effffff,
  0x3f7fffff,
  0x3f800000,
  0x3f800000,
  0x3fbfffff,
  0x3fc00000,
  0x3fc00001,
  0x40000000,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x00000000,
  0xb3000000,
  0xb3c00000,
  0xbeffffff,
  0xbf000000,
  0xbf000002,
  0xbf800000,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3f000000,
  0x3f000000,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3fc00000,
  0x3fc00000,
  0x3fc00001,
  0x40000000,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x33000000,
  0x00000000,
  0xb3800000,
  0xbefffffe,
  0xbf000000,
  0xbf000002,
  0xbf800000,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000001,
  0x3f000001,
  0x3f800000,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x3fc00000,
  0x3fc00002,
  0x40000000,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x33c00000,
  0x33800000,
  0x00000000,
  0xbefffffc,
  0xbefffffe,
  0xbf000001,
  0xbf7fffff,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f7fffff,
  0x3f7fffff,
  0x3fbfffff,
  0x3fc00000,
  0x3fc00000,
  0x3fffffff,
  0x40000000,
  0x40000000,
  0x40200000,
  0x41300000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f7fffff,
  0x3f7fffff,
  0x3f7fffff,
  0x3f7fffff,
  0x3f7fffff,
  0x3effffff,
  0x3efffffe,
  0x3efffffc,
  0x00000000,
  0xb3800000,
  0xb4400000,
  0xbf000001,
  0xc1100000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f7fffff,
  0x3f7fffff,
  0x3f7fffff,
  0x3f800000,
  0x3f800000,
  0x3fc00000,
  0x3fc00000,
  0x3fc00000,
  0x40000000,
  0x40000000,
  0x40000000,
  0x40200000,
  0x41300000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3f000000,
  0x3f000000,
  0x3efffffe,
  0x33800000,
  0x00000000,
  0xb4000000,
  0xbf000000,
  0xc1100000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3f800001,
  0x3f800001,
  0x3fc00001,
  0x3fc00001,
  0x3fc00002,
  0x40000000,
  0x40000000,
  0x40000001,
  0x40200000,
  0x41300000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f800001,
  0x3f800001,
  0x3f800001,
  0x3f800001,
  0x3f800001,
  0x3f000002,
  0x3f000002,
  0x3f000001,
  0x34400000,
  0x34000000,
  0x00000000,
  0xbefffffc,
  0xc1100000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f800001,
  0x3f800001,
  0x3f800001,
  0x3fc00000,
  0x3fc00000,
  0x40000000,
  0x40000000,
  0x40000000,
  0x40200000,
  0x40200000,
  0x40200000,
  0x40400000,
  0x41380000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3fc00000,
  0x3fc00000,
  0x3fc00000,
  0x3fc00000,
  0x3fc00000,
  0x3f800000,
  0x3f800000,
  0x3f7fffff,
  0x3f000001,
  0x3f000000,
  0x3efffffc,
  0x00000000,
  0xc1080000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3fc00000,
  0x3fc00000,
  0x3fc00000,
  0x41200000,
  0x41200000,
  0x41280000,
  0x41280000,
  0x41280000,
  0x41300000,
  0x41300000,
  0x41300000,
  0x41380000,
  0x41a00000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x41200000,
  0x41200000,
  0x41200000,
  0x41200000,
  0x41200000,
  0x41180000,
  0x41180000,
  0x41180000,
  0x41100000,
  0x41100000,
  0x41100000,
  0x41080000,
  0x00000000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x41200000,
  0x41200000,
  0x41200000,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x00123456,
  0x00923456,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x002468ac,
  0x00923455,
  0x00123457,
  0x00123456,
  0x806dcbaa,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x00000000,
  0x806dcba9,
  0x00123455,
  0x007fffff,
  0x00ffffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00923455,
  0x00fffffe,
  0x00800000,
  0x007fffff,
  0x80000001,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x006dcba9,
  0x00000000,
  0x007ffffe,
  0x00000001,
  0x00800001,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123457,
  0x00800000,
  0x00000002,
  0x00000001,
  0x807fffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123455,
  0x807ffffe,
  0x00000000,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80800000,
  0x00000000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x806dcbaa,
  0x80000001,
  0x807fffff,
  0x80800000,
  0x81000000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80923456,
  0x80ffffff,
  0x80800001,
  0xbeffffff,
  0xbeffffff,
  0x00000000,
  0x33000000,
  0x33c00000,
  0x3effffff,
  0x3f000000,
  0x3f000002,
  0x3f800000,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbf7fffff,
  0xbf800000,
  0xbf800000,
  0xbfbfffff,
  0xbfc00000,
  0xbfc00001,
  0xc0000000,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbf000000,
  0xbf000000,
  0xb3000000,
  0x00000000,
  0x33800000,
  0x3efffffe,
  0x3f000000,
  0x3f000002,
  0x3f800000,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbfc00000,
  0xbfc00000,
  0xbfc00001,
  0xc0000000,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000001,
  0xbf000001,
  0xb3c00000,
  0xb3800000,
  0x00000000,
  0x3efffffc,
  0x3efffffe,
  0x3f000001,
  0x3f7fffff,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf800000,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xbfc00000,
  0xbfc00002,
  0xc0000000,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf7fffff,
  0xbf7fffff,
  0xbeffffff,
  0xbefffffe,
  0xbefffffc,
  0x00000000,
  0x33800000,
  0x34400000,
  0x3f000001,
  0x41100000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf7fffff,
  0xbf7fffff,
  0xbf7fffff,
  0xbf7fffff,
  0xbf7fffff,
  0xbfbfffff,
  0xbfc00000,
  0xbfc00000,
  0xbfffffff,
  0xc0000000,
  0xc0000000,
  0xc0200000,
  0xc1300000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf7fffff,
  0xbf7fffff,
  0xbf7fffff,
  0xbf800000,
  0xbf800000,
  0xbf000000,
  0xbf000000,
  0xbefffffe,
  0xb3800000,
  0x00000000,
  0x34000000,
  0x3f000000,
  0x41100000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbfc00000,
  0xbfc00000,
  0xbfc00000,
  0xc0000000,
  0xc0000000,
  0xc0000000,
  0xc0200000,
  0xc1300000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbf800001,
  0xbf800001,
  0xbf000002,
  0xbf000002,
  0xbf000001,
  0xb4400000,
  0xb4000000,
  0x00000000,
  0x3efffffc,
  0x41100000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf800001,
  0xbf800001,
  0xbf800001,
  0xbf800001,
  0xbf800001,
  0xbfc00001,
  0xbfc00001,
  0xbfc00002,
  0xc0000000,
  0xc0000000,
  0xc0000001,
  0xc0200000,
  0xc1300000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf800001,
  0xbf800001,
  0xbf800001,
  0xbfc00000,
  0xbfc00000,
  0xbf800000,
  0xbf800000,
  0xbf7fffff,
  0xbf000001,
  0xbf000000,
  0xbefffffc,
  0x00000000,
  0x41080000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbfc00000,
  0xbfc00000,
  0xbfc00000,
  0xbfc00000,
  0xbfc00000,
  0xc0000000,
  0xc0000000,
  0xc0000000,
  0xc0200000,
  0xc0200000,
  0xc0200000,
  0xc0400000,
  0xc1380000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbfc00000,
  0xbfc00000,
  0xbfc00000,
  0xc1200000,
  0xc1200000,
  0xc1180000,
  0xc1180000,
  0xc1180000,
  0xc1100000,
  0xc1100000,
  0xc1100000,
  0xc1080000,
  0x00000000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xc1200000,
  0xc1200000,
  0xc1200000,
  0xc1200000,
  0xc1200000,
  0xc1280000,
  0xc1280000,
  0xc1280000,
  0xc1300000,
  0xc1300000,
  0xc1300000,
  0xc1380000,
  0xc1a00000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xc1200000,
  0xc1200000,
  0xc1200000,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x80123456,
  0x006dcbaa,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00000000,
  0x006dcba9,
  0x80123455,
  0x80123456,
  0x80923456,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x802468ac,
  0x80923455,
  0x80123457,
  0x807fffff,
  0x00000001,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x806dcba9,
  0x00000000,
  0x807ffffe,
  0x807fffff,
  0x80ffffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80923455,
  0x80fffffe,
  0x80800000,
  0x80000001,
  0x007fffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123455,
  0x007ffffe,
  0x00000000,
  0x80000001,
  0x80800001,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123457,
  0x80800000,
  0x80000002,
};
const unsigned kExpectedCount_fadd_s = 1444;

const uint8_t kExpected_fcmp_d[] = {
  0x6,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x3,
  0x3,
  0x3,
  0x8,
  0x8,
  0x8,
  0x8,
  0x6,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x3,
  0x3,
  0x3,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x6,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x3,
  0x3,
  0x3,
  0x8,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x3,
  0x3,
  0x3,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x6,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x3,
  0x3,
  0x3,
  0x8,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x3,
  0x3,
  0x3,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x6,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x3,
  0x3,
  0x3,
  0x8,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x3,
  0x3,
  0x3,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x6,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x3,
  0x3,
  0x3,
  0x8,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x3,
  0x3,
  0x3,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x6,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x3,
  0x3,
  0x3,
  0x8,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x3,
  0x3,
  0x3,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x6,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x3,
  0x3,
  0x3,
  0x8,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x3,
  0x3,
  0x3,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x6,
  0x8,
  0x8,
  0x8,
  0x8,
  0x3,
  0x3,
  0x3,
  0x8,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x3,
  0x3,
  0x3,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x6,
  0x8,
  0x8,
  0x8,
  0x3,
  0x3,
  0x3,
  0x8,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x3,
  0x3,
  0x3,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x6,
  0x8,
  0x8,
  0x3,
  0x3,
  0x3,
  0x8,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x3,
  0x3,
  0x3,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x6,
  0x8,
  0x3,
  0x3,
  0x3,
  0x8,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x3,
  0x3,
  0x3,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x6,
  0x3,
  0x3,
  0x3,
  0x6,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x3,
  0x3,
  0x3,
  0x2,
  0x2,
  0x2,
  0x2,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x6,
  0x3,
  0x3,
  0x3,
  0x6,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x3,
  0x3,
  0x3,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x3,
  0x3,
  0x3,
  0x8,
  0x6,
  0x8,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x3,
  0x3,
  0x3,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x3,
  0x3,
  0x3,
  0x8,
  0x2,
  0x6,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x3,
  0x3,
  0x3,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x3,
  0x3,
  0x3,
  0x8,
  0x8,
  0x8,
  0x6,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x3,
  0x3,
  0x3,
  0x2,
  0x2,
  0x2,
  0x2,
  0x6,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x3,
  0x3,
  0x3,
  0x8,
  0x8,
  0x8,
  0x8,
  0x6,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x3,
  0x3,
  0x3,
  0x2,
  0x2,
  0x2,
  0x2,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x3,
  0x3,
  0x3,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x6,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x3,
  0x3,
  0x3,
  0x2,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x3,
  0x3,
  0x3,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x6,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x3,
  0x3,
  0x3,
  0x2,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x3,
  0x3,
  0x3,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x6,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x3,
  0x3,
  0x3,
  0x2,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x3,
  0x3,
  0x3,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x6,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x3,
  0x3,
  0x3,
  0x2,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x3,
  0x3,
  0x3,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x6,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x3,
  0x3,
  0x3,
  0x2,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x3,
  0x3,
  0x3,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x6,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x3,
  0x3,
  0x3,
  0x2,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x3,
  0x3,
  0x3,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x6,
  0x2,
  0x2,
  0x2,
  0x2,
  0x3,
  0x3,
  0x3,
  0x2,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x3,
  0x3,
  0x3,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x6,
  0x2,
  0x2,
  0x2,
  0x3,
  0x3,
  0x3,
  0x2,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x3,
  0x3,
  0x3,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x6,
  0x2,
  0x2,
  0x3,
  0x3,
  0x3,
  0x2,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x3,
  0x3,
  0x3,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x6,
  0x2,
  0x3,
  0x3,
  0x3,
  0x2,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x3,
  0x3,
  0x3,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x6,
  0x3,
  0x3,
  0x3,
  0x6,
  0x8,
  0x8,
  0x8,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x3,
  0x3,
  0x3,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x6,
  0x3,
  0x3,
  0x3,
  0x6,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x3,
  0x3,
  0x3,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x3,
  0x3,
  0x3,
  0x2,
  0x6,
  0x2,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x3,
  0x3,
  0x3,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x3,
  0x3,
  0x3,
  0x2,
  0x8,
  0x6,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x3,
  0x3,
  0x3,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x3,
  0x3,
  0x3,
  0x2,
  0x2,
  0x2,
  0x6,
};
const unsigned kExpectedCount_fcmp_d = 1444;

const uint8_t kExpected_fcmp_dz[] = {
  0x6,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x3,
  0x3,
  0x3,
  0x2,
  0x2,
  0x2,
  0x2,
  0x6,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x3,
  0x3,
  0x3,
  0x8,
  0x8,
  0x8,
  0x8,
};
const unsigned kExpectedCount_fcmp_dz = 38;

const uint8_t kExpected_fcmp_s[] = {
  0x6,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x3,
  0x8,
  0x3,
  0x3,
  0x3,
  0x3,
  0x8,
  0x8,
  0x8,
  0x6,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x3,
  0x2,
  0x3,
  0x3,
  0x3,
  0x3,
  0x2,
  0x2,
  0x2,
  0x2,
  0x6,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x3,
  0x8,
  0x3,
  0x3,
  0x3,
  0x3,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x3,
  0x2,
  0x3,
  0x3,
  0x3,
  0x3,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x6,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x3,
  0x8,
  0x3,
  0x3,
  0x3,
  0x3,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x3,
  0x2,
  0x3,
  0x3,
  0x3,
  0x3,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x6,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x3,
  0x8,
  0x3,
  0x3,
  0x3,
  0x3,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x3,
  0x2,
  0x3,
  0x3,
  0x3,
  0x3,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x6,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x3,
  0x8,
  0x3,
  0x3,
  0x3,
  0x3,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x3,
  0x2,
  0x3,
  0x3,
  0x3,
  0x3,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x6,
  0x8,
  0x8,
  0x8,
  0x8,
  0x3,
  0x8,
  0x3,
  0x3,
  0x3,
  0x3,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x3,
  0x2,
  0x3,
  0x3,
  0x3,
  0x3,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x6,
  0x8,
  0x8,
  0x8,
  0x3,
  0x8,
  0x3,
  0x3,
  0x3,
  0x3,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x3,
  0x2,
  0x3,
  0x3,
  0x3,
  0x3,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x6,
  0x8,
  0x8,
  0x3,
  0x8,
  0x3,
  0x3,
  0x3,
  0x3,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x3,
  0x2,
  0x3,
  0x3,
  0x3,
  0x3,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x6,
  0x8,
  0x3,
  0x8,
  0x3,
  0x3,
  0x3,
  0x3,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x3,
  0x2,
  0x3,
  0x3,
  0x3,
  0x3,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x6,
  0x3,
  0x8,
  0x3,
  0x3,
  0x3,
  0x3,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x3,
  0x2,
  0x3,
  0x3,
  0x3,
  0x3,
  0x2,
  0x2,
  0x2,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x3,
  0x6,
  0x3,
  0x3,
  0x3,
  0x3,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x3,
  0x2,
  0x3,
  0x3,
  0x3,
  0x3,
  0x2,
  0x2,
  0x2,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x2,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x3,
  0x8,
  0x3,
  0x3,
  0x3,
  0x3,
  0x6,
  0x8,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x3,
  0x2,
  0x3,
  0x3,
  0x3,
  0x3,
  0x2,
  0x2,
  0x2,
  0x2,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x3,
  0x8,
  0x3,
  0x3,
  0x3,
  0x3,
  0x2,
  0x6,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x3,
  0x2,
  0x3,
  0x3,
  0x3,
  0x3,
  0x2,
  0x2,
  0x2,
  0x2,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x3,
  0x8,
  0x3,
  0x3,
  0x3,
  0x3,
  0x8,
  0x8,
  0x6,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x3,
  0x2,
  0x3,
  0x3,
  0x3,
  0x3,
  0x2,
  0x2,
  0x2,
  0x6,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x3,
  0x8,
  0x3,
  0x3,
  0x3,
  0x3,
  0x8,
  0x8,
  0x8,
  0x6,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x3,
  0x2,
  0x3,
  0x3,
  0x3,
  0x3,
  0x2,
  0x2,
  0x2,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x3,
  0x8,
  0x3,
  0x3,
  0x3,
  0x3,
  0x8,
  0x8,
  0x8,
  0x8,
  0x6,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x3,
  0x2,
  0x3,
  0x3,
  0x3,
  0x3,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x3,
  0x8,
  0x3,
  0x3,
  0x3,
  0x3,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x6,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x3,
  0x2,
  0x3,
  0x3,
  0x3,
  0x3,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x3,
  0x8,
  0x3,
  0x3,
  0x3,
  0x3,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x6,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x3,
  0x2,
  0x3,
  0x3,
  0x3,
  0x3,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x3,
  0x8,
  0x3,
  0x3,
  0x3,
  0x3,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x6,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x3,
  0x2,
  0x3,
  0x3,
  0x3,
  0x3,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x3,
  0x8,
  0x3,
  0x3,
  0x3,
  0x3,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x6,
  0x2,
  0x2,
  0x2,
  0x2,
  0x3,
  0x2,
  0x3,
  0x3,
  0x3,
  0x3,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x3,
  0x8,
  0x3,
  0x3,
  0x3,
  0x3,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x6,
  0x2,
  0x2,
  0x2,
  0x3,
  0x2,
  0x3,
  0x3,
  0x3,
  0x3,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x3,
  0x8,
  0x3,
  0x3,
  0x3,
  0x3,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x6,
  0x2,
  0x2,
  0x3,
  0x2,
  0x3,
  0x3,
  0x3,
  0x3,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x3,
  0x8,
  0x3,
  0x3,
  0x3,
  0x3,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x6,
  0x2,
  0x3,
  0x2,
  0x3,
  0x3,
  0x3,
  0x3,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x3,
  0x8,
  0x3,
  0x3,
  0x3,
  0x3,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x6,
  0x3,
  0x2,
  0x3,
  0x3,
  0x3,
  0x3,
  0x8,
  0x8,
  0x8,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x3,
  0x8,
  0x3,
  0x3,
  0x3,
  0x3,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x3,
  0x6,
  0x3,
  0x3,
  0x3,
  0x3,
  0x8,
  0x8,
  0x8,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x3,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x3,
  0x8,
  0x3,
  0x3,
  0x3,
  0x3,
  0x8,
  0x8,
  0x8,
  0x8,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x3,
  0x2,
  0x3,
  0x3,
  0x3,
  0x3,
  0x6,
  0x2,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x3,
  0x8,
  0x3,
  0x3,
  0x3,
  0x3,
  0x8,
  0x8,
  0x8,
  0x8,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x3,
  0x2,
  0x3,
  0x3,
  0x3,
  0x3,
  0x8,
  0x6,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x3,
  0x8,
  0x3,
  0x3,
  0x3,
  0x3,
  0x8,
  0x8,
  0x8,
  0x8,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x3,
  0x2,
  0x3,
  0x3,
  0x3,
  0x3,
  0x2,
  0x2,
  0x6,
};
const unsigned kExpectedCount_fcmp_s = 1444;

const uint8_t kExpected_fcmp_sz[] = {
  0x6,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x2,
  0x3,
  0x2,
  0x3,
  0x3,
  0x3,
  0x3,
  0x2,
  0x2,
  0x2,
  0x6,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x8,
  0x3,
  0x8,
  0x3,
  0x3,
  0x3,
  0x3,
  0x8,
  0x8,
  0x8,
};
const unsigned kExpectedCount_fcmp_sz = 38;

const uint64_t kExpected_fcvt_ds[] = {
  0x0000000000000000,
  0x3810000000000000,
  0x3fdfffffe0000000,
  0x3fe0000000000000,
  0x3fe0000020000000,
  0x3fefffffe0000000,
  0x3ff0000000000000,
  0x3ff0000020000000,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7ff9ffffe0000000,
  0x7ff0000000000000,
  0x7ffa468ac0000000,
  0x7ff8000000000000,
  0x7ffa468ac0000000,
  0x7ff8000020000000,
  0x37e2345600000000,
  0x380fffffc0000000,
  0x36a0000000000000,
  0x8000000000000000,
  0xb810000000000000,
  0xbfdfffffe0000000,
  0xbfe0000000000000,
  0xbfe0000020000000,
  0xbfefffffe0000000,
  0xbff0000000000000,
  0xbff0000020000000,
  0xbff8000000000000,
  0xc024000000000000,
  0xfff9ffffe0000000,
  0xfff0000000000000,
  0xfffa468ac0000000,
  0xfff8000000000000,
  0xfffa468ac0000000,
  0xfff8000020000000,
  0xb7e2345600000000,
  0xb80fffffc0000000,
  0xb6a0000000000000,
  0x4160000000000000,
  0x4160000020000000,
  0x4160000040000000,
  0x4160000060000000,
  0x416eca8640000000,
  0x416fffff80000000,
  0x416fffffa0000000,
  0x416fffffc0000000,
  0x416fffffe0000000,
  0x4150000000000000,
  0x4150000020000000,
  0x4150000040000000,
  0x4150000060000000,
  0x415eca8640000000,
  0x415fffff80000000,
  0x415fffffa0000000,
  0x415fffffc0000000,
  0x415fffffe0000000,
  0x4140000000000000,
  0x4140000020000000,
  0x4140000040000000,
  0x4140000060000000,
  0x414eca8640000000,
  0x414fffff80000000,
  0x414fffffa0000000,
  0x414fffffc0000000,
  0x414fffffe0000000,
  0xc160000000000000,
  0xc160000020000000,
  0xc160000040000000,
  0xc160000060000000,
  0xc16eca8640000000,
  0xc16fffff80000000,
  0xc16fffffa0000000,
  0xc16fffffc0000000,
  0xc16fffffe0000000,
  0xc150000000000000,
  0xc150000020000000,
  0xc150000040000000,
  0xc150000060000000,
  0xc15eca8640000000,
  0xc15fffff80000000,
  0xc15fffffa0000000,
  0xc15fffffc0000000,
  0xc15fffffe0000000,
  0xc140000000000000,
  0xc140000020000000,
  0xc140000040000000,
  0xc140000060000000,
  0xc14eca8640000000,
  0xc14fffff80000000,
  0xc14fffffa0000000,
  0xc14fffffc0000000,
  0xc14fffffe0000000,
  0xc3e0000020000000,
  0xc3e0000000000000,
  0xc3dfffffe0000000,
  0x43dfffffe0000000,
  0x43e0000000000000,
  0x43efffffe0000000,
  0x43f0000000000000,
  0xc1e0000020000000,
  0xc1e0000000000000,
  0xc1dfffffe0000000,
  0x41dfffffe0000000,
  0x41e0000000000000,
};
const unsigned kExpectedCount_fcvt_ds = 104;

const uint32_t kExpected_fcvt_sd[] = {
  0x00000000,
  0x00000000,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3fc00000,
  0x41200000,
  0x7f800000,
  0x7f800000,
  0x7fc91a2b,
  0x7fc00000,
  0x7fc91a2b,
  0x7f800000,
  0x00000000,
  0x00000000,
  0x00000000,
  0x80000000,
  0x80000000,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbfc00000,
  0xc1200000,
  0xff800000,
  0xff800000,
  0xffc91a2b,
  0xffc00000,
  0xffc91a2b,
  0xff800000,
  0x80000000,
  0x80000000,
  0x80000000,
  0x7f7ffff8,
  0x00800000,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3f800001,
  0x3f800001,
  0x3f800001,
  0x3f800002,
  0x3f800002,
  0x3f800002,
  0x3f800002,
  0x3f800002,
  0x3f800003,
  0x3f800003,
  0x3f800000,
  0x7f7fffff,
  0x7f800000,
  0x7f800000,
  0x00000000,
  0x007fffff,
  0x00000001,
  0x00045678,
  0x00045678,
  0x00045678,
  0x00045679,
  0x00045679,
  0x00045679,
  0x0004567a,
  0x0004567a,
  0x0004567a,
  0x0004567a,
  0x0004567a,
  0x0004567b,
  0x0004567b,
  0x00000001,
  0xff7ffff8,
  0x80800000,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbf800001,
  0xbf800001,
  0xbf800001,
  0xbf800002,
  0xbf800002,
  0xbf800002,
  0xbf800002,
  0xbf800002,
  0xbf800003,
  0xbf800003,
  0xbf800000,
  0xff7fffff,
  0xff800000,
  0xff800000,
  0x80000000,
  0x807fffff,
  0x80000001,
  0x80045678,
  0x80045678,
  0x80045678,
  0x80045679,
  0x80045679,
  0x80045679,
  0x8004567a,
  0x8004567a,
  0x8004567a,
  0x8004567a,
  0x8004567a,
  0x8004567b,
  0x8004567b,
  0x80000001,
  0x59800000,
  0x59800000,
  0x59800000,
  0x59800000,
  0x59ff6e5d,
  0x5a000000,
  0x5a000000,
  0x5a000000,
  0x5a000000,
  0x59000000,
  0x59000000,
  0x59000000,
  0x59000000,
  0x597f6e5d,
  0x59800000,
  0x59800000,
  0x59800000,
  0x59800000,
  0x58800000,
  0x58800000,
  0x58800000,
  0x58800000,
  0x58ff6e5d,
  0x59000000,
  0x59000000,
  0x59000000,
  0x59000000,
  0xd9800000,
  0xd9800000,
  0xd9800000,
  0xd9800000,
  0xd9ff6e5d,
  0xda000000,
  0xda000000,
  0xda000000,
  0xda000000,
  0xd9000000,
  0xd9000000,
  0xd9000000,
  0xd9000000,
  0xd97f6e5d,
  0xd9800000,
  0xd9800000,
  0xd9800000,
  0xd9800000,
  0xd8800000,
  0xd8800000,
  0xd8800000,
  0xd8800000,
  0xd8ff6e5d,
  0xd9000000,
  0xd9000000,
  0xd9000000,
  0xd9000000,
  0xdf000000,
  0xdf000000,
  0xdf000000,
  0x5f000000,
  0x5f000000,
  0x5f800000,
  0x5f800000,
  0xcf000000,
  0xcf000000,
  0xcf000000,
  0xcf000000,
  0xcf000000,
  0xcf000000,
  0xcf000000,
  0xcf000000,
  0xcf000000,
  0xcf000000,
  0xcf000000,
  0xcf000000,
  0x4f000000,
  0x4f000000,
  0x4f000000,
  0x4f000000,
  0x4f000000,
  0x4f000000,
  0x4f000000,
  0x4f000000,
  0x4f000000,
  0x4f000000,
  0x4f000000,
  0x4f000000,
  0x4f800000,
  0x4f800000,
  0x4f800000,
  0x4f800000,
  0x4f800000,
  0x4f800000,
  0x4f800000,
  0x4f800000,
  0x4f800000,
  0x4f800000,
  0x4f800000,
  0x4f800000,
};
const unsigned kExpectedCount_fcvt_sd = 207;

const int32_t kExpected_fcvtas_wd[] = {
  0,
  0,
  0,
  1,
  1,
  1,
  1,
  1,
  2,
  10,
  2147483647,
  2147483647,
  0,
  0,
  0,
  2147483647,
  0,
  0,
  0,
  0,
  0,
  0,
  -1,
  -1,
  -1,
  -1,
  -1,
  -2,
  -10,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  0,
  0,
  0,
  -INT32_C(2147483647) - 1,
  0,
  0,
  0,
  2147483647,
  0,
  1,
  1,
  1,
  1,
  1,
  1,
  1,
  1,
  1,
  1,
  1,
  1,
  1,
  1,
  2147483647,
  2147483647,
  2147483647,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  -INT32_C(2147483647) - 1,
  0,
  -1,
  -1,
  -1,
  -1,
  -1,
  -1,
  -1,
  -1,
  -1,
  -1,
  -1,
  -1,
  -1,
  -1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -2147483647,
  2147483646,
  2147483646,
  2147483646,
  2147483646,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
};
const unsigned kExpectedCount_fcvtas_wd = 207;

const int32_t kExpected_fcvtas_ws[] = {
  0,
  0,
  0,
  1,
  1,
  1,
  1,
  1,
  2,
  10,
  0,
  2147483647,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  -1,
  -1,
  -1,
  -1,
  -1,
  -2,
  -10,
  0,
  -INT32_C(2147483647) - 1,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  8388608,
  8388609,
  8388610,
  8388611,
  16143410,
  16777212,
  16777213,
  16777214,
  16777215,
  4194304,
  4194305,
  4194305,
  4194306,
  8071705,
  8388606,
  8388607,
  8388607,
  8388608,
  2097152,
  2097152,
  2097153,
  2097153,
  4035853,
  4194303,
  4194303,
  4194304,
  4194304,
  -8388608,
  -8388609,
  -8388610,
  -8388611,
  -16143410,
  -16777212,
  -16777213,
  -16777214,
  -16777215,
  -4194304,
  -4194305,
  -4194305,
  -4194306,
  -8071705,
  -8388606,
  -8388607,
  -8388607,
  -8388608,
  -2097152,
  -2097152,
  -2097153,
  -2097153,
  -4035853,
  -4194303,
  -4194303,
  -4194304,
  -4194304,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -2147483520,
  2147483520,
  2147483647,
};
const unsigned kExpectedCount_fcvtas_ws = 104;

const int64_t kExpected_fcvtas_xd[] = {
  0,
  0,
  0,
  1,
  1,
  1,
  1,
  1,
  2,
  10,
  9223372036854775807,
  9223372036854775807,
  0,
  0,
  0,
  9223372036854775807,
  0,
  0,
  0,
  0,
  0,
  0,
  -1,
  -1,
  -1,
  -1,
  -1,
  -2,
  -10,
  -INT64_C(9223372036854775807) - 1,
  -INT64_C(9223372036854775807) - 1,
  0,
  0,
  0,
  -INT64_C(9223372036854775807) - 1,
  0,
  0,
  0,
  9223372036854775807,
  0,
  1,
  1,
  1,
  1,
  1,
  1,
  1,
  1,
  1,
  1,
  1,
  1,
  1,
  1,
  9223372036854775807,
  9223372036854775807,
  9223372036854775807,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  -INT64_C(9223372036854775807) - 1,
  0,
  -1,
  -1,
  -1,
  -1,
  -1,
  -1,
  -1,
  -1,
  -1,
  -1,
  -1,
  -1,
  -1,
  -1,
  -INT64_C(9223372036854775807) - 1,
  -INT64_C(9223372036854775807) - 1,
  -INT64_C(9223372036854775807) - 1,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  4503599627370496,
  4503599627370497,
  4503599627370498,
  4503599627370499,
  8987183256397123,
  9007199254740988,
  9007199254740989,
  9007199254740990,
  9007199254740991,
  2251799813685248,
  2251799813685249,
  2251799813685249,
  2251799813685250,
  4493591628198562,
  4503599627370494,
  4503599627370495,
  4503599627370495,
  4503599627370496,
  1125899906842624,
  1125899906842624,
  1125899906842625,
  1125899906842625,
  2246795814099281,
  2251799813685247,
  2251799813685247,
  2251799813685248,
  2251799813685248,
  -4503599627370496,
  -4503599627370497,
  -4503599627370498,
  -4503599627370499,
  -8987183256397123,
  -9007199254740988,
  -9007199254740989,
  -9007199254740990,
  -9007199254740991,
  -2251799813685248,
  -2251799813685249,
  -2251799813685249,
  -2251799813685250,
  -4493591628198562,
  -4503599627370494,
  -4503599627370495,
  -4503599627370495,
  -4503599627370496,
  -1125899906842624,
  -1125899906842624,
  -1125899906842625,
  -1125899906842625,
  -2246795814099281,
  -2251799813685247,
  -2251799813685247,
  -2251799813685248,
  -2251799813685248,
  -INT64_C(9223372036854775807) - 1,
  -INT64_C(9223372036854775807) - 1,
  -9223372036854774784,
  9223372036854774784,
  9223372036854775807,
  9223372036854775807,
  9223372036854775807,
  -2147483649,
  -2147483649,
  -2147483649,
  -2147483649,
  -2147483649,
  -2147483648,
  -2147483648,
  -2147483648,
  -2147483648,
  -2147483648,
  -2147483648,
  -2147483647,
  2147483646,
  2147483646,
  2147483646,
  2147483646,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483648,
  2147483648,
  4294967294,
  4294967294,
  4294967294,
  4294967294,
  4294967295,
  4294967295,
  4294967295,
  4294967295,
  4294967295,
  4294967295,
  4294967296,
  4294967296,
};
const unsigned kExpectedCount_fcvtas_xd = 207;

const int64_t kExpected_fcvtas_xs[] = {
  0,
  0,
  0,
  1,
  1,
  1,
  1,
  1,
  2,
  10,
  0,
  9223372036854775807,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  -1,
  -1,
  -1,
  -1,
  -1,
  -2,
  -10,
  0,
  -INT64_C(9223372036854775807) - 1,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  8388608,
  8388609,
  8388610,
  8388611,
  16143410,
  16777212,
  16777213,
  16777214,
  16777215,
  4194304,
  4194305,
  4194305,
  4194306,
  8071705,
  8388606,
  8388607,
  8388607,
  8388608,
  2097152,
  2097152,
  2097153,
  2097153,
  4035853,
  4194303,
  4194303,
  4194304,
  4194304,
  -8388608,
  -8388609,
  -8388610,
  -8388611,
  -16143410,
  -16777212,
  -16777213,
  -16777214,
  -16777215,
  -4194304,
  -4194305,
  -4194305,
  -4194306,
  -8071705,
  -8388606,
  -8388607,
  -8388607,
  -8388608,
  -2097152,
  -2097152,
  -2097153,
  -2097153,
  -4035853,
  -4194303,
  -4194303,
  -4194304,
  -4194304,
  -INT64_C(9223372036854775807) - 1,
  -INT64_C(9223372036854775807) - 1,
  -9223371487098961920,
  9223371487098961920,
  9223372036854775807,
  9223372036854775807,
  9223372036854775807,
  -2147483904,
  -2147483648,
  -2147483520,
  2147483520,
  2147483648,
};
const unsigned kExpectedCount_fcvtas_xs = 104;

const uint32_t kExpected_fcvtau_wd[] = {
  0u,
  0u,
  0u,
  1u,
  1u,
  1u,
  1u,
  1u,
  2u,
  10u,
  4294967295u,
  4294967295u,
  0u,
  0u,
  0u,
  4294967295u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  4294967295u,
  0u,
  1u,
  1u,
  1u,
  1u,
  1u,
  1u,
  1u,
  1u,
  1u,
  1u,
  1u,
  1u,
  1u,
  1u,
  4294967295u,
  4294967295u,
  4294967295u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  4294967295u,
  4294967295u,
  4294967295u,
  4294967295u,
  4294967295u,
  4294967295u,
  4294967295u,
  4294967295u,
  4294967295u,
  4294967295u,
  4294967295u,
  4294967295u,
  4294967295u,
  4294967295u,
  4294967295u,
  4294967295u,
  4294967295u,
  4294967295u,
  4294967295u,
  4294967295u,
  4294967295u,
  4294967295u,
  4294967295u,
  4294967295u,
  4294967295u,
  4294967295u,
  4294967295u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  4294967295u,
  4294967295u,
  4294967295u,
  4294967295u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  2147483646u,
  2147483646u,
  2147483646u,
  2147483646u,
  2147483647u,
  2147483647u,
  2147483647u,
  2147483647u,
  2147483647u,
  2147483647u,
  2147483648u,
  2147483648u,
  4294967294u,
  4294967294u,
  4294967294u,
  4294967294u,
  4294967295u,
  4294967295u,
  4294967295u,
  4294967295u,
  4294967295u,
  4294967295u,
  4294967295u,
  4294967295u,
};
const unsigned kExpectedCount_fcvtau_wd = 207;

const uint32_t kExpected_fcvtau_ws[] = {
  0u,
  0u,
  0u,
  1u,
  1u,
  1u,
  1u,
  1u,
  2u,
  10u,
  0u,
  4294967295u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  8388608u,
  8388609u,
  8388610u,
  8388611u,
  16143410u,
  16777212u,
  16777213u,
  16777214u,
  16777215u,
  4194304u,
  4194305u,
  4194305u,
  4194306u,
  8071705u,
  8388606u,
  8388607u,
  8388607u,
  8388608u,
  2097152u,
  2097152u,
  2097153u,
  2097153u,
  4035853u,
  4194303u,
  4194303u,
  4194304u,
  4194304u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  4294967295u,
  4294967295u,
  4294967295u,
  4294967295u,
  0u,
  0u,
  0u,
  2147483520u,
  2147483648u,
};
const unsigned kExpectedCount_fcvtau_ws = 104;

const uint64_t kExpected_fcvtau_xd[] = {
  0u,
  0u,
  0u,
  1u,
  1u,
  1u,
  1u,
  1u,
  2u,
  10u,
  18446744073709551615u,
  18446744073709551615u,
  0u,
  0u,
  0u,
  18446744073709551615u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  18446744073709551615u,
  0u,
  1u,
  1u,
  1u,
  1u,
  1u,
  1u,
  1u,
  1u,
  1u,
  1u,
  1u,
  1u,
  1u,
  1u,
  18446744073709551615u,
  18446744073709551615u,
  18446744073709551615u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  4503599627370496u,
  4503599627370497u,
  4503599627370498u,
  4503599627370499u,
  8987183256397123u,
  9007199254740988u,
  9007199254740989u,
  9007199254740990u,
  9007199254740991u,
  2251799813685248u,
  2251799813685249u,
  2251799813685249u,
  2251799813685250u,
  4493591628198562u,
  4503599627370494u,
  4503599627370495u,
  4503599627370495u,
  4503599627370496u,
  1125899906842624u,
  1125899906842624u,
  1125899906842625u,
  1125899906842625u,
  2246795814099281u,
  2251799813685247u,
  2251799813685247u,
  2251799813685248u,
  2251799813685248u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  9223372036854774784u,
  9223372036854775808u,
  18446744073709549568u,
  18446744073709551615u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  2147483646u,
  2147483646u,
  2147483646u,
  2147483646u,
  2147483647u,
  2147483647u,
  2147483647u,
  2147483647u,
  2147483647u,
  2147483647u,
  2147483648u,
  2147483648u,
  4294967294u,
  4294967294u,
  4294967294u,
  4294967294u,
  4294967295u,
  4294967295u,
  4294967295u,
  4294967295u,
  4294967295u,
  4294967295u,
  4294967296u,
  4294967296u,
};
const unsigned kExpectedCount_fcvtau_xd = 207;

const uint64_t kExpected_fcvtau_xs[] = {
  0u,
  0u,
  0u,
  1u,
  1u,
  1u,
  1u,
  1u,
  2u,
  10u,
  0u,
  18446744073709551615u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  8388608u,
  8388609u,
  8388610u,
  8388611u,
  16143410u,
  16777212u,
  16777213u,
  16777214u,
  16777215u,
  4194304u,
  4194305u,
  4194305u,
  4194306u,
  8071705u,
  8388606u,
  8388607u,
  8388607u,
  8388608u,
  2097152u,
  2097152u,
  2097153u,
  2097153u,
  4035853u,
  4194303u,
  4194303u,
  4194304u,
  4194304u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  9223371487098961920u,
  9223372036854775808u,
  18446742974197923840u,
  18446744073709551615u,
  0u,
  0u,
  0u,
  2147483520u,
  2147483648u,
};
const unsigned kExpectedCount_fcvtau_xs = 104;

const int32_t kExpected_fcvtms_wd[] = {
  0,
  0,
  0,
  0,
  0,
  0,
  1,
  1,
  1,
  10,
  2147483647,
  2147483647,
  0,
  0,
  0,
  2147483647,
  0,
  0,
  0,
  0,
  -1,
  -1,
  -1,
  -1,
  -1,
  -1,
  -2,
  -2,
  -10,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  0,
  0,
  0,
  -INT32_C(2147483647) - 1,
  -1,
  -1,
  -1,
  2147483647,
  0,
  1,
  1,
  1,
  1,
  1,
  1,
  1,
  1,
  1,
  1,
  1,
  1,
  1,
  0,
  2147483647,
  2147483647,
  2147483647,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  -INT32_C(2147483647) - 1,
  -1,
  -1,
  -2,
  -2,
  -2,
  -2,
  -2,
  -2,
  -2,
  -2,
  -2,
  -2,
  -2,
  -2,
  -1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -1,
  -1,
  -1,
  -1,
  -1,
  -1,
  -1,
  -1,
  -1,
  -1,
  -1,
  -1,
  -1,
  -1,
  -1,
  -1,
  -1,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  2147483645,
  2147483646,
  2147483646,
  2147483646,
  2147483646,
  2147483646,
  2147483646,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
};
const unsigned kExpectedCount_fcvtms_wd = 207;

const int32_t kExpected_fcvtms_ws[] = {
  0,
  0,
  0,
  0,
  0,
  0,
  1,
  1,
  1,
  10,
  0,
  2147483647,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  -1,
  -1,
  -1,
  -1,
  -1,
  -1,
  -2,
  -2,
  -10,
  0,
  -INT32_C(2147483647) - 1,
  0,
  0,
  0,
  0,
  -1,
  -1,
  -1,
  8388608,
  8388609,
  8388610,
  8388611,
  16143410,
  16777212,
  16777213,
  16777214,
  16777215,
  4194304,
  4194304,
  4194305,
  4194305,
  8071705,
  8388606,
  8388606,
  8388607,
  8388607,
  2097152,
  2097152,
  2097152,
  2097152,
  4035852,
  4194303,
  4194303,
  4194303,
  4194303,
  -8388608,
  -8388609,
  -8388610,
  -8388611,
  -16143410,
  -16777212,
  -16777213,
  -16777214,
  -16777215,
  -4194304,
  -4194305,
  -4194305,
  -4194306,
  -8071705,
  -8388606,
  -8388607,
  -8388607,
  -8388608,
  -2097152,
  -2097153,
  -2097153,
  -2097153,
  -4035853,
  -4194303,
  -4194304,
  -4194304,
  -4194304,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -2147483520,
  2147483520,
  2147483647,
};
const unsigned kExpectedCount_fcvtms_ws = 104;

const int64_t kExpected_fcvtms_xd[] = {
  0,
  0,
  0,
  0,
  0,
  0,
  1,
  1,
  1,
  10,
  9223372036854775807,
  9223372036854775807,
  0,
  0,
  0,
  9223372036854775807,
  0,
  0,
  0,
  0,
  -1,
  -1,
  -1,
  -1,
  -1,
  -1,
  -2,
  -2,
  -10,
  -INT64_C(9223372036854775807) - 1,
  -INT64_C(9223372036854775807) - 1,
  0,
  0,
  0,
  -INT64_C(9223372036854775807) - 1,
  -1,
  -1,
  -1,
  9223372036854775807,
  0,
  1,
  1,
  1,
  1,
  1,
  1,
  1,
  1,
  1,
  1,
  1,
  1,
  1,
  0,
  9223372036854775807,
  9223372036854775807,
  9223372036854775807,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  -INT64_C(9223372036854775807) - 1,
  -1,
  -1,
  -2,
  -2,
  -2,
  -2,
  -2,
  -2,
  -2,
  -2,
  -2,
  -2,
  -2,
  -2,
  -1,
  -INT64_C(9223372036854775807) - 1,
  -INT64_C(9223372036854775807) - 1,
  -INT64_C(9223372036854775807) - 1,
  -1,
  -1,
  -1,
  -1,
  -1,
  -1,
  -1,
  -1,
  -1,
  -1,
  -1,
  -1,
  -1,
  -1,
  -1,
  -1,
  -1,
  4503599627370496,
  4503599627370497,
  4503599627370498,
  4503599627370499,
  8987183256397123,
  9007199254740988,
  9007199254740989,
  9007199254740990,
  9007199254740991,
  2251799813685248,
  2251799813685248,
  2251799813685249,
  2251799813685249,
  4493591628198561,
  4503599627370494,
  4503599627370494,
  4503599627370495,
  4503599627370495,
  1125899906842624,
  1125899906842624,
  1125899906842624,
  1125899906842624,
  2246795814099280,
  2251799813685247,
  2251799813685247,
  2251799813685247,
  2251799813685247,
  -4503599627370496,
  -4503599627370497,
  -4503599627370498,
  -4503599627370499,
  -8987183256397123,
  -9007199254740988,
  -9007199254740989,
  -9007199254740990,
  -9007199254740991,
  -2251799813685248,
  -2251799813685249,
  -2251799813685249,
  -2251799813685250,
  -4493591628198562,
  -4503599627370494,
  -4503599627370495,
  -4503599627370495,
  -4503599627370496,
  -1125899906842624,
  -1125899906842625,
  -1125899906842625,
  -1125899906842625,
  -2246795814099281,
  -2251799813685247,
  -2251799813685248,
  -2251799813685248,
  -2251799813685248,
  -INT64_C(9223372036854775807) - 1,
  -INT64_C(9223372036854775807) - 1,
  -9223372036854774784,
  9223372036854774784,
  9223372036854775807,
  9223372036854775807,
  9223372036854775807,
  -2147483650,
  -2147483649,
  -2147483649,
  -2147483649,
  -2147483649,
  -2147483649,
  -2147483649,
  -2147483648,
  -2147483648,
  -2147483648,
  -2147483648,
  -2147483648,
  2147483645,
  2147483646,
  2147483646,
  2147483646,
  2147483646,
  2147483646,
  2147483646,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  4294967293,
  4294967294,
  4294967294,
  4294967294,
  4294967294,
  4294967294,
  4294967294,
  4294967295,
  4294967295,
  4294967295,
  4294967295,
  4294967295,
};
const unsigned kExpectedCount_fcvtms_xd = 207;

const int64_t kExpected_fcvtms_xs[] = {
  0,
  0,
  0,
  0,
  0,
  0,
  1,
  1,
  1,
  10,
  0,
  9223372036854775807,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  -1,
  -1,
  -1,
  -1,
  -1,
  -1,
  -2,
  -2,
  -10,
  0,
  -INT64_C(9223372036854775807) - 1,
  0,
  0,
  0,
  0,
  -1,
  -1,
  -1,
  8388608,
  8388609,
  8388610,
  8388611,
  16143410,
  16777212,
  16777213,
  16777214,
  16777215,
  4194304,
  4194304,
  4194305,
  4194305,
  8071705,
  8388606,
  8388606,
  8388607,
  8388607,
  2097152,
  2097152,
  2097152,
  2097152,
  4035852,
  4194303,
  4194303,
  4194303,
  4194303,
  -8388608,
  -8388609,
  -8388610,
  -8388611,
  -16143410,
  -16777212,
  -16777213,
  -16777214,
  -16777215,
  -4194304,
  -4194305,
  -4194305,
  -4194306,
  -8071705,
  -8388606,
  -8388607,
  -8388607,
  -8388608,
  -2097152,
  -2097153,
  -2097153,
  -2097153,
  -4035853,
  -4194303,
  -4194304,
  -4194304,
  -4194304,
  -INT64_C(9223372036854775807) - 1,
  -INT64_C(9223372036854775807) - 1,
  -9223371487098961920,
  9223371487098961920,
  9223372036854775807,
  9223372036854775807,
  9223372036854775807,
  -2147483904,
  -2147483648,
  -2147483520,
  2147483520,
  2147483648,
};
const unsigned kExpectedCount_fcvtms_xs = 104;

const uint32_t kExpected_fcvtmu_wd[] = {
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  1u,
  1u,
  1u,
  10u,
  4294967295u,
  4294967295u,
  0u,
  0u,
  0u,
  4294967295u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  4294967295u,
  0u,
  1u,
  1u,
  1u,
  1u,
  1u,
  1u,
  1u,
  1u,
  1u,
  1u,
  1u,
  1u,
  1u,
  0u,
  4294967295u,
  4294967295u,
  4294967295u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  4294967295u,
  4294967295u,
  4294967295u,
  4294967295u,
  4294967295u,
  4294967295u,
  4294967295u,
  4294967295u,
  4294967295u,
  4294967295u,
  4294967295u,
  4294967295u,
  4294967295u,
  4294967295u,
  4294967295u,
  4294967295u,
  4294967295u,
  4294967295u,
  4294967295u,
  4294967295u,
  4294967295u,
  4294967295u,
  4294967295u,
  4294967295u,
  4294967295u,
  4294967295u,
  4294967295u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  4294967295u,
  4294967295u,
  4294967295u,
  4294967295u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  2147483645u,
  2147483646u,
  2147483646u,
  2147483646u,
  2147483646u,
  2147483646u,
  2147483646u,
  2147483647u,
  2147483647u,
  2147483647u,
  2147483647u,
  2147483647u,
  4294967293u,
  4294967294u,
  4294967294u,
  4294967294u,
  4294967294u,
  4294967294u,
  4294967294u,
  4294967295u,
  4294967295u,
  4294967295u,
  4294967295u,
  4294967295u,
};
const unsigned kExpectedCount_fcvtmu_wd = 207;

const uint32_t kExpected_fcvtmu_ws[] = {
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  1u,
  1u,
  1u,
  10u,
  0u,
  4294967295u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  8388608u,
  8388609u,
  8388610u,
  8388611u,
  16143410u,
  16777212u,
  16777213u,
  16777214u,
  16777215u,
  4194304u,
  4194304u,
  4194305u,
  4194305u,
  8071705u,
  8388606u,
  8388606u,
  8388607u,
  8388607u,
  2097152u,
  2097152u,
  2097152u,
  2097152u,
  4035852u,
  4194303u,
  4194303u,
  4194303u,
  4194303u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  4294967295u,
  4294967295u,
  4294967295u,
  4294967295u,
  0u,
  0u,
  0u,
  2147483520u,
  2147483648u,
};
const unsigned kExpectedCount_fcvtmu_ws = 104;

const uint64_t kExpected_fcvtmu_xd[] = {
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  1u,
  1u,
  1u,
  10u,
  18446744073709551615u,
  18446744073709551615u,
  0u,
  0u,
  0u,
  18446744073709551615u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  18446744073709551615u,
  0u,
  1u,
  1u,
  1u,
  1u,
  1u,
  1u,
  1u,
  1u,
  1u,
  1u,
  1u,
  1u,
  1u,
  0u,
  18446744073709551615u,
  18446744073709551615u,
  18446744073709551615u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  4503599627370496u,
  4503599627370497u,
  4503599627370498u,
  4503599627370499u,
  8987183256397123u,
  9007199254740988u,
  9007199254740989u,
  9007199254740990u,
  9007199254740991u,
  2251799813685248u,
  2251799813685248u,
  2251799813685249u,
  2251799813685249u,
  4493591628198561u,
  4503599627370494u,
  4503599627370494u,
  4503599627370495u,
  4503599627370495u,
  1125899906842624u,
  1125899906842624u,
  1125899906842624u,
  1125899906842624u,
  2246795814099280u,
  2251799813685247u,
  2251799813685247u,
  2251799813685247u,
  2251799813685247u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  9223372036854774784u,
  9223372036854775808u,
  18446744073709549568u,
  18446744073709551615u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  2147483645u,
  2147483646u,
  2147483646u,
  2147483646u,
  2147483646u,
  2147483646u,
  2147483646u,
  2147483647u,
  2147483647u,
  2147483647u,
  2147483647u,
  2147483647u,
  4294967293u,
  4294967294u,
  4294967294u,
  4294967294u,
  4294967294u,
  4294967294u,
  4294967294u,
  4294967295u,
  4294967295u,
  4294967295u,
  4294967295u,
  4294967295u,
};
const unsigned kExpectedCount_fcvtmu_xd = 207;

const uint64_t kExpected_fcvtmu_xs[] = {
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  1u,
  1u,
  1u,
  10u,
  0u,
  18446744073709551615u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  8388608u,
  8388609u,
  8388610u,
  8388611u,
  16143410u,
  16777212u,
  16777213u,
  16777214u,
  16777215u,
  4194304u,
  4194304u,
  4194305u,
  4194305u,
  8071705u,
  8388606u,
  8388606u,
  8388607u,
  8388607u,
  2097152u,
  2097152u,
  2097152u,
  2097152u,
  4035852u,
  4194303u,
  4194303u,
  4194303u,
  4194303u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  9223371487098961920u,
  9223372036854775808u,
  18446742974197923840u,
  18446744073709551615u,
  0u,
  0u,
  0u,
  2147483520u,
  2147483648u,
};
const unsigned kExpectedCount_fcvtmu_xs = 104;

const int32_t kExpected_fcvtns_wd[] = {
  0,
  0,
  0,
  0,
  1,
  1,
  1,
  1,
  2,
  10,
  2147483647,
  2147483647,
  0,
  0,
  0,
  2147483647,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  -1,
  -1,
  -1,
  -1,
  -2,
  -10,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  0,
  0,
  0,
  -INT32_C(2147483647) - 1,
  0,
  0,
  0,
  2147483647,
  0,
  1,
  1,
  1,
  1,
  1,
  1,
  1,
  1,
  1,
  1,
  1,
  1,
  1,
  1,
  2147483647,
  2147483647,
  2147483647,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  -INT32_C(2147483647) - 1,
  0,
  -1,
  -1,
  -1,
  -1,
  -1,
  -1,
  -1,
  -1,
  -1,
  -1,
  -1,
  -1,
  -1,
  -1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -2147483647,
  2147483646,
  2147483646,
  2147483646,
  2147483646,
  2147483646,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
};
const unsigned kExpectedCount_fcvtns_wd = 207;

const int32_t kExpected_fcvtns_ws[] = {
  0,
  0,
  0,
  0,
  1,
  1,
  1,
  1,
  2,
  10,
  0,
  2147483647,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  -1,
  -1,
  -1,
  -1,
  -2,
  -10,
  0,
  -INT32_C(2147483647) - 1,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  8388608,
  8388609,
  8388610,
  8388611,
  16143410,
  16777212,
  16777213,
  16777214,
  16777215,
  4194304,
  4194304,
  4194305,
  4194306,
  8071705,
  8388606,
  8388606,
  8388607,
  8388608,
  2097152,
  2097152,
  2097152,
  2097153,
  4035852,
  4194303,
  4194303,
  4194304,
  4194304,
  -8388608,
  -8388609,
  -8388610,
  -8388611,
  -16143410,
  -16777212,
  -16777213,
  -16777214,
  -16777215,
  -4194304,
  -4194304,
  -4194305,
  -4194306,
  -8071705,
  -8388606,
  -8388606,
  -8388607,
  -8388608,
  -2097152,
  -2097152,
  -2097152,
  -2097153,
  -4035852,
  -4194303,
  -4194303,
  -4194304,
  -4194304,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -2147483520,
  2147483520,
  2147483647,
};
const unsigned kExpectedCount_fcvtns_ws = 104;

const int64_t kExpected_fcvtns_xd[] = {
  0,
  0,
  0,
  0,
  1,
  1,
  1,
  1,
  2,
  10,
  9223372036854775807,
  9223372036854775807,
  0,
  0,
  0,
  9223372036854775807,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  -1,
  -1,
  -1,
  -1,
  -2,
  -10,
  -INT64_C(9223372036854775807) - 1,
  -INT64_C(9223372036854775807) - 1,
  0,
  0,
  0,
  -INT64_C(9223372036854775807) - 1,
  0,
  0,
  0,
  9223372036854775807,
  0,
  1,
  1,
  1,
  1,
  1,
  1,
  1,
  1,
  1,
  1,
  1,
  1,
  1,
  1,
  9223372036854775807,
  9223372036854775807,
  9223372036854775807,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  -INT64_C(9223372036854775807) - 1,
  0,
  -1,
  -1,
  -1,
  -1,
  -1,
  -1,
  -1,
  -1,
  -1,
  -1,
  -1,
  -1,
  -1,
  -1,
  -INT64_C(9223372036854775807) - 1,
  -INT64_C(9223372036854775807) - 1,
  -INT64_C(9223372036854775807) - 1,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  4503599627370496,
  4503599627370497,
  4503599627370498,
  4503599627370499,
  8987183256397123,
  9007199254740988,
  9007199254740989,
  9007199254740990,
  9007199254740991,
  2251799813685248,
  2251799813685248,
  2251799813685249,
  2251799813685250,
  4493591628198562,
  4503599627370494,
  4503599627370494,
  4503599627370495,
  4503599627370496,
  1125899906842624,
  1125899906842624,
  1125899906842624,
  1125899906842625,
  2246795814099281,
  2251799813685247,
  2251799813685247,
  2251799813685248,
  2251799813685248,
  -4503599627370496,
  -4503599627370497,
  -4503599627370498,
  -4503599627370499,
  -8987183256397123,
  -9007199254740988,
  -9007199254740989,
  -9007199254740990,
  -9007199254740991,
  -2251799813685248,
  -2251799813685248,
  -2251799813685249,
  -2251799813685250,
  -4493591628198562,
  -4503599627370494,
  -4503599627370494,
  -4503599627370495,
  -4503599627370496,
  -1125899906842624,
  -1125899906842624,
  -1125899906842624,
  -1125899906842625,
  -2246795814099281,
  -2251799813685247,
  -2251799813685247,
  -2251799813685248,
  -2251799813685248,
  -INT64_C(9223372036854775807) - 1,
  -INT64_C(9223372036854775807) - 1,
  -9223372036854774784,
  9223372036854774784,
  9223372036854775807,
  9223372036854775807,
  9223372036854775807,
  -2147483649,
  -2147483649,
  -2147483649,
  -2147483649,
  -2147483648,
  -2147483648,
  -2147483648,
  -2147483648,
  -2147483648,
  -2147483648,
  -2147483648,
  -2147483647,
  2147483646,
  2147483646,
  2147483646,
  2147483646,
  2147483646,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483648,
  2147483648,
  4294967294,
  4294967294,
  4294967294,
  4294967294,
  4294967294,
  4294967295,
  4294967295,
  4294967295,
  4294967295,
  4294967295,
  4294967296,
  4294967296,
};
const unsigned kExpectedCount_fcvtns_xd = 207;

const int64_t kExpected_fcvtns_xs[] = {
  0,
  0,
  0,
  0,
  1,
  1,
  1,
  1,
  2,
  10,
  0,
  9223372036854775807,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  -1,
  -1,
  -1,
  -1,
  -2,
  -10,
  0,
  -INT64_C(9223372036854775807) - 1,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  8388608,
  8388609,
  8388610,
  8388611,
  16143410,
  16777212,
  16777213,
  16777214,
  16777215,
  4194304,
  4194304,
  4194305,
  4194306,
  8071705,
  8388606,
  8388606,
  8388607,
  8388608,
  2097152,
  2097152,
  2097152,
  2097153,
  4035852,
  4194303,
  4194303,
  4194304,
  4194304,
  -8388608,
  -8388609,
  -8388610,
  -8388611,
  -16143410,
  -16777212,
  -16777213,
  -16777214,
  -16777215,
  -4194304,
  -4194304,
  -4194305,
  -4194306,
  -8071705,
  -8388606,
  -8388606,
  -8388607,
  -8388608,
  -2097152,
  -2097152,
  -2097152,
  -2097153,
  -4035852,
  -4194303,
  -4194303,
  -4194304,
  -4194304,
  -INT64_C(9223372036854775807) - 1,
  -INT64_C(9223372036854775807) - 1,
  -9223371487098961920,
  9223371487098961920,
  9223372036854775807,
  9223372036854775807,
  9223372036854775807,
  -2147483904,
  -2147483648,
  -2147483520,
  2147483520,
  2147483648,
};
const unsigned kExpectedCount_fcvtns_xs = 104;

const uint32_t kExpected_fcvtnu_wd[] = {
  0u,
  0u,
  0u,
  0u,
  1u,
  1u,
  1u,
  1u,
  2u,
  10u,
  4294967295u,
  4294967295u,
  0u,
  0u,
  0u,
  4294967295u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  4294967295u,
  0u,
  1u,
  1u,
  1u,
  1u,
  1u,
  1u,
  1u,
  1u,
  1u,
  1u,
  1u,
  1u,
  1u,
  1u,
  4294967295u,
  4294967295u,
  4294967295u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  4294967295u,
  4294967295u,
  4294967295u,
  4294967295u,
  4294967295u,
  4294967295u,
  4294967295u,
  4294967295u,
  4294967295u,
  4294967295u,
  4294967295u,
  4294967295u,
  4294967295u,
  4294967295u,
  4294967295u,
  4294967295u,
  4294967295u,
  4294967295u,
  4294967295u,
  4294967295u,
  4294967295u,
  4294967295u,
  4294967295u,
  4294967295u,
  4294967295u,
  4294967295u,
  4294967295u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  4294967295u,
  4294967295u,
  4294967295u,
  4294967295u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  2147483646u,
  2147483646u,
  2147483646u,
  2147483646u,
  2147483646u,
  2147483647u,
  2147483647u,
  2147483647u,
  2147483647u,
  2147483647u,
  2147483648u,
  2147483648u,
  4294967294u,
  4294967294u,
  4294967294u,
  4294967294u,
  4294967294u,
  4294967295u,
  4294967295u,
  4294967295u,
  4294967295u,
  4294967295u,
  4294967295u,
  4294967295u,
};
const unsigned kExpectedCount_fcvtnu_wd = 207;

const uint32_t kExpected_fcvtnu_ws[] = {
  0u,
  0u,
  0u,
  0u,
  1u,
  1u,
  1u,
  1u,
  2u,
  10u,
  0u,
  4294967295u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  8388608u,
  8388609u,
  8388610u,
  8388611u,
  16143410u,
  16777212u,
  16777213u,
  16777214u,
  16777215u,
  4194304u,
  4194304u,
  4194305u,
  4194306u,
  8071705u,
  8388606u,
  8388606u,
  8388607u,
  8388608u,
  2097152u,
  2097152u,
  2097152u,
  2097153u,
  4035852u,
  4194303u,
  4194303u,
  4194304u,
  4194304u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  4294967295u,
  4294967295u,
  4294967295u,
  4294967295u,
  0u,
  0u,
  0u,
  2147483520u,
  2147483648u,
};
const unsigned kExpectedCount_fcvtnu_ws = 104;

const uint64_t kExpected_fcvtnu_xd[] = {
  0u,
  0u,
  0u,
  0u,
  1u,
  1u,
  1u,
  1u,
  2u,
  10u,
  18446744073709551615u,
  18446744073709551615u,
  0u,
  0u,
  0u,
  18446744073709551615u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  18446744073709551615u,
  0u,
  1u,
  1u,
  1u,
  1u,
  1u,
  1u,
  1u,
  1u,
  1u,
  1u,
  1u,
  1u,
  1u,
  1u,
  18446744073709551615u,
  18446744073709551615u,
  18446744073709551615u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  4503599627370496u,
  4503599627370497u,
  4503599627370498u,
  4503599627370499u,
  8987183256397123u,
  9007199254740988u,
  9007199254740989u,
  9007199254740990u,
  9007199254740991u,
  2251799813685248u,
  2251799813685248u,
  2251799813685249u,
  2251799813685250u,
  4493591628198562u,
  4503599627370494u,
  4503599627370494u,
  4503599627370495u,
  4503599627370496u,
  1125899906842624u,
  1125899906842624u,
  1125899906842624u,
  1125899906842625u,
  2246795814099281u,
  2251799813685247u,
  2251799813685247u,
  2251799813685248u,
  2251799813685248u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  9223372036854774784u,
  9223372036854775808u,
  18446744073709549568u,
  18446744073709551615u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  2147483646u,
  2147483646u,
  2147483646u,
  2147483646u,
  2147483646u,
  2147483647u,
  2147483647u,
  2147483647u,
  2147483647u,
  2147483647u,
  2147483648u,
  2147483648u,
  4294967294u,
  4294967294u,
  4294967294u,
  4294967294u,
  4294967294u,
  4294967295u,
  4294967295u,
  4294967295u,
  4294967295u,
  4294967295u,
  4294967296u,
  4294967296u,
};
const unsigned kExpectedCount_fcvtnu_xd = 207;

const uint64_t kExpected_fcvtnu_xs[] = {
  0u,
  0u,
  0u,
  0u,
  1u,
  1u,
  1u,
  1u,
  2u,
  10u,
  0u,
  18446744073709551615u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  8388608u,
  8388609u,
  8388610u,
  8388611u,
  16143410u,
  16777212u,
  16777213u,
  16777214u,
  16777215u,
  4194304u,
  4194304u,
  4194305u,
  4194306u,
  8071705u,
  8388606u,
  8388606u,
  8388607u,
  8388608u,
  2097152u,
  2097152u,
  2097152u,
  2097153u,
  4035852u,
  4194303u,
  4194303u,
  4194304u,
  4194304u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  9223371487098961920u,
  9223372036854775808u,
  18446742974197923840u,
  18446744073709551615u,
  0u,
  0u,
  0u,
  2147483520u,
  2147483648u,
};
const unsigned kExpectedCount_fcvtnu_xs = 104;

const int32_t kExpected_fcvtzs_wd[] = {
  0,
  0,
  0,
  0,
  0,
  0,
  1,
  1,
  1,
  10,
  2147483647,
  2147483647,
  0,
  0,
  0,
  2147483647,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  -1,
  -1,
  -1,
  -10,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  0,
  0,
  0,
  -INT32_C(2147483647) - 1,
  0,
  0,
  0,
  2147483647,
  0,
  1,
  1,
  1,
  1,
  1,
  1,
  1,
  1,
  1,
  1,
  1,
  1,
  1,
  0,
  2147483647,
  2147483647,
  2147483647,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  -INT32_C(2147483647) - 1,
  0,
  -1,
  -1,
  -1,
  -1,
  -1,
  -1,
  -1,
  -1,
  -1,
  -1,
  -1,
  -1,
  -1,
  0,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -2147483647,
  -2147483647,
  -2147483647,
  -2147483647,
  2147483645,
  2147483646,
  2147483646,
  2147483646,
  2147483646,
  2147483646,
  2147483646,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
};
const unsigned kExpectedCount_fcvtzs_wd = 207;

const int32_t kExpected_fcvtzs_ws[] = {
  0,
  0,
  0,
  0,
  0,
  0,
  1,
  1,
  1,
  10,
  0,
  2147483647,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  -1,
  -1,
  -1,
  -10,
  0,
  -INT32_C(2147483647) - 1,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  8388608,
  8388609,
  8388610,
  8388611,
  16143410,
  16777212,
  16777213,
  16777214,
  16777215,
  4194304,
  4194304,
  4194305,
  4194305,
  8071705,
  8388606,
  8388606,
  8388607,
  8388607,
  2097152,
  2097152,
  2097152,
  2097152,
  4035852,
  4194303,
  4194303,
  4194303,
  4194303,
  -8388608,
  -8388609,
  -8388610,
  -8388611,
  -16143410,
  -16777212,
  -16777213,
  -16777214,
  -16777215,
  -4194304,
  -4194304,
  -4194305,
  -4194305,
  -8071705,
  -8388606,
  -8388606,
  -8388607,
  -8388607,
  -2097152,
  -2097152,
  -2097152,
  -2097152,
  -4035852,
  -4194303,
  -4194303,
  -4194303,
  -4194303,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  -INT32_C(2147483647) - 1,
  -INT32_C(2147483647) - 1,
  -2147483520,
  2147483520,
  2147483647,
};
const unsigned kExpectedCount_fcvtzs_ws = 104;

const int64_t kExpected_fcvtzs_xd[] = {
  0,
  0,
  0,
  0,
  0,
  0,
  1,
  1,
  1,
  10,
  9223372036854775807,
  9223372036854775807,
  0,
  0,
  0,
  9223372036854775807,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  -1,
  -1,
  -1,
  -10,
  -INT64_C(9223372036854775807) - 1,
  -INT64_C(9223372036854775807) - 1,
  0,
  0,
  0,
  -INT64_C(9223372036854775807) - 1,
  0,
  0,
  0,
  9223372036854775807,
  0,
  1,
  1,
  1,
  1,
  1,
  1,
  1,
  1,
  1,
  1,
  1,
  1,
  1,
  0,
  9223372036854775807,
  9223372036854775807,
  9223372036854775807,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  -INT64_C(9223372036854775807) - 1,
  0,
  -1,
  -1,
  -1,
  -1,
  -1,
  -1,
  -1,
  -1,
  -1,
  -1,
  -1,
  -1,
  -1,
  0,
  -INT64_C(9223372036854775807) - 1,
  -INT64_C(9223372036854775807) - 1,
  -INT64_C(9223372036854775807) - 1,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  4503599627370496,
  4503599627370497,
  4503599627370498,
  4503599627370499,
  8987183256397123,
  9007199254740988,
  9007199254740989,
  9007199254740990,
  9007199254740991,
  2251799813685248,
  2251799813685248,
  2251799813685249,
  2251799813685249,
  4493591628198561,
  4503599627370494,
  4503599627370494,
  4503599627370495,
  4503599627370495,
  1125899906842624,
  1125899906842624,
  1125899906842624,
  1125899906842624,
  2246795814099280,
  2251799813685247,
  2251799813685247,
  2251799813685247,
  2251799813685247,
  -4503599627370496,
  -4503599627370497,
  -4503599627370498,
  -4503599627370499,
  -8987183256397123,
  -9007199254740988,
  -9007199254740989,
  -9007199254740990,
  -9007199254740991,
  -2251799813685248,
  -2251799813685248,
  -2251799813685249,
  -2251799813685249,
  -4493591628198561,
  -4503599627370494,
  -4503599627370494,
  -4503599627370495,
  -4503599627370495,
  -1125899906842624,
  -1125899906842624,
  -1125899906842624,
  -1125899906842624,
  -2246795814099280,
  -2251799813685247,
  -2251799813685247,
  -2251799813685247,
  -2251799813685247,
  -INT64_C(9223372036854775807) - 1,
  -INT64_C(9223372036854775807) - 1,
  -9223372036854774784,
  9223372036854774784,
  9223372036854775807,
  9223372036854775807,
  9223372036854775807,
  -2147483649,
  -2147483649,
  -2147483648,
  -2147483648,
  -2147483648,
  -2147483648,
  -2147483648,
  -2147483648,
  -2147483647,
  -2147483647,
  -2147483647,
  -2147483647,
  2147483645,
  2147483646,
  2147483646,
  2147483646,
  2147483646,
  2147483646,
  2147483646,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  2147483647,
  4294967293,
  4294967294,
  4294967294,
  4294967294,
  4294967294,
  4294967294,
  4294967294,
  4294967295,
  4294967295,
  4294967295,
  4294967295,
  4294967295,
};
const unsigned kExpectedCount_fcvtzs_xd = 207;

const int64_t kExpected_fcvtzs_xs[] = {
  0,
  0,
  0,
  0,
  0,
  0,
  1,
  1,
  1,
  10,
  0,
  9223372036854775807,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  -1,
  -1,
  -1,
  -10,
  0,
  -INT64_C(9223372036854775807) - 1,
  0,
  0,
  0,
  0,
  0,
  0,
  0,
  8388608,
  8388609,
  8388610,
  8388611,
  16143410,
  16777212,
  16777213,
  16777214,
  16777215,
  4194304,
  4194304,
  4194305,
  4194305,
  8071705,
  8388606,
  8388606,
  8388607,
  8388607,
  2097152,
  2097152,
  2097152,
  2097152,
  4035852,
  4194303,
  4194303,
  4194303,
  4194303,
  -8388608,
  -8388609,
  -8388610,
  -8388611,
  -16143410,
  -16777212,
  -16777213,
  -16777214,
  -16777215,
  -4194304,
  -4194304,
  -4194305,
  -4194305,
  -8071705,
  -8388606,
  -8388606,
  -8388607,
  -8388607,
  -2097152,
  -2097152,
  -2097152,
  -2097152,
  -4035852,
  -4194303,
  -4194303,
  -4194303,
  -4194303,
  -INT64_C(9223372036854775807) - 1,
  -INT64_C(9223372036854775807) - 1,
  -9223371487098961920,
  9223371487098961920,
  9223372036854775807,
  9223372036854775807,
  9223372036854775807,
  -2147483904,
  -2147483648,
  -2147483520,
  2147483520,
  2147483648,
};
const unsigned kExpectedCount_fcvtzs_xs = 104;

const uint32_t kExpected_fcvtzu_wd[] = {
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  1u,
  1u,
  1u,
  10u,
  4294967295u,
  4294967295u,
  0u,
  0u,
  0u,
  4294967295u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  4294967295u,
  0u,
  1u,
  1u,
  1u,
  1u,
  1u,
  1u,
  1u,
  1u,
  1u,
  1u,
  1u,
  1u,
  1u,
  0u,
  4294967295u,
  4294967295u,
  4294967295u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  4294967295u,
  4294967295u,
  4294967295u,
  4294967295u,
  4294967295u,
  4294967295u,
  4294967295u,
  4294967295u,
  4294967295u,
  4294967295u,
  4294967295u,
  4294967295u,
  4294967295u,
  4294967295u,
  4294967295u,
  4294967295u,
  4294967295u,
  4294967295u,
  4294967295u,
  4294967295u,
  4294967295u,
  4294967295u,
  4294967295u,
  4294967295u,
  4294967295u,
  4294967295u,
  4294967295u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  4294967295u,
  4294967295u,
  4294967295u,
  4294967295u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  2147483645u,
  2147483646u,
  2147483646u,
  2147483646u,
  2147483646u,
  2147483646u,
  2147483646u,
  2147483647u,
  2147483647u,
  2147483647u,
  2147483647u,
  2147483647u,
  4294967293u,
  4294967294u,
  4294967294u,
  4294967294u,
  4294967294u,
  4294967294u,
  4294967294u,
  4294967295u,
  4294967295u,
  4294967295u,
  4294967295u,
  4294967295u,
};
const unsigned kExpectedCount_fcvtzu_wd = 207;

const uint32_t kExpected_fcvtzu_ws[] = {
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  1u,
  1u,
  1u,
  10u,
  0u,
  4294967295u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  8388608u,
  8388609u,
  8388610u,
  8388611u,
  16143410u,
  16777212u,
  16777213u,
  16777214u,
  16777215u,
  4194304u,
  4194304u,
  4194305u,
  4194305u,
  8071705u,
  8388606u,
  8388606u,
  8388607u,
  8388607u,
  2097152u,
  2097152u,
  2097152u,
  2097152u,
  4035852u,
  4194303u,
  4194303u,
  4194303u,
  4194303u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  4294967295u,
  4294967295u,
  4294967295u,
  4294967295u,
  0u,
  0u,
  0u,
  2147483520u,
  2147483648u,
};
const unsigned kExpectedCount_fcvtzu_ws = 104;

const uint64_t kExpected_fcvtzu_xd[] = {
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  1u,
  1u,
  1u,
  10u,
  18446744073709551615u,
  18446744073709551615u,
  0u,
  0u,
  0u,
  18446744073709551615u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  18446744073709551615u,
  0u,
  1u,
  1u,
  1u,
  1u,
  1u,
  1u,
  1u,
  1u,
  1u,
  1u,
  1u,
  1u,
  1u,
  0u,
  18446744073709551615u,
  18446744073709551615u,
  18446744073709551615u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  4503599627370496u,
  4503599627370497u,
  4503599627370498u,
  4503599627370499u,
  8987183256397123u,
  9007199254740988u,
  9007199254740989u,
  9007199254740990u,
  9007199254740991u,
  2251799813685248u,
  2251799813685248u,
  2251799813685249u,
  2251799813685249u,
  4493591628198561u,
  4503599627370494u,
  4503599627370494u,
  4503599627370495u,
  4503599627370495u,
  1125899906842624u,
  1125899906842624u,
  1125899906842624u,
  1125899906842624u,
  2246795814099280u,
  2251799813685247u,
  2251799813685247u,
  2251799813685247u,
  2251799813685247u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  9223372036854774784u,
  9223372036854775808u,
  18446744073709549568u,
  18446744073709551615u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  2147483645u,
  2147483646u,
  2147483646u,
  2147483646u,
  2147483646u,
  2147483646u,
  2147483646u,
  2147483647u,
  2147483647u,
  2147483647u,
  2147483647u,
  2147483647u,
  4294967293u,
  4294967294u,
  4294967294u,
  4294967294u,
  4294967294u,
  4294967294u,
  4294967294u,
  4294967295u,
  4294967295u,
  4294967295u,
  4294967295u,
  4294967295u,
};
const unsigned kExpectedCount_fcvtzu_xd = 207;

const uint64_t kExpected_fcvtzu_xs[] = {
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  1u,
  1u,
  1u,
  10u,
  0u,
  18446744073709551615u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  8388608u,
  8388609u,
  8388610u,
  8388611u,
  16143410u,
  16777212u,
  16777213u,
  16777214u,
  16777215u,
  4194304u,
  4194304u,
  4194305u,
  4194305u,
  8071705u,
  8388606u,
  8388606u,
  8388607u,
  8388607u,
  2097152u,
  2097152u,
  2097152u,
  2097152u,
  4035852u,
  4194303u,
  4194303u,
  4194303u,
  4194303u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  0u,
  9223371487098961920u,
  9223372036854775808u,
  18446742974197923840u,
  18446744073709551615u,
  0u,
  0u,
  0u,
  2147483520u,
  2147483648u,
};
const unsigned kExpectedCount_fcvtzu_xs = 104;

const uint64_t kExpected_fdiv_d[] = {
  0x7ff8000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x7ff8000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x7ff0000000000000,
  0x3ff0000000000000,
  0x0020000000000001,
  0x0020000000000000,
  0x001ffffffffffffe,
  0x0010000000000001,
  0x0010000000000000,
  0x000fffffffffffff,
  0x000aaaaaaaaaaaab,
  0x000199999999999a,
  0x0000000000000000,
  0x0000000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x0000000000000000,
  0x402c200000000017,
  0x3ff0000000000001,
  0x4330000000000000,
  0xfff0000000000000,
  0xbff0000000000000,
  0x8020000000000001,
  0x8020000000000000,
  0x801ffffffffffffe,
  0x8010000000000001,
  0x8010000000000000,
  0x800fffffffffffff,
  0x800aaaaaaaaaaaab,
  0x800199999999999a,
  0x8000000000000000,
  0x8000000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x8000000000000000,
  0xc02c200000000017,
  0xbff0000000000001,
  0xc330000000000000,
  0x7ff0000000000000,
  0x7fbfffffffffffff,
  0x3ff0000000000000,
  0x3fefffffffffffff,
  0x3feffffffffffffd,
  0x3fe0000000000000,
  0x3fdfffffffffffff,
  0x3fdffffffffffffd,
  0x3fd5555555555555,
  0x3fa9999999999999,
  0x0002000000000000,
  0x0000000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x0000000000000000,
  0x7ff0000000000000,
  0x7fc0000000000001,
  0x7ff0000000000000,
  0xfff0000000000000,
  0xffbfffffffffffff,
  0xbff0000000000000,
  0xbfefffffffffffff,
  0xbfeffffffffffffd,
  0xbfe0000000000000,
  0xbfdfffffffffffff,
  0xbfdffffffffffffd,
  0xbfd5555555555555,
  0xbfa9999999999999,
  0x8002000000000000,
  0x8000000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x8000000000000000,
  0xfff0000000000000,
  0xffc0000000000001,
  0xfff0000000000000,
  0x7ff0000000000000,
  0x7fc0000000000000,
  0x3ff0000000000001,
  0x3ff0000000000000,
  0x3feffffffffffffe,
  0x3fe0000000000001,
  0x3fe0000000000000,
  0x3fdffffffffffffe,
  0x3fd5555555555555,
  0x3fa999999999999a,
  0x0002000000000000,
  0x0000000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x0000000000000000,
  0x7ff0000000000000,
  0x7fc0000000000001,
  0x7ff0000000000000,
  0xfff0000000000000,
  0xffc0000000000000,
  0xbff0000000000001,
  0xbff0000000000000,
  0xbfeffffffffffffe,
  0xbfe0000000000001,
  0xbfe0000000000000,
  0xbfdffffffffffffe,
  0xbfd5555555555555,
  0xbfa999999999999a,
  0x8002000000000000,
  0x8000000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x8000000000000000,
  0xfff0000000000000,
  0xffc0000000000001,
  0xfff0000000000000,
  0x7ff0000000000000,
  0x7fc0000000000001,
  0x3ff0000000000002,
  0x3ff0000000000001,
  0x3ff0000000000000,
  0x3fe0000000000002,
  0x3fe0000000000001,
  0x3fe0000000000000,
  0x3fd5555555555557,
  0x3fa999999999999b,
  0x0002000000000000,
  0x0000000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x0000000000000000,
  0x7ff0000000000000,
  0x7fc0000000000002,
  0x7ff0000000000000,
  0xfff0000000000000,
  0xffc0000000000001,
  0xbff0000000000002,
  0xbff0000000000001,
  0xbff0000000000000,
  0xbfe0000000000002,
  0xbfe0000000000001,
  0xbfe0000000000000,
  0xbfd5555555555557,
  0xbfa999999999999b,
  0x8002000000000000,
  0x8000000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x8000000000000000,
  0xfff0000000000000,
  0xffc0000000000002,
  0xfff0000000000000,
  0x7ff0000000000000,
  0x7fcfffffffffffff,
  0x4000000000000000,
  0x3fffffffffffffff,
  0x3ffffffffffffffd,
  0x3ff0000000000000,
  0x3fefffffffffffff,
  0x3feffffffffffffd,
  0x3fe5555555555555,
  0x3fb9999999999999,
  0x0004000000000000,
  0x0000000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x0000000000000000,
  0x7ff0000000000000,
  0x7fd0000000000001,
  0x7ff0000000000000,
  0xfff0000000000000,
  0xffcfffffffffffff,
  0xc000000000000000,
  0xbfffffffffffffff,
  0xbffffffffffffffd,
  0xbff0000000000000,
  0xbfefffffffffffff,
  0xbfeffffffffffffd,
  0xbfe5555555555555,
  0xbfb9999999999999,
  0x8004000000000000,
  0x8000000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x8000000000000000,
  0xfff0000000000000,
  0xffd0000000000001,
  0xfff0000000000000,
  0x7ff0000000000000,
  0x7fd0000000000000,
  0x4000000000000001,
  0x4000000000000000,
  0x3ffffffffffffffe,
  0x3ff0000000000001,
  0x3ff0000000000000,
  0x3feffffffffffffe,
  0x3fe5555555555555,
  0x3fb999999999999a,
  0x0004000000000000,
  0x0000000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x0000000000000000,
  0x7ff0000000000000,
  0x7fd0000000000001,
  0x7ff0000000000000,
  0xfff0000000000000,
  0xffd0000000000000,
  0xc000000000000001,
  0xc000000000000000,
  0xbffffffffffffffe,
  0xbff0000000000001,
  0xbff0000000000000,
  0xbfeffffffffffffe,
  0xbfe5555555555555,
  0xbfb999999999999a,
  0x8004000000000000,
  0x8000000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x8000000000000000,
  0xfff0000000000000,
  0xffd0000000000001,
  0xfff0000000000000,
  0x7ff0000000000000,
  0x7fd0000000000001,
  0x4000000000000002,
  0x4000000000000001,
  0x4000000000000000,
  0x3ff0000000000002,
  0x3ff0000000000001,
  0x3ff0000000000000,
  0x3fe5555555555557,
  0x3fb999999999999b,
  0x0004000000000000,
  0x0000000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x0000000000000000,
  0x7ff0000000000000,
  0x7fd0000000000002,
  0x7ff0000000000000,
  0xfff0000000000000,
  0xffd0000000000001,
  0xc000000000000002,
  0xc000000000000001,
  0xc000000000000000,
  0xbff0000000000002,
  0xbff0000000000001,
  0xbff0000000000000,
  0xbfe5555555555557,
  0xbfb999999999999b,
  0x8004000000000000,
  0x8000000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x8000000000000000,
  0xfff0000000000000,
  0xffd0000000000002,
  0xfff0000000000000,
  0x7ff0000000000000,
  0x7fd8000000000000,
  0x4008000000000001,
  0x4008000000000000,
  0x4007ffffffffffff,
  0x3ff8000000000001,
  0x3ff8000000000000,
  0x3ff7ffffffffffff,
  0x3ff0000000000000,
  0x3fc3333333333333,
  0x0006000000000000,
  0x0000000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x0000000000000000,
  0x7ff0000000000000,
  0x7fd8000000000002,
  0x7ff0000000000000,
  0xfff0000000000000,
  0xffd8000000000000,
  0xc008000000000001,
  0xc008000000000000,
  0xc007ffffffffffff,
  0xbff8000000000001,
  0xbff8000000000000,
  0xbff7ffffffffffff,
  0xbff0000000000000,
  0xbfc3333333333333,
  0x8006000000000000,
  0x8000000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x8000000000000000,
  0xfff0000000000000,
  0xffd8000000000002,
  0xfff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x4034000000000001,
  0x4034000000000000,
  0x4033ffffffffffff,
  0x4024000000000001,
  0x4024000000000000,
  0x4023ffffffffffff,
  0x401aaaaaaaaaaaab,
  0x3ff0000000000000,
  0x0024000000000001,
  0x0000000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x0000000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xc034000000000001,
  0xc034000000000000,
  0xc033ffffffffffff,
  0xc024000000000001,
  0xc024000000000000,
  0xc023ffffffffffff,
  0xc01aaaaaaaaaaaab,
  0xbff0000000000000,
  0x8024000000000001,
  0x8000000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x8000000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7fefffffffffffff,
  0x7feffffffffffffd,
  0x7fe5555555555555,
  0x7fb9999999999999,
  0x3ff0000000000000,
  0x0000000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x0000000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xffefffffffffffff,
  0xffeffffffffffffd,
  0xffe5555555555555,
  0xffb9999999999999,
  0xbff0000000000000,
  0x8000000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x8000000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff0000000000000,
  0x3fb23456789abcd0,
  0x0002468acf13579a,
  0x0002468acf13579a,
  0x0002468acf13579a,
  0x000123456789abcd,
  0x000123456789abcd,
  0x000123456789abcd,
  0x0000c22e45067289,
  0x00001d208a5a912e,
  0x0000000000000000,
  0x0000000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x0000000000000000,
  0x3ff0000000000000,
  0x3fb23456789abcd1,
  0x42f23456789abcd0,
  0xfff0000000000000,
  0xbfb23456789abcd0,
  0x8002468acf13579a,
  0x8002468acf13579a,
  0x8002468acf13579a,
  0x800123456789abcd,
  0x800123456789abcd,
  0x800123456789abcd,
  0x8000c22e45067289,
  0x80001d208a5a912e,
  0x8000000000000000,
  0x8000000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x8000000000000000,
  0xbff0000000000000,
  0xbfb23456789abcd1,
  0xc2f23456789abcd0,
  0x7ff0000000000000,
  0x3feffffffffffffe,
  0x001fffffffffffff,
  0x001ffffffffffffe,
  0x001ffffffffffffc,
  0x000fffffffffffff,
  0x000fffffffffffff,
  0x000ffffffffffffe,
  0x000aaaaaaaaaaaaa,
  0x000199999999999a,
  0x0000000000000000,
  0x0000000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x0000000000000000,
  0x402c200000000015,
  0x3ff0000000000000,
  0x432ffffffffffffe,
  0xfff0000000000000,
  0xbfeffffffffffffe,
  0x801fffffffffffff,
  0x801ffffffffffffe,
  0x801ffffffffffffc,
  0x800fffffffffffff,
  0x800fffffffffffff,
  0x800ffffffffffffe,
  0x800aaaaaaaaaaaaa,
  0x800199999999999a,
  0x8000000000000000,
  0x8000000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x8000000000000000,
  0xc02c200000000015,
  0xbff0000000000000,
  0xc32ffffffffffffe,
  0x7ff0000000000000,
  0x3cb0000000000000,
  0x0000000000000002,
  0x0000000000000002,
  0x0000000000000002,
  0x0000000000000001,
  0x0000000000000001,
  0x0000000000000001,
  0x0000000000000001,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x0000000000000000,
  0x3cec200000000017,
  0x3cb0000000000001,
  0x3ff0000000000000,
  0xfff0000000000000,
  0xbcb0000000000000,
  0x8000000000000002,
  0x8000000000000002,
  0x8000000000000002,
  0x8000000000000001,
  0x8000000000000001,
  0x8000000000000001,
  0x8000000000000001,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x8000000000000000,
  0xbcec200000000017,
  0xbcb0000000000001,
  0xbff0000000000000,
  0x7ff8000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x7ff8000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0xfff0000000000000,
  0xbff0000000000000,
  0x8020000000000001,
  0x8020000000000000,
  0x801ffffffffffffe,
  0x8010000000000001,
  0x8010000000000000,
  0x800fffffffffffff,
  0x800aaaaaaaaaaaab,
  0x800199999999999a,
  0x8000000000000000,
  0x8000000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x8000000000000000,
  0xc02c200000000017,
  0xbff0000000000001,
  0xc330000000000000,
  0x7ff0000000000000,
  0x3ff0000000000000,
  0x0020000000000001,
  0x0020000000000000,
  0x001ffffffffffffe,
  0x0010000000000001,
  0x0010000000000000,
  0x000fffffffffffff,
  0x000aaaaaaaaaaaab,
  0x000199999999999a,
  0x0000000000000000,
  0x0000000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x0000000000000000,
  0x402c200000000017,
  0x3ff0000000000001,
  0x4330000000000000,
  0xfff0000000000000,
  0xffbfffffffffffff,
  0xbff0000000000000,
  0xbfefffffffffffff,
  0xbfeffffffffffffd,
  0xbfe0000000000000,
  0xbfdfffffffffffff,
  0xbfdffffffffffffd,
  0xbfd5555555555555,
  0xbfa9999999999999,
  0x8002000000000000,
  0x8000000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x8000000000000000,
  0xfff0000000000000,
  0xffc0000000000001,
  0xfff0000000000000,
  0x7ff0000000000000,
  0x7fbfffffffffffff,
  0x3ff0000000000000,
  0x3fefffffffffffff,
  0x3feffffffffffffd,
  0x3fe0000000000000,
  0x3fdfffffffffffff,
  0x3fdffffffffffffd,
  0x3fd5555555555555,
  0x3fa9999999999999,
  0x0002000000000000,
  0x0000000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x0000000000000000,
  0x7ff0000000000000,
  0x7fc0000000000001,
  0x7ff0000000000000,
  0xfff0000000000000,
  0xffc0000000000000,
  0xbff0000000000001,
  0xbff0000000000000,
  0xbfeffffffffffffe,
  0xbfe0000000000001,
  0xbfe0000000000000,
  0xbfdffffffffffffe,
  0xbfd5555555555555,
  0xbfa999999999999a,
  0x8002000000000000,
  0x8000000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x8000000000000000,
  0xfff0000000000000,
  0xffc0000000000001,
  0xfff0000000000000,
  0x7ff0000000000000,
  0x7fc0000000000000,
  0x3ff0000000000001,
  0x3ff0000000000000,
  0x3feffffffffffffe,
  0x3fe0000000000001,
  0x3fe0000000000000,
  0x3fdffffffffffffe,
  0x3fd5555555555555,
  0x3fa999999999999a,
  0x0002000000000000,
  0x0000000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x0000000000000000,
  0x7ff0000000000000,
  0x7fc0000000000001,
  0x7ff0000000000000,
  0xfff0000000000000,
  0xffc0000000000001,
  0xbff0000000000002,
  0xbff0000000000001,
  0xbff0000000000000,
  0xbfe0000000000002,
  0xbfe0000000000001,
  0xbfe0000000000000,
  0xbfd5555555555557,
  0xbfa999999999999b,
  0x8002000000000000,
  0x8000000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x8000000000000000,
  0xfff0000000000000,
  0xffc0000000000002,
  0xfff0000000000000,
  0x7ff0000000000000,
  0x7fc0000000000001,
  0x3ff0000000000002,
  0x3ff0000000000001,
  0x3ff0000000000000,
  0x3fe0000000000002,
  0x3fe0000000000001,
  0x3fe0000000000000,
  0x3fd5555555555557,
  0x3fa999999999999b,
  0x0002000000000000,
  0x0000000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x0000000000000000,
  0x7ff0000000000000,
  0x7fc0000000000002,
  0x7ff0000000000000,
  0xfff0000000000000,
  0xffcfffffffffffff,
  0xc000000000000000,
  0xbfffffffffffffff,
  0xbffffffffffffffd,
  0xbff0000000000000,
  0xbfefffffffffffff,
  0xbfeffffffffffffd,
  0xbfe5555555555555,
  0xbfb9999999999999,
  0x8004000000000000,
  0x8000000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x8000000000000000,
  0xfff0000000000000,
  0xffd0000000000001,
  0xfff0000000000000,
  0x7ff0000000000000,
  0x7fcfffffffffffff,
  0x4000000000000000,
  0x3fffffffffffffff,
  0x3ffffffffffffffd,
  0x3ff0000000000000,
  0x3fefffffffffffff,
  0x3feffffffffffffd,
  0x3fe5555555555555,
  0x3fb9999999999999,
  0x0004000000000000,
  0x0000000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x0000000000000000,
  0x7ff0000000000000,
  0x7fd0000000000001,
  0x7ff0000000000000,
  0xfff0000000000000,
  0xffd0000000000000,
  0xc000000000000001,
  0xc000000000000000,
  0xbffffffffffffffe,
  0xbff0000000000001,
  0xbff0000000000000,
  0xbfeffffffffffffe,
  0xbfe5555555555555,
  0xbfb999999999999a,
  0x8004000000000000,
  0x8000000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x8000000000000000,
  0xfff0000000000000,
  0xffd0000000000001,
  0xfff0000000000000,
  0x7ff0000000000000,
  0x7fd0000000000000,
  0x4000000000000001,
  0x4000000000000000,
  0x3ffffffffffffffe,
  0x3ff0000000000001,
  0x3ff0000000000000,
  0x3feffffffffffffe,
  0x3fe5555555555555,
  0x3fb999999999999a,
  0x0004000000000000,
  0x0000000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x0000000000000000,
  0x7ff0000000000000,
  0x7fd0000000000001,
  0x7ff0000000000000,
  0xfff0000000000000,
  0xffd0000000000001,
  0xc000000000000002,
  0xc000000000000001,
  0xc000000000000000,
  0xbff0000000000002,
  0xbff0000000000001,
  0xbff0000000000000,
  0xbfe5555555555557,
  0xbfb999999999999b,
  0x8004000000000000,
  0x8000000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x8000000000000000,
  0xfff0000000000000,
  0xffd0000000000002,
  0xfff0000000000000,
  0x7ff0000000000000,
  0x7fd0000000000001,
  0x4000000000000002,
  0x4000000000000001,
  0x4000000000000000,
  0x3ff0000000000002,
  0x3ff0000000000001,
  0x3ff0000000000000,
  0x3fe5555555555557,
  0x3fb999999999999b,
  0x0004000000000000,
  0x0000000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x0000000000000000,
  0x7ff0000000000000,
  0x7fd0000000000002,
  0x7ff0000000000000,
  0xfff0000000000000,
  0xffd8000000000000,
  0xc008000000000001,
  0xc008000000000000,
  0xc007ffffffffffff,
  0xbff8000000000001,
  0xbff8000000000000,
  0xbff7ffffffffffff,
  0xbff0000000000000,
  0xbfc3333333333333,
  0x8006000000000000,
  0x8000000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x8000000000000000,
  0xfff0000000000000,
  0xffd8000000000002,
  0xfff0000000000000,
  0x7ff0000000000000,
  0x7fd8000000000000,
  0x4008000000000001,
  0x4008000000000000,
  0x4007ffffffffffff,
  0x3ff8000000000001,
  0x3ff8000000000000,
  0x3ff7ffffffffffff,
  0x3ff0000000000000,
  0x3fc3333333333333,
  0x0006000000000000,
  0x0000000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x0000000000000000,
  0x7ff0000000000000,
  0x7fd8000000000002,
  0x7ff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xc034000000000001,
  0xc034000000000000,
  0xc033ffffffffffff,
  0xc024000000000001,
  0xc024000000000000,
  0xc023ffffffffffff,
  0xc01aaaaaaaaaaaab,
  0xbff0000000000000,
  0x8024000000000001,
  0x8000000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x8000000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x4034000000000001,
  0x4034000000000000,
  0x4033ffffffffffff,
  0x4024000000000001,
  0x4024000000000000,
  0x4023ffffffffffff,
  0x401aaaaaaaaaaaab,
  0x3ff0000000000000,
  0x0024000000000001,
  0x0000000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x0000000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xffefffffffffffff,
  0xffeffffffffffffd,
  0xffe5555555555555,
  0xffb9999999999999,
  0xbff0000000000000,
  0x8000000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x8000000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7fefffffffffffff,
  0x7feffffffffffffd,
  0x7fe5555555555555,
  0x7fb9999999999999,
  0x3ff0000000000000,
  0x0000000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x0000000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0xfff0000000000000,
  0xbfb23456789abcd0,
  0x8002468acf13579a,
  0x8002468acf13579a,
  0x8002468acf13579a,
  0x800123456789abcd,
  0x800123456789abcd,
  0x800123456789abcd,
  0x8000c22e45067289,
  0x80001d208a5a912e,
  0x8000000000000000,
  0x8000000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x8000000000000000,
  0xbff0000000000000,
  0xbfb23456789abcd1,
  0xc2f23456789abcd0,
  0x7ff0000000000000,
  0x3fb23456789abcd0,
  0x0002468acf13579a,
  0x0002468acf13579a,
  0x0002468acf13579a,
  0x000123456789abcd,
  0x000123456789abcd,
  0x000123456789abcd,
  0x0000c22e45067289,
  0x00001d208a5a912e,
  0x0000000000000000,
  0x0000000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x0000000000000000,
  0x3ff0000000000000,
  0x3fb23456789abcd1,
  0x42f23456789abcd0,
  0xfff0000000000000,
  0xbfeffffffffffffe,
  0x801fffffffffffff,
  0x801ffffffffffffe,
  0x801ffffffffffffc,
  0x800fffffffffffff,
  0x800fffffffffffff,
  0x800ffffffffffffe,
  0x800aaaaaaaaaaaaa,
  0x800199999999999a,
  0x8000000000000000,
  0x8000000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x8000000000000000,
  0xc02c200000000015,
  0xbff0000000000000,
  0xc32ffffffffffffe,
  0x7ff0000000000000,
  0x3feffffffffffffe,
  0x001fffffffffffff,
  0x001ffffffffffffe,
  0x001ffffffffffffc,
  0x000fffffffffffff,
  0x000fffffffffffff,
  0x000ffffffffffffe,
  0x000aaaaaaaaaaaaa,
  0x000199999999999a,
  0x0000000000000000,
  0x0000000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x0000000000000000,
  0x402c200000000015,
  0x3ff0000000000000,
  0x432ffffffffffffe,
  0xfff0000000000000,
  0xbcb0000000000000,
  0x8000000000000002,
  0x8000000000000002,
  0x8000000000000002,
  0x8000000000000001,
  0x8000000000000001,
  0x8000000000000001,
  0x8000000000000001,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x8000000000000000,
  0xbcec200000000017,
  0xbcb0000000000001,
  0xbff0000000000000,
  0x7ff0000000000000,
  0x3cb0000000000000,
  0x0000000000000002,
  0x0000000000000002,
  0x0000000000000002,
  0x0000000000000001,
  0x0000000000000001,
  0x0000000000000001,
  0x0000000000000001,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x0000000000000000,
  0x3cec200000000017,
  0x3cb0000000000001,
  0x3ff0000000000000,
};
const unsigned kExpectedCount_fdiv_d = 1444;

const uint32_t kExpected_fdiv_s[] = {
  0x7fc00000,
  0x00000000,
  0x00000000,
  0x00000000,
  0x00000000,
  0x00000000,
  0x00000000,
  0x00000000,
  0x00000000,
  0x00000000,
  0x7fcfffff,
  0x00000000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00000000,
  0x00000000,
  0x00000000,
  0x7fc00000,
  0x80000000,
  0x80000000,
  0x80000000,
  0x80000000,
  0x80000000,
  0x80000000,
  0x80000000,
  0x80000000,
  0x80000000,
  0xffcfffff,
  0x80000000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80000000,
  0x80000000,
  0x80000000,
  0x7f800000,
  0x3f800000,
  0x01000001,
  0x01000000,
  0x00fffffe,
  0x00800001,
  0x00800000,
  0x007fffff,
  0x00555555,
  0x000ccccd,
  0x7fcfffff,
  0x00000000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x40e10006,
  0x3f800001,
  0x4b000000,
  0xff800000,
  0xbf800000,
  0x81000001,
  0x81000000,
  0x80fffffe,
  0x80800001,
  0x80800000,
  0x807fffff,
  0x80555555,
  0x800ccccd,
  0xffcfffff,
  0x80000000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xc0e10006,
  0xbf800001,
  0xcb000000,
  0x7f800000,
  0x7dffffff,
  0x3f800000,
  0x3f7fffff,
  0x3f7ffffd,
  0x3f000000,
  0x3effffff,
  0x3efffffd,
  0x3eaaaaaa,
  0x3d4ccccc,
  0x7fcfffff,
  0x00000000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f610005,
  0x7e000001,
  0x7f800000,
  0xff800000,
  0xfdffffff,
  0xbf800000,
  0xbf7fffff,
  0xbf7ffffd,
  0xbf000000,
  0xbeffffff,
  0xbefffffd,
  0xbeaaaaaa,
  0xbd4ccccc,
  0xffcfffff,
  0x80000000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff610005,
  0xfe000001,
  0xff800000,
  0x7f800000,
  0x7e000000,
  0x3f800001,
  0x3f800000,
  0x3f7ffffe,
  0x3f000001,
  0x3f000000,
  0x3efffffe,
  0x3eaaaaab,
  0x3d4ccccd,
  0x7fcfffff,
  0x00000000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f610006,
  0x7e000001,
  0x7f800000,
  0xff800000,
  0xfe000000,
  0xbf800001,
  0xbf800000,
  0xbf7ffffe,
  0xbf000001,
  0xbf000000,
  0xbefffffe,
  0xbeaaaaab,
  0xbd4ccccd,
  0xffcfffff,
  0x80000000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff610006,
  0xfe000001,
  0xff800000,
  0x7f800000,
  0x7e000001,
  0x3f800002,
  0x3f800001,
  0x3f800000,
  0x3f000002,
  0x3f000001,
  0x3f000000,
  0x3eaaaaac,
  0x3d4cccce,
  0x7fcfffff,
  0x00000000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f610008,
  0x7e000002,
  0x7f800000,
  0xff800000,
  0xfe000001,
  0xbf800002,
  0xbf800001,
  0xbf800000,
  0xbf000002,
  0xbf000001,
  0xbf000000,
  0xbeaaaaac,
  0xbd4cccce,
  0xffcfffff,
  0x80000000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff610008,
  0xfe000002,
  0xff800000,
  0x7f800000,
  0x7e7fffff,
  0x40000000,
  0x3fffffff,
  0x3ffffffd,
  0x3f800000,
  0x3f7fffff,
  0x3f7ffffd,
  0x3f2aaaaa,
  0x3dcccccc,
  0x7fcfffff,
  0x00000000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7e800001,
  0x7f800000,
  0xff800000,
  0xfe7fffff,
  0xc0000000,
  0xbfffffff,
  0xbffffffd,
  0xbf800000,
  0xbf7fffff,
  0xbf7ffffd,
  0xbf2aaaaa,
  0xbdcccccc,
  0xffcfffff,
  0x80000000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xfe800001,
  0xff800000,
  0x7f800000,
  0x7e800000,
  0x40000001,
  0x40000000,
  0x3ffffffe,
  0x3f800001,
  0x3f800000,
  0x3f7ffffe,
  0x3f2aaaab,
  0x3dcccccd,
  0x7fcfffff,
  0x00000000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7e800001,
  0x7f800000,
  0xff800000,
  0xfe800000,
  0xc0000001,
  0xc0000000,
  0xbffffffe,
  0xbf800001,
  0xbf800000,
  0xbf7ffffe,
  0xbf2aaaab,
  0xbdcccccd,
  0xffcfffff,
  0x80000000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xfe800001,
  0xff800000,
  0x7f800000,
  0x7e800001,
  0x40000002,
  0x40000001,
  0x40000000,
  0x3f800002,
  0x3f800001,
  0x3f800000,
  0x3f2aaaac,
  0x3dccccce,
  0x7fcfffff,
  0x00000000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7e800002,
  0x7f800000,
  0xff800000,
  0xfe800001,
  0xc0000002,
  0xc0000001,
  0xc0000000,
  0xbf800002,
  0xbf800001,
  0xbf800000,
  0xbf2aaaac,
  0xbdccccce,
  0xffcfffff,
  0x80000000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xfe800002,
  0xff800000,
  0x7f800000,
  0x7ec00000,
  0x40400001,
  0x40400000,
  0x403fffff,
  0x3fc00001,
  0x3fc00000,
  0x3fbfffff,
  0x3f800000,
  0x3e19999a,
  0x7fcfffff,
  0x00000000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7ec00002,
  0x7f800000,
  0xff800000,
  0xfec00000,
  0xc0400001,
  0xc0400000,
  0xc03fffff,
  0xbfc00001,
  0xbfc00000,
  0xbfbfffff,
  0xbf800000,
  0xbe19999a,
  0xffcfffff,
  0x80000000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xfec00002,
  0xff800000,
  0x7f800000,
  0x7f800000,
  0x41a00001,
  0x41a00000,
  0x419fffff,
  0x41200001,
  0x41200000,
  0x411fffff,
  0x40d55555,
  0x3f800000,
  0x7fcfffff,
  0x00000000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xff800000,
  0xff800000,
  0xc1a00001,
  0xc1a00000,
  0xc19fffff,
  0xc1200001,
  0xc1200000,
  0xc11fffff,
  0xc0d55555,
  0xbf800000,
  0xffcfffff,
  0x80000000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7f800000,
  0x3e11a2b0,
  0x002468ac,
  0x002468ac,
  0x002468ac,
  0x00123456,
  0x00123456,
  0x00123456,
  0x000c22e4,
  0x0001d209,
  0x7fcfffff,
  0x00000000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f800000,
  0x3e11a2b1,
  0x4991a2b0,
  0xff800000,
  0xbe11a2b0,
  0x802468ac,
  0x802468ac,
  0x802468ac,
  0x80123456,
  0x80123456,
  0x80123456,
  0x800c22e4,
  0x8001d209,
  0xffcfffff,
  0x80000000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf800000,
  0xbe11a2b1,
  0xc991a2b0,
  0x7f800000,
  0x3f7ffffe,
  0x00ffffff,
  0x00fffffe,
  0x00fffffc,
  0x007fffff,
  0x007fffff,
  0x007ffffe,
  0x00555555,
  0x000ccccd,
  0x7fcfffff,
  0x00000000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x40e10004,
  0x3f800000,
  0x4afffffe,
  0xff800000,
  0xbf7ffffe,
  0x80ffffff,
  0x80fffffe,
  0x80fffffc,
  0x807fffff,
  0x807fffff,
  0x807ffffe,
  0x80555555,
  0x800ccccd,
  0xffcfffff,
  0x80000000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xc0e10004,
  0xbf800000,
  0xcafffffe,
  0x7f800000,
  0x34000000,
  0x00000002,
  0x00000002,
  0x00000002,
  0x00000001,
  0x00000001,
  0x00000001,
  0x00000001,
  0x00000000,
  0x7fcfffff,
  0x00000000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x35610006,
  0x34000001,
  0x3f800000,
  0xff800000,
  0xb4000000,
  0x80000002,
  0x80000002,
  0x80000002,
  0x80000001,
  0x80000001,
  0x80000001,
  0x80000001,
  0x80000000,
  0xffcfffff,
  0x80000000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xb5610006,
  0xb4000001,
  0xbf800000,
  0x7fc00000,
  0x80000000,
  0x80000000,
  0x80000000,
  0x80000000,
  0x80000000,
  0x80000000,
  0x80000000,
  0x80000000,
  0x80000000,
  0x7fcfffff,
  0x80000000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x80000000,
  0x80000000,
  0x80000000,
  0x7fc00000,
  0x00000000,
  0x00000000,
  0x00000000,
  0x00000000,
  0x00000000,
  0x00000000,
  0x00000000,
  0x00000000,
  0x00000000,
  0xffcfffff,
  0x00000000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x00000000,
  0x00000000,
  0x00000000,
  0xff800000,
  0xbf800000,
  0x81000001,
  0x81000000,
  0x80fffffe,
  0x80800001,
  0x80800000,
  0x807fffff,
  0x80555555,
  0x800ccccd,
  0x7fcfffff,
  0x80000000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xc0e10006,
  0xbf800001,
  0xcb000000,
  0x7f800000,
  0x3f800000,
  0x01000001,
  0x01000000,
  0x00fffffe,
  0x00800001,
  0x00800000,
  0x007fffff,
  0x00555555,
  0x000ccccd,
  0xffcfffff,
  0x00000000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x40e10006,
  0x3f800001,
  0x4b000000,
  0xff800000,
  0xfdffffff,
  0xbf800000,
  0xbf7fffff,
  0xbf7ffffd,
  0xbf000000,
  0xbeffffff,
  0xbefffffd,
  0xbeaaaaaa,
  0xbd4ccccc,
  0x7fcfffff,
  0x80000000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff610005,
  0xfe000001,
  0xff800000,
  0x7f800000,
  0x7dffffff,
  0x3f800000,
  0x3f7fffff,
  0x3f7ffffd,
  0x3f000000,
  0x3effffff,
  0x3efffffd,
  0x3eaaaaaa,
  0x3d4ccccc,
  0xffcfffff,
  0x00000000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f610005,
  0x7e000001,
  0x7f800000,
  0xff800000,
  0xfe000000,
  0xbf800001,
  0xbf800000,
  0xbf7ffffe,
  0xbf000001,
  0xbf000000,
  0xbefffffe,
  0xbeaaaaab,
  0xbd4ccccd,
  0x7fcfffff,
  0x80000000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff610006,
  0xfe000001,
  0xff800000,
  0x7f800000,
  0x7e000000,
  0x3f800001,
  0x3f800000,
  0x3f7ffffe,
  0x3f000001,
  0x3f000000,
  0x3efffffe,
  0x3eaaaaab,
  0x3d4ccccd,
  0xffcfffff,
  0x00000000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f610006,
  0x7e000001,
  0x7f800000,
  0xff800000,
  0xfe000001,
  0xbf800002,
  0xbf800001,
  0xbf800000,
  0xbf000002,
  0xbf000001,
  0xbf000000,
  0xbeaaaaac,
  0xbd4cccce,
  0x7fcfffff,
  0x80000000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff610008,
  0xfe000002,
  0xff800000,
  0x7f800000,
  0x7e000001,
  0x3f800002,
  0x3f800001,
  0x3f800000,
  0x3f000002,
  0x3f000001,
  0x3f000000,
  0x3eaaaaac,
  0x3d4cccce,
  0xffcfffff,
  0x00000000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f610008,
  0x7e000002,
  0x7f800000,
  0xff800000,
  0xfe7fffff,
  0xc0000000,
  0xbfffffff,
  0xbffffffd,
  0xbf800000,
  0xbf7fffff,
  0xbf7ffffd,
  0xbf2aaaaa,
  0xbdcccccc,
  0x7fcfffff,
  0x80000000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xfe800001,
  0xff800000,
  0x7f800000,
  0x7e7fffff,
  0x40000000,
  0x3fffffff,
  0x3ffffffd,
  0x3f800000,
  0x3f7fffff,
  0x3f7ffffd,
  0x3f2aaaaa,
  0x3dcccccc,
  0xffcfffff,
  0x00000000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7e800001,
  0x7f800000,
  0xff800000,
  0xfe800000,
  0xc0000001,
  0xc0000000,
  0xbffffffe,
  0xbf800001,
  0xbf800000,
  0xbf7ffffe,
  0xbf2aaaab,
  0xbdcccccd,
  0x7fcfffff,
  0x80000000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xfe800001,
  0xff800000,
  0x7f800000,
  0x7e800000,
  0x40000001,
  0x40000000,
  0x3ffffffe,
  0x3f800001,
  0x3f800000,
  0x3f7ffffe,
  0x3f2aaaab,
  0x3dcccccd,
  0xffcfffff,
  0x00000000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7e800001,
  0x7f800000,
  0xff800000,
  0xfe800001,
  0xc0000002,
  0xc0000001,
  0xc0000000,
  0xbf800002,
  0xbf800001,
  0xbf800000,
  0xbf2aaaac,
  0xbdccccce,
  0x7fcfffff,
  0x80000000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xfe800002,
  0xff800000,
  0x7f800000,
  0x7e800001,
  0x40000002,
  0x40000001,
  0x40000000,
  0x3f800002,
  0x3f800001,
  0x3f800000,
  0x3f2aaaac,
  0x3dccccce,
  0xffcfffff,
  0x00000000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7e800002,
  0x7f800000,
  0xff800000,
  0xfec00000,
  0xc0400001,
  0xc0400000,
  0xc03fffff,
  0xbfc00001,
  0xbfc00000,
  0xbfbfffff,
  0xbf800000,
  0xbe19999a,
  0x7fcfffff,
  0x80000000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xfec00002,
  0xff800000,
  0x7f800000,
  0x7ec00000,
  0x40400001,
  0x40400000,
  0x403fffff,
  0x3fc00001,
  0x3fc00000,
  0x3fbfffff,
  0x3f800000,
  0x3e19999a,
  0xffcfffff,
  0x00000000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7ec00002,
  0x7f800000,
  0xff800000,
  0xff800000,
  0xc1a00001,
  0xc1a00000,
  0xc19fffff,
  0xc1200001,
  0xc1200000,
  0xc11fffff,
  0xc0d55555,
  0xbf800000,
  0x7fcfffff,
  0x80000000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7f800000,
  0x7f800000,
  0x41a00001,
  0x41a00000,
  0x419fffff,
  0x41200001,
  0x41200000,
  0x411fffff,
  0x40d55555,
  0x3f800000,
  0xffcfffff,
  0x00000000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xff800000,
  0xbe11a2b0,
  0x802468ac,
  0x802468ac,
  0x802468ac,
  0x80123456,
  0x80123456,
  0x80123456,
  0x800c22e4,
  0x8001d209,
  0x7fcfffff,
  0x80000000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf800000,
  0xbe11a2b1,
  0xc991a2b0,
  0x7f800000,
  0x3e11a2b0,
  0x002468ac,
  0x002468ac,
  0x002468ac,
  0x00123456,
  0x00123456,
  0x00123456,
  0x000c22e4,
  0x0001d209,
  0xffcfffff,
  0x00000000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f800000,
  0x3e11a2b1,
  0x4991a2b0,
  0xff800000,
  0xbf7ffffe,
  0x80ffffff,
  0x80fffffe,
  0x80fffffc,
  0x807fffff,
  0x807fffff,
  0x807ffffe,
  0x80555555,
  0x800ccccd,
  0x7fcfffff,
  0x80000000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xc0e10004,
  0xbf800000,
  0xcafffffe,
  0x7f800000,
  0x3f7ffffe,
  0x00ffffff,
  0x00fffffe,
  0x00fffffc,
  0x007fffff,
  0x007fffff,
  0x007ffffe,
  0x00555555,
  0x000ccccd,
  0xffcfffff,
  0x00000000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x40e10004,
  0x3f800000,
  0x4afffffe,
  0xff800000,
  0xb4000000,
  0x80000002,
  0x80000002,
  0x80000002,
  0x80000001,
  0x80000001,
  0x80000001,
  0x80000001,
  0x80000000,
  0x7fcfffff,
  0x80000000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xb5610006,
  0xb4000001,
  0xbf800000,
  0x7f800000,
  0x34000000,
  0x00000002,
  0x00000002,
  0x00000002,
  0x00000001,
  0x00000001,
  0x00000001,
  0x00000001,
  0x00000000,
  0xffcfffff,
  0x00000000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x35610006,
  0x34000001,
  0x3f800000,
};
const unsigned kExpectedCount_fdiv_s = 1444;

const uint64_t kExpected_fmadd_d[] = {
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0008000000000000,
  0x0018000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000923456789abcd,
  0x0017ffffffffffff,
  0x0008000000000001,
  0x0008000000000000,
  0x8008000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0006dcba98765433,
  0x8007ffffffffffff,
  0x0007ffffffffffff,
  0x0008000000000000,
  0x0018000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000923456789abcd,
  0x0017ffffffffffff,
  0x0008000000000001,
  0x0008000000000000,
  0x8008000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0006dcba98765433,
  0x8007ffffffffffff,
  0x0007ffffffffffff,
  0x0008000000000000,
  0x0018000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000923456789abce,
  0x0018000000000000,
  0x0008000000000002,
  0x0008000000000000,
  0x8008000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0006dcba98765434,
  0x8007fffffffffffe,
  0x0008000000000000,
  0x0010000000000000,
  0x0020000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x001123456789abcc,
  0x001ffffffffffffe,
  0x0010000000000000,
  0x0010000000000000,
  0x8000000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x000edcba98765432,
  0x0000000000000000,
  0x000ffffffffffffe,
  0x0010000000000000,
  0x0020000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x001123456789abcd,
  0x001fffffffffffff,
  0x0010000000000001,
  0x0010000000000000,
  0x0000000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x000edcba98765433,
  0x0000000000000001,
  0x000fffffffffffff,
  0x0010000000000001,
  0x0020000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x001123456789abce,
  0x0020000000000000,
  0x0010000000000002,
  0x0010000000000001,
  0x0000000000000001,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x000edcba98765434,
  0x0000000000000002,
  0x0010000000000000,
  0x0018000000000000,
  0x0024000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x001923456789abcd,
  0x0024000000000000,
  0x0018000000000001,
  0x0018000000000000,
  0x0008000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0016dcba98765433,
  0x0008000000000001,
  0x0017ffffffffffff,
  0x0044000000000000,
  0x0046000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x00442468acf1357a,
  0x0046000000000000,
  0x0044000000000000,
  0x0044000000000000,
  0x0042000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0043db97530eca86,
  0x0042000000000000,
  0x0044000000000000,
  0x400fffffffffffff,
  0x400fffffffffffff,
  0x4011ffffffffffff,
  0x4012000000000000,
  0x4012000000000000,
  0x4013ffffffffffff,
  0x4014000000000000,
  0x4014000000000000,
  0x4016000000000000,
  0x402c000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x400fffffffffffff,
  0x400fffffffffffff,
  0x400fffffffffffff,
  0x400fffffffffffff,
  0x400fffffffffffff,
  0x400bffffffffffff,
  0x400bffffffffffff,
  0x400bffffffffffff,
  0x4007ffffffffffff,
  0x4007ffffffffffff,
  0x4007fffffffffffe,
  0x4003ffffffffffff,
  0xc018000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x400fffffffffffff,
  0x400fffffffffffff,
  0x400fffffffffffff,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8008000000000000,
  0x0008000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8006dcba98765433,
  0x0007ffffffffffff,
  0x8007ffffffffffff,
  0x8008000000000000,
  0x8018000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800923456789abcd,
  0x8017ffffffffffff,
  0x8008000000000001,
  0x8008000000000000,
  0x0008000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8006dcba98765433,
  0x0007ffffffffffff,
  0x8007ffffffffffff,
  0x8008000000000000,
  0x8018000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800923456789abcd,
  0x8017ffffffffffff,
  0x8008000000000001,
  0x8008000000000000,
  0x0008000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8006dcba98765434,
  0x0007fffffffffffe,
  0x8008000000000000,
  0x8008000000000000,
  0x8018000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800923456789abce,
  0x8018000000000000,
  0x8008000000000002,
  0x8010000000000000,
  0x0000000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x800edcba98765432,
  0x8000000000000000,
  0x800ffffffffffffe,
  0x8010000000000000,
  0x8020000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x801123456789abcc,
  0x801ffffffffffffe,
  0x8010000000000000,
  0x8010000000000000,
  0x0000000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x800edcba98765433,
  0x8000000000000001,
  0x800fffffffffffff,
  0x8010000000000000,
  0x8020000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x801123456789abcd,
  0x801fffffffffffff,
  0x8010000000000001,
  0x8010000000000001,
  0x8000000000000001,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x800edcba98765434,
  0x8000000000000002,
  0x8010000000000000,
  0x8010000000000001,
  0x8020000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x801123456789abce,
  0x8020000000000000,
  0x8010000000000002,
  0x8018000000000000,
  0x8008000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8016dcba98765433,
  0x8008000000000001,
  0x8017ffffffffffff,
  0x8018000000000000,
  0x8024000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x801923456789abcd,
  0x8024000000000000,
  0x8018000000000001,
  0x8044000000000000,
  0x8042000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8043db97530eca86,
  0x8042000000000000,
  0x8044000000000000,
  0x8044000000000000,
  0x8046000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x80442468acf1357a,
  0x8046000000000000,
  0x8044000000000000,
  0xc00fffffffffffff,
  0xc00fffffffffffff,
  0xc00bffffffffffff,
  0xc00bffffffffffff,
  0xc00bffffffffffff,
  0xc007ffffffffffff,
  0xc007ffffffffffff,
  0xc007fffffffffffe,
  0xc003ffffffffffff,
  0x4018000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc00fffffffffffff,
  0xc00fffffffffffff,
  0xc00fffffffffffff,
  0xc00fffffffffffff,
  0xc00fffffffffffff,
  0xc011ffffffffffff,
  0xc012000000000000,
  0xc012000000000000,
  0xc013ffffffffffff,
  0xc014000000000000,
  0xc014000000000000,
  0xc016000000000000,
  0xc02c000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc00fffffffffffff,
  0xc00fffffffffffff,
  0xc00fffffffffffff,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0008000000000000,
  0x0018000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000923456789abcd,
  0x0017ffffffffffff,
  0x0008000000000001,
  0x0008000000000000,
  0x8008000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0006dcba98765433,
  0x8007ffffffffffff,
  0x0007ffffffffffff,
  0x3fcffffffffffffe,
  0x3fcffffffffffffe,
  0x3fe7ffffffffffff,
  0x3fe8000000000000,
  0x3fe8000000000001,
  0x3ff3ffffffffffff,
  0x3ff4000000000000,
  0x3ff4000000000001,
  0x3ffc000000000000,
  0x4024800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fcffffffffffffe,
  0x3fcffffffffffffe,
  0x3fcffffffffffffe,
  0x3fcffffffffffffe,
  0x3fcffffffffffffe,
  0xbfd0000000000000,
  0xbfd0000000000001,
  0xbfd0000000000003,
  0xbfe7ffffffffffff,
  0xbfe8000000000000,
  0xbfe8000000000002,
  0xbff4000000000000,
  0xc023800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fcffffffffffffe,
  0x3fcffffffffffffe,
  0x3fcffffffffffffe,
  0x3fcfffffffffffff,
  0x3fcfffffffffffff,
  0x3fe7ffffffffffff,
  0x3fe8000000000000,
  0x3fe8000000000001,
  0x3ff3ffffffffffff,
  0x3ff4000000000000,
  0x3ff4000000000001,
  0x3ffc000000000000,
  0x4024800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fcfffffffffffff,
  0x3fcfffffffffffff,
  0x3fcfffffffffffff,
  0x3fcfffffffffffff,
  0x3fcfffffffffffff,
  0xbfcfffffffffffff,
  0xbfd0000000000000,
  0xbfd0000000000002,
  0xbfe7ffffffffffff,
  0xbfe8000000000000,
  0xbfe8000000000002,
  0xbff4000000000000,
  0xc023800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fcfffffffffffff,
  0x3fcfffffffffffff,
  0x3fcfffffffffffff,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3fe8000000000001,
  0x3ff4000000000000,
  0x3ff4000000000000,
  0x3ff4000000000001,
  0x3ffc000000000000,
  0x4024800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0xbfcffffffffffffd,
  0xbfcfffffffffffff,
  0xbfd0000000000002,
  0xbfe7ffffffffffff,
  0xbfe8000000000000,
  0xbfe8000000000002,
  0xbff4000000000000,
  0xc023800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fdffffffffffffe,
  0x3fdffffffffffffe,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff7ffffffffffff,
  0x3ff8000000000000,
  0x3ff8000000000001,
  0x4000000000000000,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fdffffffffffffe,
  0x3fdffffffffffffe,
  0x3fdffffffffffffe,
  0x3fdffffffffffffe,
  0x3fdffffffffffffe,
  0xbc8fffffffffffff,
  0xbca0000000000000,
  0xbcb0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000003,
  0xbff0000000000000,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fdffffffffffffe,
  0x3fdffffffffffffe,
  0x3fdffffffffffffe,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff7ffffffffffff,
  0x3ff8000000000000,
  0x3ff8000000000001,
  0x4000000000000000,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x0000000000000000,
  0xbc90000000000000,
  0xbca8000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000002,
  0xbff0000000000000,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000001,
  0x4000000000000000,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3c9fffffffffffff,
  0x3c8ffffffffffffe,
  0xbc90000000000001,
  0xbfdffffffffffffd,
  0xbfdfffffffffffff,
  0xbfe0000000000002,
  0xbff0000000000000,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe7ffffffffffff,
  0x3fe7ffffffffffff,
  0x3ff3ffffffffffff,
  0x3ff4000000000000,
  0x3ff4000000000000,
  0x3ffbffffffffffff,
  0x3ffc000000000000,
  0x3ffc000000000001,
  0x4002000000000000,
  0x4025800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe7ffffffffffff,
  0x3fe7ffffffffffff,
  0x3fe7ffffffffffff,
  0x3fe7ffffffffffff,
  0x3fe7ffffffffffff,
  0x3fcfffffffffffff,
  0x3fcffffffffffffd,
  0x3fcffffffffffff9,
  0xbfcfffffffffffff,
  0xbfd0000000000002,
  0xbfd0000000000006,
  0xbfe8000000000001,
  0xc022800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe7ffffffffffff,
  0x3fe7ffffffffffff,
  0x3fe7ffffffffffff,
  0x4013ffffffffffff,
  0x4013ffffffffffff,
  0x4015ffffffffffff,
  0x4015ffffffffffff,
  0x4016000000000000,
  0x4017ffffffffffff,
  0x4017ffffffffffff,
  0x4018000000000000,
  0x4019ffffffffffff,
  0x402e000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x4013ffffffffffff,
  0x4013ffffffffffff,
  0x4013ffffffffffff,
  0x4013ffffffffffff,
  0x4013ffffffffffff,
  0x4011ffffffffffff,
  0x4011ffffffffffff,
  0x4011ffffffffffff,
  0x400fffffffffffff,
  0x400fffffffffffff,
  0x400ffffffffffffe,
  0x400bffffffffffff,
  0xc014000000000001,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x4013ffffffffffff,
  0x4013ffffffffffff,
  0x4013ffffffffffff,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0xffe0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x000091a2b3c4d5e6,
  0x001091a2b3c4d5e6,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0001b4e81b4e81b3,
  0x001091a2b3c4d5e5,
  0x000091a2b3c4d5e7,
  0x000091a2b3c4d5e6,
  0x800f6e5d4c3b2a1a,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800091a2b3c4d5e7,
  0x800f6e5d4c3b2a19,
  0x000091a2b3c4d5e5,
  0x0007ffffffffffff,
  0x0017ffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000923456789abcc,
  0x0017fffffffffffe,
  0x0008000000000000,
  0x0007ffffffffffff,
  0x8008000000000001,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0006dcba98765432,
  0x8008000000000000,
  0x0007fffffffffffe,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8008000000000000,
  0x0008000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8006dcba98765433,
  0x0007ffffffffffff,
  0x8007ffffffffffff,
  0x8008000000000000,
  0x8018000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800923456789abcd,
  0x8017ffffffffffff,
  0x8008000000000001,
  0xbfcffffffffffffe,
  0xbfcffffffffffffe,
  0x3fd0000000000000,
  0x3fd0000000000001,
  0x3fd0000000000003,
  0x3fe7ffffffffffff,
  0x3fe8000000000000,
  0x3fe8000000000002,
  0x3ff4000000000000,
  0x4023800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfcffffffffffffe,
  0xbfcffffffffffffe,
  0xbfcffffffffffffe,
  0xbfcffffffffffffe,
  0xbfcffffffffffffe,
  0xbfe7ffffffffffff,
  0xbfe8000000000000,
  0xbfe8000000000001,
  0xbff3ffffffffffff,
  0xbff4000000000000,
  0xbff4000000000001,
  0xbffc000000000000,
  0xc024800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfcffffffffffffe,
  0xbfcffffffffffffe,
  0xbfcffffffffffffe,
  0xbfcfffffffffffff,
  0xbfcfffffffffffff,
  0x3fcfffffffffffff,
  0x3fd0000000000000,
  0x3fd0000000000002,
  0x3fe7ffffffffffff,
  0x3fe8000000000000,
  0x3fe8000000000002,
  0x3ff4000000000000,
  0x4023800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfcfffffffffffff,
  0xbfcfffffffffffff,
  0xbfcfffffffffffff,
  0xbfcfffffffffffff,
  0xbfcfffffffffffff,
  0xbfe7ffffffffffff,
  0xbfe8000000000000,
  0xbfe8000000000001,
  0xbff3ffffffffffff,
  0xbff4000000000000,
  0xbff4000000000001,
  0xbffc000000000000,
  0xc024800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfcfffffffffffff,
  0xbfcfffffffffffff,
  0xbfcfffffffffffff,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0x3fcffffffffffffd,
  0x3fcfffffffffffff,
  0x3fd0000000000002,
  0x3fe7ffffffffffff,
  0x3fe8000000000000,
  0x3fe8000000000002,
  0x3ff4000000000000,
  0x4023800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbfe8000000000001,
  0xbff4000000000000,
  0xbff4000000000000,
  0xbff4000000000001,
  0xbffc000000000000,
  0xc024800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfdffffffffffffe,
  0xbfdffffffffffffe,
  0x3c8fffffffffffff,
  0x3ca0000000000000,
  0x3cb0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000003,
  0x3ff0000000000000,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfdffffffffffffe,
  0xbfdffffffffffffe,
  0xbfdffffffffffffe,
  0xbfdffffffffffffe,
  0xbfdffffffffffffe,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff7ffffffffffff,
  0xbff8000000000000,
  0xbff8000000000001,
  0xc000000000000000,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfdffffffffffffe,
  0xbfdffffffffffffe,
  0xbfdffffffffffffe,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0x0000000000000000,
  0x3c90000000000000,
  0x3ca8000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000002,
  0x3ff0000000000000,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff7ffffffffffff,
  0xbff8000000000000,
  0xbff8000000000001,
  0xc000000000000000,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbc9fffffffffffff,
  0xbc8ffffffffffffe,
  0x3c90000000000001,
  0x3fdffffffffffffd,
  0x3fdfffffffffffff,
  0x3fe0000000000002,
  0x3ff0000000000000,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000001,
  0xc000000000000000,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe7ffffffffffff,
  0xbfe7ffffffffffff,
  0xbfcfffffffffffff,
  0xbfcffffffffffffd,
  0xbfcffffffffffff9,
  0x3fcfffffffffffff,
  0x3fd0000000000002,
  0x3fd0000000000006,
  0x3fe8000000000001,
  0x4022800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe7ffffffffffff,
  0xbfe7ffffffffffff,
  0xbfe7ffffffffffff,
  0xbfe7ffffffffffff,
  0xbfe7ffffffffffff,
  0xbff3ffffffffffff,
  0xbff4000000000000,
  0xbff4000000000000,
  0xbffbffffffffffff,
  0xbffc000000000000,
  0xbffc000000000001,
  0xc002000000000000,
  0xc025800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe7ffffffffffff,
  0xbfe7ffffffffffff,
  0xbfe7ffffffffffff,
  0xc013ffffffffffff,
  0xc013ffffffffffff,
  0xc011ffffffffffff,
  0xc011ffffffffffff,
  0xc011ffffffffffff,
  0xc00fffffffffffff,
  0xc00fffffffffffff,
  0xc00ffffffffffffe,
  0xc00bffffffffffff,
  0x4014000000000001,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc013ffffffffffff,
  0xc013ffffffffffff,
  0xc013ffffffffffff,
  0xc013ffffffffffff,
  0xc013ffffffffffff,
  0xc015ffffffffffff,
  0xc015ffffffffffff,
  0xc016000000000000,
  0xc017ffffffffffff,
  0xc017ffffffffffff,
  0xc018000000000000,
  0xc019ffffffffffff,
  0xc02e000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc013ffffffffffff,
  0xc013ffffffffffff,
  0xc013ffffffffffff,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0x7fe0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x800091a2b3c4d5e6,
  0x000f6e5d4c3b2a1a,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000091a2b3c4d5e7,
  0x000f6e5d4c3b2a19,
  0x800091a2b3c4d5e5,
  0x800091a2b3c4d5e6,
  0x801091a2b3c4d5e6,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x8001b4e81b4e81b3,
  0x801091a2b3c4d5e5,
  0x800091a2b3c4d5e7,
  0x8007ffffffffffff,
  0x0008000000000001,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8006dcba98765432,
  0x0008000000000000,
  0x8007fffffffffffe,
  0x8007ffffffffffff,
  0x8017ffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800923456789abcc,
  0x8017fffffffffffe,
  0x8008000000000000,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0008000000000000,
  0x0018000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000923456789abcd,
  0x0017ffffffffffff,
  0x0008000000000001,
  0x0008000000000000,
  0x8008000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0006dcba98765433,
  0x8007ffffffffffff,
  0x0007ffffffffffff,
  0x3fcfffffffffffff,
  0x3fcfffffffffffff,
  0x3fe7ffffffffffff,
  0x3fe8000000000000,
  0x3fe8000000000001,
  0x3ff3ffffffffffff,
  0x3ff4000000000000,
  0x3ff4000000000001,
  0x3ffc000000000000,
  0x4024800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fcfffffffffffff,
  0x3fcfffffffffffff,
  0x3fcfffffffffffff,
  0x3fcfffffffffffff,
  0x3fcfffffffffffff,
  0xbfcfffffffffffff,
  0xbfd0000000000000,
  0xbfd0000000000002,
  0xbfe7ffffffffffff,
  0xbfe8000000000000,
  0xbfe8000000000002,
  0xbff4000000000000,
  0xc023800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fcfffffffffffff,
  0x3fcfffffffffffff,
  0x3fcfffffffffffff,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3fe8000000000001,
  0x3ff4000000000000,
  0x3ff4000000000000,
  0x3ff4000000000001,
  0x3ffc000000000000,
  0x4024800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0xbfcffffffffffffe,
  0xbfd0000000000000,
  0xbfd0000000000002,
  0xbfe7ffffffffffff,
  0xbfe8000000000000,
  0xbfe8000000000002,
  0xbff4000000000000,
  0xc023800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000001,
  0x3fd0000000000001,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3fe8000000000002,
  0x3ff4000000000000,
  0x3ff4000000000000,
  0x3ff4000000000001,
  0x3ffc000000000000,
  0x4024800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fd0000000000001,
  0x3fd0000000000001,
  0x3fd0000000000001,
  0x3fd0000000000001,
  0x3fd0000000000001,
  0xbfcffffffffffffc,
  0xbfcffffffffffffe,
  0xbfd0000000000001,
  0xbfe7fffffffffffe,
  0xbfe8000000000000,
  0xbfe8000000000002,
  0xbff4000000000000,
  0xc023800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fd0000000000001,
  0x3fd0000000000001,
  0x3fd0000000000001,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff7ffffffffffff,
  0x3ff8000000000000,
  0x3ff8000000000001,
  0x4000000000000000,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x0000000000000000,
  0xbc90000000000000,
  0xbca8000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000002,
  0xbff0000000000000,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000001,
  0x4000000000000000,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3c90000000000000,
  0x0000000000000000,
  0xbca0000000000000,
  0xbfdffffffffffffe,
  0xbfe0000000000000,
  0xbfe0000000000002,
  0xbff0000000000000,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000002,
  0x4000000000000000,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3ca8000000000000,
  0x3ca0000000000000,
  0x0000000000000000,
  0xbfdffffffffffffc,
  0xbfdffffffffffffe,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3ff4000000000000,
  0x3ff4000000000000,
  0x3ff4000000000000,
  0x3ffc000000000000,
  0x3ffc000000000000,
  0x3ffc000000000001,
  0x4002000000000000,
  0x4025800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3fd0000000000001,
  0x3fd0000000000000,
  0x3fcffffffffffffc,
  0xbfcffffffffffffc,
  0xbfd0000000000000,
  0xbfd0000000000004,
  0xbfe8000000000000,
  0xc022800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x4014000000000000,
  0x4014000000000000,
  0x4016000000000000,
  0x4016000000000000,
  0x4016000000000000,
  0x4018000000000000,
  0x4018000000000000,
  0x4018000000000000,
  0x401a000000000000,
  0x402e000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x4014000000000000,
  0x4014000000000000,
  0x4014000000000000,
  0x4014000000000000,
  0x4014000000000000,
  0x4012000000000000,
  0x4012000000000000,
  0x4012000000000000,
  0x4010000000000000,
  0x4010000000000000,
  0x4010000000000000,
  0x400c000000000000,
  0xc014000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x4014000000000000,
  0x4014000000000000,
  0x4014000000000000,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0xffdfffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x000091a2b3c4d5e6,
  0x001091a2b3c4d5e6,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0001b4e81b4e81b4,
  0x001091a2b3c4d5e6,
  0x000091a2b3c4d5e8,
  0x000091a2b3c4d5e6,
  0x800f6e5d4c3b2a1a,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800091a2b3c4d5e6,
  0x800f6e5d4c3b2a18,
  0x000091a2b3c4d5e6,
  0x0008000000000000,
  0x0018000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000923456789abcc,
  0x0017fffffffffffe,
  0x0008000000000000,
  0x0008000000000000,
  0x8008000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0006dcba98765432,
  0x8008000000000000,
  0x0007fffffffffffe,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abce,
  0x0010000000000000,
  0x0000000000000002,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcc,
  0x800ffffffffffffe,
  0x8000000000000000,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8008000000000000,
  0x0008000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8006dcba98765433,
  0x0007ffffffffffff,
  0x8007ffffffffffff,
  0x8008000000000000,
  0x8018000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800923456789abcd,
  0x8017ffffffffffff,
  0x8008000000000001,
  0xbfcfffffffffffff,
  0xbfcfffffffffffff,
  0x3fcfffffffffffff,
  0x3fd0000000000000,
  0x3fd0000000000002,
  0x3fe7ffffffffffff,
  0x3fe8000000000000,
  0x3fe8000000000002,
  0x3ff4000000000000,
  0x4023800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfcfffffffffffff,
  0xbfcfffffffffffff,
  0xbfcfffffffffffff,
  0xbfcfffffffffffff,
  0xbfcfffffffffffff,
  0xbfe7ffffffffffff,
  0xbfe8000000000000,
  0xbfe8000000000001,
  0xbff3ffffffffffff,
  0xbff4000000000000,
  0xbff4000000000001,
  0xbffc000000000000,
  0xc024800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfcfffffffffffff,
  0xbfcfffffffffffff,
  0xbfcfffffffffffff,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0x3fcffffffffffffe,
  0x3fd0000000000000,
  0x3fd0000000000002,
  0x3fe7ffffffffffff,
  0x3fe8000000000000,
  0x3fe8000000000002,
  0x3ff4000000000000,
  0x4023800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbfe8000000000001,
  0xbff4000000000000,
  0xbff4000000000000,
  0xbff4000000000001,
  0xbffc000000000000,
  0xc024800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000001,
  0xbfd0000000000001,
  0x3fcffffffffffffc,
  0x3fcffffffffffffe,
  0x3fd0000000000001,
  0x3fe7fffffffffffe,
  0x3fe8000000000000,
  0x3fe8000000000002,
  0x3ff4000000000000,
  0x4023800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfd0000000000001,
  0xbfd0000000000001,
  0xbfd0000000000001,
  0xbfd0000000000001,
  0xbfd0000000000001,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbfe8000000000002,
  0xbff4000000000000,
  0xbff4000000000000,
  0xbff4000000000001,
  0xbffc000000000000,
  0xc024800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfd0000000000001,
  0xbfd0000000000001,
  0xbfd0000000000001,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0x0000000000000000,
  0x3c90000000000000,
  0x3ca8000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000002,
  0x3ff0000000000000,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff7ffffffffffff,
  0xbff8000000000000,
  0xbff8000000000001,
  0xc000000000000000,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbc90000000000000,
  0x0000000000000000,
  0x3ca0000000000000,
  0x3fdffffffffffffe,
  0x3fe0000000000000,
  0x3fe0000000000002,
  0x3ff0000000000000,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000001,
  0xc000000000000000,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbca8000000000000,
  0xbca0000000000000,
  0x0000000000000000,
  0x3fdffffffffffffc,
  0x3fdffffffffffffe,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000002,
  0xc000000000000000,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbfd0000000000001,
  0xbfd0000000000000,
  0xbfcffffffffffffc,
  0x3fcffffffffffffc,
  0x3fd0000000000000,
  0x3fd0000000000004,
  0x3fe8000000000000,
  0x4022800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbff4000000000000,
  0xbff4000000000000,
  0xbff4000000000000,
  0xbffc000000000000,
  0xbffc000000000000,
  0xbffc000000000001,
  0xc002000000000000,
  0xc025800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xc014000000000000,
  0xc014000000000000,
  0xc012000000000000,
  0xc012000000000000,
  0xc012000000000000,
  0xc010000000000000,
  0xc010000000000000,
  0xc010000000000000,
  0xc00c000000000000,
  0x4014000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc014000000000000,
  0xc014000000000000,
  0xc014000000000000,
  0xc014000000000000,
  0xc014000000000000,
  0xc016000000000000,
  0xc016000000000000,
  0xc016000000000000,
  0xc018000000000000,
  0xc018000000000000,
  0xc018000000000000,
  0xc01a000000000000,
  0xc02e000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc014000000000000,
  0xc014000000000000,
  0xc014000000000000,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0x7fdfffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x800091a2b3c4d5e6,
  0x000f6e5d4c3b2a1a,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000091a2b3c4d5e6,
  0x000f6e5d4c3b2a18,
  0x800091a2b3c4d5e6,
  0x800091a2b3c4d5e6,
  0x801091a2b3c4d5e6,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x8001b4e81b4e81b4,
  0x801091a2b3c4d5e6,
  0x800091a2b3c4d5e8,
  0x8008000000000000,
  0x0008000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8006dcba98765432,
  0x0008000000000000,
  0x8007fffffffffffe,
  0x8008000000000000,
  0x8018000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800923456789abcc,
  0x8017fffffffffffe,
  0x8008000000000000,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcc,
  0x000ffffffffffffe,
  0x0000000000000000,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abce,
  0x8010000000000000,
  0x8000000000000002,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0008000000000000,
  0x0018000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000923456789abce,
  0x0018000000000000,
  0x0008000000000002,
  0x0008000000000000,
  0x8008000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0006dcba98765434,
  0x8007fffffffffffe,
  0x0008000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3fe8000000000001,
  0x3ff4000000000000,
  0x3ff4000000000000,
  0x3ff4000000000001,
  0x3ffc000000000000,
  0x4024800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0xbfcffffffffffffd,
  0xbfcfffffffffffff,
  0xbfd0000000000002,
  0xbfe7ffffffffffff,
  0xbfe8000000000000,
  0xbfe8000000000002,
  0xbff4000000000000,
  0xc023800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000001,
  0x3fd0000000000001,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3fe8000000000002,
  0x3ff4000000000000,
  0x3ff4000000000000,
  0x3ff4000000000001,
  0x3ffc000000000000,
  0x4024800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fd0000000000001,
  0x3fd0000000000001,
  0x3fd0000000000001,
  0x3fd0000000000001,
  0x3fd0000000000001,
  0xbfcffffffffffffc,
  0xbfcffffffffffffe,
  0xbfd0000000000001,
  0xbfe7fffffffffffe,
  0xbfe8000000000000,
  0xbfe8000000000002,
  0xbff4000000000000,
  0xc023800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fd0000000000001,
  0x3fd0000000000001,
  0x3fd0000000000001,
  0x3fd0000000000002,
  0x3fd0000000000002,
  0x3fe8000000000001,
  0x3fe8000000000001,
  0x3fe8000000000002,
  0x3ff4000000000000,
  0x3ff4000000000001,
  0x3ff4000000000002,
  0x3ffc000000000001,
  0x4024800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fd0000000000002,
  0x3fd0000000000002,
  0x3fd0000000000002,
  0x3fd0000000000002,
  0x3fd0000000000002,
  0xbfcffffffffffffa,
  0xbfcffffffffffffc,
  0xbfd0000000000000,
  0xbfe7fffffffffffe,
  0xbfe7ffffffffffff,
  0xbfe8000000000001,
  0xbff3ffffffffffff,
  0xc023800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fd0000000000002,
  0x3fd0000000000002,
  0x3fd0000000000002,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000001,
  0x4000000000000000,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3c9fffffffffffff,
  0x3c8ffffffffffffe,
  0xbc90000000000001,
  0xbfdffffffffffffd,
  0xbfdfffffffffffff,
  0xbfe0000000000002,
  0xbff0000000000000,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000002,
  0x4000000000000000,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3ca8000000000000,
  0x3ca0000000000000,
  0x0000000000000000,
  0xbfdffffffffffffc,
  0xbfdffffffffffffe,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000002,
  0x3fe0000000000002,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000002,
  0x3ff8000000000001,
  0x3ff8000000000001,
  0x3ff8000000000002,
  0x4000000000000001,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe0000000000002,
  0x3fe0000000000002,
  0x3fe0000000000002,
  0x3fe0000000000002,
  0x3fe0000000000002,
  0x3cb4000000000000,
  0x3cb0000000000000,
  0x3ca0000000000001,
  0xbfdffffffffffffa,
  0xbfdffffffffffffc,
  0xbfe0000000000000,
  0xbfeffffffffffffe,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe0000000000002,
  0x3fe0000000000002,
  0x3fe0000000000002,
  0x3fe8000000000002,
  0x3fe8000000000002,
  0x3ff4000000000000,
  0x3ff4000000000001,
  0x3ff4000000000001,
  0x3ffc000000000000,
  0x3ffc000000000001,
  0x3ffc000000000002,
  0x4002000000000000,
  0x4025800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe8000000000002,
  0x3fe8000000000002,
  0x3fe8000000000002,
  0x3fe8000000000002,
  0x3fe8000000000001,
  0x3fd0000000000004,
  0x3fd0000000000003,
  0x3fd0000000000001,
  0xbfcffffffffffff6,
  0xbfcffffffffffffa,
  0xbfd0000000000001,
  0xbfe7fffffffffffe,
  0xc022800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe8000000000001,
  0x3fe8000000000001,
  0x3fe8000000000001,
  0x4014000000000001,
  0x4014000000000001,
  0x4016000000000001,
  0x4016000000000001,
  0x4016000000000001,
  0x4018000000000001,
  0x4018000000000001,
  0x4018000000000002,
  0x401a000000000001,
  0x402e000000000001,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x4014000000000001,
  0x4014000000000001,
  0x4014000000000001,
  0x4014000000000001,
  0x4014000000000001,
  0x4012000000000001,
  0x4012000000000001,
  0x4012000000000001,
  0x4010000000000001,
  0x4010000000000001,
  0x4010000000000001,
  0x400c000000000002,
  0xc013ffffffffffff,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x4014000000000001,
  0x4014000000000001,
  0x4014000000000001,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0xffdffffffffffffd,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x000091a2b3c4d5e7,
  0x001091a2b3c4d5e7,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0001b4e81b4e81b4,
  0x001091a2b3c4d5e6,
  0x000091a2b3c4d5e8,
  0x000091a2b3c4d5e7,
  0x800f6e5d4c3b2a19,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800091a2b3c4d5e6,
  0x800f6e5d4c3b2a18,
  0x000091a2b3c4d5e6,
  0x0008000000000000,
  0x0018000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000923456789abcd,
  0x0017ffffffffffff,
  0x0008000000000001,
  0x0008000000000000,
  0x8008000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0006dcba98765433,
  0x8007ffffffffffff,
  0x0007ffffffffffff,
  0x0000000000000001,
  0x0010000000000001,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abce,
  0x0010000000000000,
  0x0000000000000002,
  0x0000000000000001,
  0x800fffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcc,
  0x800ffffffffffffe,
  0x8000000000000000,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8008000000000000,
  0x0008000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8006dcba98765434,
  0x0007fffffffffffe,
  0x8008000000000000,
  0x8008000000000000,
  0x8018000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800923456789abce,
  0x8018000000000000,
  0x8008000000000002,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0x3fcffffffffffffd,
  0x3fcfffffffffffff,
  0x3fd0000000000002,
  0x3fe7ffffffffffff,
  0x3fe8000000000000,
  0x3fe8000000000002,
  0x3ff4000000000000,
  0x4023800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbfe8000000000001,
  0xbff4000000000000,
  0xbff4000000000000,
  0xbff4000000000001,
  0xbffc000000000000,
  0xc024800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000001,
  0xbfd0000000000001,
  0x3fcffffffffffffc,
  0x3fcffffffffffffe,
  0x3fd0000000000001,
  0x3fe7fffffffffffe,
  0x3fe8000000000000,
  0x3fe8000000000002,
  0x3ff4000000000000,
  0x4023800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfd0000000000001,
  0xbfd0000000000001,
  0xbfd0000000000001,
  0xbfd0000000000001,
  0xbfd0000000000001,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbfe8000000000002,
  0xbff4000000000000,
  0xbff4000000000000,
  0xbff4000000000001,
  0xbffc000000000000,
  0xc024800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfd0000000000001,
  0xbfd0000000000001,
  0xbfd0000000000001,
  0xbfd0000000000002,
  0xbfd0000000000002,
  0x3fcffffffffffffa,
  0x3fcffffffffffffc,
  0x3fd0000000000000,
  0x3fe7fffffffffffe,
  0x3fe7ffffffffffff,
  0x3fe8000000000001,
  0x3ff3ffffffffffff,
  0x4023800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfd0000000000002,
  0xbfd0000000000002,
  0xbfd0000000000002,
  0xbfd0000000000002,
  0xbfd0000000000002,
  0xbfe8000000000001,
  0xbfe8000000000001,
  0xbfe8000000000002,
  0xbff4000000000000,
  0xbff4000000000001,
  0xbff4000000000002,
  0xbffc000000000001,
  0xc024800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfd0000000000002,
  0xbfd0000000000002,
  0xbfd0000000000002,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbc9fffffffffffff,
  0xbc8ffffffffffffe,
  0x3c90000000000001,
  0x3fdffffffffffffd,
  0x3fdfffffffffffff,
  0x3fe0000000000002,
  0x3ff0000000000000,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000001,
  0xc000000000000000,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbca8000000000000,
  0xbca0000000000000,
  0x0000000000000000,
  0x3fdffffffffffffc,
  0x3fdffffffffffffe,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000002,
  0xc000000000000000,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000002,
  0xbfe0000000000002,
  0xbcb4000000000000,
  0xbcb0000000000000,
  0xbca0000000000001,
  0x3fdffffffffffffa,
  0x3fdffffffffffffc,
  0x3fe0000000000000,
  0x3feffffffffffffe,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe0000000000002,
  0xbfe0000000000002,
  0xbfe0000000000002,
  0xbfe0000000000002,
  0xbfe0000000000002,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000002,
  0xbff8000000000001,
  0xbff8000000000001,
  0xbff8000000000002,
  0xc000000000000001,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe0000000000002,
  0xbfe0000000000002,
  0xbfe0000000000002,
  0xbfe8000000000002,
  0xbfe8000000000001,
  0xbfd0000000000004,
  0xbfd0000000000003,
  0xbfd0000000000001,
  0x3fcffffffffffff6,
  0x3fcffffffffffffa,
  0x3fd0000000000001,
  0x3fe7fffffffffffe,
  0x4022800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe8000000000001,
  0xbfe8000000000001,
  0xbfe8000000000001,
  0xbfe8000000000002,
  0xbfe8000000000002,
  0xbff4000000000000,
  0xbff4000000000001,
  0xbff4000000000001,
  0xbffc000000000000,
  0xbffc000000000001,
  0xbffc000000000002,
  0xc002000000000000,
  0xc025800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe8000000000002,
  0xbfe8000000000002,
  0xbfe8000000000002,
  0xc014000000000001,
  0xc014000000000001,
  0xc012000000000001,
  0xc012000000000001,
  0xc012000000000001,
  0xc010000000000001,
  0xc010000000000001,
  0xc010000000000001,
  0xc00c000000000002,
  0x4013ffffffffffff,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc014000000000001,
  0xc014000000000001,
  0xc014000000000001,
  0xc014000000000001,
  0xc014000000000001,
  0xc016000000000001,
  0xc016000000000001,
  0xc016000000000001,
  0xc018000000000001,
  0xc018000000000001,
  0xc018000000000002,
  0xc01a000000000001,
  0xc02e000000000001,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc014000000000001,
  0xc014000000000001,
  0xc014000000000001,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0x7fdffffffffffffd,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x800091a2b3c4d5e7,
  0x000f6e5d4c3b2a19,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000091a2b3c4d5e6,
  0x000f6e5d4c3b2a18,
  0x800091a2b3c4d5e6,
  0x800091a2b3c4d5e7,
  0x801091a2b3c4d5e7,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x8001b4e81b4e81b4,
  0x801091a2b3c4d5e6,
  0x800091a2b3c4d5e8,
  0x8008000000000000,
  0x0008000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8006dcba98765433,
  0x0007ffffffffffff,
  0x8007ffffffffffff,
  0x8008000000000000,
  0x8018000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800923456789abcd,
  0x8017ffffffffffff,
  0x8008000000000001,
  0x8000000000000001,
  0x000fffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcc,
  0x000ffffffffffffe,
  0x0000000000000000,
  0x8000000000000001,
  0x8010000000000001,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abce,
  0x8010000000000000,
  0x8000000000000002,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0010000000000000,
  0x0020000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x001123456789abcc,
  0x001ffffffffffffe,
  0x0010000000000000,
  0x0010000000000000,
  0x8000000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x000edcba98765432,
  0x0000000000000000,
  0x000ffffffffffffe,
  0x3fdffffffffffffe,
  0x3fdffffffffffffe,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff7ffffffffffff,
  0x3ff8000000000000,
  0x3ff8000000000001,
  0x4000000000000000,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fdffffffffffffe,
  0x3fdffffffffffffe,
  0x3fdffffffffffffe,
  0x3fdffffffffffffe,
  0x3fdffffffffffffe,
  0xbc8fffffffffffff,
  0xbca0000000000000,
  0xbcb0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000003,
  0xbff0000000000000,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fdffffffffffffe,
  0x3fdffffffffffffe,
  0x3fdffffffffffffe,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff7ffffffffffff,
  0x3ff8000000000000,
  0x3ff8000000000001,
  0x4000000000000000,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x0000000000000000,
  0xbc90000000000000,
  0xbca8000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000002,
  0xbff0000000000000,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000001,
  0x4000000000000000,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3c9fffffffffffff,
  0x3c8ffffffffffffe,
  0xbc90000000000001,
  0xbfdffffffffffffd,
  0xbfdfffffffffffff,
  0xbfe0000000000002,
  0xbff0000000000000,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3feffffffffffffe,
  0x3feffffffffffffe,
  0x3ff7ffffffffffff,
  0x3ff7ffffffffffff,
  0x3ff8000000000000,
  0x3fffffffffffffff,
  0x3fffffffffffffff,
  0x4000000000000000,
  0x4004000000000000,
  0x4026000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3feffffffffffffe,
  0x3feffffffffffffe,
  0x3feffffffffffffe,
  0x3feffffffffffffe,
  0x3feffffffffffffe,
  0x3fdffffffffffffd,
  0x3fdffffffffffffc,
  0x3fdffffffffffffa,
  0xbc9fffffffffffff,
  0xbcb0000000000000,
  0xbcc0000000000000,
  0xbfe0000000000002,
  0xc022000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3feffffffffffffe,
  0x3feffffffffffffe,
  0x3feffffffffffffe,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3ff7ffffffffffff,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3fffffffffffffff,
  0x4000000000000000,
  0x4000000000000000,
  0x4004000000000000,
  0x4026000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fdfffffffffffff,
  0x3fdffffffffffffe,
  0x3fdffffffffffffc,
  0x0000000000000000,
  0xbca0000000000000,
  0xbcb8000000000000,
  0xbfe0000000000001,
  0xc022000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000001,
  0x4000000000000000,
  0x4000000000000000,
  0x4000000000000001,
  0x4004000000000000,
  0x4026000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000000,
  0x3cafffffffffffff,
  0x3c9ffffffffffffe,
  0xbca0000000000001,
  0xbfdffffffffffffe,
  0xc022000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff7ffffffffffff,
  0x3ff7ffffffffffff,
  0x3fffffffffffffff,
  0x3fffffffffffffff,
  0x4000000000000000,
  0x4003ffffffffffff,
  0x4004000000000000,
  0x4004000000000000,
  0x4008000000000000,
  0x4027000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3ff7ffffffffffff,
  0x3ff7ffffffffffff,
  0x3ff7ffffffffffff,
  0x3ff7ffffffffffff,
  0x3ff7ffffffffffff,
  0x3fefffffffffffff,
  0x3feffffffffffffe,
  0x3feffffffffffffe,
  0x3fdfffffffffffff,
  0x3fdffffffffffffd,
  0x3fdffffffffffff9,
  0xbca8000000000000,
  0xc021000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3ff7ffffffffffff,
  0x3ff7ffffffffffff,
  0x3ff7ffffffffffff,
  0x4023ffffffffffff,
  0x4023ffffffffffff,
  0x4024ffffffffffff,
  0x4024ffffffffffff,
  0x4024ffffffffffff,
  0x4025ffffffffffff,
  0x4025ffffffffffff,
  0x4026000000000000,
  0x4026ffffffffffff,
  0x4034000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x4023ffffffffffff,
  0x4023ffffffffffff,
  0x4023ffffffffffff,
  0x4023ffffffffffff,
  0x4023ffffffffffff,
  0x4022ffffffffffff,
  0x4022ffffffffffff,
  0x4022ffffffffffff,
  0x4021ffffffffffff,
  0x4021ffffffffffff,
  0x4021ffffffffffff,
  0x4020ffffffffffff,
  0xbcd4000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x4023ffffffffffff,
  0x4023ffffffffffff,
  0x4023ffffffffffff,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0xfc9fffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x001123456789abcd,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0002468acf13579a,
  0x001123456789abcc,
  0x000123456789abce,
  0x000123456789abcd,
  0x800edcba98765433,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x8000000000000000,
  0x800edcba98765432,
  0x000123456789abcc,
  0x000fffffffffffff,
  0x001fffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x001123456789abcc,
  0x001ffffffffffffe,
  0x0010000000000000,
  0x000fffffffffffff,
  0x8000000000000001,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x000edcba98765432,
  0x8000000000000000,
  0x000ffffffffffffe,
  0x0000000000000001,
  0x0010000000000001,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abce,
  0x0010000000000000,
  0x0000000000000002,
  0x0000000000000001,
  0x800fffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcc,
  0x800ffffffffffffe,
  0x8000000000000000,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8010000000000000,
  0x0000000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x800edcba98765432,
  0x8000000000000000,
  0x800ffffffffffffe,
  0x8010000000000000,
  0x8020000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x801123456789abcc,
  0x801ffffffffffffe,
  0x8010000000000000,
  0xbfdffffffffffffe,
  0xbfdffffffffffffe,
  0x3c8fffffffffffff,
  0x3ca0000000000000,
  0x3cb0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000003,
  0x3ff0000000000000,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfdffffffffffffe,
  0xbfdffffffffffffe,
  0xbfdffffffffffffe,
  0xbfdffffffffffffe,
  0xbfdffffffffffffe,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff7ffffffffffff,
  0xbff8000000000000,
  0xbff8000000000001,
  0xc000000000000000,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfdffffffffffffe,
  0xbfdffffffffffffe,
  0xbfdffffffffffffe,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0x0000000000000000,
  0x3c90000000000000,
  0x3ca8000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000002,
  0x3ff0000000000000,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff7ffffffffffff,
  0xbff8000000000000,
  0xbff8000000000001,
  0xc000000000000000,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbc9fffffffffffff,
  0xbc8ffffffffffffe,
  0x3c90000000000001,
  0x3fdffffffffffffd,
  0x3fdfffffffffffff,
  0x3fe0000000000002,
  0x3ff0000000000000,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000001,
  0xc000000000000000,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfeffffffffffffe,
  0xbfeffffffffffffe,
  0xbfdffffffffffffd,
  0xbfdffffffffffffc,
  0xbfdffffffffffffa,
  0x3c9fffffffffffff,
  0x3cb0000000000000,
  0x3cc0000000000000,
  0x3fe0000000000002,
  0x4022000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfeffffffffffffe,
  0xbfeffffffffffffe,
  0xbfeffffffffffffe,
  0xbfeffffffffffffe,
  0xbfeffffffffffffe,
  0xbff7ffffffffffff,
  0xbff7ffffffffffff,
  0xbff8000000000000,
  0xbfffffffffffffff,
  0xbfffffffffffffff,
  0xc000000000000000,
  0xc004000000000000,
  0xc026000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfeffffffffffffe,
  0xbfeffffffffffffe,
  0xbfeffffffffffffe,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfdfffffffffffff,
  0xbfdffffffffffffe,
  0xbfdffffffffffffc,
  0x0000000000000000,
  0x3ca0000000000000,
  0x3cb8000000000000,
  0x3fe0000000000001,
  0x4022000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbff7ffffffffffff,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbfffffffffffffff,
  0xc000000000000000,
  0xc000000000000000,
  0xc004000000000000,
  0xc026000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000000,
  0xbcafffffffffffff,
  0xbc9ffffffffffffe,
  0x3ca0000000000001,
  0x3fdffffffffffffe,
  0x4022000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000001,
  0xc000000000000000,
  0xc000000000000000,
  0xc000000000000001,
  0xc004000000000000,
  0xc026000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff7ffffffffffff,
  0xbff7ffffffffffff,
  0xbfefffffffffffff,
  0xbfeffffffffffffe,
  0xbfeffffffffffffe,
  0xbfdfffffffffffff,
  0xbfdffffffffffffd,
  0xbfdffffffffffff9,
  0x3ca8000000000000,
  0x4021000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbff7ffffffffffff,
  0xbff7ffffffffffff,
  0xbff7ffffffffffff,
  0xbff7ffffffffffff,
  0xbff7ffffffffffff,
  0xbfffffffffffffff,
  0xbfffffffffffffff,
  0xc000000000000000,
  0xc003ffffffffffff,
  0xc004000000000000,
  0xc004000000000000,
  0xc008000000000000,
  0xc027000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbff7ffffffffffff,
  0xbff7ffffffffffff,
  0xbff7ffffffffffff,
  0xc023ffffffffffff,
  0xc023ffffffffffff,
  0xc022ffffffffffff,
  0xc022ffffffffffff,
  0xc022ffffffffffff,
  0xc021ffffffffffff,
  0xc021ffffffffffff,
  0xc021ffffffffffff,
  0xc020ffffffffffff,
  0x3cd4000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc023ffffffffffff,
  0xc023ffffffffffff,
  0xc023ffffffffffff,
  0xc023ffffffffffff,
  0xc023ffffffffffff,
  0xc024ffffffffffff,
  0xc024ffffffffffff,
  0xc024ffffffffffff,
  0xc025ffffffffffff,
  0xc025ffffffffffff,
  0xc026000000000000,
  0xc026ffffffffffff,
  0xc034000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc023ffffffffffff,
  0xc023ffffffffffff,
  0xc023ffffffffffff,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0x7c9fffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x800123456789abcd,
  0x000edcba98765433,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0000000000000000,
  0x000edcba98765432,
  0x800123456789abcc,
  0x800123456789abcd,
  0x801123456789abcd,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x8002468acf13579a,
  0x801123456789abcc,
  0x800123456789abce,
  0x800fffffffffffff,
  0x0000000000000001,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x800edcba98765432,
  0x0000000000000000,
  0x800ffffffffffffe,
  0x800fffffffffffff,
  0x801fffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x801123456789abcc,
  0x801ffffffffffffe,
  0x8010000000000000,
  0x8000000000000001,
  0x000fffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcc,
  0x000ffffffffffffe,
  0x0000000000000000,
  0x8000000000000001,
  0x8010000000000001,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abce,
  0x8010000000000000,
  0x8000000000000002,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0010000000000000,
  0x0020000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x001123456789abcd,
  0x001fffffffffffff,
  0x0010000000000001,
  0x0010000000000000,
  0x0000000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x000edcba98765433,
  0x0000000000000001,
  0x000fffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff7ffffffffffff,
  0x3ff8000000000000,
  0x3ff8000000000001,
  0x4000000000000000,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x0000000000000000,
  0xbc90000000000000,
  0xbca8000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000002,
  0xbff0000000000000,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000001,
  0x4000000000000000,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3c90000000000000,
  0x0000000000000000,
  0xbca0000000000000,
  0xbfdffffffffffffe,
  0xbfe0000000000000,
  0xbfe0000000000002,
  0xbff0000000000000,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000002,
  0x4000000000000000,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3ca8000000000000,
  0x3ca0000000000000,
  0x0000000000000000,
  0xbfdffffffffffffc,
  0xbfdffffffffffffe,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3ff7ffffffffffff,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3fffffffffffffff,
  0x4000000000000000,
  0x4000000000000000,
  0x4004000000000000,
  0x4026000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fdfffffffffffff,
  0x3fdffffffffffffe,
  0x3fdffffffffffffc,
  0x0000000000000000,
  0xbca0000000000000,
  0xbcb8000000000000,
  0xbfe0000000000001,
  0xc022000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x4000000000000000,
  0x4000000000000000,
  0x4000000000000000,
  0x4004000000000000,
  0x4026000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fdffffffffffffe,
  0x3ca0000000000000,
  0x0000000000000000,
  0xbcb0000000000000,
  0xbfe0000000000000,
  0xc022000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff8000000000001,
  0x3ff8000000000001,
  0x3ff8000000000002,
  0x4000000000000000,
  0x4000000000000000,
  0x4000000000000001,
  0x4004000000000000,
  0x4026000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3fe0000000000002,
  0x3fe0000000000002,
  0x3fe0000000000001,
  0x3cb8000000000000,
  0x3cb0000000000000,
  0x0000000000000000,
  0xbfdffffffffffffc,
  0xc022000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x4000000000000000,
  0x4000000000000000,
  0x4000000000000000,
  0x4004000000000000,
  0x4004000000000000,
  0x4004000000000000,
  0x4008000000000000,
  0x4027000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3fefffffffffffff,
  0x3fe0000000000001,
  0x3fe0000000000000,
  0x3fdffffffffffffc,
  0x0000000000000000,
  0xc021000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4025000000000000,
  0x4025000000000000,
  0x4025000000000000,
  0x4026000000000000,
  0x4026000000000000,
  0x4026000000000000,
  0x4027000000000000,
  0x4034000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4023000000000000,
  0x4023000000000000,
  0x4023000000000000,
  0x4022000000000000,
  0x4022000000000000,
  0x4022000000000000,
  0x4021000000000000,
  0x0000000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x0000000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x001123456789abcd,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0002468acf13579a,
  0x001123456789abcc,
  0x000123456789abce,
  0x000123456789abcd,
  0x800edcba98765433,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0000000000000000,
  0x800edcba98765432,
  0x000123456789abcc,
  0x000fffffffffffff,
  0x001fffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x001123456789abcc,
  0x001ffffffffffffe,
  0x0010000000000000,
  0x000fffffffffffff,
  0x8000000000000001,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x000edcba98765432,
  0x0000000000000000,
  0x000ffffffffffffe,
  0x0000000000000001,
  0x0010000000000001,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abce,
  0x0010000000000000,
  0x0000000000000002,
  0x0000000000000001,
  0x800fffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcc,
  0x800ffffffffffffe,
  0x0000000000000000,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8010000000000000,
  0x0000000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x800edcba98765433,
  0x8000000000000001,
  0x800fffffffffffff,
  0x8010000000000000,
  0x8020000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x801123456789abcd,
  0x801fffffffffffff,
  0x8010000000000001,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0x0000000000000000,
  0x3c90000000000000,
  0x3ca8000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000002,
  0x3ff0000000000000,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff7ffffffffffff,
  0xbff8000000000000,
  0xbff8000000000001,
  0xc000000000000000,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbc90000000000000,
  0x0000000000000000,
  0x3ca0000000000000,
  0x3fdffffffffffffe,
  0x3fe0000000000000,
  0x3fe0000000000002,
  0x3ff0000000000000,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000001,
  0xc000000000000000,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbca8000000000000,
  0xbca0000000000000,
  0x0000000000000000,
  0x3fdffffffffffffc,
  0x3fdffffffffffffe,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000002,
  0xc000000000000000,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfdfffffffffffff,
  0xbfdffffffffffffe,
  0xbfdffffffffffffc,
  0x0000000000000000,
  0x3ca0000000000000,
  0x3cb8000000000000,
  0x3fe0000000000001,
  0x4022000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbff7ffffffffffff,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbfffffffffffffff,
  0xc000000000000000,
  0xc000000000000000,
  0xc004000000000000,
  0xc026000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfdffffffffffffe,
  0xbca0000000000000,
  0x0000000000000000,
  0x3cb0000000000000,
  0x3fe0000000000000,
  0x4022000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xc000000000000000,
  0xc000000000000000,
  0xc000000000000000,
  0xc004000000000000,
  0xc026000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbfe0000000000002,
  0xbfe0000000000002,
  0xbfe0000000000001,
  0xbcb8000000000000,
  0xbcb0000000000000,
  0x0000000000000000,
  0x3fdffffffffffffc,
  0x4022000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff8000000000001,
  0xbff8000000000001,
  0xbff8000000000002,
  0xc000000000000000,
  0xc000000000000000,
  0xc000000000000001,
  0xc004000000000000,
  0xc026000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbfefffffffffffff,
  0xbfe0000000000001,
  0xbfe0000000000000,
  0xbfdffffffffffffc,
  0x0000000000000000,
  0x4021000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xc000000000000000,
  0xc000000000000000,
  0xc000000000000000,
  0xc004000000000000,
  0xc004000000000000,
  0xc004000000000000,
  0xc008000000000000,
  0xc027000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc023000000000000,
  0xc023000000000000,
  0xc023000000000000,
  0xc022000000000000,
  0xc022000000000000,
  0xc022000000000000,
  0xc021000000000000,
  0x0000000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc025000000000000,
  0xc025000000000000,
  0xc025000000000000,
  0xc026000000000000,
  0xc026000000000000,
  0xc026000000000000,
  0xc027000000000000,
  0xc034000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0x0000000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x800123456789abcd,
  0x000edcba98765433,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0000000000000000,
  0x000edcba98765432,
  0x800123456789abcc,
  0x800123456789abcd,
  0x801123456789abcd,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x8002468acf13579a,
  0x801123456789abcc,
  0x800123456789abce,
  0x800fffffffffffff,
  0x0000000000000001,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x800edcba98765432,
  0x0000000000000000,
  0x800ffffffffffffe,
  0x800fffffffffffff,
  0x801fffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x801123456789abcc,
  0x801ffffffffffffe,
  0x8010000000000000,
  0x8000000000000001,
  0x000fffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcc,
  0x000ffffffffffffe,
  0x0000000000000000,
  0x8000000000000001,
  0x8010000000000001,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abce,
  0x8010000000000000,
  0x8000000000000002,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0010000000000001,
  0x0020000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x001123456789abce,
  0x0020000000000000,
  0x0010000000000002,
  0x0010000000000001,
  0x0000000000000001,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x000edcba98765434,
  0x0000000000000002,
  0x0010000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000001,
  0x4000000000000000,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3c9fffffffffffff,
  0x3c8ffffffffffffe,
  0xbc90000000000001,
  0xbfdffffffffffffd,
  0xbfdfffffffffffff,
  0xbfe0000000000002,
  0xbff0000000000000,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000002,
  0x4000000000000000,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3ca8000000000000,
  0x3ca0000000000000,
  0x0000000000000000,
  0xbfdffffffffffffc,
  0xbfdffffffffffffe,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000002,
  0x3fe0000000000002,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000002,
  0x3ff8000000000001,
  0x3ff8000000000001,
  0x3ff8000000000002,
  0x4000000000000001,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe0000000000002,
  0x3fe0000000000002,
  0x3fe0000000000002,
  0x3fe0000000000002,
  0x3fe0000000000002,
  0x3cb4000000000000,
  0x3cb0000000000000,
  0x3ca0000000000001,
  0xbfdffffffffffffa,
  0xbfdffffffffffffc,
  0xbfe0000000000000,
  0xbfeffffffffffffe,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe0000000000002,
  0x3fe0000000000002,
  0x3fe0000000000002,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000001,
  0x4000000000000000,
  0x4000000000000000,
  0x4000000000000001,
  0x4004000000000000,
  0x4026000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000000,
  0x3cafffffffffffff,
  0x3c9ffffffffffffe,
  0xbca0000000000001,
  0xbfdffffffffffffe,
  0xc022000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff8000000000001,
  0x3ff8000000000001,
  0x3ff8000000000002,
  0x4000000000000000,
  0x4000000000000000,
  0x4000000000000001,
  0x4004000000000000,
  0x4026000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3fe0000000000002,
  0x3fe0000000000002,
  0x3fe0000000000001,
  0x3cb8000000000000,
  0x3cb0000000000000,
  0x0000000000000000,
  0xbfdffffffffffffc,
  0xc022000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000002,
  0x3ff0000000000002,
  0x3ff8000000000002,
  0x3ff8000000000002,
  0x3ff8000000000003,
  0x4000000000000001,
  0x4000000000000001,
  0x4000000000000002,
  0x4004000000000001,
  0x4026000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3ff0000000000002,
  0x3ff0000000000002,
  0x3ff0000000000002,
  0x3ff0000000000002,
  0x3ff0000000000002,
  0x3fe0000000000005,
  0x3fe0000000000004,
  0x3fe0000000000003,
  0x3cc4000000000000,
  0x3cc0000000000000,
  0x3cb0000000000001,
  0xbfdffffffffffff8,
  0xc022000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3ff0000000000002,
  0x3ff0000000000002,
  0x3ff0000000000002,
  0x3ff8000000000002,
  0x3ff8000000000002,
  0x4000000000000001,
  0x4000000000000001,
  0x4000000000000001,
  0x4004000000000000,
  0x4004000000000001,
  0x4004000000000001,
  0x4008000000000001,
  0x4027000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3ff8000000000002,
  0x3ff8000000000002,
  0x3ff8000000000002,
  0x3ff8000000000002,
  0x3ff8000000000001,
  0x3ff0000000000002,
  0x3ff0000000000002,
  0x3ff0000000000001,
  0x3fe0000000000004,
  0x3fe0000000000003,
  0x3fe0000000000001,
  0x3cb8000000000000,
  0xc021000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3ff8000000000001,
  0x3ff8000000000001,
  0x3ff8000000000001,
  0x4024000000000001,
  0x4024000000000001,
  0x4025000000000001,
  0x4025000000000001,
  0x4025000000000001,
  0x4026000000000001,
  0x4026000000000001,
  0x4026000000000001,
  0x4027000000000001,
  0x4034000000000001,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x4024000000000001,
  0x4024000000000001,
  0x4024000000000001,
  0x4024000000000001,
  0x4024000000000001,
  0x4023000000000001,
  0x4023000000000001,
  0x4023000000000001,
  0x4022000000000001,
  0x4022000000000001,
  0x4022000000000001,
  0x4021000000000001,
  0x3ce4000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x4024000000000001,
  0x4024000000000001,
  0x4024000000000001,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7cafffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x001123456789abcd,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0002468acf13579a,
  0x001123456789abcc,
  0x000123456789abce,
  0x000123456789abcd,
  0x800edcba98765433,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0000000000000000,
  0x800edcba98765432,
  0x000123456789abcc,
  0x0010000000000000,
  0x0020000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x001123456789abcd,
  0x001fffffffffffff,
  0x0010000000000001,
  0x0010000000000000,
  0x8000000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x000edcba98765433,
  0x0000000000000001,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0010000000000001,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abce,
  0x0010000000000000,
  0x0000000000000002,
  0x0000000000000001,
  0x800fffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcc,
  0x800ffffffffffffe,
  0x0000000000000000,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8010000000000001,
  0x8000000000000001,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x800edcba98765434,
  0x8000000000000002,
  0x8010000000000000,
  0x8010000000000001,
  0x8020000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x801123456789abce,
  0x8020000000000000,
  0x8010000000000002,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbc9fffffffffffff,
  0xbc8ffffffffffffe,
  0x3c90000000000001,
  0x3fdffffffffffffd,
  0x3fdfffffffffffff,
  0x3fe0000000000002,
  0x3ff0000000000000,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000001,
  0xc000000000000000,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbca8000000000000,
  0xbca0000000000000,
  0x0000000000000000,
  0x3fdffffffffffffc,
  0x3fdffffffffffffe,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000002,
  0xc000000000000000,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000002,
  0xbfe0000000000002,
  0xbcb4000000000000,
  0xbcb0000000000000,
  0xbca0000000000001,
  0x3fdffffffffffffa,
  0x3fdffffffffffffc,
  0x3fe0000000000000,
  0x3feffffffffffffe,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe0000000000002,
  0xbfe0000000000002,
  0xbfe0000000000002,
  0xbfe0000000000002,
  0xbfe0000000000002,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000002,
  0xbff8000000000001,
  0xbff8000000000001,
  0xbff8000000000002,
  0xc000000000000001,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe0000000000002,
  0xbfe0000000000002,
  0xbfe0000000000002,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000000,
  0xbcafffffffffffff,
  0xbc9ffffffffffffe,
  0x3ca0000000000001,
  0x3fdffffffffffffe,
  0x4022000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000001,
  0xc000000000000000,
  0xc000000000000000,
  0xc000000000000001,
  0xc004000000000000,
  0xc026000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbfe0000000000002,
  0xbfe0000000000002,
  0xbfe0000000000001,
  0xbcb8000000000000,
  0xbcb0000000000000,
  0x0000000000000000,
  0x3fdffffffffffffc,
  0x4022000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff8000000000001,
  0xbff8000000000001,
  0xbff8000000000002,
  0xc000000000000000,
  0xc000000000000000,
  0xc000000000000001,
  0xc004000000000000,
  0xc026000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000002,
  0xbff0000000000002,
  0xbfe0000000000005,
  0xbfe0000000000004,
  0xbfe0000000000003,
  0xbcc4000000000000,
  0xbcc0000000000000,
  0xbcb0000000000001,
  0x3fdffffffffffff8,
  0x4022000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbff0000000000002,
  0xbff0000000000002,
  0xbff0000000000002,
  0xbff0000000000002,
  0xbff0000000000002,
  0xbff8000000000002,
  0xbff8000000000002,
  0xbff8000000000003,
  0xc000000000000001,
  0xc000000000000001,
  0xc000000000000002,
  0xc004000000000001,
  0xc026000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbff0000000000002,
  0xbff0000000000002,
  0xbff0000000000002,
  0xbff8000000000002,
  0xbff8000000000001,
  0xbff0000000000002,
  0xbff0000000000002,
  0xbff0000000000001,
  0xbfe0000000000004,
  0xbfe0000000000003,
  0xbfe0000000000001,
  0xbcb8000000000000,
  0x4021000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbff8000000000001,
  0xbff8000000000001,
  0xbff8000000000001,
  0xbff8000000000002,
  0xbff8000000000002,
  0xc000000000000001,
  0xc000000000000001,
  0xc000000000000001,
  0xc004000000000000,
  0xc004000000000001,
  0xc004000000000001,
  0xc008000000000001,
  0xc027000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbff8000000000002,
  0xbff8000000000002,
  0xbff8000000000002,
  0xc024000000000001,
  0xc024000000000001,
  0xc023000000000001,
  0xc023000000000001,
  0xc023000000000001,
  0xc022000000000001,
  0xc022000000000001,
  0xc022000000000001,
  0xc021000000000001,
  0xbce4000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc024000000000001,
  0xc024000000000001,
  0xc024000000000001,
  0xc024000000000001,
  0xc024000000000001,
  0xc025000000000001,
  0xc025000000000001,
  0xc025000000000001,
  0xc026000000000001,
  0xc026000000000001,
  0xc026000000000001,
  0xc027000000000001,
  0xc034000000000001,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc024000000000001,
  0xc024000000000001,
  0xc024000000000001,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfcafffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x800123456789abcd,
  0x000edcba98765433,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8000000000000000,
  0x000edcba98765432,
  0x800123456789abcc,
  0x800123456789abcd,
  0x801123456789abcd,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x8002468acf13579a,
  0x801123456789abcc,
  0x800123456789abce,
  0x8010000000000000,
  0x0000000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x800edcba98765433,
  0x8000000000000001,
  0x800fffffffffffff,
  0x8010000000000000,
  0x8020000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x801123456789abcd,
  0x801fffffffffffff,
  0x8010000000000001,
  0x8000000000000001,
  0x000fffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcc,
  0x000ffffffffffffe,
  0x8000000000000000,
  0x8000000000000001,
  0x8010000000000001,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abce,
  0x8010000000000000,
  0x8000000000000002,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0018000000000000,
  0x0024000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x001923456789abcd,
  0x0024000000000000,
  0x0018000000000001,
  0x0018000000000000,
  0x0008000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0016dcba98765433,
  0x0008000000000001,
  0x0017ffffffffffff,
  0x3fe7ffffffffffff,
  0x3fe7ffffffffffff,
  0x3ff3ffffffffffff,
  0x3ff4000000000000,
  0x3ff4000000000000,
  0x3ffbffffffffffff,
  0x3ffc000000000000,
  0x3ffc000000000001,
  0x4002000000000000,
  0x4025800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe7ffffffffffff,
  0x3fe7ffffffffffff,
  0x3fe7ffffffffffff,
  0x3fe7ffffffffffff,
  0x3fe7ffffffffffff,
  0x3fcfffffffffffff,
  0x3fcffffffffffffd,
  0x3fcffffffffffff9,
  0xbfcfffffffffffff,
  0xbfd0000000000002,
  0xbfd0000000000006,
  0xbfe8000000000001,
  0xc022800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe7ffffffffffff,
  0x3fe7ffffffffffff,
  0x3fe7ffffffffffff,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3ff4000000000000,
  0x3ff4000000000000,
  0x3ff4000000000000,
  0x3ffc000000000000,
  0x3ffc000000000000,
  0x3ffc000000000001,
  0x4002000000000000,
  0x4025800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3fd0000000000001,
  0x3fd0000000000000,
  0x3fcffffffffffffc,
  0xbfcffffffffffffc,
  0xbfd0000000000000,
  0xbfd0000000000004,
  0xbfe8000000000000,
  0xc022800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3fe8000000000002,
  0x3fe8000000000002,
  0x3ff4000000000000,
  0x3ff4000000000001,
  0x3ff4000000000001,
  0x3ffc000000000000,
  0x3ffc000000000001,
  0x3ffc000000000002,
  0x4002000000000000,
  0x4025800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe8000000000002,
  0x3fe8000000000002,
  0x3fe8000000000002,
  0x3fe8000000000002,
  0x3fe8000000000001,
  0x3fd0000000000004,
  0x3fd0000000000003,
  0x3fd0000000000001,
  0xbfcffffffffffff6,
  0xbfcffffffffffffa,
  0xbfd0000000000001,
  0xbfe7fffffffffffe,
  0xc022800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe8000000000001,
  0x3fe8000000000001,
  0x3fe8000000000001,
  0x3ff7ffffffffffff,
  0x3ff7ffffffffffff,
  0x3fffffffffffffff,
  0x3fffffffffffffff,
  0x4000000000000000,
  0x4003ffffffffffff,
  0x4004000000000000,
  0x4004000000000000,
  0x4008000000000000,
  0x4027000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3ff7ffffffffffff,
  0x3ff7ffffffffffff,
  0x3ff7ffffffffffff,
  0x3ff7ffffffffffff,
  0x3ff7ffffffffffff,
  0x3fefffffffffffff,
  0x3feffffffffffffe,
  0x3feffffffffffffe,
  0x3fdfffffffffffff,
  0x3fdffffffffffffd,
  0x3fdffffffffffff9,
  0xbca8000000000000,
  0xc021000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3ff7ffffffffffff,
  0x3ff7ffffffffffff,
  0x3ff7ffffffffffff,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x4000000000000000,
  0x4000000000000000,
  0x4000000000000000,
  0x4004000000000000,
  0x4004000000000000,
  0x4004000000000000,
  0x4008000000000000,
  0x4027000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3fefffffffffffff,
  0x3fe0000000000001,
  0x3fe0000000000000,
  0x3fdffffffffffffc,
  0x0000000000000000,
  0xc021000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000002,
  0x3ff8000000000002,
  0x4000000000000001,
  0x4000000000000001,
  0x4000000000000001,
  0x4004000000000000,
  0x4004000000000001,
  0x4004000000000001,
  0x4008000000000001,
  0x4027000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3ff8000000000002,
  0x3ff8000000000002,
  0x3ff8000000000002,
  0x3ff8000000000002,
  0x3ff8000000000001,
  0x3ff0000000000002,
  0x3ff0000000000002,
  0x3ff0000000000001,
  0x3fe0000000000004,
  0x3fe0000000000003,
  0x3fe0000000000001,
  0x3cb8000000000000,
  0xc021000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3ff8000000000001,
  0x3ff8000000000001,
  0x3ff8000000000001,
  0x4002000000000000,
  0x4002000000000000,
  0x4006000000000000,
  0x4006000000000000,
  0x4006000000000000,
  0x400a000000000000,
  0x400a000000000000,
  0x400a000000000000,
  0x400e000000000000,
  0x4028800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x4002000000000000,
  0x4002000000000000,
  0x4002000000000000,
  0x4002000000000000,
  0x4002000000000000,
  0x3ffc000000000000,
  0x3ffc000000000000,
  0x3ffc000000000000,
  0x3ff4000000000000,
  0x3ff4000000000000,
  0x3ff3ffffffffffff,
  0x3fe8000000000000,
  0xc01f000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x4002000000000000,
  0x4002000000000000,
  0x4002000000000000,
  0x402e000000000000,
  0x402e000000000000,
  0x402f000000000000,
  0x402f000000000000,
  0x402f000000000000,
  0x4030000000000000,
  0x4030000000000000,
  0x4030000000000000,
  0x4030800000000000,
  0x4039000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x402e000000000000,
  0x402e000000000000,
  0x402e000000000000,
  0x402e000000000000,
  0x402e000000000000,
  0x402d000000000000,
  0x402d000000000000,
  0x402d000000000000,
  0x402c000000000000,
  0x402c000000000000,
  0x402c000000000000,
  0x402b000000000000,
  0x4014000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x402e000000000000,
  0x402e000000000000,
  0x402e000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7fdfffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x0001b4e81b4e81b4,
  0x0011b4e81b4e81b4,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0002d82d82d82d80,
  0x0011b4e81b4e81b2,
  0x0001b4e81b4e81b4,
  0x0001b4e81b4e81b4,
  0x800e4b17e4b17e4c,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x000091a2b3c4d5e6,
  0x800e4b17e4b17e4c,
  0x0001b4e81b4e81b2,
  0x0017fffffffffffe,
  0x0023ffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x001923456789abcc,
  0x0023ffffffffffff,
  0x0018000000000000,
  0x0017fffffffffffe,
  0x0007fffffffffffe,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0016dcba98765432,
  0x0008000000000000,
  0x0017fffffffffffe,
  0x0000000000000002,
  0x0010000000000002,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abce,
  0x0010000000000000,
  0x0000000000000002,
  0x0000000000000002,
  0x800ffffffffffffe,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcc,
  0x800ffffffffffffe,
  0x0000000000000000,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8018000000000000,
  0x8008000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8016dcba98765433,
  0x8008000000000001,
  0x8017ffffffffffff,
  0x8018000000000000,
  0x8024000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x801923456789abcd,
  0x8024000000000000,
  0x8018000000000001,
  0xbfe7ffffffffffff,
  0xbfe7ffffffffffff,
  0xbfcfffffffffffff,
  0xbfcffffffffffffd,
  0xbfcffffffffffff9,
  0x3fcfffffffffffff,
  0x3fd0000000000002,
  0x3fd0000000000006,
  0x3fe8000000000001,
  0x4022800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe7ffffffffffff,
  0xbfe7ffffffffffff,
  0xbfe7ffffffffffff,
  0xbfe7ffffffffffff,
  0xbfe7ffffffffffff,
  0xbff3ffffffffffff,
  0xbff4000000000000,
  0xbff4000000000000,
  0xbffbffffffffffff,
  0xbffc000000000000,
  0xbffc000000000001,
  0xc002000000000000,
  0xc025800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe7ffffffffffff,
  0xbfe7ffffffffffff,
  0xbfe7ffffffffffff,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbfd0000000000001,
  0xbfd0000000000000,
  0xbfcffffffffffffc,
  0x3fcffffffffffffc,
  0x3fd0000000000000,
  0x3fd0000000000004,
  0x3fe8000000000000,
  0x4022800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbff4000000000000,
  0xbff4000000000000,
  0xbff4000000000000,
  0xbffc000000000000,
  0xbffc000000000000,
  0xbffc000000000001,
  0xc002000000000000,
  0xc025800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbfe8000000000002,
  0xbfe8000000000001,
  0xbfd0000000000004,
  0xbfd0000000000003,
  0xbfd0000000000001,
  0x3fcffffffffffff6,
  0x3fcffffffffffffa,
  0x3fd0000000000001,
  0x3fe7fffffffffffe,
  0x4022800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe8000000000001,
  0xbfe8000000000001,
  0xbfe8000000000001,
  0xbfe8000000000002,
  0xbfe8000000000002,
  0xbff4000000000000,
  0xbff4000000000001,
  0xbff4000000000001,
  0xbffc000000000000,
  0xbffc000000000001,
  0xbffc000000000002,
  0xc002000000000000,
  0xc025800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe8000000000002,
  0xbfe8000000000002,
  0xbfe8000000000002,
  0xbff7ffffffffffff,
  0xbff7ffffffffffff,
  0xbfefffffffffffff,
  0xbfeffffffffffffe,
  0xbfeffffffffffffe,
  0xbfdfffffffffffff,
  0xbfdffffffffffffd,
  0xbfdffffffffffff9,
  0x3ca8000000000000,
  0x4021000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbff7ffffffffffff,
  0xbff7ffffffffffff,
  0xbff7ffffffffffff,
  0xbff7ffffffffffff,
  0xbff7ffffffffffff,
  0xbfffffffffffffff,
  0xbfffffffffffffff,
  0xc000000000000000,
  0xc003ffffffffffff,
  0xc004000000000000,
  0xc004000000000000,
  0xc008000000000000,
  0xc027000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbff7ffffffffffff,
  0xbff7ffffffffffff,
  0xbff7ffffffffffff,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbfefffffffffffff,
  0xbfe0000000000001,
  0xbfe0000000000000,
  0xbfdffffffffffffc,
  0x0000000000000000,
  0x4021000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xc000000000000000,
  0xc000000000000000,
  0xc000000000000000,
  0xc004000000000000,
  0xc004000000000000,
  0xc004000000000000,
  0xc008000000000000,
  0xc027000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000002,
  0xbff8000000000001,
  0xbff0000000000002,
  0xbff0000000000002,
  0xbff0000000000001,
  0xbfe0000000000004,
  0xbfe0000000000003,
  0xbfe0000000000001,
  0xbcb8000000000000,
  0x4021000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbff8000000000001,
  0xbff8000000000001,
  0xbff8000000000001,
  0xbff8000000000002,
  0xbff8000000000002,
  0xc000000000000001,
  0xc000000000000001,
  0xc000000000000001,
  0xc004000000000000,
  0xc004000000000001,
  0xc004000000000001,
  0xc008000000000001,
  0xc027000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbff8000000000002,
  0xbff8000000000002,
  0xbff8000000000002,
  0xc002000000000000,
  0xc002000000000000,
  0xbffc000000000000,
  0xbffc000000000000,
  0xbffc000000000000,
  0xbff4000000000000,
  0xbff4000000000000,
  0xbff3ffffffffffff,
  0xbfe8000000000000,
  0x401f000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc002000000000000,
  0xc002000000000000,
  0xc002000000000000,
  0xc002000000000000,
  0xc002000000000000,
  0xc006000000000000,
  0xc006000000000000,
  0xc006000000000000,
  0xc00a000000000000,
  0xc00a000000000000,
  0xc00a000000000000,
  0xc00e000000000000,
  0xc028800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc002000000000000,
  0xc002000000000000,
  0xc002000000000000,
  0xc02e000000000000,
  0xc02e000000000000,
  0xc02d000000000000,
  0xc02d000000000000,
  0xc02d000000000000,
  0xc02c000000000000,
  0xc02c000000000000,
  0xc02c000000000000,
  0xc02b000000000000,
  0xc014000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc02e000000000000,
  0xc02e000000000000,
  0xc02e000000000000,
  0xc02e000000000000,
  0xc02e000000000000,
  0xc02f000000000000,
  0xc02f000000000000,
  0xc02f000000000000,
  0xc030000000000000,
  0xc030000000000000,
  0xc030000000000000,
  0xc030800000000000,
  0xc039000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc02e000000000000,
  0xc02e000000000000,
  0xc02e000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xffdfffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x8001b4e81b4e81b4,
  0x000e4b17e4b17e4c,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x800091a2b3c4d5e6,
  0x000e4b17e4b17e4c,
  0x8001b4e81b4e81b2,
  0x8001b4e81b4e81b4,
  0x8011b4e81b4e81b4,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x8002d82d82d82d80,
  0x8011b4e81b4e81b2,
  0x8001b4e81b4e81b4,
  0x8017fffffffffffe,
  0x8007fffffffffffe,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8016dcba98765432,
  0x8008000000000000,
  0x8017fffffffffffe,
  0x8017fffffffffffe,
  0x8023ffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x801923456789abcc,
  0x8023ffffffffffff,
  0x8018000000000000,
  0x8000000000000002,
  0x000ffffffffffffe,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcc,
  0x000ffffffffffffe,
  0x8000000000000000,
  0x8000000000000002,
  0x8010000000000002,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abce,
  0x8010000000000000,
  0x8000000000000002,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0044000000000000,
  0x0046000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x00442468acf1357a,
  0x0046000000000000,
  0x0044000000000000,
  0x0044000000000000,
  0x0042000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0043db97530eca86,
  0x0042000000000000,
  0x0044000000000000,
  0x4013ffffffffffff,
  0x4013ffffffffffff,
  0x4015ffffffffffff,
  0x4015ffffffffffff,
  0x4016000000000000,
  0x4017ffffffffffff,
  0x4017ffffffffffff,
  0x4018000000000000,
  0x4019ffffffffffff,
  0x402e000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x4013ffffffffffff,
  0x4013ffffffffffff,
  0x4013ffffffffffff,
  0x4013ffffffffffff,
  0x4013ffffffffffff,
  0x4011ffffffffffff,
  0x4011ffffffffffff,
  0x4011ffffffffffff,
  0x400fffffffffffff,
  0x400fffffffffffff,
  0x400ffffffffffffe,
  0x400bffffffffffff,
  0xc014000000000001,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x4013ffffffffffff,
  0x4013ffffffffffff,
  0x4013ffffffffffff,
  0x4014000000000000,
  0x4014000000000000,
  0x4016000000000000,
  0x4016000000000000,
  0x4016000000000000,
  0x4018000000000000,
  0x4018000000000000,
  0x4018000000000000,
  0x401a000000000000,
  0x402e000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x4014000000000000,
  0x4014000000000000,
  0x4014000000000000,
  0x4014000000000000,
  0x4014000000000000,
  0x4012000000000000,
  0x4012000000000000,
  0x4012000000000000,
  0x4010000000000000,
  0x4010000000000000,
  0x4010000000000000,
  0x400c000000000000,
  0xc014000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x4014000000000000,
  0x4014000000000000,
  0x4014000000000000,
  0x4014000000000001,
  0x4014000000000001,
  0x4016000000000001,
  0x4016000000000001,
  0x4016000000000001,
  0x4018000000000001,
  0x4018000000000001,
  0x4018000000000002,
  0x401a000000000001,
  0x402e000000000001,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x4014000000000001,
  0x4014000000000001,
  0x4014000000000001,
  0x4014000000000001,
  0x4014000000000001,
  0x4012000000000001,
  0x4012000000000001,
  0x4012000000000001,
  0x4010000000000001,
  0x4010000000000001,
  0x4010000000000001,
  0x400c000000000002,
  0xc013ffffffffffff,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x4014000000000001,
  0x4014000000000001,
  0x4014000000000001,
  0x4023ffffffffffff,
  0x4023ffffffffffff,
  0x4024ffffffffffff,
  0x4024ffffffffffff,
  0x4024ffffffffffff,
  0x4025ffffffffffff,
  0x4025ffffffffffff,
  0x4026000000000000,
  0x4026ffffffffffff,
  0x4034000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x4023ffffffffffff,
  0x4023ffffffffffff,
  0x4023ffffffffffff,
  0x4023ffffffffffff,
  0x4023ffffffffffff,
  0x4022ffffffffffff,
  0x4022ffffffffffff,
  0x4022ffffffffffff,
  0x4021ffffffffffff,
  0x4021ffffffffffff,
  0x4021ffffffffffff,
  0x4020ffffffffffff,
  0xbcd4000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x4023ffffffffffff,
  0x4023ffffffffffff,
  0x4023ffffffffffff,
  0x4024000000000000,
  0x4024000000000000,
  0x4025000000000000,
  0x4025000000000000,
  0x4025000000000000,
  0x4026000000000000,
  0x4026000000000000,
  0x4026000000000000,
  0x4027000000000000,
  0x4034000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4023000000000000,
  0x4023000000000000,
  0x4023000000000000,
  0x4022000000000000,
  0x4022000000000000,
  0x4022000000000000,
  0x4021000000000000,
  0x0000000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4024000000000001,
  0x4024000000000001,
  0x4025000000000001,
  0x4025000000000001,
  0x4025000000000001,
  0x4026000000000001,
  0x4026000000000001,
  0x4026000000000001,
  0x4027000000000001,
  0x4034000000000001,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x4024000000000001,
  0x4024000000000001,
  0x4024000000000001,
  0x4024000000000001,
  0x4024000000000001,
  0x4023000000000001,
  0x4023000000000001,
  0x4023000000000001,
  0x4022000000000001,
  0x4022000000000001,
  0x4022000000000001,
  0x4021000000000001,
  0x3ce4000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x4024000000000001,
  0x4024000000000001,
  0x4024000000000001,
  0x402e000000000000,
  0x402e000000000000,
  0x402f000000000000,
  0x402f000000000000,
  0x402f000000000000,
  0x4030000000000000,
  0x4030000000000000,
  0x4030000000000000,
  0x4030800000000000,
  0x4039000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x402e000000000000,
  0x402e000000000000,
  0x402e000000000000,
  0x402e000000000000,
  0x402e000000000000,
  0x402d000000000000,
  0x402d000000000000,
  0x402d000000000000,
  0x402c000000000000,
  0x402c000000000000,
  0x402c000000000000,
  0x402b000000000000,
  0x4014000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x402e000000000000,
  0x402e000000000000,
  0x402e000000000000,
  0x4059000000000000,
  0x4059000000000000,
  0x4059200000000000,
  0x4059200000000000,
  0x4059200000000000,
  0x4059400000000000,
  0x4059400000000000,
  0x4059400000000000,
  0x4059600000000000,
  0x405b800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x4059000000000000,
  0x4059000000000000,
  0x4059000000000000,
  0x4059000000000000,
  0x4059000000000000,
  0x4058e00000000000,
  0x4058e00000000000,
  0x4058e00000000000,
  0x4058c00000000000,
  0x4058c00000000000,
  0x4058c00000000000,
  0x4058a00000000000,
  0x4056800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x4059000000000000,
  0x4059000000000000,
  0x4059000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x000b60b60b60b602,
  0x001b60b60b60b602,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000c83fb72ea61cf,
  0x001b60b60b60b601,
  0x000b60b60b60b603,
  0x000b60b60b60b602,
  0x80049f49f49f49fe,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x000a3d70a3d70a35,
  0x80049f49f49f49fd,
  0x000b60b60b60b601,
  0x0043ffffffffffff,
  0x0045ffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x00442468acf13578,
  0x0045ffffffffffff,
  0x0043ffffffffffff,
  0x0043ffffffffffff,
  0x0041ffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0043db97530eca85,
  0x0041ffffffffffff,
  0x0043ffffffffffff,
  0x000000000000000a,
  0x001000000000000a,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abd7,
  0x0010000000000009,
  0x000000000000000b,
  0x000000000000000a,
  0x800ffffffffffff6,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abc3,
  0x800ffffffffffff5,
  0x0000000000000009,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8044000000000000,
  0x8042000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8043db97530eca86,
  0x8042000000000000,
  0x8044000000000000,
  0x8044000000000000,
  0x8046000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x80442468acf1357a,
  0x8046000000000000,
  0x8044000000000000,
  0xc013ffffffffffff,
  0xc013ffffffffffff,
  0xc011ffffffffffff,
  0xc011ffffffffffff,
  0xc011ffffffffffff,
  0xc00fffffffffffff,
  0xc00fffffffffffff,
  0xc00ffffffffffffe,
  0xc00bffffffffffff,
  0x4014000000000001,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc013ffffffffffff,
  0xc013ffffffffffff,
  0xc013ffffffffffff,
  0xc013ffffffffffff,
  0xc013ffffffffffff,
  0xc015ffffffffffff,
  0xc015ffffffffffff,
  0xc016000000000000,
  0xc017ffffffffffff,
  0xc017ffffffffffff,
  0xc018000000000000,
  0xc019ffffffffffff,
  0xc02e000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc013ffffffffffff,
  0xc013ffffffffffff,
  0xc013ffffffffffff,
  0xc014000000000000,
  0xc014000000000000,
  0xc012000000000000,
  0xc012000000000000,
  0xc012000000000000,
  0xc010000000000000,
  0xc010000000000000,
  0xc010000000000000,
  0xc00c000000000000,
  0x4014000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc014000000000000,
  0xc014000000000000,
  0xc014000000000000,
  0xc014000000000000,
  0xc014000000000000,
  0xc016000000000000,
  0xc016000000000000,
  0xc016000000000000,
  0xc018000000000000,
  0xc018000000000000,
  0xc018000000000000,
  0xc01a000000000000,
  0xc02e000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc014000000000000,
  0xc014000000000000,
  0xc014000000000000,
  0xc014000000000001,
  0xc014000000000001,
  0xc012000000000001,
  0xc012000000000001,
  0xc012000000000001,
  0xc010000000000001,
  0xc010000000000001,
  0xc010000000000001,
  0xc00c000000000002,
  0x4013ffffffffffff,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc014000000000001,
  0xc014000000000001,
  0xc014000000000001,
  0xc014000000000001,
  0xc014000000000001,
  0xc016000000000001,
  0xc016000000000001,
  0xc016000000000001,
  0xc018000000000001,
  0xc018000000000001,
  0xc018000000000002,
  0xc01a000000000001,
  0xc02e000000000001,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc014000000000001,
  0xc014000000000001,
  0xc014000000000001,
  0xc023ffffffffffff,
  0xc023ffffffffffff,
  0xc022ffffffffffff,
  0xc022ffffffffffff,
  0xc022ffffffffffff,
  0xc021ffffffffffff,
  0xc021ffffffffffff,
  0xc021ffffffffffff,
  0xc020ffffffffffff,
  0x3cd4000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc023ffffffffffff,
  0xc023ffffffffffff,
  0xc023ffffffffffff,
  0xc023ffffffffffff,
  0xc023ffffffffffff,
  0xc024ffffffffffff,
  0xc024ffffffffffff,
  0xc024ffffffffffff,
  0xc025ffffffffffff,
  0xc025ffffffffffff,
  0xc026000000000000,
  0xc026ffffffffffff,
  0xc034000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc023ffffffffffff,
  0xc023ffffffffffff,
  0xc023ffffffffffff,
  0xc024000000000000,
  0xc024000000000000,
  0xc023000000000000,
  0xc023000000000000,
  0xc023000000000000,
  0xc022000000000000,
  0xc022000000000000,
  0xc022000000000000,
  0xc021000000000000,
  0x0000000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc025000000000000,
  0xc025000000000000,
  0xc025000000000000,
  0xc026000000000000,
  0xc026000000000000,
  0xc026000000000000,
  0xc027000000000000,
  0xc034000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc024000000000001,
  0xc024000000000001,
  0xc023000000000001,
  0xc023000000000001,
  0xc023000000000001,
  0xc022000000000001,
  0xc022000000000001,
  0xc022000000000001,
  0xc021000000000001,
  0xbce4000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc024000000000001,
  0xc024000000000001,
  0xc024000000000001,
  0xc024000000000001,
  0xc024000000000001,
  0xc025000000000001,
  0xc025000000000001,
  0xc025000000000001,
  0xc026000000000001,
  0xc026000000000001,
  0xc026000000000001,
  0xc027000000000001,
  0xc034000000000001,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc024000000000001,
  0xc024000000000001,
  0xc024000000000001,
  0xc02e000000000000,
  0xc02e000000000000,
  0xc02d000000000000,
  0xc02d000000000000,
  0xc02d000000000000,
  0xc02c000000000000,
  0xc02c000000000000,
  0xc02c000000000000,
  0xc02b000000000000,
  0xc014000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc02e000000000000,
  0xc02e000000000000,
  0xc02e000000000000,
  0xc02e000000000000,
  0xc02e000000000000,
  0xc02f000000000000,
  0xc02f000000000000,
  0xc02f000000000000,
  0xc030000000000000,
  0xc030000000000000,
  0xc030000000000000,
  0xc030800000000000,
  0xc039000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc02e000000000000,
  0xc02e000000000000,
  0xc02e000000000000,
  0xc059000000000000,
  0xc059000000000000,
  0xc058e00000000000,
  0xc058e00000000000,
  0xc058e00000000000,
  0xc058c00000000000,
  0xc058c00000000000,
  0xc058c00000000000,
  0xc058a00000000000,
  0xc056800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc059000000000000,
  0xc059000000000000,
  0xc059000000000000,
  0xc059000000000000,
  0xc059000000000000,
  0xc059200000000000,
  0xc059200000000000,
  0xc059200000000000,
  0xc059400000000000,
  0xc059400000000000,
  0xc059400000000000,
  0xc059600000000000,
  0xc05b800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc059000000000000,
  0xc059000000000000,
  0xc059000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x800b60b60b60b602,
  0x00049f49f49f49fe,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x800a3d70a3d70a35,
  0x00049f49f49f49fd,
  0x800b60b60b60b601,
  0x800b60b60b60b602,
  0x801b60b60b60b602,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800c83fb72ea61cf,
  0x801b60b60b60b601,
  0x800b60b60b60b603,
  0x8043ffffffffffff,
  0x8041ffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8043db97530eca85,
  0x8041ffffffffffff,
  0x8043ffffffffffff,
  0x8043ffffffffffff,
  0x8045ffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x80442468acf13578,
  0x8045ffffffffffff,
  0x8043ffffffffffff,
  0x800000000000000a,
  0x000ffffffffffff6,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abc3,
  0x000ffffffffffff5,
  0x8000000000000009,
  0x800000000000000a,
  0x801000000000000a,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abd7,
  0x8010000000000009,
  0x800000000000000b,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x400fffffffffffff,
  0x400fffffffffffff,
  0x4011ffffffffffff,
  0x4012000000000000,
  0x4012000000000000,
  0x4013ffffffffffff,
  0x4014000000000000,
  0x4014000000000000,
  0x4016000000000000,
  0x402c000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x400fffffffffffff,
  0x400fffffffffffff,
  0x400fffffffffffff,
  0x400fffffffffffff,
  0x400fffffffffffff,
  0x400bffffffffffff,
  0x400bffffffffffff,
  0x400bffffffffffff,
  0x4007ffffffffffff,
  0x4007ffffffffffff,
  0x4007fffffffffffe,
  0x4003ffffffffffff,
  0xc018000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x400fffffffffffff,
  0x400fffffffffffff,
  0x400fffffffffffff,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0xffe0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0xffdfffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0xffdffffffffffffd,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0xfc9fffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x0000000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7cafffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7fdfffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x3fd23456789abccf,
  0x3fd23456789abccf,
  0x3fe91a2b3c4d5e67,
  0x3fe91a2b3c4d5e68,
  0x3fe91a2b3c4d5e69,
  0x3ff48d159e26af33,
  0x3ff48d159e26af34,
  0x3ff48d159e26af35,
  0x3ffc8d159e26af34,
  0x402491a2b3c4d5e6,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fd23456789abccf,
  0x3fd23456789abccf,
  0x3fd23456789abccf,
  0x3fd23456789abccf,
  0x3fd23456789abccf,
  0xbfcb97530eca865f,
  0xbfcb97530eca8661,
  0xbfcb97530eca8665,
  0xbfe6e5d4c3b2a197,
  0xbfe6e5d4c3b2a198,
  0xbfe6e5d4c3b2a19a,
  0xbff372ea61d950cc,
  0xc0236e5d4c3b2a1a,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fd23456789abccf,
  0x3fd23456789abccf,
  0x3fd23456789abccf,
  0x400ffffffffffffd,
  0x400ffffffffffffd,
  0x4011fffffffffffe,
  0x4011ffffffffffff,
  0x4011ffffffffffff,
  0x4013fffffffffffe,
  0x4013ffffffffffff,
  0x4013ffffffffffff,
  0x4015ffffffffffff,
  0x402bffffffffffff,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x400ffffffffffffd,
  0x400ffffffffffffd,
  0x400ffffffffffffd,
  0x400ffffffffffffd,
  0x400ffffffffffffd,
  0x400bfffffffffffd,
  0x400bfffffffffffd,
  0x400bfffffffffffd,
  0x4007fffffffffffd,
  0x4007fffffffffffd,
  0x4007fffffffffffd,
  0x4003fffffffffffd,
  0xc018000000000001,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x400ffffffffffffd,
  0x400ffffffffffffd,
  0x400ffffffffffffd,
  0x3ccfffffffffffff,
  0x3ccfffffffffffff,
  0x3fe0000000000007,
  0x3fe0000000000008,
  0x3fe0000000000009,
  0x3ff0000000000003,
  0x3ff0000000000004,
  0x3ff0000000000005,
  0x3ff8000000000004,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3ccfffffffffffff,
  0x3ccfffffffffffff,
  0x3ccfffffffffffff,
  0x3ccfffffffffffff,
  0x3ccfffffffffffff,
  0xbfdfffffffffffef,
  0xbfdffffffffffff0,
  0xbfdffffffffffff2,
  0xbfeffffffffffff7,
  0xbfeffffffffffff8,
  0xbfeffffffffffffa,
  0xbff7fffffffffffc,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3ccfffffffffffff,
  0x3ccfffffffffffff,
  0x3ccfffffffffffff,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0xc00fffffffffffff,
  0xc00fffffffffffff,
  0xc00bffffffffffff,
  0xc00bffffffffffff,
  0xc00bffffffffffff,
  0xc007ffffffffffff,
  0xc007ffffffffffff,
  0xc007fffffffffffe,
  0xc003ffffffffffff,
  0x4018000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc00fffffffffffff,
  0xc00fffffffffffff,
  0xc00fffffffffffff,
  0xc00fffffffffffff,
  0xc00fffffffffffff,
  0xc011ffffffffffff,
  0xc012000000000000,
  0xc012000000000000,
  0xc013ffffffffffff,
  0xc014000000000000,
  0xc014000000000000,
  0xc016000000000000,
  0xc02c000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc00fffffffffffff,
  0xc00fffffffffffff,
  0xc00fffffffffffff,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0x7fe0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0x7fdfffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0x7fdffffffffffffd,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0x7c9fffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0x0000000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfcafffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xffdfffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xbfd23456789abccf,
  0xbfd23456789abccf,
  0x3fcb97530eca865f,
  0x3fcb97530eca8661,
  0x3fcb97530eca8665,
  0x3fe6e5d4c3b2a197,
  0x3fe6e5d4c3b2a198,
  0x3fe6e5d4c3b2a19a,
  0x3ff372ea61d950cc,
  0x40236e5d4c3b2a1a,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfd23456789abccf,
  0xbfd23456789abccf,
  0xbfd23456789abccf,
  0xbfd23456789abccf,
  0xbfd23456789abccf,
  0xbfe91a2b3c4d5e67,
  0xbfe91a2b3c4d5e68,
  0xbfe91a2b3c4d5e69,
  0xbff48d159e26af33,
  0xbff48d159e26af34,
  0xbff48d159e26af35,
  0xbffc8d159e26af34,
  0xc02491a2b3c4d5e6,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfd23456789abccf,
  0xbfd23456789abccf,
  0xbfd23456789abccf,
  0xc00ffffffffffffd,
  0xc00ffffffffffffd,
  0xc00bfffffffffffd,
  0xc00bfffffffffffd,
  0xc00bfffffffffffd,
  0xc007fffffffffffd,
  0xc007fffffffffffd,
  0xc007fffffffffffd,
  0xc003fffffffffffd,
  0x4018000000000001,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc00ffffffffffffd,
  0xc00ffffffffffffd,
  0xc00ffffffffffffd,
  0xc00ffffffffffffd,
  0xc00ffffffffffffd,
  0xc011fffffffffffe,
  0xc011ffffffffffff,
  0xc011ffffffffffff,
  0xc013fffffffffffe,
  0xc013ffffffffffff,
  0xc013ffffffffffff,
  0xc015ffffffffffff,
  0xc02bffffffffffff,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc00ffffffffffffd,
  0xc00ffffffffffffd,
  0xc00ffffffffffffd,
  0xbccfffffffffffff,
  0xbccfffffffffffff,
  0x3fdfffffffffffef,
  0x3fdffffffffffff0,
  0x3fdffffffffffff2,
  0x3feffffffffffff7,
  0x3feffffffffffff8,
  0x3feffffffffffffa,
  0x3ff7fffffffffffc,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbccfffffffffffff,
  0xbccfffffffffffff,
  0xbccfffffffffffff,
  0xbccfffffffffffff,
  0xbccfffffffffffff,
  0xbfe0000000000007,
  0xbfe0000000000008,
  0xbfe0000000000009,
  0xbff0000000000003,
  0xbff0000000000004,
  0xbff0000000000005,
  0xbff8000000000004,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbccfffffffffffff,
  0xbccfffffffffffff,
  0xbccfffffffffffff,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x000091a2b3c4d5e6,
  0x001091a2b3c4d5e6,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0001b4e81b4e81b3,
  0x001091a2b3c4d5e5,
  0x000091a2b3c4d5e7,
  0x000091a2b3c4d5e6,
  0x800f6e5d4c3b2a1a,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800091a2b3c4d5e7,
  0x800f6e5d4c3b2a19,
  0x000091a2b3c4d5e5,
  0x000091a2b3c4d5e6,
  0x001091a2b3c4d5e6,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0001b4e81b4e81b4,
  0x001091a2b3c4d5e6,
  0x000091a2b3c4d5e8,
  0x000091a2b3c4d5e6,
  0x800f6e5d4c3b2a1a,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800091a2b3c4d5e6,
  0x800f6e5d4c3b2a18,
  0x000091a2b3c4d5e6,
  0x000091a2b3c4d5e7,
  0x001091a2b3c4d5e7,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0001b4e81b4e81b4,
  0x001091a2b3c4d5e6,
  0x000091a2b3c4d5e8,
  0x000091a2b3c4d5e7,
  0x800f6e5d4c3b2a19,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800091a2b3c4d5e6,
  0x800f6e5d4c3b2a18,
  0x000091a2b3c4d5e6,
  0x000123456789abcd,
  0x001123456789abcd,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0002468acf13579a,
  0x001123456789abcc,
  0x000123456789abce,
  0x000123456789abcd,
  0x800edcba98765433,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x8000000000000000,
  0x800edcba98765432,
  0x000123456789abcc,
  0x000123456789abcd,
  0x001123456789abcd,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0002468acf13579a,
  0x001123456789abcc,
  0x000123456789abce,
  0x000123456789abcd,
  0x800edcba98765433,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0000000000000000,
  0x800edcba98765432,
  0x000123456789abcc,
  0x000123456789abcd,
  0x001123456789abcd,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0002468acf13579a,
  0x001123456789abcc,
  0x000123456789abce,
  0x000123456789abcd,
  0x800edcba98765433,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0000000000000000,
  0x800edcba98765432,
  0x000123456789abcc,
  0x0001b4e81b4e81b4,
  0x0011b4e81b4e81b4,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0002d82d82d82d80,
  0x0011b4e81b4e81b2,
  0x0001b4e81b4e81b4,
  0x0001b4e81b4e81b4,
  0x800e4b17e4b17e4c,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x000091a2b3c4d5e6,
  0x800e4b17e4b17e4c,
  0x0001b4e81b4e81b2,
  0x000b60b60b60b602,
  0x001b60b60b60b602,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000c83fb72ea61cf,
  0x001b60b60b60b601,
  0x000b60b60b60b603,
  0x000b60b60b60b602,
  0x80049f49f49f49fe,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x000a3d70a3d70a35,
  0x80049f49f49f49fd,
  0x000b60b60b60b601,
  0x3fd23456789abccf,
  0x3fd23456789abccf,
  0x3fe91a2b3c4d5e67,
  0x3fe91a2b3c4d5e68,
  0x3fe91a2b3c4d5e69,
  0x3ff48d159e26af33,
  0x3ff48d159e26af34,
  0x3ff48d159e26af35,
  0x3ffc8d159e26af34,
  0x402491a2b3c4d5e6,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fd23456789abccf,
  0x3fd23456789abccf,
  0x3fd23456789abccf,
  0x3fd23456789abccf,
  0x3fd23456789abccf,
  0xbfcb97530eca865f,
  0xbfcb97530eca8661,
  0xbfcb97530eca8665,
  0xbfe6e5d4c3b2a197,
  0xbfe6e5d4c3b2a198,
  0xbfe6e5d4c3b2a19a,
  0xbff372ea61d950cc,
  0xc0236e5d4c3b2a1a,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fd23456789abccf,
  0x3fd23456789abccf,
  0x3fd23456789abccf,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x800091a2b3c4d5e6,
  0x000f6e5d4c3b2a1a,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000091a2b3c4d5e7,
  0x000f6e5d4c3b2a19,
  0x800091a2b3c4d5e5,
  0x800091a2b3c4d5e6,
  0x801091a2b3c4d5e6,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x8001b4e81b4e81b3,
  0x801091a2b3c4d5e5,
  0x800091a2b3c4d5e7,
  0x800091a2b3c4d5e6,
  0x000f6e5d4c3b2a1a,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000091a2b3c4d5e6,
  0x000f6e5d4c3b2a18,
  0x800091a2b3c4d5e6,
  0x800091a2b3c4d5e6,
  0x801091a2b3c4d5e6,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x8001b4e81b4e81b4,
  0x801091a2b3c4d5e6,
  0x800091a2b3c4d5e8,
  0x800091a2b3c4d5e7,
  0x000f6e5d4c3b2a19,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000091a2b3c4d5e6,
  0x000f6e5d4c3b2a18,
  0x800091a2b3c4d5e6,
  0x800091a2b3c4d5e7,
  0x801091a2b3c4d5e7,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x8001b4e81b4e81b4,
  0x801091a2b3c4d5e6,
  0x800091a2b3c4d5e8,
  0x800123456789abcd,
  0x000edcba98765433,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0000000000000000,
  0x000edcba98765432,
  0x800123456789abcc,
  0x800123456789abcd,
  0x801123456789abcd,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x8002468acf13579a,
  0x801123456789abcc,
  0x800123456789abce,
  0x800123456789abcd,
  0x000edcba98765433,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0000000000000000,
  0x000edcba98765432,
  0x800123456789abcc,
  0x800123456789abcd,
  0x801123456789abcd,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x8002468acf13579a,
  0x801123456789abcc,
  0x800123456789abce,
  0x800123456789abcd,
  0x000edcba98765433,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8000000000000000,
  0x000edcba98765432,
  0x800123456789abcc,
  0x800123456789abcd,
  0x801123456789abcd,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x8002468acf13579a,
  0x801123456789abcc,
  0x800123456789abce,
  0x8001b4e81b4e81b4,
  0x000e4b17e4b17e4c,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x800091a2b3c4d5e6,
  0x000e4b17e4b17e4c,
  0x8001b4e81b4e81b2,
  0x8001b4e81b4e81b4,
  0x8011b4e81b4e81b4,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x8002d82d82d82d80,
  0x8011b4e81b4e81b2,
  0x8001b4e81b4e81b4,
  0x800b60b60b60b602,
  0x00049f49f49f49fe,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x800a3d70a3d70a35,
  0x00049f49f49f49fd,
  0x800b60b60b60b601,
  0x800b60b60b60b602,
  0x801b60b60b60b602,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800c83fb72ea61cf,
  0x801b60b60b60b601,
  0x800b60b60b60b603,
  0xbfd23456789abccf,
  0xbfd23456789abccf,
  0x3fcb97530eca865f,
  0x3fcb97530eca8661,
  0x3fcb97530eca8665,
  0x3fe6e5d4c3b2a197,
  0x3fe6e5d4c3b2a198,
  0x3fe6e5d4c3b2a19a,
  0x3ff372ea61d950cc,
  0x40236e5d4c3b2a1a,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfd23456789abccf,
  0xbfd23456789abccf,
  0xbfd23456789abccf,
  0xbfd23456789abccf,
  0xbfd23456789abccf,
  0xbfe91a2b3c4d5e67,
  0xbfe91a2b3c4d5e68,
  0xbfe91a2b3c4d5e69,
  0xbff48d159e26af33,
  0xbff48d159e26af34,
  0xbff48d159e26af35,
  0xbffc8d159e26af34,
  0xc02491a2b3c4d5e6,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfd23456789abccf,
  0xbfd23456789abccf,
  0xbfd23456789abccf,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0007ffffffffffff,
  0x0017ffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000923456789abcc,
  0x0017fffffffffffe,
  0x0008000000000000,
  0x0007ffffffffffff,
  0x8008000000000001,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0006dcba98765432,
  0x8008000000000000,
  0x0007fffffffffffe,
  0x0008000000000000,
  0x0018000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000923456789abcc,
  0x0017fffffffffffe,
  0x0008000000000000,
  0x0008000000000000,
  0x8008000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0006dcba98765432,
  0x8008000000000000,
  0x0007fffffffffffe,
  0x0008000000000000,
  0x0018000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000923456789abcd,
  0x0017ffffffffffff,
  0x0008000000000001,
  0x0008000000000000,
  0x8008000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0006dcba98765433,
  0x8007ffffffffffff,
  0x0007ffffffffffff,
  0x000fffffffffffff,
  0x001fffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x001123456789abcc,
  0x001ffffffffffffe,
  0x0010000000000000,
  0x000fffffffffffff,
  0x8000000000000001,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x000edcba98765432,
  0x8000000000000000,
  0x000ffffffffffffe,
  0x000fffffffffffff,
  0x001fffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x001123456789abcc,
  0x001ffffffffffffe,
  0x0010000000000000,
  0x000fffffffffffff,
  0x8000000000000001,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x000edcba98765432,
  0x0000000000000000,
  0x000ffffffffffffe,
  0x0010000000000000,
  0x0020000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x001123456789abcd,
  0x001fffffffffffff,
  0x0010000000000001,
  0x0010000000000000,
  0x8000000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x000edcba98765433,
  0x0000000000000001,
  0x000fffffffffffff,
  0x0017fffffffffffe,
  0x0023ffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x001923456789abcc,
  0x0023ffffffffffff,
  0x0018000000000000,
  0x0017fffffffffffe,
  0x0007fffffffffffe,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0016dcba98765432,
  0x0008000000000000,
  0x0017fffffffffffe,
  0x0043ffffffffffff,
  0x0045ffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x00442468acf13578,
  0x0045ffffffffffff,
  0x0043ffffffffffff,
  0x0043ffffffffffff,
  0x0041ffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0043db97530eca85,
  0x0041ffffffffffff,
  0x0043ffffffffffff,
  0x400ffffffffffffd,
  0x400ffffffffffffd,
  0x4011fffffffffffe,
  0x4011ffffffffffff,
  0x4011ffffffffffff,
  0x4013fffffffffffe,
  0x4013ffffffffffff,
  0x4013ffffffffffff,
  0x4015ffffffffffff,
  0x402bffffffffffff,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x400ffffffffffffd,
  0x400ffffffffffffd,
  0x400ffffffffffffd,
  0x400ffffffffffffd,
  0x400ffffffffffffd,
  0x400bfffffffffffd,
  0x400bfffffffffffd,
  0x400bfffffffffffd,
  0x4007fffffffffffd,
  0x4007fffffffffffd,
  0x4007fffffffffffd,
  0x4003fffffffffffd,
  0xc018000000000001,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x400ffffffffffffd,
  0x400ffffffffffffd,
  0x400ffffffffffffd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8007ffffffffffff,
  0x0008000000000001,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8006dcba98765432,
  0x0008000000000000,
  0x8007fffffffffffe,
  0x8007ffffffffffff,
  0x8017ffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800923456789abcc,
  0x8017fffffffffffe,
  0x8008000000000000,
  0x8008000000000000,
  0x0008000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8006dcba98765432,
  0x0008000000000000,
  0x8007fffffffffffe,
  0x8008000000000000,
  0x8018000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800923456789abcc,
  0x8017fffffffffffe,
  0x8008000000000000,
  0x8008000000000000,
  0x0008000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8006dcba98765433,
  0x0007ffffffffffff,
  0x8007ffffffffffff,
  0x8008000000000000,
  0x8018000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800923456789abcd,
  0x8017ffffffffffff,
  0x8008000000000001,
  0x800fffffffffffff,
  0x0000000000000001,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x800edcba98765432,
  0x0000000000000000,
  0x800ffffffffffffe,
  0x800fffffffffffff,
  0x801fffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x801123456789abcc,
  0x801ffffffffffffe,
  0x8010000000000000,
  0x800fffffffffffff,
  0x0000000000000001,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x800edcba98765432,
  0x0000000000000000,
  0x800ffffffffffffe,
  0x800fffffffffffff,
  0x801fffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x801123456789abcc,
  0x801ffffffffffffe,
  0x8010000000000000,
  0x8010000000000000,
  0x0000000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x800edcba98765433,
  0x8000000000000001,
  0x800fffffffffffff,
  0x8010000000000000,
  0x8020000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x801123456789abcd,
  0x801fffffffffffff,
  0x8010000000000001,
  0x8017fffffffffffe,
  0x8007fffffffffffe,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8016dcba98765432,
  0x8008000000000000,
  0x8017fffffffffffe,
  0x8017fffffffffffe,
  0x8023ffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x801923456789abcc,
  0x8023ffffffffffff,
  0x8018000000000000,
  0x8043ffffffffffff,
  0x8041ffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8043db97530eca85,
  0x8041ffffffffffff,
  0x8043ffffffffffff,
  0x8043ffffffffffff,
  0x8045ffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x80442468acf13578,
  0x8045ffffffffffff,
  0x8043ffffffffffff,
  0xc00ffffffffffffd,
  0xc00ffffffffffffd,
  0xc00bfffffffffffd,
  0xc00bfffffffffffd,
  0xc00bfffffffffffd,
  0xc007fffffffffffd,
  0xc007fffffffffffd,
  0xc007fffffffffffd,
  0xc003fffffffffffd,
  0x4018000000000001,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc00ffffffffffffd,
  0xc00ffffffffffffd,
  0xc00ffffffffffffd,
  0xc00ffffffffffffd,
  0xc00ffffffffffffd,
  0xc011fffffffffffe,
  0xc011ffffffffffff,
  0xc011ffffffffffff,
  0xc013fffffffffffe,
  0xc013ffffffffffff,
  0xc013ffffffffffff,
  0xc015ffffffffffff,
  0xc02bffffffffffff,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc00ffffffffffffd,
  0xc00ffffffffffffd,
  0xc00ffffffffffffd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abce,
  0x0010000000000000,
  0x0000000000000002,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcc,
  0x800ffffffffffffe,
  0x8000000000000000,
  0x0000000000000001,
  0x0010000000000001,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abce,
  0x0010000000000000,
  0x0000000000000002,
  0x0000000000000001,
  0x800fffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcc,
  0x800ffffffffffffe,
  0x8000000000000000,
  0x0000000000000001,
  0x0010000000000001,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abce,
  0x0010000000000000,
  0x0000000000000002,
  0x0000000000000001,
  0x800fffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcc,
  0x800ffffffffffffe,
  0x8000000000000000,
  0x0000000000000001,
  0x0010000000000001,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abce,
  0x0010000000000000,
  0x0000000000000002,
  0x0000000000000001,
  0x800fffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcc,
  0x800ffffffffffffe,
  0x0000000000000000,
  0x0000000000000001,
  0x0010000000000001,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abce,
  0x0010000000000000,
  0x0000000000000002,
  0x0000000000000001,
  0x800fffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcc,
  0x800ffffffffffffe,
  0x0000000000000000,
  0x0000000000000002,
  0x0010000000000002,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abce,
  0x0010000000000000,
  0x0000000000000002,
  0x0000000000000002,
  0x800ffffffffffffe,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcc,
  0x800ffffffffffffe,
  0x0000000000000000,
  0x000000000000000a,
  0x001000000000000a,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abd7,
  0x0010000000000009,
  0x000000000000000b,
  0x000000000000000a,
  0x800ffffffffffff6,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abc3,
  0x800ffffffffffff5,
  0x0000000000000009,
  0x3ccfffffffffffff,
  0x3ccfffffffffffff,
  0x3fe0000000000007,
  0x3fe0000000000008,
  0x3fe0000000000009,
  0x3ff0000000000003,
  0x3ff0000000000004,
  0x3ff0000000000005,
  0x3ff8000000000004,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3ccfffffffffffff,
  0x3ccfffffffffffff,
  0x3ccfffffffffffff,
  0x3ccfffffffffffff,
  0x3ccfffffffffffff,
  0xbfdfffffffffffef,
  0xbfdffffffffffff0,
  0xbfdffffffffffff2,
  0xbfeffffffffffff7,
  0xbfeffffffffffff8,
  0xbfeffffffffffffa,
  0xbff7fffffffffffc,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3ccfffffffffffff,
  0x3ccfffffffffffff,
  0x3ccfffffffffffff,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcc,
  0x000ffffffffffffe,
  0x0000000000000000,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abce,
  0x8010000000000000,
  0x8000000000000002,
  0x8000000000000001,
  0x000fffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcc,
  0x000ffffffffffffe,
  0x0000000000000000,
  0x8000000000000001,
  0x8010000000000001,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abce,
  0x8010000000000000,
  0x8000000000000002,
  0x8000000000000001,
  0x000fffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcc,
  0x000ffffffffffffe,
  0x0000000000000000,
  0x8000000000000001,
  0x8010000000000001,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abce,
  0x8010000000000000,
  0x8000000000000002,
  0x8000000000000001,
  0x000fffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcc,
  0x000ffffffffffffe,
  0x0000000000000000,
  0x8000000000000001,
  0x8010000000000001,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abce,
  0x8010000000000000,
  0x8000000000000002,
  0x8000000000000001,
  0x000fffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcc,
  0x000ffffffffffffe,
  0x8000000000000000,
  0x8000000000000001,
  0x8010000000000001,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abce,
  0x8010000000000000,
  0x8000000000000002,
  0x8000000000000002,
  0x000ffffffffffffe,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcc,
  0x000ffffffffffffe,
  0x8000000000000000,
  0x8000000000000002,
  0x8010000000000002,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abce,
  0x8010000000000000,
  0x8000000000000002,
  0x800000000000000a,
  0x000ffffffffffff6,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abc3,
  0x000ffffffffffff5,
  0x8000000000000009,
  0x800000000000000a,
  0x801000000000000a,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abd7,
  0x8010000000000009,
  0x800000000000000b,
  0xbccfffffffffffff,
  0xbccfffffffffffff,
  0x3fdfffffffffffef,
  0x3fdffffffffffff0,
  0x3fdffffffffffff2,
  0x3feffffffffffff7,
  0x3feffffffffffff8,
  0x3feffffffffffffa,
  0x3ff7fffffffffffc,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbccfffffffffffff,
  0xbccfffffffffffff,
  0xbccfffffffffffff,
  0xbccfffffffffffff,
  0xbccfffffffffffff,
  0xbfe0000000000007,
  0xbfe0000000000008,
  0xbfe0000000000009,
  0xbff0000000000003,
  0xbff0000000000004,
  0xbff0000000000005,
  0xbff8000000000004,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbccfffffffffffff,
  0xbccfffffffffffff,
  0xbccfffffffffffff,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8008000000000000,
  0x0008000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8006dcba98765433,
  0x0007ffffffffffff,
  0x8007ffffffffffff,
  0x8008000000000000,
  0x8018000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800923456789abcd,
  0x8017ffffffffffff,
  0x8008000000000001,
  0x8008000000000000,
  0x0008000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8006dcba98765433,
  0x0007ffffffffffff,
  0x8007ffffffffffff,
  0x8008000000000000,
  0x8018000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800923456789abcd,
  0x8017ffffffffffff,
  0x8008000000000001,
  0x8008000000000000,
  0x0008000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8006dcba98765434,
  0x0007fffffffffffe,
  0x8008000000000000,
  0x8008000000000000,
  0x8018000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800923456789abce,
  0x8018000000000000,
  0x8008000000000002,
  0x8010000000000000,
  0x0000000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x800edcba98765432,
  0x8000000000000000,
  0x800ffffffffffffe,
  0x8010000000000000,
  0x8020000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x801123456789abcc,
  0x801ffffffffffffe,
  0x8010000000000000,
  0x8010000000000000,
  0x0000000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x800edcba98765433,
  0x8000000000000001,
  0x800fffffffffffff,
  0x8010000000000000,
  0x8020000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x801123456789abcd,
  0x801fffffffffffff,
  0x8010000000000001,
  0x8010000000000001,
  0x8000000000000001,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x800edcba98765434,
  0x8000000000000002,
  0x8010000000000000,
  0x8010000000000001,
  0x8020000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x801123456789abce,
  0x8020000000000000,
  0x8010000000000002,
  0x8018000000000000,
  0x8008000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8016dcba98765433,
  0x8008000000000001,
  0x8017ffffffffffff,
  0x8018000000000000,
  0x8024000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x801923456789abcd,
  0x8024000000000000,
  0x8018000000000001,
  0x8044000000000000,
  0x8042000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8043db97530eca86,
  0x8042000000000000,
  0x8044000000000000,
  0x8044000000000000,
  0x8046000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x80442468acf1357a,
  0x8046000000000000,
  0x8044000000000000,
  0xc00fffffffffffff,
  0xc00fffffffffffff,
  0xc00bffffffffffff,
  0xc00bffffffffffff,
  0xc00bffffffffffff,
  0xc007ffffffffffff,
  0xc007ffffffffffff,
  0xc007fffffffffffe,
  0xc003ffffffffffff,
  0x4018000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc00fffffffffffff,
  0xc00fffffffffffff,
  0xc00fffffffffffff,
  0xc00fffffffffffff,
  0xc00fffffffffffff,
  0xc011ffffffffffff,
  0xc012000000000000,
  0xc012000000000000,
  0xc013ffffffffffff,
  0xc014000000000000,
  0xc014000000000000,
  0xc016000000000000,
  0xc02c000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc00fffffffffffff,
  0xc00fffffffffffff,
  0xc00fffffffffffff,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0008000000000000,
  0x0018000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000923456789abcd,
  0x0017ffffffffffff,
  0x0008000000000001,
  0x0008000000000000,
  0x8008000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0006dcba98765433,
  0x8007ffffffffffff,
  0x0007ffffffffffff,
  0x0008000000000000,
  0x0018000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000923456789abcd,
  0x0017ffffffffffff,
  0x0008000000000001,
  0x0008000000000000,
  0x8008000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0006dcba98765433,
  0x8007ffffffffffff,
  0x0007ffffffffffff,
  0x0008000000000000,
  0x0018000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000923456789abce,
  0x0018000000000000,
  0x0008000000000002,
  0x0008000000000000,
  0x8008000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0006dcba98765434,
  0x8007fffffffffffe,
  0x0008000000000000,
  0x0010000000000000,
  0x0020000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x001123456789abcc,
  0x001ffffffffffffe,
  0x0010000000000000,
  0x0010000000000000,
  0x8000000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x000edcba98765432,
  0x0000000000000000,
  0x000ffffffffffffe,
  0x0010000000000000,
  0x0020000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x001123456789abcd,
  0x001fffffffffffff,
  0x0010000000000001,
  0x0010000000000000,
  0x0000000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x000edcba98765433,
  0x0000000000000001,
  0x000fffffffffffff,
  0x0010000000000001,
  0x0020000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x001123456789abce,
  0x0020000000000000,
  0x0010000000000002,
  0x0010000000000001,
  0x0000000000000001,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x000edcba98765434,
  0x0000000000000002,
  0x0010000000000000,
  0x0018000000000000,
  0x0024000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x001923456789abcd,
  0x0024000000000000,
  0x0018000000000001,
  0x0018000000000000,
  0x0008000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0016dcba98765433,
  0x0008000000000001,
  0x0017ffffffffffff,
  0x0044000000000000,
  0x0046000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x00442468acf1357a,
  0x0046000000000000,
  0x0044000000000000,
  0x0044000000000000,
  0x0042000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0043db97530eca86,
  0x0042000000000000,
  0x0044000000000000,
  0x400fffffffffffff,
  0x400fffffffffffff,
  0x4011ffffffffffff,
  0x4012000000000000,
  0x4012000000000000,
  0x4013ffffffffffff,
  0x4014000000000000,
  0x4014000000000000,
  0x4016000000000000,
  0x402c000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x400fffffffffffff,
  0x400fffffffffffff,
  0x400fffffffffffff,
  0x400fffffffffffff,
  0x400fffffffffffff,
  0x400bffffffffffff,
  0x400bffffffffffff,
  0x400bffffffffffff,
  0x4007ffffffffffff,
  0x4007ffffffffffff,
  0x4007fffffffffffe,
  0x4003ffffffffffff,
  0xc018000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x400fffffffffffff,
  0x400fffffffffffff,
  0x400fffffffffffff,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8008000000000000,
  0x0008000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8006dcba98765433,
  0x0007ffffffffffff,
  0x8007ffffffffffff,
  0x8008000000000000,
  0x8018000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800923456789abcd,
  0x8017ffffffffffff,
  0x8008000000000001,
  0xbfcffffffffffffe,
  0xbfcffffffffffffe,
  0x3fd0000000000000,
  0x3fd0000000000001,
  0x3fd0000000000003,
  0x3fe7ffffffffffff,
  0x3fe8000000000000,
  0x3fe8000000000002,
  0x3ff4000000000000,
  0x4023800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfcffffffffffffe,
  0xbfcffffffffffffe,
  0xbfcffffffffffffe,
  0xbfcffffffffffffe,
  0xbfcffffffffffffe,
  0xbfe7ffffffffffff,
  0xbfe8000000000000,
  0xbfe8000000000001,
  0xbff3ffffffffffff,
  0xbff4000000000000,
  0xbff4000000000001,
  0xbffc000000000000,
  0xc024800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfcffffffffffffe,
  0xbfcffffffffffffe,
  0xbfcffffffffffffe,
  0xbfcfffffffffffff,
  0xbfcfffffffffffff,
  0x3fcfffffffffffff,
  0x3fd0000000000000,
  0x3fd0000000000002,
  0x3fe7ffffffffffff,
  0x3fe8000000000000,
  0x3fe8000000000002,
  0x3ff4000000000000,
  0x4023800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfcfffffffffffff,
  0xbfcfffffffffffff,
  0xbfcfffffffffffff,
  0xbfcfffffffffffff,
  0xbfcfffffffffffff,
  0xbfe7ffffffffffff,
  0xbfe8000000000000,
  0xbfe8000000000001,
  0xbff3ffffffffffff,
  0xbff4000000000000,
  0xbff4000000000001,
  0xbffc000000000000,
  0xc024800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfcfffffffffffff,
  0xbfcfffffffffffff,
  0xbfcfffffffffffff,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0x3fcffffffffffffd,
  0x3fcfffffffffffff,
  0x3fd0000000000002,
  0x3fe7ffffffffffff,
  0x3fe8000000000000,
  0x3fe8000000000002,
  0x3ff4000000000000,
  0x4023800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbfe8000000000001,
  0xbff4000000000000,
  0xbff4000000000000,
  0xbff4000000000001,
  0xbffc000000000000,
  0xc024800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfdffffffffffffe,
  0xbfdffffffffffffe,
  0x3c8fffffffffffff,
  0x3ca0000000000000,
  0x3cb0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000003,
  0x3ff0000000000000,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfdffffffffffffe,
  0xbfdffffffffffffe,
  0xbfdffffffffffffe,
  0xbfdffffffffffffe,
  0xbfdffffffffffffe,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff7ffffffffffff,
  0xbff8000000000000,
  0xbff8000000000001,
  0xc000000000000000,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfdffffffffffffe,
  0xbfdffffffffffffe,
  0xbfdffffffffffffe,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0x0000000000000000,
  0x3c90000000000000,
  0x3ca8000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000002,
  0x3ff0000000000000,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff7ffffffffffff,
  0xbff8000000000000,
  0xbff8000000000001,
  0xc000000000000000,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbc9fffffffffffff,
  0xbc8ffffffffffffe,
  0x3c90000000000001,
  0x3fdffffffffffffd,
  0x3fdfffffffffffff,
  0x3fe0000000000002,
  0x3ff0000000000000,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000001,
  0xc000000000000000,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe7ffffffffffff,
  0xbfe7ffffffffffff,
  0xbfcfffffffffffff,
  0xbfcffffffffffffd,
  0xbfcffffffffffff9,
  0x3fcfffffffffffff,
  0x3fd0000000000002,
  0x3fd0000000000006,
  0x3fe8000000000001,
  0x4022800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe7ffffffffffff,
  0xbfe7ffffffffffff,
  0xbfe7ffffffffffff,
  0xbfe7ffffffffffff,
  0xbfe7ffffffffffff,
  0xbff3ffffffffffff,
  0xbff4000000000000,
  0xbff4000000000000,
  0xbffbffffffffffff,
  0xbffc000000000000,
  0xbffc000000000001,
  0xc002000000000000,
  0xc025800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe7ffffffffffff,
  0xbfe7ffffffffffff,
  0xbfe7ffffffffffff,
  0xc013ffffffffffff,
  0xc013ffffffffffff,
  0xc011ffffffffffff,
  0xc011ffffffffffff,
  0xc011ffffffffffff,
  0xc00fffffffffffff,
  0xc00fffffffffffff,
  0xc00ffffffffffffe,
  0xc00bffffffffffff,
  0x4014000000000001,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc013ffffffffffff,
  0xc013ffffffffffff,
  0xc013ffffffffffff,
  0xc013ffffffffffff,
  0xc013ffffffffffff,
  0xc015ffffffffffff,
  0xc015ffffffffffff,
  0xc016000000000000,
  0xc017ffffffffffff,
  0xc017ffffffffffff,
  0xc018000000000000,
  0xc019ffffffffffff,
  0xc02e000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc013ffffffffffff,
  0xc013ffffffffffff,
  0xc013ffffffffffff,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0x7fe0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x800091a2b3c4d5e6,
  0x000f6e5d4c3b2a1a,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000091a2b3c4d5e7,
  0x000f6e5d4c3b2a19,
  0x800091a2b3c4d5e5,
  0x800091a2b3c4d5e6,
  0x801091a2b3c4d5e6,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x8001b4e81b4e81b3,
  0x801091a2b3c4d5e5,
  0x800091a2b3c4d5e7,
  0x8007ffffffffffff,
  0x0008000000000001,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8006dcba98765432,
  0x0008000000000000,
  0x8007fffffffffffe,
  0x8007ffffffffffff,
  0x8017ffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800923456789abcc,
  0x8017fffffffffffe,
  0x8008000000000000,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0008000000000000,
  0x0018000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000923456789abcd,
  0x0017ffffffffffff,
  0x0008000000000001,
  0x0008000000000000,
  0x8008000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0006dcba98765433,
  0x8007ffffffffffff,
  0x0007ffffffffffff,
  0x3fcffffffffffffe,
  0x3fcffffffffffffe,
  0x3fe7ffffffffffff,
  0x3fe8000000000000,
  0x3fe8000000000001,
  0x3ff3ffffffffffff,
  0x3ff4000000000000,
  0x3ff4000000000001,
  0x3ffc000000000000,
  0x4024800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fcffffffffffffe,
  0x3fcffffffffffffe,
  0x3fcffffffffffffe,
  0x3fcffffffffffffe,
  0x3fcffffffffffffe,
  0xbfd0000000000000,
  0xbfd0000000000001,
  0xbfd0000000000003,
  0xbfe7ffffffffffff,
  0xbfe8000000000000,
  0xbfe8000000000002,
  0xbff4000000000000,
  0xc023800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fcffffffffffffe,
  0x3fcffffffffffffe,
  0x3fcffffffffffffe,
  0x3fcfffffffffffff,
  0x3fcfffffffffffff,
  0x3fe7ffffffffffff,
  0x3fe8000000000000,
  0x3fe8000000000001,
  0x3ff3ffffffffffff,
  0x3ff4000000000000,
  0x3ff4000000000001,
  0x3ffc000000000000,
  0x4024800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fcfffffffffffff,
  0x3fcfffffffffffff,
  0x3fcfffffffffffff,
  0x3fcfffffffffffff,
  0x3fcfffffffffffff,
  0xbfcfffffffffffff,
  0xbfd0000000000000,
  0xbfd0000000000002,
  0xbfe7ffffffffffff,
  0xbfe8000000000000,
  0xbfe8000000000002,
  0xbff4000000000000,
  0xc023800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fcfffffffffffff,
  0x3fcfffffffffffff,
  0x3fcfffffffffffff,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3fe8000000000001,
  0x3ff4000000000000,
  0x3ff4000000000000,
  0x3ff4000000000001,
  0x3ffc000000000000,
  0x4024800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0xbfcffffffffffffd,
  0xbfcfffffffffffff,
  0xbfd0000000000002,
  0xbfe7ffffffffffff,
  0xbfe8000000000000,
  0xbfe8000000000002,
  0xbff4000000000000,
  0xc023800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fdffffffffffffe,
  0x3fdffffffffffffe,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff7ffffffffffff,
  0x3ff8000000000000,
  0x3ff8000000000001,
  0x4000000000000000,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fdffffffffffffe,
  0x3fdffffffffffffe,
  0x3fdffffffffffffe,
  0x3fdffffffffffffe,
  0x3fdffffffffffffe,
  0xbc8fffffffffffff,
  0xbca0000000000000,
  0xbcb0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000003,
  0xbff0000000000000,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fdffffffffffffe,
  0x3fdffffffffffffe,
  0x3fdffffffffffffe,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff7ffffffffffff,
  0x3ff8000000000000,
  0x3ff8000000000001,
  0x4000000000000000,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x0000000000000000,
  0xbc90000000000000,
  0xbca8000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000002,
  0xbff0000000000000,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000001,
  0x4000000000000000,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3c9fffffffffffff,
  0x3c8ffffffffffffe,
  0xbc90000000000001,
  0xbfdffffffffffffd,
  0xbfdfffffffffffff,
  0xbfe0000000000002,
  0xbff0000000000000,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe7ffffffffffff,
  0x3fe7ffffffffffff,
  0x3ff3ffffffffffff,
  0x3ff4000000000000,
  0x3ff4000000000000,
  0x3ffbffffffffffff,
  0x3ffc000000000000,
  0x3ffc000000000001,
  0x4002000000000000,
  0x4025800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe7ffffffffffff,
  0x3fe7ffffffffffff,
  0x3fe7ffffffffffff,
  0x3fe7ffffffffffff,
  0x3fe7ffffffffffff,
  0x3fcfffffffffffff,
  0x3fcffffffffffffd,
  0x3fcffffffffffff9,
  0xbfcfffffffffffff,
  0xbfd0000000000002,
  0xbfd0000000000006,
  0xbfe8000000000001,
  0xc022800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe7ffffffffffff,
  0x3fe7ffffffffffff,
  0x3fe7ffffffffffff,
  0x4013ffffffffffff,
  0x4013ffffffffffff,
  0x4015ffffffffffff,
  0x4015ffffffffffff,
  0x4016000000000000,
  0x4017ffffffffffff,
  0x4017ffffffffffff,
  0x4018000000000000,
  0x4019ffffffffffff,
  0x402e000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x4013ffffffffffff,
  0x4013ffffffffffff,
  0x4013ffffffffffff,
  0x4013ffffffffffff,
  0x4013ffffffffffff,
  0x4011ffffffffffff,
  0x4011ffffffffffff,
  0x4011ffffffffffff,
  0x400fffffffffffff,
  0x400fffffffffffff,
  0x400ffffffffffffe,
  0x400bffffffffffff,
  0xc014000000000001,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x4013ffffffffffff,
  0x4013ffffffffffff,
  0x4013ffffffffffff,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0xffe0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x000091a2b3c4d5e6,
  0x001091a2b3c4d5e6,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0001b4e81b4e81b3,
  0x001091a2b3c4d5e5,
  0x000091a2b3c4d5e7,
  0x000091a2b3c4d5e6,
  0x800f6e5d4c3b2a1a,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800091a2b3c4d5e7,
  0x800f6e5d4c3b2a19,
  0x000091a2b3c4d5e5,
  0x0007ffffffffffff,
  0x0017ffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000923456789abcc,
  0x0017fffffffffffe,
  0x0008000000000000,
  0x0007ffffffffffff,
  0x8008000000000001,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0006dcba98765432,
  0x8008000000000000,
  0x0007fffffffffffe,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8008000000000000,
  0x0008000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8006dcba98765433,
  0x0007ffffffffffff,
  0x8007ffffffffffff,
  0x8008000000000000,
  0x8018000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800923456789abcd,
  0x8017ffffffffffff,
  0x8008000000000001,
  0xbfcfffffffffffff,
  0xbfcfffffffffffff,
  0x3fcfffffffffffff,
  0x3fd0000000000000,
  0x3fd0000000000002,
  0x3fe7ffffffffffff,
  0x3fe8000000000000,
  0x3fe8000000000002,
  0x3ff4000000000000,
  0x4023800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfcfffffffffffff,
  0xbfcfffffffffffff,
  0xbfcfffffffffffff,
  0xbfcfffffffffffff,
  0xbfcfffffffffffff,
  0xbfe7ffffffffffff,
  0xbfe8000000000000,
  0xbfe8000000000001,
  0xbff3ffffffffffff,
  0xbff4000000000000,
  0xbff4000000000001,
  0xbffc000000000000,
  0xc024800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfcfffffffffffff,
  0xbfcfffffffffffff,
  0xbfcfffffffffffff,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0x3fcffffffffffffe,
  0x3fd0000000000000,
  0x3fd0000000000002,
  0x3fe7ffffffffffff,
  0x3fe8000000000000,
  0x3fe8000000000002,
  0x3ff4000000000000,
  0x4023800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbfe8000000000001,
  0xbff4000000000000,
  0xbff4000000000000,
  0xbff4000000000001,
  0xbffc000000000000,
  0xc024800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000001,
  0xbfd0000000000001,
  0x3fcffffffffffffc,
  0x3fcffffffffffffe,
  0x3fd0000000000001,
  0x3fe7fffffffffffe,
  0x3fe8000000000000,
  0x3fe8000000000002,
  0x3ff4000000000000,
  0x4023800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfd0000000000001,
  0xbfd0000000000001,
  0xbfd0000000000001,
  0xbfd0000000000001,
  0xbfd0000000000001,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbfe8000000000002,
  0xbff4000000000000,
  0xbff4000000000000,
  0xbff4000000000001,
  0xbffc000000000000,
  0xc024800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfd0000000000001,
  0xbfd0000000000001,
  0xbfd0000000000001,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0x0000000000000000,
  0x3c90000000000000,
  0x3ca8000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000002,
  0x3ff0000000000000,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff7ffffffffffff,
  0xbff8000000000000,
  0xbff8000000000001,
  0xc000000000000000,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbc90000000000000,
  0x0000000000000000,
  0x3ca0000000000000,
  0x3fdffffffffffffe,
  0x3fe0000000000000,
  0x3fe0000000000002,
  0x3ff0000000000000,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000001,
  0xc000000000000000,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbca8000000000000,
  0xbca0000000000000,
  0x0000000000000000,
  0x3fdffffffffffffc,
  0x3fdffffffffffffe,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000002,
  0xc000000000000000,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbfd0000000000001,
  0xbfd0000000000000,
  0xbfcffffffffffffc,
  0x3fcffffffffffffc,
  0x3fd0000000000000,
  0x3fd0000000000004,
  0x3fe8000000000000,
  0x4022800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbff4000000000000,
  0xbff4000000000000,
  0xbff4000000000000,
  0xbffc000000000000,
  0xbffc000000000000,
  0xbffc000000000001,
  0xc002000000000000,
  0xc025800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xc014000000000000,
  0xc014000000000000,
  0xc012000000000000,
  0xc012000000000000,
  0xc012000000000000,
  0xc010000000000000,
  0xc010000000000000,
  0xc010000000000000,
  0xc00c000000000000,
  0x4014000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc014000000000000,
  0xc014000000000000,
  0xc014000000000000,
  0xc014000000000000,
  0xc014000000000000,
  0xc016000000000000,
  0xc016000000000000,
  0xc016000000000000,
  0xc018000000000000,
  0xc018000000000000,
  0xc018000000000000,
  0xc01a000000000000,
  0xc02e000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc014000000000000,
  0xc014000000000000,
  0xc014000000000000,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0x7fdfffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x800091a2b3c4d5e6,
  0x000f6e5d4c3b2a1a,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000091a2b3c4d5e6,
  0x000f6e5d4c3b2a18,
  0x800091a2b3c4d5e6,
  0x800091a2b3c4d5e6,
  0x801091a2b3c4d5e6,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x8001b4e81b4e81b4,
  0x801091a2b3c4d5e6,
  0x800091a2b3c4d5e8,
  0x8008000000000000,
  0x0008000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8006dcba98765432,
  0x0008000000000000,
  0x8007fffffffffffe,
  0x8008000000000000,
  0x8018000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800923456789abcc,
  0x8017fffffffffffe,
  0x8008000000000000,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcc,
  0x000ffffffffffffe,
  0x0000000000000000,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abce,
  0x8010000000000000,
  0x8000000000000002,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0008000000000000,
  0x0018000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000923456789abcd,
  0x0017ffffffffffff,
  0x0008000000000001,
  0x0008000000000000,
  0x8008000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0006dcba98765433,
  0x8007ffffffffffff,
  0x0007ffffffffffff,
  0x3fcfffffffffffff,
  0x3fcfffffffffffff,
  0x3fe7ffffffffffff,
  0x3fe8000000000000,
  0x3fe8000000000001,
  0x3ff3ffffffffffff,
  0x3ff4000000000000,
  0x3ff4000000000001,
  0x3ffc000000000000,
  0x4024800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fcfffffffffffff,
  0x3fcfffffffffffff,
  0x3fcfffffffffffff,
  0x3fcfffffffffffff,
  0x3fcfffffffffffff,
  0xbfcfffffffffffff,
  0xbfd0000000000000,
  0xbfd0000000000002,
  0xbfe7ffffffffffff,
  0xbfe8000000000000,
  0xbfe8000000000002,
  0xbff4000000000000,
  0xc023800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fcfffffffffffff,
  0x3fcfffffffffffff,
  0x3fcfffffffffffff,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3fe8000000000001,
  0x3ff4000000000000,
  0x3ff4000000000000,
  0x3ff4000000000001,
  0x3ffc000000000000,
  0x4024800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0xbfcffffffffffffe,
  0xbfd0000000000000,
  0xbfd0000000000002,
  0xbfe7ffffffffffff,
  0xbfe8000000000000,
  0xbfe8000000000002,
  0xbff4000000000000,
  0xc023800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000001,
  0x3fd0000000000001,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3fe8000000000002,
  0x3ff4000000000000,
  0x3ff4000000000000,
  0x3ff4000000000001,
  0x3ffc000000000000,
  0x4024800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fd0000000000001,
  0x3fd0000000000001,
  0x3fd0000000000001,
  0x3fd0000000000001,
  0x3fd0000000000001,
  0xbfcffffffffffffc,
  0xbfcffffffffffffe,
  0xbfd0000000000001,
  0xbfe7fffffffffffe,
  0xbfe8000000000000,
  0xbfe8000000000002,
  0xbff4000000000000,
  0xc023800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fd0000000000001,
  0x3fd0000000000001,
  0x3fd0000000000001,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff7ffffffffffff,
  0x3ff8000000000000,
  0x3ff8000000000001,
  0x4000000000000000,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x0000000000000000,
  0xbc90000000000000,
  0xbca8000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000002,
  0xbff0000000000000,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000001,
  0x4000000000000000,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3c90000000000000,
  0x0000000000000000,
  0xbca0000000000000,
  0xbfdffffffffffffe,
  0xbfe0000000000000,
  0xbfe0000000000002,
  0xbff0000000000000,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000002,
  0x4000000000000000,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3ca8000000000000,
  0x3ca0000000000000,
  0x0000000000000000,
  0xbfdffffffffffffc,
  0xbfdffffffffffffe,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3ff4000000000000,
  0x3ff4000000000000,
  0x3ff4000000000000,
  0x3ffc000000000000,
  0x3ffc000000000000,
  0x3ffc000000000001,
  0x4002000000000000,
  0x4025800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3fd0000000000001,
  0x3fd0000000000000,
  0x3fcffffffffffffc,
  0xbfcffffffffffffc,
  0xbfd0000000000000,
  0xbfd0000000000004,
  0xbfe8000000000000,
  0xc022800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x4014000000000000,
  0x4014000000000000,
  0x4016000000000000,
  0x4016000000000000,
  0x4016000000000000,
  0x4018000000000000,
  0x4018000000000000,
  0x4018000000000000,
  0x401a000000000000,
  0x402e000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x4014000000000000,
  0x4014000000000000,
  0x4014000000000000,
  0x4014000000000000,
  0x4014000000000000,
  0x4012000000000000,
  0x4012000000000000,
  0x4012000000000000,
  0x4010000000000000,
  0x4010000000000000,
  0x4010000000000000,
  0x400c000000000000,
  0xc014000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x4014000000000000,
  0x4014000000000000,
  0x4014000000000000,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0xffdfffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x000091a2b3c4d5e6,
  0x001091a2b3c4d5e6,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0001b4e81b4e81b4,
  0x001091a2b3c4d5e6,
  0x000091a2b3c4d5e8,
  0x000091a2b3c4d5e6,
  0x800f6e5d4c3b2a1a,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800091a2b3c4d5e6,
  0x800f6e5d4c3b2a18,
  0x000091a2b3c4d5e6,
  0x0008000000000000,
  0x0018000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000923456789abcc,
  0x0017fffffffffffe,
  0x0008000000000000,
  0x0008000000000000,
  0x8008000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0006dcba98765432,
  0x8008000000000000,
  0x0007fffffffffffe,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abce,
  0x0010000000000000,
  0x0000000000000002,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcc,
  0x800ffffffffffffe,
  0x8000000000000000,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8008000000000000,
  0x0008000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8006dcba98765434,
  0x0007fffffffffffe,
  0x8008000000000000,
  0x8008000000000000,
  0x8018000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800923456789abce,
  0x8018000000000000,
  0x8008000000000002,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0x3fcffffffffffffd,
  0x3fcfffffffffffff,
  0x3fd0000000000002,
  0x3fe7ffffffffffff,
  0x3fe8000000000000,
  0x3fe8000000000002,
  0x3ff4000000000000,
  0x4023800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbfe8000000000001,
  0xbff4000000000000,
  0xbff4000000000000,
  0xbff4000000000001,
  0xbffc000000000000,
  0xc024800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000001,
  0xbfd0000000000001,
  0x3fcffffffffffffc,
  0x3fcffffffffffffe,
  0x3fd0000000000001,
  0x3fe7fffffffffffe,
  0x3fe8000000000000,
  0x3fe8000000000002,
  0x3ff4000000000000,
  0x4023800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfd0000000000001,
  0xbfd0000000000001,
  0xbfd0000000000001,
  0xbfd0000000000001,
  0xbfd0000000000001,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbfe8000000000002,
  0xbff4000000000000,
  0xbff4000000000000,
  0xbff4000000000001,
  0xbffc000000000000,
  0xc024800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfd0000000000001,
  0xbfd0000000000001,
  0xbfd0000000000001,
  0xbfd0000000000002,
  0xbfd0000000000002,
  0x3fcffffffffffffa,
  0x3fcffffffffffffc,
  0x3fd0000000000000,
  0x3fe7fffffffffffe,
  0x3fe7ffffffffffff,
  0x3fe8000000000001,
  0x3ff3ffffffffffff,
  0x4023800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfd0000000000002,
  0xbfd0000000000002,
  0xbfd0000000000002,
  0xbfd0000000000002,
  0xbfd0000000000002,
  0xbfe8000000000001,
  0xbfe8000000000001,
  0xbfe8000000000002,
  0xbff4000000000000,
  0xbff4000000000001,
  0xbff4000000000002,
  0xbffc000000000001,
  0xc024800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfd0000000000002,
  0xbfd0000000000002,
  0xbfd0000000000002,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbc9fffffffffffff,
  0xbc8ffffffffffffe,
  0x3c90000000000001,
  0x3fdffffffffffffd,
  0x3fdfffffffffffff,
  0x3fe0000000000002,
  0x3ff0000000000000,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000001,
  0xc000000000000000,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbca8000000000000,
  0xbca0000000000000,
  0x0000000000000000,
  0x3fdffffffffffffc,
  0x3fdffffffffffffe,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000002,
  0xc000000000000000,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000002,
  0xbfe0000000000002,
  0xbcb4000000000000,
  0xbcb0000000000000,
  0xbca0000000000001,
  0x3fdffffffffffffa,
  0x3fdffffffffffffc,
  0x3fe0000000000000,
  0x3feffffffffffffe,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe0000000000002,
  0xbfe0000000000002,
  0xbfe0000000000002,
  0xbfe0000000000002,
  0xbfe0000000000002,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000002,
  0xbff8000000000001,
  0xbff8000000000001,
  0xbff8000000000002,
  0xc000000000000001,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe0000000000002,
  0xbfe0000000000002,
  0xbfe0000000000002,
  0xbfe8000000000002,
  0xbfe8000000000001,
  0xbfd0000000000004,
  0xbfd0000000000003,
  0xbfd0000000000001,
  0x3fcffffffffffff6,
  0x3fcffffffffffffa,
  0x3fd0000000000001,
  0x3fe7fffffffffffe,
  0x4022800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe8000000000001,
  0xbfe8000000000001,
  0xbfe8000000000001,
  0xbfe8000000000002,
  0xbfe8000000000002,
  0xbff4000000000000,
  0xbff4000000000001,
  0xbff4000000000001,
  0xbffc000000000000,
  0xbffc000000000001,
  0xbffc000000000002,
  0xc002000000000000,
  0xc025800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe8000000000002,
  0xbfe8000000000002,
  0xbfe8000000000002,
  0xc014000000000001,
  0xc014000000000001,
  0xc012000000000001,
  0xc012000000000001,
  0xc012000000000001,
  0xc010000000000001,
  0xc010000000000001,
  0xc010000000000001,
  0xc00c000000000002,
  0x4013ffffffffffff,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc014000000000001,
  0xc014000000000001,
  0xc014000000000001,
  0xc014000000000001,
  0xc014000000000001,
  0xc016000000000001,
  0xc016000000000001,
  0xc016000000000001,
  0xc018000000000001,
  0xc018000000000001,
  0xc018000000000002,
  0xc01a000000000001,
  0xc02e000000000001,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc014000000000001,
  0xc014000000000001,
  0xc014000000000001,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0x7fdffffffffffffd,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x800091a2b3c4d5e7,
  0x000f6e5d4c3b2a19,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000091a2b3c4d5e6,
  0x000f6e5d4c3b2a18,
  0x800091a2b3c4d5e6,
  0x800091a2b3c4d5e7,
  0x801091a2b3c4d5e7,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x8001b4e81b4e81b4,
  0x801091a2b3c4d5e6,
  0x800091a2b3c4d5e8,
  0x8008000000000000,
  0x0008000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8006dcba98765433,
  0x0007ffffffffffff,
  0x8007ffffffffffff,
  0x8008000000000000,
  0x8018000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800923456789abcd,
  0x8017ffffffffffff,
  0x8008000000000001,
  0x8000000000000001,
  0x000fffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcc,
  0x000ffffffffffffe,
  0x0000000000000000,
  0x8000000000000001,
  0x8010000000000001,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abce,
  0x8010000000000000,
  0x8000000000000002,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0008000000000000,
  0x0018000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000923456789abce,
  0x0018000000000000,
  0x0008000000000002,
  0x0008000000000000,
  0x8008000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0006dcba98765434,
  0x8007fffffffffffe,
  0x0008000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3fe8000000000001,
  0x3ff4000000000000,
  0x3ff4000000000000,
  0x3ff4000000000001,
  0x3ffc000000000000,
  0x4024800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0xbfcffffffffffffd,
  0xbfcfffffffffffff,
  0xbfd0000000000002,
  0xbfe7ffffffffffff,
  0xbfe8000000000000,
  0xbfe8000000000002,
  0xbff4000000000000,
  0xc023800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000001,
  0x3fd0000000000001,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3fe8000000000002,
  0x3ff4000000000000,
  0x3ff4000000000000,
  0x3ff4000000000001,
  0x3ffc000000000000,
  0x4024800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fd0000000000001,
  0x3fd0000000000001,
  0x3fd0000000000001,
  0x3fd0000000000001,
  0x3fd0000000000001,
  0xbfcffffffffffffc,
  0xbfcffffffffffffe,
  0xbfd0000000000001,
  0xbfe7fffffffffffe,
  0xbfe8000000000000,
  0xbfe8000000000002,
  0xbff4000000000000,
  0xc023800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fd0000000000001,
  0x3fd0000000000001,
  0x3fd0000000000001,
  0x3fd0000000000002,
  0x3fd0000000000002,
  0x3fe8000000000001,
  0x3fe8000000000001,
  0x3fe8000000000002,
  0x3ff4000000000000,
  0x3ff4000000000001,
  0x3ff4000000000002,
  0x3ffc000000000001,
  0x4024800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fd0000000000002,
  0x3fd0000000000002,
  0x3fd0000000000002,
  0x3fd0000000000002,
  0x3fd0000000000002,
  0xbfcffffffffffffa,
  0xbfcffffffffffffc,
  0xbfd0000000000000,
  0xbfe7fffffffffffe,
  0xbfe7ffffffffffff,
  0xbfe8000000000001,
  0xbff3ffffffffffff,
  0xc023800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fd0000000000002,
  0x3fd0000000000002,
  0x3fd0000000000002,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000001,
  0x4000000000000000,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3c9fffffffffffff,
  0x3c8ffffffffffffe,
  0xbc90000000000001,
  0xbfdffffffffffffd,
  0xbfdfffffffffffff,
  0xbfe0000000000002,
  0xbff0000000000000,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000002,
  0x4000000000000000,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3ca8000000000000,
  0x3ca0000000000000,
  0x0000000000000000,
  0xbfdffffffffffffc,
  0xbfdffffffffffffe,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000002,
  0x3fe0000000000002,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000002,
  0x3ff8000000000001,
  0x3ff8000000000001,
  0x3ff8000000000002,
  0x4000000000000001,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe0000000000002,
  0x3fe0000000000002,
  0x3fe0000000000002,
  0x3fe0000000000002,
  0x3fe0000000000002,
  0x3cb4000000000000,
  0x3cb0000000000000,
  0x3ca0000000000001,
  0xbfdffffffffffffa,
  0xbfdffffffffffffc,
  0xbfe0000000000000,
  0xbfeffffffffffffe,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe0000000000002,
  0x3fe0000000000002,
  0x3fe0000000000002,
  0x3fe8000000000002,
  0x3fe8000000000002,
  0x3ff4000000000000,
  0x3ff4000000000001,
  0x3ff4000000000001,
  0x3ffc000000000000,
  0x3ffc000000000001,
  0x3ffc000000000002,
  0x4002000000000000,
  0x4025800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe8000000000002,
  0x3fe8000000000002,
  0x3fe8000000000002,
  0x3fe8000000000002,
  0x3fe8000000000001,
  0x3fd0000000000004,
  0x3fd0000000000003,
  0x3fd0000000000001,
  0xbfcffffffffffff6,
  0xbfcffffffffffffa,
  0xbfd0000000000001,
  0xbfe7fffffffffffe,
  0xc022800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe8000000000001,
  0x3fe8000000000001,
  0x3fe8000000000001,
  0x4014000000000001,
  0x4014000000000001,
  0x4016000000000001,
  0x4016000000000001,
  0x4016000000000001,
  0x4018000000000001,
  0x4018000000000001,
  0x4018000000000002,
  0x401a000000000001,
  0x402e000000000001,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x4014000000000001,
  0x4014000000000001,
  0x4014000000000001,
  0x4014000000000001,
  0x4014000000000001,
  0x4012000000000001,
  0x4012000000000001,
  0x4012000000000001,
  0x4010000000000001,
  0x4010000000000001,
  0x4010000000000001,
  0x400c000000000002,
  0xc013ffffffffffff,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x4014000000000001,
  0x4014000000000001,
  0x4014000000000001,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0xffdffffffffffffd,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x000091a2b3c4d5e7,
  0x001091a2b3c4d5e7,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0001b4e81b4e81b4,
  0x001091a2b3c4d5e6,
  0x000091a2b3c4d5e8,
  0x000091a2b3c4d5e7,
  0x800f6e5d4c3b2a19,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800091a2b3c4d5e6,
  0x800f6e5d4c3b2a18,
  0x000091a2b3c4d5e6,
  0x0008000000000000,
  0x0018000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000923456789abcd,
  0x0017ffffffffffff,
  0x0008000000000001,
  0x0008000000000000,
  0x8008000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0006dcba98765433,
  0x8007ffffffffffff,
  0x0007ffffffffffff,
  0x0000000000000001,
  0x0010000000000001,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abce,
  0x0010000000000000,
  0x0000000000000002,
  0x0000000000000001,
  0x800fffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcc,
  0x800ffffffffffffe,
  0x8000000000000000,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8010000000000000,
  0x0000000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x800edcba98765432,
  0x8000000000000000,
  0x800ffffffffffffe,
  0x8010000000000000,
  0x8020000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x801123456789abcc,
  0x801ffffffffffffe,
  0x8010000000000000,
  0xbfdffffffffffffe,
  0xbfdffffffffffffe,
  0x3c8fffffffffffff,
  0x3ca0000000000000,
  0x3cb0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000003,
  0x3ff0000000000000,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfdffffffffffffe,
  0xbfdffffffffffffe,
  0xbfdffffffffffffe,
  0xbfdffffffffffffe,
  0xbfdffffffffffffe,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff7ffffffffffff,
  0xbff8000000000000,
  0xbff8000000000001,
  0xc000000000000000,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfdffffffffffffe,
  0xbfdffffffffffffe,
  0xbfdffffffffffffe,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0x0000000000000000,
  0x3c90000000000000,
  0x3ca8000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000002,
  0x3ff0000000000000,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff7ffffffffffff,
  0xbff8000000000000,
  0xbff8000000000001,
  0xc000000000000000,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbc9fffffffffffff,
  0xbc8ffffffffffffe,
  0x3c90000000000001,
  0x3fdffffffffffffd,
  0x3fdfffffffffffff,
  0x3fe0000000000002,
  0x3ff0000000000000,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000001,
  0xc000000000000000,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfeffffffffffffe,
  0xbfeffffffffffffe,
  0xbfdffffffffffffd,
  0xbfdffffffffffffc,
  0xbfdffffffffffffa,
  0x3c9fffffffffffff,
  0x3cb0000000000000,
  0x3cc0000000000000,
  0x3fe0000000000002,
  0x4022000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfeffffffffffffe,
  0xbfeffffffffffffe,
  0xbfeffffffffffffe,
  0xbfeffffffffffffe,
  0xbfeffffffffffffe,
  0xbff7ffffffffffff,
  0xbff7ffffffffffff,
  0xbff8000000000000,
  0xbfffffffffffffff,
  0xbfffffffffffffff,
  0xc000000000000000,
  0xc004000000000000,
  0xc026000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfeffffffffffffe,
  0xbfeffffffffffffe,
  0xbfeffffffffffffe,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfdfffffffffffff,
  0xbfdffffffffffffe,
  0xbfdffffffffffffc,
  0x0000000000000000,
  0x3ca0000000000000,
  0x3cb8000000000000,
  0x3fe0000000000001,
  0x4022000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbff7ffffffffffff,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbfffffffffffffff,
  0xc000000000000000,
  0xc000000000000000,
  0xc004000000000000,
  0xc026000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000000,
  0xbcafffffffffffff,
  0xbc9ffffffffffffe,
  0x3ca0000000000001,
  0x3fdffffffffffffe,
  0x4022000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000001,
  0xc000000000000000,
  0xc000000000000000,
  0xc000000000000001,
  0xc004000000000000,
  0xc026000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff7ffffffffffff,
  0xbff7ffffffffffff,
  0xbfefffffffffffff,
  0xbfeffffffffffffe,
  0xbfeffffffffffffe,
  0xbfdfffffffffffff,
  0xbfdffffffffffffd,
  0xbfdffffffffffff9,
  0x3ca8000000000000,
  0x4021000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbff7ffffffffffff,
  0xbff7ffffffffffff,
  0xbff7ffffffffffff,
  0xbff7ffffffffffff,
  0xbff7ffffffffffff,
  0xbfffffffffffffff,
  0xbfffffffffffffff,
  0xc000000000000000,
  0xc003ffffffffffff,
  0xc004000000000000,
  0xc004000000000000,
  0xc008000000000000,
  0xc027000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbff7ffffffffffff,
  0xbff7ffffffffffff,
  0xbff7ffffffffffff,
  0xc023ffffffffffff,
  0xc023ffffffffffff,
  0xc022ffffffffffff,
  0xc022ffffffffffff,
  0xc022ffffffffffff,
  0xc021ffffffffffff,
  0xc021ffffffffffff,
  0xc021ffffffffffff,
  0xc020ffffffffffff,
  0x3cd4000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc023ffffffffffff,
  0xc023ffffffffffff,
  0xc023ffffffffffff,
  0xc023ffffffffffff,
  0xc023ffffffffffff,
  0xc024ffffffffffff,
  0xc024ffffffffffff,
  0xc024ffffffffffff,
  0xc025ffffffffffff,
  0xc025ffffffffffff,
  0xc026000000000000,
  0xc026ffffffffffff,
  0xc034000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc023ffffffffffff,
  0xc023ffffffffffff,
  0xc023ffffffffffff,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0x7c9fffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x800123456789abcd,
  0x000edcba98765433,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0000000000000000,
  0x000edcba98765432,
  0x800123456789abcc,
  0x800123456789abcd,
  0x801123456789abcd,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x8002468acf13579a,
  0x801123456789abcc,
  0x800123456789abce,
  0x800fffffffffffff,
  0x0000000000000001,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x800edcba98765432,
  0x0000000000000000,
  0x800ffffffffffffe,
  0x800fffffffffffff,
  0x801fffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x801123456789abcc,
  0x801ffffffffffffe,
  0x8010000000000000,
  0x8000000000000001,
  0x000fffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcc,
  0x000ffffffffffffe,
  0x0000000000000000,
  0x8000000000000001,
  0x8010000000000001,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abce,
  0x8010000000000000,
  0x8000000000000002,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0010000000000000,
  0x0020000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x001123456789abcc,
  0x001ffffffffffffe,
  0x0010000000000000,
  0x0010000000000000,
  0x8000000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x000edcba98765432,
  0x0000000000000000,
  0x000ffffffffffffe,
  0x3fdffffffffffffe,
  0x3fdffffffffffffe,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff7ffffffffffff,
  0x3ff8000000000000,
  0x3ff8000000000001,
  0x4000000000000000,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fdffffffffffffe,
  0x3fdffffffffffffe,
  0x3fdffffffffffffe,
  0x3fdffffffffffffe,
  0x3fdffffffffffffe,
  0xbc8fffffffffffff,
  0xbca0000000000000,
  0xbcb0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000003,
  0xbff0000000000000,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fdffffffffffffe,
  0x3fdffffffffffffe,
  0x3fdffffffffffffe,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff7ffffffffffff,
  0x3ff8000000000000,
  0x3ff8000000000001,
  0x4000000000000000,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x0000000000000000,
  0xbc90000000000000,
  0xbca8000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000002,
  0xbff0000000000000,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000001,
  0x4000000000000000,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3c9fffffffffffff,
  0x3c8ffffffffffffe,
  0xbc90000000000001,
  0xbfdffffffffffffd,
  0xbfdfffffffffffff,
  0xbfe0000000000002,
  0xbff0000000000000,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3feffffffffffffe,
  0x3feffffffffffffe,
  0x3ff7ffffffffffff,
  0x3ff7ffffffffffff,
  0x3ff8000000000000,
  0x3fffffffffffffff,
  0x3fffffffffffffff,
  0x4000000000000000,
  0x4004000000000000,
  0x4026000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3feffffffffffffe,
  0x3feffffffffffffe,
  0x3feffffffffffffe,
  0x3feffffffffffffe,
  0x3feffffffffffffe,
  0x3fdffffffffffffd,
  0x3fdffffffffffffc,
  0x3fdffffffffffffa,
  0xbc9fffffffffffff,
  0xbcb0000000000000,
  0xbcc0000000000000,
  0xbfe0000000000002,
  0xc022000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3feffffffffffffe,
  0x3feffffffffffffe,
  0x3feffffffffffffe,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3ff7ffffffffffff,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3fffffffffffffff,
  0x4000000000000000,
  0x4000000000000000,
  0x4004000000000000,
  0x4026000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fdfffffffffffff,
  0x3fdffffffffffffe,
  0x3fdffffffffffffc,
  0x0000000000000000,
  0xbca0000000000000,
  0xbcb8000000000000,
  0xbfe0000000000001,
  0xc022000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000001,
  0x4000000000000000,
  0x4000000000000000,
  0x4000000000000001,
  0x4004000000000000,
  0x4026000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000000,
  0x3cafffffffffffff,
  0x3c9ffffffffffffe,
  0xbca0000000000001,
  0xbfdffffffffffffe,
  0xc022000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff7ffffffffffff,
  0x3ff7ffffffffffff,
  0x3fffffffffffffff,
  0x3fffffffffffffff,
  0x4000000000000000,
  0x4003ffffffffffff,
  0x4004000000000000,
  0x4004000000000000,
  0x4008000000000000,
  0x4027000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3ff7ffffffffffff,
  0x3ff7ffffffffffff,
  0x3ff7ffffffffffff,
  0x3ff7ffffffffffff,
  0x3ff7ffffffffffff,
  0x3fefffffffffffff,
  0x3feffffffffffffe,
  0x3feffffffffffffe,
  0x3fdfffffffffffff,
  0x3fdffffffffffffd,
  0x3fdffffffffffff9,
  0xbca8000000000000,
  0xc021000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3ff7ffffffffffff,
  0x3ff7ffffffffffff,
  0x3ff7ffffffffffff,
  0x4023ffffffffffff,
  0x4023ffffffffffff,
  0x4024ffffffffffff,
  0x4024ffffffffffff,
  0x4024ffffffffffff,
  0x4025ffffffffffff,
  0x4025ffffffffffff,
  0x4026000000000000,
  0x4026ffffffffffff,
  0x4034000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x4023ffffffffffff,
  0x4023ffffffffffff,
  0x4023ffffffffffff,
  0x4023ffffffffffff,
  0x4023ffffffffffff,
  0x4022ffffffffffff,
  0x4022ffffffffffff,
  0x4022ffffffffffff,
  0x4021ffffffffffff,
  0x4021ffffffffffff,
  0x4021ffffffffffff,
  0x4020ffffffffffff,
  0xbcd4000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x4023ffffffffffff,
  0x4023ffffffffffff,
  0x4023ffffffffffff,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0xfc9fffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x001123456789abcd,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0002468acf13579a,
  0x001123456789abcc,
  0x000123456789abce,
  0x000123456789abcd,
  0x800edcba98765433,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x8000000000000000,
  0x800edcba98765432,
  0x000123456789abcc,
  0x000fffffffffffff,
  0x001fffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x001123456789abcc,
  0x001ffffffffffffe,
  0x0010000000000000,
  0x000fffffffffffff,
  0x8000000000000001,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x000edcba98765432,
  0x8000000000000000,
  0x000ffffffffffffe,
  0x0000000000000001,
  0x0010000000000001,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abce,
  0x0010000000000000,
  0x0000000000000002,
  0x0000000000000001,
  0x800fffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcc,
  0x800ffffffffffffe,
  0x8000000000000000,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8010000000000000,
  0x0000000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x800edcba98765433,
  0x8000000000000001,
  0x800fffffffffffff,
  0x8010000000000000,
  0x8020000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x801123456789abcd,
  0x801fffffffffffff,
  0x8010000000000001,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0x0000000000000000,
  0x3c90000000000000,
  0x3ca8000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000002,
  0x3ff0000000000000,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff7ffffffffffff,
  0xbff8000000000000,
  0xbff8000000000001,
  0xc000000000000000,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbc90000000000000,
  0x0000000000000000,
  0x3ca0000000000000,
  0x3fdffffffffffffe,
  0x3fe0000000000000,
  0x3fe0000000000002,
  0x3ff0000000000000,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000001,
  0xc000000000000000,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbca8000000000000,
  0xbca0000000000000,
  0x0000000000000000,
  0x3fdffffffffffffc,
  0x3fdffffffffffffe,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000002,
  0xc000000000000000,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfdfffffffffffff,
  0xbfdffffffffffffe,
  0xbfdffffffffffffc,
  0x0000000000000000,
  0x3ca0000000000000,
  0x3cb8000000000000,
  0x3fe0000000000001,
  0x4022000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbff7ffffffffffff,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbfffffffffffffff,
  0xc000000000000000,
  0xc000000000000000,
  0xc004000000000000,
  0xc026000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfdffffffffffffe,
  0xbca0000000000000,
  0x0000000000000000,
  0x3cb0000000000000,
  0x3fe0000000000000,
  0x4022000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xc000000000000000,
  0xc000000000000000,
  0xc000000000000000,
  0xc004000000000000,
  0xc026000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbfe0000000000002,
  0xbfe0000000000002,
  0xbfe0000000000001,
  0xbcb8000000000000,
  0xbcb0000000000000,
  0x0000000000000000,
  0x3fdffffffffffffc,
  0x4022000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff8000000000001,
  0xbff8000000000001,
  0xbff8000000000002,
  0xc000000000000000,
  0xc000000000000000,
  0xc000000000000001,
  0xc004000000000000,
  0xc026000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbfefffffffffffff,
  0xbfe0000000000001,
  0xbfe0000000000000,
  0xbfdffffffffffffc,
  0x0000000000000000,
  0x4021000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xc000000000000000,
  0xc000000000000000,
  0xc000000000000000,
  0xc004000000000000,
  0xc004000000000000,
  0xc004000000000000,
  0xc008000000000000,
  0xc027000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc023000000000000,
  0xc023000000000000,
  0xc023000000000000,
  0xc022000000000000,
  0xc022000000000000,
  0xc022000000000000,
  0xc021000000000000,
  0x0000000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc025000000000000,
  0xc025000000000000,
  0xc025000000000000,
  0xc026000000000000,
  0xc026000000000000,
  0xc026000000000000,
  0xc027000000000000,
  0xc034000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0x0000000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x800123456789abcd,
  0x000edcba98765433,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0000000000000000,
  0x000edcba98765432,
  0x800123456789abcc,
  0x800123456789abcd,
  0x801123456789abcd,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x8002468acf13579a,
  0x801123456789abcc,
  0x800123456789abce,
  0x800fffffffffffff,
  0x0000000000000001,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x800edcba98765432,
  0x0000000000000000,
  0x800ffffffffffffe,
  0x800fffffffffffff,
  0x801fffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x801123456789abcc,
  0x801ffffffffffffe,
  0x8010000000000000,
  0x8000000000000001,
  0x000fffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcc,
  0x000ffffffffffffe,
  0x0000000000000000,
  0x8000000000000001,
  0x8010000000000001,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abce,
  0x8010000000000000,
  0x8000000000000002,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0010000000000000,
  0x0020000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x001123456789abcd,
  0x001fffffffffffff,
  0x0010000000000001,
  0x0010000000000000,
  0x0000000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x000edcba98765433,
  0x0000000000000001,
  0x000fffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff7ffffffffffff,
  0x3ff8000000000000,
  0x3ff8000000000001,
  0x4000000000000000,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x0000000000000000,
  0xbc90000000000000,
  0xbca8000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000002,
  0xbff0000000000000,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000001,
  0x4000000000000000,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3c90000000000000,
  0x0000000000000000,
  0xbca0000000000000,
  0xbfdffffffffffffe,
  0xbfe0000000000000,
  0xbfe0000000000002,
  0xbff0000000000000,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000002,
  0x4000000000000000,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3ca8000000000000,
  0x3ca0000000000000,
  0x0000000000000000,
  0xbfdffffffffffffc,
  0xbfdffffffffffffe,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3ff7ffffffffffff,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3fffffffffffffff,
  0x4000000000000000,
  0x4000000000000000,
  0x4004000000000000,
  0x4026000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fdfffffffffffff,
  0x3fdffffffffffffe,
  0x3fdffffffffffffc,
  0x0000000000000000,
  0xbca0000000000000,
  0xbcb8000000000000,
  0xbfe0000000000001,
  0xc022000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x4000000000000000,
  0x4000000000000000,
  0x4000000000000000,
  0x4004000000000000,
  0x4026000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fdffffffffffffe,
  0x3ca0000000000000,
  0x0000000000000000,
  0xbcb0000000000000,
  0xbfe0000000000000,
  0xc022000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff8000000000001,
  0x3ff8000000000001,
  0x3ff8000000000002,
  0x4000000000000000,
  0x4000000000000000,
  0x4000000000000001,
  0x4004000000000000,
  0x4026000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3fe0000000000002,
  0x3fe0000000000002,
  0x3fe0000000000001,
  0x3cb8000000000000,
  0x3cb0000000000000,
  0x0000000000000000,
  0xbfdffffffffffffc,
  0xc022000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x4000000000000000,
  0x4000000000000000,
  0x4000000000000000,
  0x4004000000000000,
  0x4004000000000000,
  0x4004000000000000,
  0x4008000000000000,
  0x4027000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3fefffffffffffff,
  0x3fe0000000000001,
  0x3fe0000000000000,
  0x3fdffffffffffffc,
  0x0000000000000000,
  0xc021000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4025000000000000,
  0x4025000000000000,
  0x4025000000000000,
  0x4026000000000000,
  0x4026000000000000,
  0x4026000000000000,
  0x4027000000000000,
  0x4034000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4023000000000000,
  0x4023000000000000,
  0x4023000000000000,
  0x4022000000000000,
  0x4022000000000000,
  0x4022000000000000,
  0x4021000000000000,
  0x0000000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x0000000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x001123456789abcd,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0002468acf13579a,
  0x001123456789abcc,
  0x000123456789abce,
  0x000123456789abcd,
  0x800edcba98765433,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0000000000000000,
  0x800edcba98765432,
  0x000123456789abcc,
  0x000fffffffffffff,
  0x001fffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x001123456789abcc,
  0x001ffffffffffffe,
  0x0010000000000000,
  0x000fffffffffffff,
  0x8000000000000001,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x000edcba98765432,
  0x0000000000000000,
  0x000ffffffffffffe,
  0x0000000000000001,
  0x0010000000000001,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abce,
  0x0010000000000000,
  0x0000000000000002,
  0x0000000000000001,
  0x800fffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcc,
  0x800ffffffffffffe,
  0x0000000000000000,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8010000000000001,
  0x8000000000000001,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x800edcba98765434,
  0x8000000000000002,
  0x8010000000000000,
  0x8010000000000001,
  0x8020000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x801123456789abce,
  0x8020000000000000,
  0x8010000000000002,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbc9fffffffffffff,
  0xbc8ffffffffffffe,
  0x3c90000000000001,
  0x3fdffffffffffffd,
  0x3fdfffffffffffff,
  0x3fe0000000000002,
  0x3ff0000000000000,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000001,
  0xc000000000000000,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbca8000000000000,
  0xbca0000000000000,
  0x0000000000000000,
  0x3fdffffffffffffc,
  0x3fdffffffffffffe,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000002,
  0xc000000000000000,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000002,
  0xbfe0000000000002,
  0xbcb4000000000000,
  0xbcb0000000000000,
  0xbca0000000000001,
  0x3fdffffffffffffa,
  0x3fdffffffffffffc,
  0x3fe0000000000000,
  0x3feffffffffffffe,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe0000000000002,
  0xbfe0000000000002,
  0xbfe0000000000002,
  0xbfe0000000000002,
  0xbfe0000000000002,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000002,
  0xbff8000000000001,
  0xbff8000000000001,
  0xbff8000000000002,
  0xc000000000000001,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe0000000000002,
  0xbfe0000000000002,
  0xbfe0000000000002,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000000,
  0xbcafffffffffffff,
  0xbc9ffffffffffffe,
  0x3ca0000000000001,
  0x3fdffffffffffffe,
  0x4022000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000001,
  0xc000000000000000,
  0xc000000000000000,
  0xc000000000000001,
  0xc004000000000000,
  0xc026000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbfe0000000000002,
  0xbfe0000000000002,
  0xbfe0000000000001,
  0xbcb8000000000000,
  0xbcb0000000000000,
  0x0000000000000000,
  0x3fdffffffffffffc,
  0x4022000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff8000000000001,
  0xbff8000000000001,
  0xbff8000000000002,
  0xc000000000000000,
  0xc000000000000000,
  0xc000000000000001,
  0xc004000000000000,
  0xc026000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000002,
  0xbff0000000000002,
  0xbfe0000000000005,
  0xbfe0000000000004,
  0xbfe0000000000003,
  0xbcc4000000000000,
  0xbcc0000000000000,
  0xbcb0000000000001,
  0x3fdffffffffffff8,
  0x4022000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbff0000000000002,
  0xbff0000000000002,
  0xbff0000000000002,
  0xbff0000000000002,
  0xbff0000000000002,
  0xbff8000000000002,
  0xbff8000000000002,
  0xbff8000000000003,
  0xc000000000000001,
  0xc000000000000001,
  0xc000000000000002,
  0xc004000000000001,
  0xc026000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbff0000000000002,
  0xbff0000000000002,
  0xbff0000000000002,
  0xbff8000000000002,
  0xbff8000000000001,
  0xbff0000000000002,
  0xbff0000000000002,
  0xbff0000000000001,
  0xbfe0000000000004,
  0xbfe0000000000003,
  0xbfe0000000000001,
  0xbcb8000000000000,
  0x4021000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbff8000000000001,
  0xbff8000000000001,
  0xbff8000000000001,
  0xbff8000000000002,
  0xbff8000000000002,
  0xc000000000000001,
  0xc000000000000001,
  0xc000000000000001,
  0xc004000000000000,
  0xc004000000000001,
  0xc004000000000001,
  0xc008000000000001,
  0xc027000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbff8000000000002,
  0xbff8000000000002,
  0xbff8000000000002,
  0xc024000000000001,
  0xc024000000000001,
  0xc023000000000001,
  0xc023000000000001,
  0xc023000000000001,
  0xc022000000000001,
  0xc022000000000001,
  0xc022000000000001,
  0xc021000000000001,
  0xbce4000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc024000000000001,
  0xc024000000000001,
  0xc024000000000001,
  0xc024000000000001,
  0xc024000000000001,
  0xc025000000000001,
  0xc025000000000001,
  0xc025000000000001,
  0xc026000000000001,
  0xc026000000000001,
  0xc026000000000001,
  0xc027000000000001,
  0xc034000000000001,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc024000000000001,
  0xc024000000000001,
  0xc024000000000001,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfcafffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x800123456789abcd,
  0x000edcba98765433,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8000000000000000,
  0x000edcba98765432,
  0x800123456789abcc,
  0x800123456789abcd,
  0x801123456789abcd,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x8002468acf13579a,
  0x801123456789abcc,
  0x800123456789abce,
  0x8010000000000000,
  0x0000000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x800edcba98765433,
  0x8000000000000001,
  0x800fffffffffffff,
  0x8010000000000000,
  0x8020000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x801123456789abcd,
  0x801fffffffffffff,
  0x8010000000000001,
  0x8000000000000001,
  0x000fffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcc,
  0x000ffffffffffffe,
  0x8000000000000000,
  0x8000000000000001,
  0x8010000000000001,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abce,
  0x8010000000000000,
  0x8000000000000002,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0010000000000001,
  0x0020000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x001123456789abce,
  0x0020000000000000,
  0x0010000000000002,
  0x0010000000000001,
  0x0000000000000001,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x000edcba98765434,
  0x0000000000000002,
  0x0010000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000001,
  0x4000000000000000,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3c9fffffffffffff,
  0x3c8ffffffffffffe,
  0xbc90000000000001,
  0xbfdffffffffffffd,
  0xbfdfffffffffffff,
  0xbfe0000000000002,
  0xbff0000000000000,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000002,
  0x4000000000000000,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3ca8000000000000,
  0x3ca0000000000000,
  0x0000000000000000,
  0xbfdffffffffffffc,
  0xbfdffffffffffffe,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000002,
  0x3fe0000000000002,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000002,
  0x3ff8000000000001,
  0x3ff8000000000001,
  0x3ff8000000000002,
  0x4000000000000001,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe0000000000002,
  0x3fe0000000000002,
  0x3fe0000000000002,
  0x3fe0000000000002,
  0x3fe0000000000002,
  0x3cb4000000000000,
  0x3cb0000000000000,
  0x3ca0000000000001,
  0xbfdffffffffffffa,
  0xbfdffffffffffffc,
  0xbfe0000000000000,
  0xbfeffffffffffffe,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe0000000000002,
  0x3fe0000000000002,
  0x3fe0000000000002,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000001,
  0x4000000000000000,
  0x4000000000000000,
  0x4000000000000001,
  0x4004000000000000,
  0x4026000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000000,
  0x3cafffffffffffff,
  0x3c9ffffffffffffe,
  0xbca0000000000001,
  0xbfdffffffffffffe,
  0xc022000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff8000000000001,
  0x3ff8000000000001,
  0x3ff8000000000002,
  0x4000000000000000,
  0x4000000000000000,
  0x4000000000000001,
  0x4004000000000000,
  0x4026000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3fe0000000000002,
  0x3fe0000000000002,
  0x3fe0000000000001,
  0x3cb8000000000000,
  0x3cb0000000000000,
  0x0000000000000000,
  0xbfdffffffffffffc,
  0xc022000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000002,
  0x3ff0000000000002,
  0x3ff8000000000002,
  0x3ff8000000000002,
  0x3ff8000000000003,
  0x4000000000000001,
  0x4000000000000001,
  0x4000000000000002,
  0x4004000000000001,
  0x4026000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3ff0000000000002,
  0x3ff0000000000002,
  0x3ff0000000000002,
  0x3ff0000000000002,
  0x3ff0000000000002,
  0x3fe0000000000005,
  0x3fe0000000000004,
  0x3fe0000000000003,
  0x3cc4000000000000,
  0x3cc0000000000000,
  0x3cb0000000000001,
  0xbfdffffffffffff8,
  0xc022000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3ff0000000000002,
  0x3ff0000000000002,
  0x3ff0000000000002,
  0x3ff8000000000002,
  0x3ff8000000000002,
  0x4000000000000001,
  0x4000000000000001,
  0x4000000000000001,
  0x4004000000000000,
  0x4004000000000001,
  0x4004000000000001,
  0x4008000000000001,
  0x4027000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3ff8000000000002,
  0x3ff8000000000002,
  0x3ff8000000000002,
  0x3ff8000000000002,
  0x3ff8000000000001,
  0x3ff0000000000002,
  0x3ff0000000000002,
  0x3ff0000000000001,
  0x3fe0000000000004,
  0x3fe0000000000003,
  0x3fe0000000000001,
  0x3cb8000000000000,
  0xc021000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3ff8000000000001,
  0x3ff8000000000001,
  0x3ff8000000000001,
  0x4024000000000001,
  0x4024000000000001,
  0x4025000000000001,
  0x4025000000000001,
  0x4025000000000001,
  0x4026000000000001,
  0x4026000000000001,
  0x4026000000000001,
  0x4027000000000001,
  0x4034000000000001,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x4024000000000001,
  0x4024000000000001,
  0x4024000000000001,
  0x4024000000000001,
  0x4024000000000001,
  0x4023000000000001,
  0x4023000000000001,
  0x4023000000000001,
  0x4022000000000001,
  0x4022000000000001,
  0x4022000000000001,
  0x4021000000000001,
  0x3ce4000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x4024000000000001,
  0x4024000000000001,
  0x4024000000000001,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7cafffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x001123456789abcd,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0002468acf13579a,
  0x001123456789abcc,
  0x000123456789abce,
  0x000123456789abcd,
  0x800edcba98765433,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0000000000000000,
  0x800edcba98765432,
  0x000123456789abcc,
  0x0010000000000000,
  0x0020000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x001123456789abcd,
  0x001fffffffffffff,
  0x0010000000000001,
  0x0010000000000000,
  0x8000000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x000edcba98765433,
  0x0000000000000001,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0010000000000001,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abce,
  0x0010000000000000,
  0x0000000000000002,
  0x0000000000000001,
  0x800fffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcc,
  0x800ffffffffffffe,
  0x0000000000000000,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8018000000000000,
  0x8008000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8016dcba98765433,
  0x8008000000000001,
  0x8017ffffffffffff,
  0x8018000000000000,
  0x8024000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x801923456789abcd,
  0x8024000000000000,
  0x8018000000000001,
  0xbfe7ffffffffffff,
  0xbfe7ffffffffffff,
  0xbfcfffffffffffff,
  0xbfcffffffffffffd,
  0xbfcffffffffffff9,
  0x3fcfffffffffffff,
  0x3fd0000000000002,
  0x3fd0000000000006,
  0x3fe8000000000001,
  0x4022800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe7ffffffffffff,
  0xbfe7ffffffffffff,
  0xbfe7ffffffffffff,
  0xbfe7ffffffffffff,
  0xbfe7ffffffffffff,
  0xbff3ffffffffffff,
  0xbff4000000000000,
  0xbff4000000000000,
  0xbffbffffffffffff,
  0xbffc000000000000,
  0xbffc000000000001,
  0xc002000000000000,
  0xc025800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe7ffffffffffff,
  0xbfe7ffffffffffff,
  0xbfe7ffffffffffff,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbfd0000000000001,
  0xbfd0000000000000,
  0xbfcffffffffffffc,
  0x3fcffffffffffffc,
  0x3fd0000000000000,
  0x3fd0000000000004,
  0x3fe8000000000000,
  0x4022800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbff4000000000000,
  0xbff4000000000000,
  0xbff4000000000000,
  0xbffc000000000000,
  0xbffc000000000000,
  0xbffc000000000001,
  0xc002000000000000,
  0xc025800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbfe8000000000002,
  0xbfe8000000000001,
  0xbfd0000000000004,
  0xbfd0000000000003,
  0xbfd0000000000001,
  0x3fcffffffffffff6,
  0x3fcffffffffffffa,
  0x3fd0000000000001,
  0x3fe7fffffffffffe,
  0x4022800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe8000000000001,
  0xbfe8000000000001,
  0xbfe8000000000001,
  0xbfe8000000000002,
  0xbfe8000000000002,
  0xbff4000000000000,
  0xbff4000000000001,
  0xbff4000000000001,
  0xbffc000000000000,
  0xbffc000000000001,
  0xbffc000000000002,
  0xc002000000000000,
  0xc025800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe8000000000002,
  0xbfe8000000000002,
  0xbfe8000000000002,
  0xbff7ffffffffffff,
  0xbff7ffffffffffff,
  0xbfefffffffffffff,
  0xbfeffffffffffffe,
  0xbfeffffffffffffe,
  0xbfdfffffffffffff,
  0xbfdffffffffffffd,
  0xbfdffffffffffff9,
  0x3ca8000000000000,
  0x4021000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbff7ffffffffffff,
  0xbff7ffffffffffff,
  0xbff7ffffffffffff,
  0xbff7ffffffffffff,
  0xbff7ffffffffffff,
  0xbfffffffffffffff,
  0xbfffffffffffffff,
  0xc000000000000000,
  0xc003ffffffffffff,
  0xc004000000000000,
  0xc004000000000000,
  0xc008000000000000,
  0xc027000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbff7ffffffffffff,
  0xbff7ffffffffffff,
  0xbff7ffffffffffff,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbfefffffffffffff,
  0xbfe0000000000001,
  0xbfe0000000000000,
  0xbfdffffffffffffc,
  0x0000000000000000,
  0x4021000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xc000000000000000,
  0xc000000000000000,
  0xc000000000000000,
  0xc004000000000000,
  0xc004000000000000,
  0xc004000000000000,
  0xc008000000000000,
  0xc027000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000002,
  0xbff8000000000001,
  0xbff0000000000002,
  0xbff0000000000002,
  0xbff0000000000001,
  0xbfe0000000000004,
  0xbfe0000000000003,
  0xbfe0000000000001,
  0xbcb8000000000000,
  0x4021000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbff8000000000001,
  0xbff8000000000001,
  0xbff8000000000001,
  0xbff8000000000002,
  0xbff8000000000002,
  0xc000000000000001,
  0xc000000000000001,
  0xc000000000000001,
  0xc004000000000000,
  0xc004000000000001,
  0xc004000000000001,
  0xc008000000000001,
  0xc027000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbff8000000000002,
  0xbff8000000000002,
  0xbff8000000000002,
  0xc002000000000000,
  0xc002000000000000,
  0xbffc000000000000,
  0xbffc000000000000,
  0xbffc000000000000,
  0xbff4000000000000,
  0xbff4000000000000,
  0xbff3ffffffffffff,
  0xbfe8000000000000,
  0x401f000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc002000000000000,
  0xc002000000000000,
  0xc002000000000000,
  0xc002000000000000,
  0xc002000000000000,
  0xc006000000000000,
  0xc006000000000000,
  0xc006000000000000,
  0xc00a000000000000,
  0xc00a000000000000,
  0xc00a000000000000,
  0xc00e000000000000,
  0xc028800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc002000000000000,
  0xc002000000000000,
  0xc002000000000000,
  0xc02e000000000000,
  0xc02e000000000000,
  0xc02d000000000000,
  0xc02d000000000000,
  0xc02d000000000000,
  0xc02c000000000000,
  0xc02c000000000000,
  0xc02c000000000000,
  0xc02b000000000000,
  0xc014000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc02e000000000000,
  0xc02e000000000000,
  0xc02e000000000000,
  0xc02e000000000000,
  0xc02e000000000000,
  0xc02f000000000000,
  0xc02f000000000000,
  0xc02f000000000000,
  0xc030000000000000,
  0xc030000000000000,
  0xc030000000000000,
  0xc030800000000000,
  0xc039000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc02e000000000000,
  0xc02e000000000000,
  0xc02e000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xffdfffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x8001b4e81b4e81b4,
  0x000e4b17e4b17e4c,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x800091a2b3c4d5e6,
  0x000e4b17e4b17e4c,
  0x8001b4e81b4e81b2,
  0x8001b4e81b4e81b4,
  0x8011b4e81b4e81b4,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x8002d82d82d82d80,
  0x8011b4e81b4e81b2,
  0x8001b4e81b4e81b4,
  0x8017fffffffffffe,
  0x8007fffffffffffe,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8016dcba98765432,
  0x8008000000000000,
  0x8017fffffffffffe,
  0x8017fffffffffffe,
  0x8023ffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x801923456789abcc,
  0x8023ffffffffffff,
  0x8018000000000000,
  0x8000000000000002,
  0x000ffffffffffffe,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcc,
  0x000ffffffffffffe,
  0x8000000000000000,
  0x8000000000000002,
  0x8010000000000002,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abce,
  0x8010000000000000,
  0x8000000000000002,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0018000000000000,
  0x0024000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x001923456789abcd,
  0x0024000000000000,
  0x0018000000000001,
  0x0018000000000000,
  0x0008000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0016dcba98765433,
  0x0008000000000001,
  0x0017ffffffffffff,
  0x3fe7ffffffffffff,
  0x3fe7ffffffffffff,
  0x3ff3ffffffffffff,
  0x3ff4000000000000,
  0x3ff4000000000000,
  0x3ffbffffffffffff,
  0x3ffc000000000000,
  0x3ffc000000000001,
  0x4002000000000000,
  0x4025800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe7ffffffffffff,
  0x3fe7ffffffffffff,
  0x3fe7ffffffffffff,
  0x3fe7ffffffffffff,
  0x3fe7ffffffffffff,
  0x3fcfffffffffffff,
  0x3fcffffffffffffd,
  0x3fcffffffffffff9,
  0xbfcfffffffffffff,
  0xbfd0000000000002,
  0xbfd0000000000006,
  0xbfe8000000000001,
  0xc022800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe7ffffffffffff,
  0x3fe7ffffffffffff,
  0x3fe7ffffffffffff,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3ff4000000000000,
  0x3ff4000000000000,
  0x3ff4000000000000,
  0x3ffc000000000000,
  0x3ffc000000000000,
  0x3ffc000000000001,
  0x4002000000000000,
  0x4025800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3fd0000000000001,
  0x3fd0000000000000,
  0x3fcffffffffffffc,
  0xbfcffffffffffffc,
  0xbfd0000000000000,
  0xbfd0000000000004,
  0xbfe8000000000000,
  0xc022800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3fe8000000000002,
  0x3fe8000000000002,
  0x3ff4000000000000,
  0x3ff4000000000001,
  0x3ff4000000000001,
  0x3ffc000000000000,
  0x3ffc000000000001,
  0x3ffc000000000002,
  0x4002000000000000,
  0x4025800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe8000000000002,
  0x3fe8000000000002,
  0x3fe8000000000002,
  0x3fe8000000000002,
  0x3fe8000000000001,
  0x3fd0000000000004,
  0x3fd0000000000003,
  0x3fd0000000000001,
  0xbfcffffffffffff6,
  0xbfcffffffffffffa,
  0xbfd0000000000001,
  0xbfe7fffffffffffe,
  0xc022800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe8000000000001,
  0x3fe8000000000001,
  0x3fe8000000000001,
  0x3ff7ffffffffffff,
  0x3ff7ffffffffffff,
  0x3fffffffffffffff,
  0x3fffffffffffffff,
  0x4000000000000000,
  0x4003ffffffffffff,
  0x4004000000000000,
  0x4004000000000000,
  0x4008000000000000,
  0x4027000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3ff7ffffffffffff,
  0x3ff7ffffffffffff,
  0x3ff7ffffffffffff,
  0x3ff7ffffffffffff,
  0x3ff7ffffffffffff,
  0x3fefffffffffffff,
  0x3feffffffffffffe,
  0x3feffffffffffffe,
  0x3fdfffffffffffff,
  0x3fdffffffffffffd,
  0x3fdffffffffffff9,
  0xbca8000000000000,
  0xc021000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3ff7ffffffffffff,
  0x3ff7ffffffffffff,
  0x3ff7ffffffffffff,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x4000000000000000,
  0x4000000000000000,
  0x4000000000000000,
  0x4004000000000000,
  0x4004000000000000,
  0x4004000000000000,
  0x4008000000000000,
  0x4027000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3fefffffffffffff,
  0x3fe0000000000001,
  0x3fe0000000000000,
  0x3fdffffffffffffc,
  0x0000000000000000,
  0xc021000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000002,
  0x3ff8000000000002,
  0x4000000000000001,
  0x4000000000000001,
  0x4000000000000001,
  0x4004000000000000,
  0x4004000000000001,
  0x4004000000000001,
  0x4008000000000001,
  0x4027000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3ff8000000000002,
  0x3ff8000000000002,
  0x3ff8000000000002,
  0x3ff8000000000002,
  0x3ff8000000000001,
  0x3ff0000000000002,
  0x3ff0000000000002,
  0x3ff0000000000001,
  0x3fe0000000000004,
  0x3fe0000000000003,
  0x3fe0000000000001,
  0x3cb8000000000000,
  0xc021000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3ff8000000000001,
  0x3ff8000000000001,
  0x3ff8000000000001,
  0x4002000000000000,
  0x4002000000000000,
  0x4006000000000000,
  0x4006000000000000,
  0x4006000000000000,
  0x400a000000000000,
  0x400a000000000000,
  0x400a000000000000,
  0x400e000000000000,
  0x4028800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x4002000000000000,
  0x4002000000000000,
  0x4002000000000000,
  0x4002000000000000,
  0x4002000000000000,
  0x3ffc000000000000,
  0x3ffc000000000000,
  0x3ffc000000000000,
  0x3ff4000000000000,
  0x3ff4000000000000,
  0x3ff3ffffffffffff,
  0x3fe8000000000000,
  0xc01f000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x4002000000000000,
  0x4002000000000000,
  0x4002000000000000,
  0x402e000000000000,
  0x402e000000000000,
  0x402f000000000000,
  0x402f000000000000,
  0x402f000000000000,
  0x4030000000000000,
  0x4030000000000000,
  0x4030000000000000,
  0x4030800000000000,
  0x4039000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x402e000000000000,
  0x402e000000000000,
  0x402e000000000000,
  0x402e000000000000,
  0x402e000000000000,
  0x402d000000000000,
  0x402d000000000000,
  0x402d000000000000,
  0x402c000000000000,
  0x402c000000000000,
  0x402c000000000000,
  0x402b000000000000,
  0x4014000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x402e000000000000,
  0x402e000000000000,
  0x402e000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7fdfffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x0001b4e81b4e81b4,
  0x0011b4e81b4e81b4,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0002d82d82d82d80,
  0x0011b4e81b4e81b2,
  0x0001b4e81b4e81b4,
  0x0001b4e81b4e81b4,
  0x800e4b17e4b17e4c,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x000091a2b3c4d5e6,
  0x800e4b17e4b17e4c,
  0x0001b4e81b4e81b2,
  0x0017fffffffffffe,
  0x0023ffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x001923456789abcc,
  0x0023ffffffffffff,
  0x0018000000000000,
  0x0017fffffffffffe,
  0x0007fffffffffffe,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0016dcba98765432,
  0x0008000000000000,
  0x0017fffffffffffe,
  0x0000000000000002,
  0x0010000000000002,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abce,
  0x0010000000000000,
  0x0000000000000002,
  0x0000000000000002,
  0x800ffffffffffffe,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcc,
  0x800ffffffffffffe,
  0x0000000000000000,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8044000000000000,
  0x8042000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8043db97530eca86,
  0x8042000000000000,
  0x8044000000000000,
  0x8044000000000000,
  0x8046000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x80442468acf1357a,
  0x8046000000000000,
  0x8044000000000000,
  0xc013ffffffffffff,
  0xc013ffffffffffff,
  0xc011ffffffffffff,
  0xc011ffffffffffff,
  0xc011ffffffffffff,
  0xc00fffffffffffff,
  0xc00fffffffffffff,
  0xc00ffffffffffffe,
  0xc00bffffffffffff,
  0x4014000000000001,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc013ffffffffffff,
  0xc013ffffffffffff,
  0xc013ffffffffffff,
  0xc013ffffffffffff,
  0xc013ffffffffffff,
  0xc015ffffffffffff,
  0xc015ffffffffffff,
  0xc016000000000000,
  0xc017ffffffffffff,
  0xc017ffffffffffff,
  0xc018000000000000,
  0xc019ffffffffffff,
  0xc02e000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc013ffffffffffff,
  0xc013ffffffffffff,
  0xc013ffffffffffff,
  0xc014000000000000,
  0xc014000000000000,
  0xc012000000000000,
  0xc012000000000000,
  0xc012000000000000,
  0xc010000000000000,
  0xc010000000000000,
  0xc010000000000000,
  0xc00c000000000000,
  0x4014000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc014000000000000,
  0xc014000000000000,
  0xc014000000000000,
  0xc014000000000000,
  0xc014000000000000,
  0xc016000000000000,
  0xc016000000000000,
  0xc016000000000000,
  0xc018000000000000,
  0xc018000000000000,
  0xc018000000000000,
  0xc01a000000000000,
  0xc02e000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc014000000000000,
  0xc014000000000000,
  0xc014000000000000,
  0xc014000000000001,
  0xc014000000000001,
  0xc012000000000001,
  0xc012000000000001,
  0xc012000000000001,
  0xc010000000000001,
  0xc010000000000001,
  0xc010000000000001,
  0xc00c000000000002,
  0x4013ffffffffffff,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc014000000000001,
  0xc014000000000001,
  0xc014000000000001,
  0xc014000000000001,
  0xc014000000000001,
  0xc016000000000001,
  0xc016000000000001,
  0xc016000000000001,
  0xc018000000000001,
  0xc018000000000001,
  0xc018000000000002,
  0xc01a000000000001,
  0xc02e000000000001,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc014000000000001,
  0xc014000000000001,
  0xc014000000000001,
  0xc023ffffffffffff,
  0xc023ffffffffffff,
  0xc022ffffffffffff,
  0xc022ffffffffffff,
  0xc022ffffffffffff,
  0xc021ffffffffffff,
  0xc021ffffffffffff,
  0xc021ffffffffffff,
  0xc020ffffffffffff,
  0x3cd4000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc023ffffffffffff,
  0xc023ffffffffffff,
  0xc023ffffffffffff,
  0xc023ffffffffffff,
  0xc023ffffffffffff,
  0xc024ffffffffffff,
  0xc024ffffffffffff,
  0xc024ffffffffffff,
  0xc025ffffffffffff,
  0xc025ffffffffffff,
  0xc026000000000000,
  0xc026ffffffffffff,
  0xc034000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc023ffffffffffff,
  0xc023ffffffffffff,
  0xc023ffffffffffff,
  0xc024000000000000,
  0xc024000000000000,
  0xc023000000000000,
  0xc023000000000000,
  0xc023000000000000,
  0xc022000000000000,
  0xc022000000000000,
  0xc022000000000000,
  0xc021000000000000,
  0x0000000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc025000000000000,
  0xc025000000000000,
  0xc025000000000000,
  0xc026000000000000,
  0xc026000000000000,
  0xc026000000000000,
  0xc027000000000000,
  0xc034000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc024000000000001,
  0xc024000000000001,
  0xc023000000000001,
  0xc023000000000001,
  0xc023000000000001,
  0xc022000000000001,
  0xc022000000000001,
  0xc022000000000001,
  0xc021000000000001,
  0xbce4000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc024000000000001,
  0xc024000000000001,
  0xc024000000000001,
  0xc024000000000001,
  0xc024000000000001,
  0xc025000000000001,
  0xc025000000000001,
  0xc025000000000001,
  0xc026000000000001,
  0xc026000000000001,
  0xc026000000000001,
  0xc027000000000001,
  0xc034000000000001,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc024000000000001,
  0xc024000000000001,
  0xc024000000000001,
  0xc02e000000000000,
  0xc02e000000000000,
  0xc02d000000000000,
  0xc02d000000000000,
  0xc02d000000000000,
  0xc02c000000000000,
  0xc02c000000000000,
  0xc02c000000000000,
  0xc02b000000000000,
  0xc014000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc02e000000000000,
  0xc02e000000000000,
  0xc02e000000000000,
  0xc02e000000000000,
  0xc02e000000000000,
  0xc02f000000000000,
  0xc02f000000000000,
  0xc02f000000000000,
  0xc030000000000000,
  0xc030000000000000,
  0xc030000000000000,
  0xc030800000000000,
  0xc039000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc02e000000000000,
  0xc02e000000000000,
  0xc02e000000000000,
  0xc059000000000000,
  0xc059000000000000,
  0xc058e00000000000,
  0xc058e00000000000,
  0xc058e00000000000,
  0xc058c00000000000,
  0xc058c00000000000,
  0xc058c00000000000,
  0xc058a00000000000,
  0xc056800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc059000000000000,
  0xc059000000000000,
  0xc059000000000000,
  0xc059000000000000,
  0xc059000000000000,
  0xc059200000000000,
  0xc059200000000000,
  0xc059200000000000,
  0xc059400000000000,
  0xc059400000000000,
  0xc059400000000000,
  0xc059600000000000,
  0xc05b800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc059000000000000,
  0xc059000000000000,
  0xc059000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x800b60b60b60b602,
  0x00049f49f49f49fe,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x800a3d70a3d70a35,
  0x00049f49f49f49fd,
  0x800b60b60b60b601,
  0x800b60b60b60b602,
  0x801b60b60b60b602,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800c83fb72ea61cf,
  0x801b60b60b60b601,
  0x800b60b60b60b603,
  0x8043ffffffffffff,
  0x8041ffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8043db97530eca85,
  0x8041ffffffffffff,
  0x8043ffffffffffff,
  0x8043ffffffffffff,
  0x8045ffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x80442468acf13578,
  0x8045ffffffffffff,
  0x8043ffffffffffff,
  0x800000000000000a,
  0x000ffffffffffff6,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abc3,
  0x000ffffffffffff5,
  0x8000000000000009,
  0x800000000000000a,
  0x801000000000000a,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abd7,
  0x8010000000000009,
  0x800000000000000b,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0044000000000000,
  0x0046000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x00442468acf1357a,
  0x0046000000000000,
  0x0044000000000000,
  0x0044000000000000,
  0x0042000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0043db97530eca86,
  0x0042000000000000,
  0x0044000000000000,
  0x4013ffffffffffff,
  0x4013ffffffffffff,
  0x4015ffffffffffff,
  0x4015ffffffffffff,
  0x4016000000000000,
  0x4017ffffffffffff,
  0x4017ffffffffffff,
  0x4018000000000000,
  0x4019ffffffffffff,
  0x402e000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x4013ffffffffffff,
  0x4013ffffffffffff,
  0x4013ffffffffffff,
  0x4013ffffffffffff,
  0x4013ffffffffffff,
  0x4011ffffffffffff,
  0x4011ffffffffffff,
  0x4011ffffffffffff,
  0x400fffffffffffff,
  0x400fffffffffffff,
  0x400ffffffffffffe,
  0x400bffffffffffff,
  0xc014000000000001,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x4013ffffffffffff,
  0x4013ffffffffffff,
  0x4013ffffffffffff,
  0x4014000000000000,
  0x4014000000000000,
  0x4016000000000000,
  0x4016000000000000,
  0x4016000000000000,
  0x4018000000000000,
  0x4018000000000000,
  0x4018000000000000,
  0x401a000000000000,
  0x402e000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x4014000000000000,
  0x4014000000000000,
  0x4014000000000000,
  0x4014000000000000,
  0x4014000000000000,
  0x4012000000000000,
  0x4012000000000000,
  0x4012000000000000,
  0x4010000000000000,
  0x4010000000000000,
  0x4010000000000000,
  0x400c000000000000,
  0xc014000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x4014000000000000,
  0x4014000000000000,
  0x4014000000000000,
  0x4014000000000001,
  0x4014000000000001,
  0x4016000000000001,
  0x4016000000000001,
  0x4016000000000001,
  0x4018000000000001,
  0x4018000000000001,
  0x4018000000000002,
  0x401a000000000001,
  0x402e000000000001,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x4014000000000001,
  0x4014000000000001,
  0x4014000000000001,
  0x4014000000000001,
  0x4014000000000001,
  0x4012000000000001,
  0x4012000000000001,
  0x4012000000000001,
  0x4010000000000001,
  0x4010000000000001,
  0x4010000000000001,
  0x400c000000000002,
  0xc013ffffffffffff,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x4014000000000001,
  0x4014000000000001,
  0x4014000000000001,
  0x4023ffffffffffff,
  0x4023ffffffffffff,
  0x4024ffffffffffff,
  0x4024ffffffffffff,
  0x4024ffffffffffff,
  0x4025ffffffffffff,
  0x4025ffffffffffff,
  0x4026000000000000,
  0x4026ffffffffffff,
  0x4034000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x4023ffffffffffff,
  0x4023ffffffffffff,
  0x4023ffffffffffff,
  0x4023ffffffffffff,
  0x4023ffffffffffff,
  0x4022ffffffffffff,
  0x4022ffffffffffff,
  0x4022ffffffffffff,
  0x4021ffffffffffff,
  0x4021ffffffffffff,
  0x4021ffffffffffff,
  0x4020ffffffffffff,
  0xbcd4000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x4023ffffffffffff,
  0x4023ffffffffffff,
  0x4023ffffffffffff,
  0x4024000000000000,
  0x4024000000000000,
  0x4025000000000000,
  0x4025000000000000,
  0x4025000000000000,
  0x4026000000000000,
  0x4026000000000000,
  0x4026000000000000,
  0x4027000000000000,
  0x4034000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4023000000000000,
  0x4023000000000000,
  0x4023000000000000,
  0x4022000000000000,
  0x4022000000000000,
  0x4022000000000000,
  0x4021000000000000,
  0x0000000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4024000000000001,
  0x4024000000000001,
  0x4025000000000001,
  0x4025000000000001,
  0x4025000000000001,
  0x4026000000000001,
  0x4026000000000001,
  0x4026000000000001,
  0x4027000000000001,
  0x4034000000000001,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x4024000000000001,
  0x4024000000000001,
  0x4024000000000001,
  0x4024000000000001,
  0x4024000000000001,
  0x4023000000000001,
  0x4023000000000001,
  0x4023000000000001,
  0x4022000000000001,
  0x4022000000000001,
  0x4022000000000001,
  0x4021000000000001,
  0x3ce4000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x4024000000000001,
  0x4024000000000001,
  0x4024000000000001,
  0x402e000000000000,
  0x402e000000000000,
  0x402f000000000000,
  0x402f000000000000,
  0x402f000000000000,
  0x4030000000000000,
  0x4030000000000000,
  0x4030000000000000,
  0x4030800000000000,
  0x4039000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x402e000000000000,
  0x402e000000000000,
  0x402e000000000000,
  0x402e000000000000,
  0x402e000000000000,
  0x402d000000000000,
  0x402d000000000000,
  0x402d000000000000,
  0x402c000000000000,
  0x402c000000000000,
  0x402c000000000000,
  0x402b000000000000,
  0x4014000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x402e000000000000,
  0x402e000000000000,
  0x402e000000000000,
  0x4059000000000000,
  0x4059000000000000,
  0x4059200000000000,
  0x4059200000000000,
  0x4059200000000000,
  0x4059400000000000,
  0x4059400000000000,
  0x4059400000000000,
  0x4059600000000000,
  0x405b800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x4059000000000000,
  0x4059000000000000,
  0x4059000000000000,
  0x4059000000000000,
  0x4059000000000000,
  0x4058e00000000000,
  0x4058e00000000000,
  0x4058e00000000000,
  0x4058c00000000000,
  0x4058c00000000000,
  0x4058c00000000000,
  0x4058a00000000000,
  0x4056800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x4059000000000000,
  0x4059000000000000,
  0x4059000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x000b60b60b60b602,
  0x001b60b60b60b602,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000c83fb72ea61cf,
  0x001b60b60b60b601,
  0x000b60b60b60b603,
  0x000b60b60b60b602,
  0x80049f49f49f49fe,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x000a3d70a3d70a35,
  0x80049f49f49f49fd,
  0x000b60b60b60b601,
  0x0043ffffffffffff,
  0x0045ffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x00442468acf13578,
  0x0045ffffffffffff,
  0x0043ffffffffffff,
  0x0043ffffffffffff,
  0x0041ffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0043db97530eca85,
  0x0041ffffffffffff,
  0x0043ffffffffffff,
  0x000000000000000a,
  0x001000000000000a,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abd7,
  0x0010000000000009,
  0x000000000000000b,
  0x000000000000000a,
  0x800ffffffffffff6,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abc3,
  0x800ffffffffffff5,
  0x0000000000000009,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0xc00fffffffffffff,
  0xc00fffffffffffff,
  0xc00bffffffffffff,
  0xc00bffffffffffff,
  0xc00bffffffffffff,
  0xc007ffffffffffff,
  0xc007ffffffffffff,
  0xc007fffffffffffe,
  0xc003ffffffffffff,
  0x4018000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc00fffffffffffff,
  0xc00fffffffffffff,
  0xc00fffffffffffff,
  0xc00fffffffffffff,
  0xc00fffffffffffff,
  0xc011ffffffffffff,
  0xc012000000000000,
  0xc012000000000000,
  0xc013ffffffffffff,
  0xc014000000000000,
  0xc014000000000000,
  0xc016000000000000,
  0xc02c000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc00fffffffffffff,
  0xc00fffffffffffff,
  0xc00fffffffffffff,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0x7fe0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0x7fdfffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0x7fdffffffffffffd,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0x7c9fffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0x0000000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfcafffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xffdfffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xbfd23456789abccf,
  0xbfd23456789abccf,
  0x3fcb97530eca865f,
  0x3fcb97530eca8661,
  0x3fcb97530eca8665,
  0x3fe6e5d4c3b2a197,
  0x3fe6e5d4c3b2a198,
  0x3fe6e5d4c3b2a19a,
  0x3ff372ea61d950cc,
  0x40236e5d4c3b2a1a,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfd23456789abccf,
  0xbfd23456789abccf,
  0xbfd23456789abccf,
  0xbfd23456789abccf,
  0xbfd23456789abccf,
  0xbfe91a2b3c4d5e67,
  0xbfe91a2b3c4d5e68,
  0xbfe91a2b3c4d5e69,
  0xbff48d159e26af33,
  0xbff48d159e26af34,
  0xbff48d159e26af35,
  0xbffc8d159e26af34,
  0xc02491a2b3c4d5e6,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfd23456789abccf,
  0xbfd23456789abccf,
  0xbfd23456789abccf,
  0xc00ffffffffffffd,
  0xc00ffffffffffffd,
  0xc00bfffffffffffd,
  0xc00bfffffffffffd,
  0xc00bfffffffffffd,
  0xc007fffffffffffd,
  0xc007fffffffffffd,
  0xc007fffffffffffd,
  0xc003fffffffffffd,
  0x4018000000000001,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc00ffffffffffffd,
  0xc00ffffffffffffd,
  0xc00ffffffffffffd,
  0xc00ffffffffffffd,
  0xc00ffffffffffffd,
  0xc011fffffffffffe,
  0xc011ffffffffffff,
  0xc011ffffffffffff,
  0xc013fffffffffffe,
  0xc013ffffffffffff,
  0xc013ffffffffffff,
  0xc015ffffffffffff,
  0xc02bffffffffffff,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc00ffffffffffffd,
  0xc00ffffffffffffd,
  0xc00ffffffffffffd,
  0xbccfffffffffffff,
  0xbccfffffffffffff,
  0x3fdfffffffffffef,
  0x3fdffffffffffff0,
  0x3fdffffffffffff2,
  0x3feffffffffffff7,
  0x3feffffffffffff8,
  0x3feffffffffffffa,
  0x3ff7fffffffffffc,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbccfffffffffffff,
  0xbccfffffffffffff,
  0xbccfffffffffffff,
  0xbccfffffffffffff,
  0xbccfffffffffffff,
  0xbfe0000000000007,
  0xbfe0000000000008,
  0xbfe0000000000009,
  0xbff0000000000003,
  0xbff0000000000004,
  0xbff0000000000005,
  0xbff8000000000004,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbccfffffffffffff,
  0xbccfffffffffffff,
  0xbccfffffffffffff,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x400fffffffffffff,
  0x400fffffffffffff,
  0x4011ffffffffffff,
  0x4012000000000000,
  0x4012000000000000,
  0x4013ffffffffffff,
  0x4014000000000000,
  0x4014000000000000,
  0x4016000000000000,
  0x402c000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x400fffffffffffff,
  0x400fffffffffffff,
  0x400fffffffffffff,
  0x400fffffffffffff,
  0x400fffffffffffff,
  0x400bffffffffffff,
  0x400bffffffffffff,
  0x400bffffffffffff,
  0x4007ffffffffffff,
  0x4007ffffffffffff,
  0x4007fffffffffffe,
  0x4003ffffffffffff,
  0xc018000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x400fffffffffffff,
  0x400fffffffffffff,
  0x400fffffffffffff,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0xffe0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0xffdfffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0xffdffffffffffffd,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0xfc9fffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x0000000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7cafffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7fdfffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x3fd23456789abccf,
  0x3fd23456789abccf,
  0x3fe91a2b3c4d5e67,
  0x3fe91a2b3c4d5e68,
  0x3fe91a2b3c4d5e69,
  0x3ff48d159e26af33,
  0x3ff48d159e26af34,
  0x3ff48d159e26af35,
  0x3ffc8d159e26af34,
  0x402491a2b3c4d5e6,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fd23456789abccf,
  0x3fd23456789abccf,
  0x3fd23456789abccf,
  0x3fd23456789abccf,
  0x3fd23456789abccf,
  0xbfcb97530eca865f,
  0xbfcb97530eca8661,
  0xbfcb97530eca8665,
  0xbfe6e5d4c3b2a197,
  0xbfe6e5d4c3b2a198,
  0xbfe6e5d4c3b2a19a,
  0xbff372ea61d950cc,
  0xc0236e5d4c3b2a1a,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fd23456789abccf,
  0x3fd23456789abccf,
  0x3fd23456789abccf,
  0x400ffffffffffffd,
  0x400ffffffffffffd,
  0x4011fffffffffffe,
  0x4011ffffffffffff,
  0x4011ffffffffffff,
  0x4013fffffffffffe,
  0x4013ffffffffffff,
  0x4013ffffffffffff,
  0x4015ffffffffffff,
  0x402bffffffffffff,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x400ffffffffffffd,
  0x400ffffffffffffd,
  0x400ffffffffffffd,
  0x400ffffffffffffd,
  0x400ffffffffffffd,
  0x400bfffffffffffd,
  0x400bfffffffffffd,
  0x400bfffffffffffd,
  0x4007fffffffffffd,
  0x4007fffffffffffd,
  0x4007fffffffffffd,
  0x4003fffffffffffd,
  0xc018000000000001,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x400ffffffffffffd,
  0x400ffffffffffffd,
  0x400ffffffffffffd,
  0x3ccfffffffffffff,
  0x3ccfffffffffffff,
  0x3fe0000000000007,
  0x3fe0000000000008,
  0x3fe0000000000009,
  0x3ff0000000000003,
  0x3ff0000000000004,
  0x3ff0000000000005,
  0x3ff8000000000004,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3ccfffffffffffff,
  0x3ccfffffffffffff,
  0x3ccfffffffffffff,
  0x3ccfffffffffffff,
  0x3ccfffffffffffff,
  0xbfdfffffffffffef,
  0xbfdffffffffffff0,
  0xbfdffffffffffff2,
  0xbfeffffffffffff7,
  0xbfeffffffffffff8,
  0xbfeffffffffffffa,
  0xbff7fffffffffffc,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3ccfffffffffffff,
  0x3ccfffffffffffff,
  0x3ccfffffffffffff,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x800091a2b3c4d5e6,
  0x000f6e5d4c3b2a1a,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000091a2b3c4d5e7,
  0x000f6e5d4c3b2a19,
  0x800091a2b3c4d5e5,
  0x800091a2b3c4d5e6,
  0x801091a2b3c4d5e6,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x8001b4e81b4e81b3,
  0x801091a2b3c4d5e5,
  0x800091a2b3c4d5e7,
  0x800091a2b3c4d5e6,
  0x000f6e5d4c3b2a1a,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000091a2b3c4d5e6,
  0x000f6e5d4c3b2a18,
  0x800091a2b3c4d5e6,
  0x800091a2b3c4d5e6,
  0x801091a2b3c4d5e6,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x8001b4e81b4e81b4,
  0x801091a2b3c4d5e6,
  0x800091a2b3c4d5e8,
  0x800091a2b3c4d5e7,
  0x000f6e5d4c3b2a19,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000091a2b3c4d5e6,
  0x000f6e5d4c3b2a18,
  0x800091a2b3c4d5e6,
  0x800091a2b3c4d5e7,
  0x801091a2b3c4d5e7,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x8001b4e81b4e81b4,
  0x801091a2b3c4d5e6,
  0x800091a2b3c4d5e8,
  0x800123456789abcd,
  0x000edcba98765433,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0000000000000000,
  0x000edcba98765432,
  0x800123456789abcc,
  0x800123456789abcd,
  0x801123456789abcd,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x8002468acf13579a,
  0x801123456789abcc,
  0x800123456789abce,
  0x800123456789abcd,
  0x000edcba98765433,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0000000000000000,
  0x000edcba98765432,
  0x800123456789abcc,
  0x800123456789abcd,
  0x801123456789abcd,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x8002468acf13579a,
  0x801123456789abcc,
  0x800123456789abce,
  0x800123456789abcd,
  0x000edcba98765433,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8000000000000000,
  0x000edcba98765432,
  0x800123456789abcc,
  0x800123456789abcd,
  0x801123456789abcd,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x8002468acf13579a,
  0x801123456789abcc,
  0x800123456789abce,
  0x8001b4e81b4e81b4,
  0x000e4b17e4b17e4c,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x800091a2b3c4d5e6,
  0x000e4b17e4b17e4c,
  0x8001b4e81b4e81b2,
  0x8001b4e81b4e81b4,
  0x8011b4e81b4e81b4,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x8002d82d82d82d80,
  0x8011b4e81b4e81b2,
  0x8001b4e81b4e81b4,
  0x800b60b60b60b602,
  0x00049f49f49f49fe,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x800a3d70a3d70a35,
  0x00049f49f49f49fd,
  0x800b60b60b60b601,
  0x800b60b60b60b602,
  0x801b60b60b60b602,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800c83fb72ea61cf,
  0x801b60b60b60b601,
  0x800b60b60b60b603,
  0xbfd23456789abccf,
  0xbfd23456789abccf,
  0x3fcb97530eca865f,
  0x3fcb97530eca8661,
  0x3fcb97530eca8665,
  0x3fe6e5d4c3b2a197,
  0x3fe6e5d4c3b2a198,
  0x3fe6e5d4c3b2a19a,
  0x3ff372ea61d950cc,
  0x40236e5d4c3b2a1a,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfd23456789abccf,
  0xbfd23456789abccf,
  0xbfd23456789abccf,
  0xbfd23456789abccf,
  0xbfd23456789abccf,
  0xbfe91a2b3c4d5e67,
  0xbfe91a2b3c4d5e68,
  0xbfe91a2b3c4d5e69,
  0xbff48d159e26af33,
  0xbff48d159e26af34,
  0xbff48d159e26af35,
  0xbffc8d159e26af34,
  0xc02491a2b3c4d5e6,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfd23456789abccf,
  0xbfd23456789abccf,
  0xbfd23456789abccf,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x000091a2b3c4d5e6,
  0x001091a2b3c4d5e6,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0001b4e81b4e81b3,
  0x001091a2b3c4d5e5,
  0x000091a2b3c4d5e7,
  0x000091a2b3c4d5e6,
  0x800f6e5d4c3b2a1a,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800091a2b3c4d5e7,
  0x800f6e5d4c3b2a19,
  0x000091a2b3c4d5e5,
  0x000091a2b3c4d5e6,
  0x001091a2b3c4d5e6,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0001b4e81b4e81b4,
  0x001091a2b3c4d5e6,
  0x000091a2b3c4d5e8,
  0x000091a2b3c4d5e6,
  0x800f6e5d4c3b2a1a,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800091a2b3c4d5e6,
  0x800f6e5d4c3b2a18,
  0x000091a2b3c4d5e6,
  0x000091a2b3c4d5e7,
  0x001091a2b3c4d5e7,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0001b4e81b4e81b4,
  0x001091a2b3c4d5e6,
  0x000091a2b3c4d5e8,
  0x000091a2b3c4d5e7,
  0x800f6e5d4c3b2a19,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800091a2b3c4d5e6,
  0x800f6e5d4c3b2a18,
  0x000091a2b3c4d5e6,
  0x000123456789abcd,
  0x001123456789abcd,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0002468acf13579a,
  0x001123456789abcc,
  0x000123456789abce,
  0x000123456789abcd,
  0x800edcba98765433,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x8000000000000000,
  0x800edcba98765432,
  0x000123456789abcc,
  0x000123456789abcd,
  0x001123456789abcd,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0002468acf13579a,
  0x001123456789abcc,
  0x000123456789abce,
  0x000123456789abcd,
  0x800edcba98765433,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0000000000000000,
  0x800edcba98765432,
  0x000123456789abcc,
  0x000123456789abcd,
  0x001123456789abcd,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0002468acf13579a,
  0x001123456789abcc,
  0x000123456789abce,
  0x000123456789abcd,
  0x800edcba98765433,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0000000000000000,
  0x800edcba98765432,
  0x000123456789abcc,
  0x0001b4e81b4e81b4,
  0x0011b4e81b4e81b4,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0002d82d82d82d80,
  0x0011b4e81b4e81b2,
  0x0001b4e81b4e81b4,
  0x0001b4e81b4e81b4,
  0x800e4b17e4b17e4c,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x000091a2b3c4d5e6,
  0x800e4b17e4b17e4c,
  0x0001b4e81b4e81b2,
  0x000b60b60b60b602,
  0x001b60b60b60b602,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000c83fb72ea61cf,
  0x001b60b60b60b601,
  0x000b60b60b60b603,
  0x000b60b60b60b602,
  0x80049f49f49f49fe,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x000a3d70a3d70a35,
  0x80049f49f49f49fd,
  0x000b60b60b60b601,
  0x3fd23456789abccf,
  0x3fd23456789abccf,
  0x3fe91a2b3c4d5e67,
  0x3fe91a2b3c4d5e68,
  0x3fe91a2b3c4d5e69,
  0x3ff48d159e26af33,
  0x3ff48d159e26af34,
  0x3ff48d159e26af35,
  0x3ffc8d159e26af34,
  0x402491a2b3c4d5e6,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fd23456789abccf,
  0x3fd23456789abccf,
  0x3fd23456789abccf,
  0x3fd23456789abccf,
  0x3fd23456789abccf,
  0xbfcb97530eca865f,
  0xbfcb97530eca8661,
  0xbfcb97530eca8665,
  0xbfe6e5d4c3b2a197,
  0xbfe6e5d4c3b2a198,
  0xbfe6e5d4c3b2a19a,
  0xbff372ea61d950cc,
  0xc0236e5d4c3b2a1a,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fd23456789abccf,
  0x3fd23456789abccf,
  0x3fd23456789abccf,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8007ffffffffffff,
  0x0008000000000001,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8006dcba98765432,
  0x0008000000000000,
  0x8007fffffffffffe,
  0x8007ffffffffffff,
  0x8017ffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800923456789abcc,
  0x8017fffffffffffe,
  0x8008000000000000,
  0x8008000000000000,
  0x0008000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8006dcba98765432,
  0x0008000000000000,
  0x8007fffffffffffe,
  0x8008000000000000,
  0x8018000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800923456789abcc,
  0x8017fffffffffffe,
  0x8008000000000000,
  0x8008000000000000,
  0x0008000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8006dcba98765433,
  0x0007ffffffffffff,
  0x8007ffffffffffff,
  0x8008000000000000,
  0x8018000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800923456789abcd,
  0x8017ffffffffffff,
  0x8008000000000001,
  0x800fffffffffffff,
  0x0000000000000001,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x800edcba98765432,
  0x0000000000000000,
  0x800ffffffffffffe,
  0x800fffffffffffff,
  0x801fffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x801123456789abcc,
  0x801ffffffffffffe,
  0x8010000000000000,
  0x800fffffffffffff,
  0x0000000000000001,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x800edcba98765432,
  0x0000000000000000,
  0x800ffffffffffffe,
  0x800fffffffffffff,
  0x801fffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x801123456789abcc,
  0x801ffffffffffffe,
  0x8010000000000000,
  0x8010000000000000,
  0x0000000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x800edcba98765433,
  0x8000000000000001,
  0x800fffffffffffff,
  0x8010000000000000,
  0x8020000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x801123456789abcd,
  0x801fffffffffffff,
  0x8010000000000001,
  0x8017fffffffffffe,
  0x8007fffffffffffe,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8016dcba98765432,
  0x8008000000000000,
  0x8017fffffffffffe,
  0x8017fffffffffffe,
  0x8023ffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x801923456789abcc,
  0x8023ffffffffffff,
  0x8018000000000000,
  0x8043ffffffffffff,
  0x8041ffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8043db97530eca85,
  0x8041ffffffffffff,
  0x8043ffffffffffff,
  0x8043ffffffffffff,
  0x8045ffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x80442468acf13578,
  0x8045ffffffffffff,
  0x8043ffffffffffff,
  0xc00ffffffffffffd,
  0xc00ffffffffffffd,
  0xc00bfffffffffffd,
  0xc00bfffffffffffd,
  0xc00bfffffffffffd,
  0xc007fffffffffffd,
  0xc007fffffffffffd,
  0xc007fffffffffffd,
  0xc003fffffffffffd,
  0x4018000000000001,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc00ffffffffffffd,
  0xc00ffffffffffffd,
  0xc00ffffffffffffd,
  0xc00ffffffffffffd,
  0xc00ffffffffffffd,
  0xc011fffffffffffe,
  0xc011ffffffffffff,
  0xc011ffffffffffff,
  0xc013fffffffffffe,
  0xc013ffffffffffff,
  0xc013ffffffffffff,
  0xc015ffffffffffff,
  0xc02bffffffffffff,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc00ffffffffffffd,
  0xc00ffffffffffffd,
  0xc00ffffffffffffd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0007ffffffffffff,
  0x0017ffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000923456789abcc,
  0x0017fffffffffffe,
  0x0008000000000000,
  0x0007ffffffffffff,
  0x8008000000000001,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0006dcba98765432,
  0x8008000000000000,
  0x0007fffffffffffe,
  0x0008000000000000,
  0x0018000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000923456789abcc,
  0x0017fffffffffffe,
  0x0008000000000000,
  0x0008000000000000,
  0x8008000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0006dcba98765432,
  0x8008000000000000,
  0x0007fffffffffffe,
  0x0008000000000000,
  0x0018000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000923456789abcd,
  0x0017ffffffffffff,
  0x0008000000000001,
  0x0008000000000000,
  0x8008000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0006dcba98765433,
  0x8007ffffffffffff,
  0x0007ffffffffffff,
  0x000fffffffffffff,
  0x001fffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x001123456789abcc,
  0x001ffffffffffffe,
  0x0010000000000000,
  0x000fffffffffffff,
  0x8000000000000001,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x000edcba98765432,
  0x8000000000000000,
  0x000ffffffffffffe,
  0x000fffffffffffff,
  0x001fffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x001123456789abcc,
  0x001ffffffffffffe,
  0x0010000000000000,
  0x000fffffffffffff,
  0x8000000000000001,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x000edcba98765432,
  0x0000000000000000,
  0x000ffffffffffffe,
  0x0010000000000000,
  0x0020000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x001123456789abcd,
  0x001fffffffffffff,
  0x0010000000000001,
  0x0010000000000000,
  0x8000000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x000edcba98765433,
  0x0000000000000001,
  0x000fffffffffffff,
  0x0017fffffffffffe,
  0x0023ffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x001923456789abcc,
  0x0023ffffffffffff,
  0x0018000000000000,
  0x0017fffffffffffe,
  0x0007fffffffffffe,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0016dcba98765432,
  0x0008000000000000,
  0x0017fffffffffffe,
  0x0043ffffffffffff,
  0x0045ffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x00442468acf13578,
  0x0045ffffffffffff,
  0x0043ffffffffffff,
  0x0043ffffffffffff,
  0x0041ffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0043db97530eca85,
  0x0041ffffffffffff,
  0x0043ffffffffffff,
  0x400ffffffffffffd,
  0x400ffffffffffffd,
  0x4011fffffffffffe,
  0x4011ffffffffffff,
  0x4011ffffffffffff,
  0x4013fffffffffffe,
  0x4013ffffffffffff,
  0x4013ffffffffffff,
  0x4015ffffffffffff,
  0x402bffffffffffff,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x400ffffffffffffd,
  0x400ffffffffffffd,
  0x400ffffffffffffd,
  0x400ffffffffffffd,
  0x400ffffffffffffd,
  0x400bfffffffffffd,
  0x400bfffffffffffd,
  0x400bfffffffffffd,
  0x4007fffffffffffd,
  0x4007fffffffffffd,
  0x4007fffffffffffd,
  0x4003fffffffffffd,
  0xc018000000000001,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x400ffffffffffffd,
  0x400ffffffffffffd,
  0x400ffffffffffffd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcc,
  0x000ffffffffffffe,
  0x0000000000000000,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abce,
  0x8010000000000000,
  0x8000000000000002,
  0x8000000000000001,
  0x000fffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcc,
  0x000ffffffffffffe,
  0x0000000000000000,
  0x8000000000000001,
  0x8010000000000001,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abce,
  0x8010000000000000,
  0x8000000000000002,
  0x8000000000000001,
  0x000fffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcc,
  0x000ffffffffffffe,
  0x0000000000000000,
  0x8000000000000001,
  0x8010000000000001,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abce,
  0x8010000000000000,
  0x8000000000000002,
  0x8000000000000001,
  0x000fffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcc,
  0x000ffffffffffffe,
  0x0000000000000000,
  0x8000000000000001,
  0x8010000000000001,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abce,
  0x8010000000000000,
  0x8000000000000002,
  0x8000000000000001,
  0x000fffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcc,
  0x000ffffffffffffe,
  0x8000000000000000,
  0x8000000000000001,
  0x8010000000000001,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abce,
  0x8010000000000000,
  0x8000000000000002,
  0x8000000000000002,
  0x000ffffffffffffe,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcc,
  0x000ffffffffffffe,
  0x8000000000000000,
  0x8000000000000002,
  0x8010000000000002,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abce,
  0x8010000000000000,
  0x8000000000000002,
  0x800000000000000a,
  0x000ffffffffffff6,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abc3,
  0x000ffffffffffff5,
  0x8000000000000009,
  0x800000000000000a,
  0x801000000000000a,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abd7,
  0x8010000000000009,
  0x800000000000000b,
  0xbccfffffffffffff,
  0xbccfffffffffffff,
  0x3fdfffffffffffef,
  0x3fdffffffffffff0,
  0x3fdffffffffffff2,
  0x3feffffffffffff7,
  0x3feffffffffffff8,
  0x3feffffffffffffa,
  0x3ff7fffffffffffc,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbccfffffffffffff,
  0xbccfffffffffffff,
  0xbccfffffffffffff,
  0xbccfffffffffffff,
  0xbccfffffffffffff,
  0xbfe0000000000007,
  0xbfe0000000000008,
  0xbfe0000000000009,
  0xbff0000000000003,
  0xbff0000000000004,
  0xbff0000000000005,
  0xbff8000000000004,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbccfffffffffffff,
  0xbccfffffffffffff,
  0xbccfffffffffffff,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abce,
  0x0010000000000000,
  0x0000000000000002,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcc,
  0x800ffffffffffffe,
  0x8000000000000000,
  0x0000000000000001,
  0x0010000000000001,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abce,
  0x0010000000000000,
  0x0000000000000002,
  0x0000000000000001,
  0x800fffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcc,
  0x800ffffffffffffe,
  0x8000000000000000,
  0x0000000000000001,
  0x0010000000000001,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abce,
  0x0010000000000000,
  0x0000000000000002,
  0x0000000000000001,
  0x800fffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcc,
  0x800ffffffffffffe,
  0x8000000000000000,
  0x0000000000000001,
  0x0010000000000001,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abce,
  0x0010000000000000,
  0x0000000000000002,
  0x0000000000000001,
  0x800fffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcc,
  0x800ffffffffffffe,
  0x0000000000000000,
  0x0000000000000001,
  0x0010000000000001,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abce,
  0x0010000000000000,
  0x0000000000000002,
  0x0000000000000001,
  0x800fffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcc,
  0x800ffffffffffffe,
  0x0000000000000000,
  0x0000000000000002,
  0x0010000000000002,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abce,
  0x0010000000000000,
  0x0000000000000002,
  0x0000000000000002,
  0x800ffffffffffffe,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcc,
  0x800ffffffffffffe,
  0x0000000000000000,
  0x000000000000000a,
  0x001000000000000a,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abd7,
  0x0010000000000009,
  0x000000000000000b,
  0x000000000000000a,
  0x800ffffffffffff6,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abc3,
  0x800ffffffffffff5,
  0x0000000000000009,
  0x3ccfffffffffffff,
  0x3ccfffffffffffff,
  0x3fe0000000000007,
  0x3fe0000000000008,
  0x3fe0000000000009,
  0x3ff0000000000003,
  0x3ff0000000000004,
  0x3ff0000000000005,
  0x3ff8000000000004,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3ccfffffffffffff,
  0x3ccfffffffffffff,
  0x3ccfffffffffffff,
  0x3ccfffffffffffff,
  0x3ccfffffffffffff,
  0xbfdfffffffffffef,
  0xbfdffffffffffff0,
  0xbfdffffffffffff2,
  0xbfeffffffffffff7,
  0xbfeffffffffffff8,
  0xbfeffffffffffffa,
  0xbff7fffffffffffc,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3ccfffffffffffff,
  0x3ccfffffffffffff,
  0x3ccfffffffffffff,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
};
const unsigned kExpectedCount_fmadd_d = 54872;

const uint32_t kExpected_fmadd_s[] = {
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00400000,
  0x00c00000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00523456,
  0x00bfffff,
  0x00400001,
  0x00400000,
  0x80400000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x002dcbaa,
  0x803fffff,
  0x003fffff,
  0x00400000,
  0x00c00000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00523456,
  0x00bfffff,
  0x00400001,
  0x00400000,
  0x80400000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x002dcbaa,
  0x803fffff,
  0x003fffff,
  0x00400000,
  0x00c00000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00523456,
  0x00c00000,
  0x00400002,
  0x00400000,
  0x80400000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x002dcbaa,
  0x803ffffe,
  0x00400000,
  0x00800000,
  0x01000000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00923456,
  0x00fffffe,
  0x00800000,
  0x00800000,
  0x80000000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x006dcbaa,
  0x00000000,
  0x007ffffe,
  0x00800000,
  0x01000000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00923456,
  0x00ffffff,
  0x00800001,
  0x00800000,
  0x00000000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x006dcbaa,
  0x00000001,
  0x007fffff,
  0x00800001,
  0x01000000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00923457,
  0x01000000,
  0x00800002,
  0x00800001,
  0x00000001,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x006dcbab,
  0x00000002,
  0x00800000,
  0x00c00000,
  0x01200000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00d23456,
  0x01200000,
  0x00c00001,
  0x00c00000,
  0x00400000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x00adcbaa,
  0x00400001,
  0x00bfffff,
  0x02200000,
  0x02300000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x0222468b,
  0x02300000,
  0x02200000,
  0x02200000,
  0x02100000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x021db975,
  0x02100000,
  0x02200000,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80400000,
  0x00400000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x802dcbaa,
  0x003fffff,
  0x803fffff,
  0x80400000,
  0x80c00000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80523456,
  0x80bfffff,
  0x80400001,
  0x80400000,
  0x00400000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x802dcbaa,
  0x003fffff,
  0x803fffff,
  0x80400000,
  0x80c00000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80523456,
  0x80bfffff,
  0x80400001,
  0x80400000,
  0x00400000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x802dcbaa,
  0x003ffffe,
  0x80400000,
  0x80400000,
  0x80c00000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80523456,
  0x80c00000,
  0x80400002,
  0x80800000,
  0x00000000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x806dcbaa,
  0x80000000,
  0x807ffffe,
  0x80800000,
  0x81000000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80923456,
  0x80fffffe,
  0x80800000,
  0x80800000,
  0x00000000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x806dcbaa,
  0x80000001,
  0x807fffff,
  0x80800000,
  0x81000000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80923456,
  0x80ffffff,
  0x80800001,
  0x80800001,
  0x80000001,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x806dcbab,
  0x80000002,
  0x80800000,
  0x80800001,
  0x81000000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80923457,
  0x81000000,
  0x80800002,
  0x80c00000,
  0x80400000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x80adcbaa,
  0x80400001,
  0x80bfffff,
  0x80c00000,
  0x81200000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80d23456,
  0x81200000,
  0x80c00001,
  0x82200000,
  0x82100000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x821db975,
  0x82100000,
  0x82200000,
  0x82200000,
  0x82300000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x8222468b,
  0x82300000,
  0x82200000,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00400000,
  0x00c00000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00523456,
  0x00bfffff,
  0x00400001,
  0x00400000,
  0x80400000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x002dcbaa,
  0x803fffff,
  0x003fffff,
  0x3e7ffffe,
  0x3e7ffffe,
  0x3f3fffff,
  0x3f400000,
  0x3f400001,
  0x3f9fffff,
  0x3fa00000,
  0x3fa00001,
  0x3fe00000,
  0x41240000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3e7ffffe,
  0x3e7ffffe,
  0x3e7ffffe,
  0x3e7ffffe,
  0x3e7ffffe,
  0xbe800000,
  0xbe800001,
  0xbe800003,
  0xbf3fffff,
  0xbf400000,
  0xbf400002,
  0xbfa00000,
  0xc11c0000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3e7ffffe,
  0x3e7ffffe,
  0x3e7ffffe,
  0x3e7fffff,
  0x3e7fffff,
  0x3f3fffff,
  0x3f400000,
  0x3f400001,
  0x3f9fffff,
  0x3fa00000,
  0x3fa00001,
  0x3fe00000,
  0x41240000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3e7fffff,
  0x3e7fffff,
  0x3e7fffff,
  0x3e7fffff,
  0x3e7fffff,
  0xbe7fffff,
  0xbe800000,
  0xbe800002,
  0xbf3fffff,
  0xbf400000,
  0xbf400002,
  0xbfa00000,
  0xc11c0000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3e7fffff,
  0x3e7fffff,
  0x3e7fffff,
  0x3e800000,
  0x3e800000,
  0x3f400000,
  0x3f400000,
  0x3f400001,
  0x3fa00000,
  0x3fa00000,
  0x3fa00001,
  0x3fe00000,
  0x41240000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3e800000,
  0x3e800000,
  0x3e800000,
  0x3e800000,
  0x3e800000,
  0xbe7ffffd,
  0xbe7fffff,
  0xbe800002,
  0xbf3fffff,
  0xbf400000,
  0xbf400002,
  0xbfa00000,
  0xc11c0000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3e800000,
  0x3e800000,
  0x3e800000,
  0x3efffffe,
  0x3efffffe,
  0x3f7fffff,
  0x3f7fffff,
  0x3f800000,
  0x3fbfffff,
  0x3fc00000,
  0x3fc00001,
  0x40000000,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3efffffe,
  0x3efffffe,
  0x3efffffe,
  0x3efffffe,
  0x3efffffe,
  0xb2ffffff,
  0xb3800000,
  0xb4000000,
  0xbf000000,
  0xbf000001,
  0xbf000003,
  0xbf800000,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3efffffe,
  0x3efffffe,
  0x3efffffe,
  0x3effffff,
  0x3effffff,
  0x3f7fffff,
  0x3f800000,
  0x3f800000,
  0x3fbfffff,
  0x3fc00000,
  0x3fc00001,
  0x40000000,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x00000000,
  0xb3000000,
  0xb3c00000,
  0xbeffffff,
  0xbf000000,
  0xbf000002,
  0xbf800000,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3f000000,
  0x3f000000,
  0x3f800000,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x3fc00000,
  0x3fc00001,
  0x40000000,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x337fffff,
  0x32fffffe,
  0xb3000001,
  0xbefffffd,
  0xbeffffff,
  0xbf000002,
  0xbf800000,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f3fffff,
  0x3f3fffff,
  0x3f9fffff,
  0x3fa00000,
  0x3fa00000,
  0x3fdfffff,
  0x3fe00000,
  0x3fe00001,
  0x40100000,
  0x412c0000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f3fffff,
  0x3f3fffff,
  0x3f3fffff,
  0x3f3fffff,
  0x3f3fffff,
  0x3e7fffff,
  0x3e7ffffd,
  0x3e7ffff9,
  0xbe7fffff,
  0xbe800002,
  0xbe800006,
  0xbf400001,
  0xc1140000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f3fffff,
  0x3f3fffff,
  0x3f3fffff,
  0x409fffff,
  0x409fffff,
  0x40afffff,
  0x40afffff,
  0x40b00000,
  0x40bfffff,
  0x40bfffff,
  0x40c00000,
  0x40cfffff,
  0x41700000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x409fffff,
  0x409fffff,
  0x409fffff,
  0x409fffff,
  0x409fffff,
  0x408fffff,
  0x408fffff,
  0x408fffff,
  0x407fffff,
  0x407fffff,
  0x407ffffe,
  0x405fffff,
  0xc0a00001,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x409fffff,
  0x409fffff,
  0x409fffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x00091a2b,
  0x00891a2b,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x001b4e81,
  0x00891a2a,
  0x00091a2c,
  0x00091a2b,
  0x8076e5d5,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80091a2b,
  0x8076e5d4,
  0x00091a2a,
  0x003fffff,
  0x00bfffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00523455,
  0x00bffffe,
  0x00400000,
  0x003fffff,
  0x80400001,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x002dcba9,
  0x80400000,
  0x003ffffe,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80400000,
  0x00400000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x802dcbaa,
  0x003fffff,
  0x803fffff,
  0x80400000,
  0x80c00000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80523456,
  0x80bfffff,
  0x80400001,
  0xbe7ffffe,
  0xbe7ffffe,
  0x3e800000,
  0x3e800001,
  0x3e800003,
  0x3f3fffff,
  0x3f400000,
  0x3f400002,
  0x3fa00000,
  0x411c0000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbe7ffffe,
  0xbe7ffffe,
  0xbe7ffffe,
  0xbe7ffffe,
  0xbe7ffffe,
  0xbf3fffff,
  0xbf400000,
  0xbf400001,
  0xbf9fffff,
  0xbfa00000,
  0xbfa00001,
  0xbfe00000,
  0xc1240000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbe7ffffe,
  0xbe7ffffe,
  0xbe7ffffe,
  0xbe7fffff,
  0xbe7fffff,
  0x3e7fffff,
  0x3e800000,
  0x3e800002,
  0x3f3fffff,
  0x3f400000,
  0x3f400002,
  0x3fa00000,
  0x411c0000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbe7fffff,
  0xbe7fffff,
  0xbe7fffff,
  0xbe7fffff,
  0xbe7fffff,
  0xbf3fffff,
  0xbf400000,
  0xbf400001,
  0xbf9fffff,
  0xbfa00000,
  0xbfa00001,
  0xbfe00000,
  0xc1240000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbe7fffff,
  0xbe7fffff,
  0xbe7fffff,
  0xbe800000,
  0xbe800000,
  0x3e7ffffd,
  0x3e7fffff,
  0x3e800002,
  0x3f3fffff,
  0x3f400000,
  0x3f400002,
  0x3fa00000,
  0x411c0000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbe800000,
  0xbe800000,
  0xbe800000,
  0xbe800000,
  0xbe800000,
  0xbf400000,
  0xbf400000,
  0xbf400001,
  0xbfa00000,
  0xbfa00000,
  0xbfa00001,
  0xbfe00000,
  0xc1240000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbe800000,
  0xbe800000,
  0xbe800000,
  0xbefffffe,
  0xbefffffe,
  0x32ffffff,
  0x33800000,
  0x34000000,
  0x3f000000,
  0x3f000001,
  0x3f000003,
  0x3f800000,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbefffffe,
  0xbefffffe,
  0xbefffffe,
  0xbefffffe,
  0xbefffffe,
  0xbf7fffff,
  0xbf7fffff,
  0xbf800000,
  0xbfbfffff,
  0xbfc00000,
  0xbfc00001,
  0xc0000000,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbefffffe,
  0xbefffffe,
  0xbefffffe,
  0xbeffffff,
  0xbeffffff,
  0x00000000,
  0x33000000,
  0x33c00000,
  0x3effffff,
  0x3f000000,
  0x3f000002,
  0x3f800000,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbf7fffff,
  0xbf800000,
  0xbf800000,
  0xbfbfffff,
  0xbfc00000,
  0xbfc00001,
  0xc0000000,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbf000000,
  0xbf000000,
  0xb37fffff,
  0xb2fffffe,
  0x33000001,
  0x3efffffd,
  0x3effffff,
  0x3f000002,
  0x3f800000,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf800000,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xbfc00000,
  0xbfc00001,
  0xc0000000,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf3fffff,
  0xbf3fffff,
  0xbe7fffff,
  0xbe7ffffd,
  0xbe7ffff9,
  0x3e7fffff,
  0x3e800002,
  0x3e800006,
  0x3f400001,
  0x41140000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf3fffff,
  0xbf3fffff,
  0xbf3fffff,
  0xbf3fffff,
  0xbf3fffff,
  0xbf9fffff,
  0xbfa00000,
  0xbfa00000,
  0xbfdfffff,
  0xbfe00000,
  0xbfe00001,
  0xc0100000,
  0xc12c0000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf3fffff,
  0xbf3fffff,
  0xbf3fffff,
  0xc09fffff,
  0xc09fffff,
  0xc08fffff,
  0xc08fffff,
  0xc08fffff,
  0xc07fffff,
  0xc07fffff,
  0xc07ffffe,
  0xc05fffff,
  0x40a00001,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xc09fffff,
  0xc09fffff,
  0xc09fffff,
  0xc09fffff,
  0xc09fffff,
  0xc0afffff,
  0xc0afffff,
  0xc0b00000,
  0xc0bfffff,
  0xc0bfffff,
  0xc0c00000,
  0xc0cfffff,
  0xc1700000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xc09fffff,
  0xc09fffff,
  0xc09fffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x80091a2b,
  0x0076e5d5,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00091a2b,
  0x0076e5d4,
  0x80091a2a,
  0x80091a2b,
  0x80891a2b,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x801b4e81,
  0x80891a2a,
  0x80091a2c,
  0x803fffff,
  0x00400001,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x802dcba9,
  0x00400000,
  0x803ffffe,
  0x803fffff,
  0x80bfffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80523455,
  0x80bffffe,
  0x80400000,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00400000,
  0x00c00000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00523456,
  0x00bfffff,
  0x00400001,
  0x00400000,
  0x80400000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x002dcbaa,
  0x803fffff,
  0x003fffff,
  0x3e7fffff,
  0x3e7fffff,
  0x3f3fffff,
  0x3f400000,
  0x3f400001,
  0x3f9fffff,
  0x3fa00000,
  0x3fa00001,
  0x3fe00000,
  0x41240000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3e7fffff,
  0x3e7fffff,
  0x3e7fffff,
  0x3e7fffff,
  0x3e7fffff,
  0xbe7fffff,
  0xbe800000,
  0xbe800002,
  0xbf3fffff,
  0xbf400000,
  0xbf400002,
  0xbfa00000,
  0xc11c0000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3e7fffff,
  0x3e7fffff,
  0x3e7fffff,
  0x3e800000,
  0x3e800000,
  0x3f400000,
  0x3f400000,
  0x3f400001,
  0x3fa00000,
  0x3fa00000,
  0x3fa00001,
  0x3fe00000,
  0x41240000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3e800000,
  0x3e800000,
  0x3e800000,
  0x3e800000,
  0x3e800000,
  0xbe7ffffe,
  0xbe800000,
  0xbe800002,
  0xbf3fffff,
  0xbf400000,
  0xbf400002,
  0xbfa00000,
  0xc11c0000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3e800000,
  0x3e800000,
  0x3e800000,
  0x3e800001,
  0x3e800001,
  0x3f400000,
  0x3f400000,
  0x3f400002,
  0x3fa00000,
  0x3fa00000,
  0x3fa00001,
  0x3fe00000,
  0x41240000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3e800001,
  0x3e800001,
  0x3e800001,
  0x3e800001,
  0x3e800001,
  0xbe7ffffc,
  0xbe7ffffe,
  0xbe800001,
  0xbf3ffffe,
  0xbf400000,
  0xbf400002,
  0xbfa00000,
  0xc11c0000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3e800001,
  0x3e800001,
  0x3e800001,
  0x3effffff,
  0x3effffff,
  0x3f7fffff,
  0x3f800000,
  0x3f800000,
  0x3fbfffff,
  0x3fc00000,
  0x3fc00001,
  0x40000000,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x00000000,
  0xb3000000,
  0xb3c00000,
  0xbeffffff,
  0xbf000000,
  0xbf000002,
  0xbf800000,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3f000000,
  0x3f000000,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3fc00000,
  0x3fc00000,
  0x3fc00001,
  0x40000000,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x33000000,
  0x00000000,
  0xb3800000,
  0xbefffffe,
  0xbf000000,
  0xbf000002,
  0xbf800000,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000001,
  0x3f000001,
  0x3f800000,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x3fc00000,
  0x3fc00002,
  0x40000000,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x33c00000,
  0x33800000,
  0x00000000,
  0xbefffffc,
  0xbefffffe,
  0xbf000001,
  0xbf7fffff,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f400000,
  0x3f400000,
  0x3fa00000,
  0x3fa00000,
  0x3fa00000,
  0x3fe00000,
  0x3fe00000,
  0x3fe00001,
  0x40100000,
  0x412c0000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f400000,
  0x3f400000,
  0x3f400000,
  0x3f400000,
  0x3f400000,
  0x3e800001,
  0x3e800000,
  0x3e7ffffc,
  0xbe7ffffc,
  0xbe800000,
  0xbe800004,
  0xbf400000,
  0xc1140000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f400000,
  0x3f400000,
  0x3f400000,
  0x40a00000,
  0x40a00000,
  0x40b00000,
  0x40b00000,
  0x40b00000,
  0x40c00000,
  0x40c00000,
  0x40c00000,
  0x40d00000,
  0x41700000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x40a00000,
  0x40a00000,
  0x40a00000,
  0x40a00000,
  0x40a00000,
  0x40900000,
  0x40900000,
  0x40900000,
  0x40800000,
  0x40800000,
  0x40800000,
  0x40600000,
  0xc0a00000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x40a00000,
  0x40a00000,
  0x40a00000,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x00091a2b,
  0x00891a2b,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x001b4e81,
  0x00891a2a,
  0x00091a2c,
  0x00091a2b,
  0x8076e5d5,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80091a2b,
  0x8076e5d4,
  0x00091a2a,
  0x00400000,
  0x00c00000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00523456,
  0x00bffffe,
  0x00400000,
  0x00400000,
  0x80400000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x002dcbaa,
  0x80400000,
  0x003ffffe,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x00800000,
  0x00000002,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807ffffe,
  0x80000000,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80400000,
  0x00400000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x802dcbaa,
  0x003fffff,
  0x803fffff,
  0x80400000,
  0x80c00000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80523456,
  0x80bfffff,
  0x80400001,
  0xbe7fffff,
  0xbe7fffff,
  0x3e7fffff,
  0x3e800000,
  0x3e800002,
  0x3f3fffff,
  0x3f400000,
  0x3f400002,
  0x3fa00000,
  0x411c0000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbe7fffff,
  0xbe7fffff,
  0xbe7fffff,
  0xbe7fffff,
  0xbe7fffff,
  0xbf3fffff,
  0xbf400000,
  0xbf400001,
  0xbf9fffff,
  0xbfa00000,
  0xbfa00001,
  0xbfe00000,
  0xc1240000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbe7fffff,
  0xbe7fffff,
  0xbe7fffff,
  0xbe800000,
  0xbe800000,
  0x3e7ffffe,
  0x3e800000,
  0x3e800002,
  0x3f3fffff,
  0x3f400000,
  0x3f400002,
  0x3fa00000,
  0x411c0000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbe800000,
  0xbe800000,
  0xbe800000,
  0xbe800000,
  0xbe800000,
  0xbf400000,
  0xbf400000,
  0xbf400001,
  0xbfa00000,
  0xbfa00000,
  0xbfa00001,
  0xbfe00000,
  0xc1240000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbe800000,
  0xbe800000,
  0xbe800000,
  0xbe800001,
  0xbe800001,
  0x3e7ffffc,
  0x3e7ffffe,
  0x3e800001,
  0x3f3ffffe,
  0x3f400000,
  0x3f400002,
  0x3fa00000,
  0x411c0000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbe800001,
  0xbe800001,
  0xbe800001,
  0xbe800001,
  0xbe800001,
  0xbf400000,
  0xbf400000,
  0xbf400002,
  0xbfa00000,
  0xbfa00000,
  0xbfa00001,
  0xbfe00000,
  0xc1240000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbe800001,
  0xbe800001,
  0xbe800001,
  0xbeffffff,
  0xbeffffff,
  0x00000000,
  0x33000000,
  0x33c00000,
  0x3effffff,
  0x3f000000,
  0x3f000002,
  0x3f800000,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbf7fffff,
  0xbf800000,
  0xbf800000,
  0xbfbfffff,
  0xbfc00000,
  0xbfc00001,
  0xc0000000,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbf000000,
  0xbf000000,
  0xb3000000,
  0x00000000,
  0x33800000,
  0x3efffffe,
  0x3f000000,
  0x3f000002,
  0x3f800000,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbfc00000,
  0xbfc00000,
  0xbfc00001,
  0xc0000000,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000001,
  0xbf000001,
  0xb3c00000,
  0xb3800000,
  0x00000000,
  0x3efffffc,
  0x3efffffe,
  0x3f000001,
  0x3f7fffff,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf800000,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xbfc00000,
  0xbfc00002,
  0xc0000000,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf400000,
  0xbf400000,
  0xbe800001,
  0xbe800000,
  0xbe7ffffc,
  0x3e7ffffc,
  0x3e800000,
  0x3e800004,
  0x3f400000,
  0x41140000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf400000,
  0xbf400000,
  0xbf400000,
  0xbf400000,
  0xbf400000,
  0xbfa00000,
  0xbfa00000,
  0xbfa00000,
  0xbfe00000,
  0xbfe00000,
  0xbfe00001,
  0xc0100000,
  0xc12c0000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf400000,
  0xbf400000,
  0xbf400000,
  0xc0a00000,
  0xc0a00000,
  0xc0900000,
  0xc0900000,
  0xc0900000,
  0xc0800000,
  0xc0800000,
  0xc0800000,
  0xc0600000,
  0x40a00000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xc0a00000,
  0xc0a00000,
  0xc0a00000,
  0xc0a00000,
  0xc0a00000,
  0xc0b00000,
  0xc0b00000,
  0xc0b00000,
  0xc0c00000,
  0xc0c00000,
  0xc0c00000,
  0xc0d00000,
  0xc1700000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xc0a00000,
  0xc0a00000,
  0xc0a00000,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x80091a2b,
  0x0076e5d5,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00091a2b,
  0x0076e5d4,
  0x80091a2a,
  0x80091a2b,
  0x80891a2b,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x801b4e81,
  0x80891a2a,
  0x80091a2c,
  0x80400000,
  0x00400000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x802dcbaa,
  0x00400000,
  0x803ffffe,
  0x80400000,
  0x80c00000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80523456,
  0x80bffffe,
  0x80400000,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007ffffe,
  0x00000000,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x80800000,
  0x80000002,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00400000,
  0x00c00000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00523456,
  0x00c00000,
  0x00400002,
  0x00400000,
  0x80400000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x002dcbaa,
  0x803ffffe,
  0x00400000,
  0x3e800000,
  0x3e800000,
  0x3f400000,
  0x3f400000,
  0x3f400001,
  0x3fa00000,
  0x3fa00000,
  0x3fa00001,
  0x3fe00000,
  0x41240000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3e800000,
  0x3e800000,
  0x3e800000,
  0x3e800000,
  0x3e800000,
  0xbe7ffffd,
  0xbe7fffff,
  0xbe800002,
  0xbf3fffff,
  0xbf400000,
  0xbf400002,
  0xbfa00000,
  0xc11c0000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3e800000,
  0x3e800000,
  0x3e800000,
  0x3e800001,
  0x3e800001,
  0x3f400000,
  0x3f400000,
  0x3f400002,
  0x3fa00000,
  0x3fa00000,
  0x3fa00001,
  0x3fe00000,
  0x41240000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3e800001,
  0x3e800001,
  0x3e800001,
  0x3e800001,
  0x3e800001,
  0xbe7ffffc,
  0xbe7ffffe,
  0xbe800001,
  0xbf3ffffe,
  0xbf400000,
  0xbf400002,
  0xbfa00000,
  0xc11c0000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3e800001,
  0x3e800001,
  0x3e800001,
  0x3e800002,
  0x3e800002,
  0x3f400001,
  0x3f400001,
  0x3f400002,
  0x3fa00000,
  0x3fa00001,
  0x3fa00002,
  0x3fe00001,
  0x41240000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3e800002,
  0x3e800002,
  0x3e800002,
  0x3e800002,
  0x3e800002,
  0xbe7ffffa,
  0xbe7ffffc,
  0xbe800000,
  0xbf3ffffe,
  0xbf3fffff,
  0xbf400001,
  0xbf9fffff,
  0xc11c0000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3e800002,
  0x3e800002,
  0x3e800002,
  0x3f000000,
  0x3f000000,
  0x3f800000,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x3fc00000,
  0x3fc00001,
  0x40000000,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x337fffff,
  0x32fffffe,
  0xb3000001,
  0xbefffffd,
  0xbeffffff,
  0xbf000002,
  0xbf800000,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000001,
  0x3f000001,
  0x3f800000,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x3fc00000,
  0x3fc00002,
  0x40000000,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x33c00000,
  0x33800000,
  0x00000000,
  0xbefffffc,
  0xbefffffe,
  0xbf000001,
  0xbf7fffff,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f000002,
  0x3f000002,
  0x3f800001,
  0x3f800001,
  0x3f800002,
  0x3fc00001,
  0x3fc00001,
  0x3fc00002,
  0x40000001,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f000002,
  0x3f000002,
  0x3f000002,
  0x3f000002,
  0x3f000002,
  0x34200000,
  0x34000000,
  0x33800001,
  0xbefffffa,
  0xbefffffc,
  0xbf000000,
  0xbf7ffffe,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f000002,
  0x3f000002,
  0x3f000002,
  0x3f400002,
  0x3f400002,
  0x3fa00000,
  0x3fa00001,
  0x3fa00001,
  0x3fe00000,
  0x3fe00001,
  0x3fe00002,
  0x40100000,
  0x412c0000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f400002,
  0x3f400002,
  0x3f400002,
  0x3f400002,
  0x3f400001,
  0x3e800004,
  0x3e800003,
  0x3e800001,
  0xbe7ffff6,
  0xbe7ffffa,
  0xbe800001,
  0xbf3ffffe,
  0xc1140000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f400001,
  0x3f400001,
  0x3f400001,
  0x40a00001,
  0x40a00001,
  0x40b00001,
  0x40b00001,
  0x40b00001,
  0x40c00001,
  0x40c00001,
  0x40c00002,
  0x40d00001,
  0x41700001,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x40a00001,
  0x40a00001,
  0x40a00001,
  0x40a00001,
  0x40a00001,
  0x40900001,
  0x40900001,
  0x40900001,
  0x40800001,
  0x40800001,
  0x40800001,
  0x40600002,
  0xc09fffff,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x40a00001,
  0x40a00001,
  0x40a00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x00091a2b,
  0x00891a2b,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x001b4e81,
  0x00891a2a,
  0x00091a2c,
  0x00091a2b,
  0x8076e5d5,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80091a2b,
  0x8076e5d4,
  0x00091a2a,
  0x00400000,
  0x00c00000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00523456,
  0x00bfffff,
  0x00400001,
  0x00400000,
  0x80400000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x002dcbaa,
  0x803fffff,
  0x003fffff,
  0x00000001,
  0x00800001,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123457,
  0x00800000,
  0x00000002,
  0x00000001,
  0x807fffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123455,
  0x807ffffe,
  0x80000000,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80400000,
  0x00400000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x802dcbaa,
  0x003ffffe,
  0x80400000,
  0x80400000,
  0x80c00000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80523456,
  0x80c00000,
  0x80400002,
  0xbe800000,
  0xbe800000,
  0x3e7ffffd,
  0x3e7fffff,
  0x3e800002,
  0x3f3fffff,
  0x3f400000,
  0x3f400002,
  0x3fa00000,
  0x411c0000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbe800000,
  0xbe800000,
  0xbe800000,
  0xbe800000,
  0xbe800000,
  0xbf400000,
  0xbf400000,
  0xbf400001,
  0xbfa00000,
  0xbfa00000,
  0xbfa00001,
  0xbfe00000,
  0xc1240000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbe800000,
  0xbe800000,
  0xbe800000,
  0xbe800001,
  0xbe800001,
  0x3e7ffffc,
  0x3e7ffffe,
  0x3e800001,
  0x3f3ffffe,
  0x3f400000,
  0x3f400002,
  0x3fa00000,
  0x411c0000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbe800001,
  0xbe800001,
  0xbe800001,
  0xbe800001,
  0xbe800001,
  0xbf400000,
  0xbf400000,
  0xbf400002,
  0xbfa00000,
  0xbfa00000,
  0xbfa00001,
  0xbfe00000,
  0xc1240000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbe800001,
  0xbe800001,
  0xbe800001,
  0xbe800002,
  0xbe800002,
  0x3e7ffffa,
  0x3e7ffffc,
  0x3e800000,
  0x3f3ffffe,
  0x3f3fffff,
  0x3f400001,
  0x3f9fffff,
  0x411c0000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbe800002,
  0xbe800002,
  0xbe800002,
  0xbe800002,
  0xbe800002,
  0xbf400001,
  0xbf400001,
  0xbf400002,
  0xbfa00000,
  0xbfa00001,
  0xbfa00002,
  0xbfe00001,
  0xc1240000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbe800002,
  0xbe800002,
  0xbe800002,
  0xbf000000,
  0xbf000000,
  0xb37fffff,
  0xb2fffffe,
  0x33000001,
  0x3efffffd,
  0x3effffff,
  0x3f000002,
  0x3f800000,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf800000,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xbfc00000,
  0xbfc00001,
  0xc0000000,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000001,
  0xbf000001,
  0xb3c00000,
  0xb3800000,
  0x00000000,
  0x3efffffc,
  0x3efffffe,
  0x3f000001,
  0x3f7fffff,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf800000,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xbfc00000,
  0xbfc00002,
  0xc0000000,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf000002,
  0xbf000002,
  0xb4200000,
  0xb4000000,
  0xb3800001,
  0x3efffffa,
  0x3efffffc,
  0x3f000000,
  0x3f7ffffe,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf000002,
  0xbf000002,
  0xbf000002,
  0xbf000002,
  0xbf000002,
  0xbf800001,
  0xbf800001,
  0xbf800002,
  0xbfc00001,
  0xbfc00001,
  0xbfc00002,
  0xc0000001,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf000002,
  0xbf000002,
  0xbf000002,
  0xbf400002,
  0xbf400001,
  0xbe800004,
  0xbe800003,
  0xbe800001,
  0x3e7ffff6,
  0x3e7ffffa,
  0x3e800001,
  0x3f3ffffe,
  0x41140000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf400001,
  0xbf400001,
  0xbf400001,
  0xbf400002,
  0xbf400002,
  0xbfa00000,
  0xbfa00001,
  0xbfa00001,
  0xbfe00000,
  0xbfe00001,
  0xbfe00002,
  0xc0100000,
  0xc12c0000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf400002,
  0xbf400002,
  0xbf400002,
  0xc0a00001,
  0xc0a00001,
  0xc0900001,
  0xc0900001,
  0xc0900001,
  0xc0800001,
  0xc0800001,
  0xc0800001,
  0xc0600002,
  0x409fffff,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xc0a00001,
  0xc0a00001,
  0xc0a00001,
  0xc0a00001,
  0xc0a00001,
  0xc0b00001,
  0xc0b00001,
  0xc0b00001,
  0xc0c00001,
  0xc0c00001,
  0xc0c00002,
  0xc0d00001,
  0xc1700001,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xc0a00001,
  0xc0a00001,
  0xc0a00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x80091a2b,
  0x0076e5d5,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00091a2b,
  0x0076e5d4,
  0x80091a2a,
  0x80091a2b,
  0x80891a2b,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x801b4e81,
  0x80891a2a,
  0x80091a2c,
  0x80400000,
  0x00400000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x802dcbaa,
  0x003fffff,
  0x803fffff,
  0x80400000,
  0x80c00000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80523456,
  0x80bfffff,
  0x80400001,
  0x80000001,
  0x007fffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123455,
  0x007ffffe,
  0x00000000,
  0x80000001,
  0x80800001,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123457,
  0x80800000,
  0x80000002,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00800000,
  0x01000000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00923456,
  0x00fffffe,
  0x00800000,
  0x00800000,
  0x80000000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x006dcbaa,
  0x00000000,
  0x007ffffe,
  0x3efffffe,
  0x3efffffe,
  0x3f7fffff,
  0x3f7fffff,
  0x3f800000,
  0x3fbfffff,
  0x3fc00000,
  0x3fc00001,
  0x40000000,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3efffffe,
  0x3efffffe,
  0x3efffffe,
  0x3efffffe,
  0x3efffffe,
  0xb2ffffff,
  0xb3800000,
  0xb4000000,
  0xbf000000,
  0xbf000001,
  0xbf000003,
  0xbf800000,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3efffffe,
  0x3efffffe,
  0x3efffffe,
  0x3effffff,
  0x3effffff,
  0x3f7fffff,
  0x3f800000,
  0x3f800000,
  0x3fbfffff,
  0x3fc00000,
  0x3fc00001,
  0x40000000,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x00000000,
  0xb3000000,
  0xb3c00000,
  0xbeffffff,
  0xbf000000,
  0xbf000002,
  0xbf800000,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3f000000,
  0x3f000000,
  0x3f800000,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x3fc00000,
  0x3fc00001,
  0x40000000,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x337fffff,
  0x32fffffe,
  0xb3000001,
  0xbefffffd,
  0xbeffffff,
  0xbf000002,
  0xbf800000,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f7ffffe,
  0x3f7ffffe,
  0x3fbfffff,
  0x3fbfffff,
  0x3fc00000,
  0x3fffffff,
  0x3fffffff,
  0x40000000,
  0x40200000,
  0x41300000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f7ffffe,
  0x3f7ffffe,
  0x3f7ffffe,
  0x3f7ffffe,
  0x3f7ffffe,
  0x3efffffd,
  0x3efffffc,
  0x3efffffa,
  0xb37fffff,
  0xb4000000,
  0xb4800000,
  0xbf000002,
  0xc1100000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f7ffffe,
  0x3f7ffffe,
  0x3f7ffffe,
  0x3f7fffff,
  0x3f7fffff,
  0x3fbfffff,
  0x3fc00000,
  0x3fc00000,
  0x3fffffff,
  0x40000000,
  0x40000000,
  0x40200000,
  0x41300000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f7fffff,
  0x3f7fffff,
  0x3f7fffff,
  0x3f7fffff,
  0x3f7fffff,
  0x3effffff,
  0x3efffffe,
  0x3efffffc,
  0x00000000,
  0xb3800000,
  0xb4400000,
  0xbf000001,
  0xc1100000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f7fffff,
  0x3f7fffff,
  0x3f7fffff,
  0x3f800000,
  0x3f800000,
  0x3fc00000,
  0x3fc00000,
  0x3fc00001,
  0x40000000,
  0x40000000,
  0x40000001,
  0x40200000,
  0x41300000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3f000001,
  0x3f000001,
  0x3f000000,
  0x33ffffff,
  0x337ffffe,
  0xb3800001,
  0xbefffffe,
  0xc1100000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3fbfffff,
  0x3fbfffff,
  0x3fffffff,
  0x3fffffff,
  0x40000000,
  0x401fffff,
  0x40200000,
  0x40200000,
  0x40400000,
  0x41380000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3fbfffff,
  0x3fbfffff,
  0x3fbfffff,
  0x3fbfffff,
  0x3fbfffff,
  0x3f7fffff,
  0x3f7ffffe,
  0x3f7ffffe,
  0x3effffff,
  0x3efffffd,
  0x3efffff9,
  0xb3c00000,
  0xc1080000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3fbfffff,
  0x3fbfffff,
  0x3fbfffff,
  0x411fffff,
  0x411fffff,
  0x4127ffff,
  0x4127ffff,
  0x4127ffff,
  0x412fffff,
  0x412fffff,
  0x41300000,
  0x4137ffff,
  0x41a00000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x411fffff,
  0x411fffff,
  0x411fffff,
  0x411fffff,
  0x411fffff,
  0x4117ffff,
  0x4117ffff,
  0x4117ffff,
  0x410fffff,
  0x410fffff,
  0x410fffff,
  0x4107ffff,
  0xb5200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x411fffff,
  0x411fffff,
  0x411fffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x00123456,
  0x00923456,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x002468ac,
  0x00923455,
  0x00123457,
  0x00123456,
  0x806dcbaa,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80000000,
  0x806dcba9,
  0x00123455,
  0x007fffff,
  0x00ffffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00923455,
  0x00fffffe,
  0x00800000,
  0x007fffff,
  0x80000001,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x006dcba9,
  0x80000000,
  0x007ffffe,
  0x00000001,
  0x00800001,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123457,
  0x00800000,
  0x00000002,
  0x00000001,
  0x807fffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123455,
  0x807ffffe,
  0x80000000,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80800000,
  0x00000000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x806dcbaa,
  0x80000000,
  0x807ffffe,
  0x80800000,
  0x81000000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80923456,
  0x80fffffe,
  0x80800000,
  0xbefffffe,
  0xbefffffe,
  0x32ffffff,
  0x33800000,
  0x34000000,
  0x3f000000,
  0x3f000001,
  0x3f000003,
  0x3f800000,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbefffffe,
  0xbefffffe,
  0xbefffffe,
  0xbefffffe,
  0xbefffffe,
  0xbf7fffff,
  0xbf7fffff,
  0xbf800000,
  0xbfbfffff,
  0xbfc00000,
  0xbfc00001,
  0xc0000000,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbefffffe,
  0xbefffffe,
  0xbefffffe,
  0xbeffffff,
  0xbeffffff,
  0x00000000,
  0x33000000,
  0x33c00000,
  0x3effffff,
  0x3f000000,
  0x3f000002,
  0x3f800000,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbf7fffff,
  0xbf800000,
  0xbf800000,
  0xbfbfffff,
  0xbfc00000,
  0xbfc00001,
  0xc0000000,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbf000000,
  0xbf000000,
  0xb37fffff,
  0xb2fffffe,
  0x33000001,
  0x3efffffd,
  0x3effffff,
  0x3f000002,
  0x3f800000,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf800000,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xbfc00000,
  0xbfc00001,
  0xc0000000,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf7ffffe,
  0xbf7ffffe,
  0xbefffffd,
  0xbefffffc,
  0xbefffffa,
  0x337fffff,
  0x34000000,
  0x34800000,
  0x3f000002,
  0x41100000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf7ffffe,
  0xbf7ffffe,
  0xbf7ffffe,
  0xbf7ffffe,
  0xbf7ffffe,
  0xbfbfffff,
  0xbfbfffff,
  0xbfc00000,
  0xbfffffff,
  0xbfffffff,
  0xc0000000,
  0xc0200000,
  0xc1300000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf7ffffe,
  0xbf7ffffe,
  0xbf7ffffe,
  0xbf7fffff,
  0xbf7fffff,
  0xbeffffff,
  0xbefffffe,
  0xbefffffc,
  0x00000000,
  0x33800000,
  0x34400000,
  0x3f000001,
  0x41100000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf7fffff,
  0xbf7fffff,
  0xbf7fffff,
  0xbf7fffff,
  0xbf7fffff,
  0xbfbfffff,
  0xbfc00000,
  0xbfc00000,
  0xbfffffff,
  0xc0000000,
  0xc0000000,
  0xc0200000,
  0xc1300000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf7fffff,
  0xbf7fffff,
  0xbf7fffff,
  0xbf800000,
  0xbf800000,
  0xbf000001,
  0xbf000001,
  0xbf000000,
  0xb3ffffff,
  0xb37ffffe,
  0x33800001,
  0x3efffffe,
  0x41100000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbfc00000,
  0xbfc00000,
  0xbfc00001,
  0xc0000000,
  0xc0000000,
  0xc0000001,
  0xc0200000,
  0xc1300000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbfbfffff,
  0xbfbfffff,
  0xbf7fffff,
  0xbf7ffffe,
  0xbf7ffffe,
  0xbeffffff,
  0xbefffffd,
  0xbefffff9,
  0x33c00000,
  0x41080000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbfbfffff,
  0xbfbfffff,
  0xbfbfffff,
  0xbfbfffff,
  0xbfbfffff,
  0xbfffffff,
  0xbfffffff,
  0xc0000000,
  0xc01fffff,
  0xc0200000,
  0xc0200000,
  0xc0400000,
  0xc1380000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbfbfffff,
  0xbfbfffff,
  0xbfbfffff,
  0xc11fffff,
  0xc11fffff,
  0xc117ffff,
  0xc117ffff,
  0xc117ffff,
  0xc10fffff,
  0xc10fffff,
  0xc10fffff,
  0xc107ffff,
  0x35200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xc11fffff,
  0xc11fffff,
  0xc11fffff,
  0xc11fffff,
  0xc11fffff,
  0xc127ffff,
  0xc127ffff,
  0xc127ffff,
  0xc12fffff,
  0xc12fffff,
  0xc1300000,
  0xc137ffff,
  0xc1a00000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xc11fffff,
  0xc11fffff,
  0xc11fffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x80123456,
  0x006dcbaa,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00000000,
  0x006dcba9,
  0x80123455,
  0x80123456,
  0x80923456,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x802468ac,
  0x80923455,
  0x80123457,
  0x807fffff,
  0x00000001,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x806dcba9,
  0x00000000,
  0x807ffffe,
  0x807fffff,
  0x80ffffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80923455,
  0x80fffffe,
  0x80800000,
  0x80000001,
  0x007fffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123455,
  0x007ffffe,
  0x00000000,
  0x80000001,
  0x80800001,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123457,
  0x80800000,
  0x80000002,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00800000,
  0x01000000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00923456,
  0x00ffffff,
  0x00800001,
  0x00800000,
  0x00000000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x006dcbaa,
  0x00000001,
  0x007fffff,
  0x3effffff,
  0x3effffff,
  0x3f7fffff,
  0x3f800000,
  0x3f800000,
  0x3fbfffff,
  0x3fc00000,
  0x3fc00001,
  0x40000000,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x00000000,
  0xb3000000,
  0xb3c00000,
  0xbeffffff,
  0xbf000000,
  0xbf000002,
  0xbf800000,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3f000000,
  0x3f000000,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3fc00000,
  0x3fc00000,
  0x3fc00001,
  0x40000000,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x33000000,
  0x00000000,
  0xb3800000,
  0xbefffffe,
  0xbf000000,
  0xbf000002,
  0xbf800000,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000001,
  0x3f000001,
  0x3f800000,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x3fc00000,
  0x3fc00002,
  0x40000000,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x33c00000,
  0x33800000,
  0x00000000,
  0xbefffffc,
  0xbefffffe,
  0xbf000001,
  0xbf7fffff,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f7fffff,
  0x3f7fffff,
  0x3fbfffff,
  0x3fc00000,
  0x3fc00000,
  0x3fffffff,
  0x40000000,
  0x40000000,
  0x40200000,
  0x41300000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f7fffff,
  0x3f7fffff,
  0x3f7fffff,
  0x3f7fffff,
  0x3f7fffff,
  0x3effffff,
  0x3efffffe,
  0x3efffffc,
  0x00000000,
  0xb3800000,
  0xb4400000,
  0xbf000001,
  0xc1100000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f7fffff,
  0x3f7fffff,
  0x3f7fffff,
  0x3f800000,
  0x3f800000,
  0x3fc00000,
  0x3fc00000,
  0x3fc00000,
  0x40000000,
  0x40000000,
  0x40000000,
  0x40200000,
  0x41300000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3f000000,
  0x3f000000,
  0x3efffffe,
  0x33800000,
  0x00000000,
  0xb4000000,
  0xbf000000,
  0xc1100000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3f800001,
  0x3f800001,
  0x3fc00001,
  0x3fc00001,
  0x3fc00002,
  0x40000000,
  0x40000000,
  0x40000001,
  0x40200000,
  0x41300000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f800001,
  0x3f800001,
  0x3f800001,
  0x3f800001,
  0x3f800001,
  0x3f000002,
  0x3f000002,
  0x3f000001,
  0x34400000,
  0x34000000,
  0x00000000,
  0xbefffffc,
  0xc1100000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f800001,
  0x3f800001,
  0x3f800001,
  0x3fc00000,
  0x3fc00000,
  0x40000000,
  0x40000000,
  0x40000000,
  0x40200000,
  0x40200000,
  0x40200000,
  0x40400000,
  0x41380000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3fc00000,
  0x3fc00000,
  0x3fc00000,
  0x3fc00000,
  0x3fc00000,
  0x3f800000,
  0x3f800000,
  0x3f7fffff,
  0x3f000001,
  0x3f000000,
  0x3efffffc,
  0x00000000,
  0xc1080000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3fc00000,
  0x3fc00000,
  0x3fc00000,
  0x41200000,
  0x41200000,
  0x41280000,
  0x41280000,
  0x41280000,
  0x41300000,
  0x41300000,
  0x41300000,
  0x41380000,
  0x41a00000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x41200000,
  0x41200000,
  0x41200000,
  0x41200000,
  0x41200000,
  0x41180000,
  0x41180000,
  0x41180000,
  0x41100000,
  0x41100000,
  0x41100000,
  0x41080000,
  0x00000000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x41200000,
  0x41200000,
  0x41200000,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x00123456,
  0x00923456,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x002468ac,
  0x00923455,
  0x00123457,
  0x00123456,
  0x806dcbaa,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x00000000,
  0x806dcba9,
  0x00123455,
  0x007fffff,
  0x00ffffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00923455,
  0x00fffffe,
  0x00800000,
  0x007fffff,
  0x80000001,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x006dcba9,
  0x00000000,
  0x007ffffe,
  0x00000001,
  0x00800001,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123457,
  0x00800000,
  0x00000002,
  0x00000001,
  0x807fffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123455,
  0x807ffffe,
  0x00000000,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80800000,
  0x00000000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x806dcbaa,
  0x80000001,
  0x807fffff,
  0x80800000,
  0x81000000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80923456,
  0x80ffffff,
  0x80800001,
  0xbeffffff,
  0xbeffffff,
  0x00000000,
  0x33000000,
  0x33c00000,
  0x3effffff,
  0x3f000000,
  0x3f000002,
  0x3f800000,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbf7fffff,
  0xbf800000,
  0xbf800000,
  0xbfbfffff,
  0xbfc00000,
  0xbfc00001,
  0xc0000000,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbf000000,
  0xbf000000,
  0xb3000000,
  0x00000000,
  0x33800000,
  0x3efffffe,
  0x3f000000,
  0x3f000002,
  0x3f800000,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbfc00000,
  0xbfc00000,
  0xbfc00001,
  0xc0000000,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000001,
  0xbf000001,
  0xb3c00000,
  0xb3800000,
  0x00000000,
  0x3efffffc,
  0x3efffffe,
  0x3f000001,
  0x3f7fffff,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf800000,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xbfc00000,
  0xbfc00002,
  0xc0000000,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf7fffff,
  0xbf7fffff,
  0xbeffffff,
  0xbefffffe,
  0xbefffffc,
  0x00000000,
  0x33800000,
  0x34400000,
  0x3f000001,
  0x41100000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf7fffff,
  0xbf7fffff,
  0xbf7fffff,
  0xbf7fffff,
  0xbf7fffff,
  0xbfbfffff,
  0xbfc00000,
  0xbfc00000,
  0xbfffffff,
  0xc0000000,
  0xc0000000,
  0xc0200000,
  0xc1300000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf7fffff,
  0xbf7fffff,
  0xbf7fffff,
  0xbf800000,
  0xbf800000,
  0xbf000000,
  0xbf000000,
  0xbefffffe,
  0xb3800000,
  0x00000000,
  0x34000000,
  0x3f000000,
  0x41100000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbfc00000,
  0xbfc00000,
  0xbfc00000,
  0xc0000000,
  0xc0000000,
  0xc0000000,
  0xc0200000,
  0xc1300000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbf800001,
  0xbf800001,
  0xbf000002,
  0xbf000002,
  0xbf000001,
  0xb4400000,
  0xb4000000,
  0x00000000,
  0x3efffffc,
  0x41100000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf800001,
  0xbf800001,
  0xbf800001,
  0xbf800001,
  0xbf800001,
  0xbfc00001,
  0xbfc00001,
  0xbfc00002,
  0xc0000000,
  0xc0000000,
  0xc0000001,
  0xc0200000,
  0xc1300000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf800001,
  0xbf800001,
  0xbf800001,
  0xbfc00000,
  0xbfc00000,
  0xbf800000,
  0xbf800000,
  0xbf7fffff,
  0xbf000001,
  0xbf000000,
  0xbefffffc,
  0x00000000,
  0x41080000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbfc00000,
  0xbfc00000,
  0xbfc00000,
  0xbfc00000,
  0xbfc00000,
  0xc0000000,
  0xc0000000,
  0xc0000000,
  0xc0200000,
  0xc0200000,
  0xc0200000,
  0xc0400000,
  0xc1380000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbfc00000,
  0xbfc00000,
  0xbfc00000,
  0xc1200000,
  0xc1200000,
  0xc1180000,
  0xc1180000,
  0xc1180000,
  0xc1100000,
  0xc1100000,
  0xc1100000,
  0xc1080000,
  0x00000000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xc1200000,
  0xc1200000,
  0xc1200000,
  0xc1200000,
  0xc1200000,
  0xc1280000,
  0xc1280000,
  0xc1280000,
  0xc1300000,
  0xc1300000,
  0xc1300000,
  0xc1380000,
  0xc1a00000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xc1200000,
  0xc1200000,
  0xc1200000,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x80123456,
  0x006dcbaa,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00000000,
  0x006dcba9,
  0x80123455,
  0x80123456,
  0x80923456,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x802468ac,
  0x80923455,
  0x80123457,
  0x807fffff,
  0x00000001,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x806dcba9,
  0x00000000,
  0x807ffffe,
  0x807fffff,
  0x80ffffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80923455,
  0x80fffffe,
  0x80800000,
  0x80000001,
  0x007fffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123455,
  0x007ffffe,
  0x00000000,
  0x80000001,
  0x80800001,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123457,
  0x80800000,
  0x80000002,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00800001,
  0x01000000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00923457,
  0x01000000,
  0x00800002,
  0x00800001,
  0x00000001,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x006dcbab,
  0x00000002,
  0x00800000,
  0x3f000000,
  0x3f000000,
  0x3f800000,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x3fc00000,
  0x3fc00001,
  0x40000000,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x337fffff,
  0x32fffffe,
  0xb3000001,
  0xbefffffd,
  0xbeffffff,
  0xbf000002,
  0xbf800000,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000001,
  0x3f000001,
  0x3f800000,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x3fc00000,
  0x3fc00002,
  0x40000000,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x33c00000,
  0x33800000,
  0x00000000,
  0xbefffffc,
  0xbefffffe,
  0xbf000001,
  0xbf7fffff,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f000002,
  0x3f000002,
  0x3f800001,
  0x3f800001,
  0x3f800002,
  0x3fc00001,
  0x3fc00001,
  0x3fc00002,
  0x40000001,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f000002,
  0x3f000002,
  0x3f000002,
  0x3f000002,
  0x3f000002,
  0x34200000,
  0x34000000,
  0x33800001,
  0xbefffffa,
  0xbefffffc,
  0xbf000000,
  0xbf7ffffe,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f000002,
  0x3f000002,
  0x3f000002,
  0x3f800000,
  0x3f800000,
  0x3fc00000,
  0x3fc00000,
  0x3fc00001,
  0x40000000,
  0x40000000,
  0x40000001,
  0x40200000,
  0x41300000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3f000001,
  0x3f000001,
  0x3f000000,
  0x33ffffff,
  0x337ffffe,
  0xb3800001,
  0xbefffffe,
  0xc1100000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3f800001,
  0x3f800001,
  0x3fc00001,
  0x3fc00001,
  0x3fc00002,
  0x40000000,
  0x40000000,
  0x40000001,
  0x40200000,
  0x41300000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f800001,
  0x3f800001,
  0x3f800001,
  0x3f800001,
  0x3f800001,
  0x3f000002,
  0x3f000002,
  0x3f000001,
  0x34400000,
  0x34000000,
  0x00000000,
  0xbefffffc,
  0xc1100000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f800001,
  0x3f800001,
  0x3f800001,
  0x3f800002,
  0x3f800002,
  0x3fc00002,
  0x3fc00002,
  0x3fc00003,
  0x40000001,
  0x40000001,
  0x40000002,
  0x40200001,
  0x41300000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f800002,
  0x3f800002,
  0x3f800002,
  0x3f800002,
  0x3f800002,
  0x3f000005,
  0x3f000004,
  0x3f000003,
  0x34a00000,
  0x34800000,
  0x34000001,
  0xbefffff8,
  0xc1100000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f800002,
  0x3f800002,
  0x3f800002,
  0x3fc00002,
  0x3fc00002,
  0x40000001,
  0x40000001,
  0x40000001,
  0x40200000,
  0x40200001,
  0x40200001,
  0x40400001,
  0x41380000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3fc00002,
  0x3fc00002,
  0x3fc00002,
  0x3fc00002,
  0x3fc00001,
  0x3f800002,
  0x3f800002,
  0x3f800001,
  0x3f000004,
  0x3f000003,
  0x3f000001,
  0x34400000,
  0xc1080000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3fc00001,
  0x3fc00001,
  0x3fc00001,
  0x41200001,
  0x41200001,
  0x41280001,
  0x41280001,
  0x41280001,
  0x41300001,
  0x41300001,
  0x41300001,
  0x41380001,
  0x41a00001,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x41200001,
  0x41200001,
  0x41200001,
  0x41200001,
  0x41200001,
  0x41180001,
  0x41180001,
  0x41180001,
  0x41100001,
  0x41100001,
  0x41100001,
  0x41080001,
  0x35a00000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x41200001,
  0x41200001,
  0x41200001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x00123456,
  0x00923456,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x002468ac,
  0x00923455,
  0x00123457,
  0x00123456,
  0x806dcbaa,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x00000000,
  0x806dcba9,
  0x00123455,
  0x00800000,
  0x01000000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00923456,
  0x00ffffff,
  0x00800001,
  0x00800000,
  0x80000000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x006dcbaa,
  0x00000001,
  0x007fffff,
  0x00000001,
  0x00800001,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123457,
  0x00800000,
  0x00000002,
  0x00000001,
  0x807fffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123455,
  0x807ffffe,
  0x00000000,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80800001,
  0x80000001,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x806dcbab,
  0x80000002,
  0x80800000,
  0x80800001,
  0x81000000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80923457,
  0x81000000,
  0x80800002,
  0xbf000000,
  0xbf000000,
  0xb37fffff,
  0xb2fffffe,
  0x33000001,
  0x3efffffd,
  0x3effffff,
  0x3f000002,
  0x3f800000,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf800000,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xbfc00000,
  0xbfc00001,
  0xc0000000,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000001,
  0xbf000001,
  0xb3c00000,
  0xb3800000,
  0x00000000,
  0x3efffffc,
  0x3efffffe,
  0x3f000001,
  0x3f7fffff,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf800000,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xbfc00000,
  0xbfc00002,
  0xc0000000,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf000002,
  0xbf000002,
  0xb4200000,
  0xb4000000,
  0xb3800001,
  0x3efffffa,
  0x3efffffc,
  0x3f000000,
  0x3f7ffffe,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf000002,
  0xbf000002,
  0xbf000002,
  0xbf000002,
  0xbf000002,
  0xbf800001,
  0xbf800001,
  0xbf800002,
  0xbfc00001,
  0xbfc00001,
  0xbfc00002,
  0xc0000001,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf000002,
  0xbf000002,
  0xbf000002,
  0xbf800000,
  0xbf800000,
  0xbf000001,
  0xbf000001,
  0xbf000000,
  0xb3ffffff,
  0xb37ffffe,
  0x33800001,
  0x3efffffe,
  0x41100000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbfc00000,
  0xbfc00000,
  0xbfc00001,
  0xc0000000,
  0xc0000000,
  0xc0000001,
  0xc0200000,
  0xc1300000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbf800001,
  0xbf800001,
  0xbf000002,
  0xbf000002,
  0xbf000001,
  0xb4400000,
  0xb4000000,
  0x00000000,
  0x3efffffc,
  0x41100000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf800001,
  0xbf800001,
  0xbf800001,
  0xbf800001,
  0xbf800001,
  0xbfc00001,
  0xbfc00001,
  0xbfc00002,
  0xc0000000,
  0xc0000000,
  0xc0000001,
  0xc0200000,
  0xc1300000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf800001,
  0xbf800001,
  0xbf800001,
  0xbf800002,
  0xbf800002,
  0xbf000005,
  0xbf000004,
  0xbf000003,
  0xb4a00000,
  0xb4800000,
  0xb4000001,
  0x3efffff8,
  0x41100000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf800002,
  0xbf800002,
  0xbf800002,
  0xbf800002,
  0xbf800002,
  0xbfc00002,
  0xbfc00002,
  0xbfc00003,
  0xc0000001,
  0xc0000001,
  0xc0000002,
  0xc0200001,
  0xc1300000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf800002,
  0xbf800002,
  0xbf800002,
  0xbfc00002,
  0xbfc00001,
  0xbf800002,
  0xbf800002,
  0xbf800001,
  0xbf000004,
  0xbf000003,
  0xbf000001,
  0xb4400000,
  0x41080000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbfc00001,
  0xbfc00001,
  0xbfc00001,
  0xbfc00002,
  0xbfc00002,
  0xc0000001,
  0xc0000001,
  0xc0000001,
  0xc0200000,
  0xc0200001,
  0xc0200001,
  0xc0400001,
  0xc1380000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbfc00002,
  0xbfc00002,
  0xbfc00002,
  0xc1200001,
  0xc1200001,
  0xc1180001,
  0xc1180001,
  0xc1180001,
  0xc1100001,
  0xc1100001,
  0xc1100001,
  0xc1080001,
  0xb5a00000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xc1200001,
  0xc1200001,
  0xc1200001,
  0xc1200001,
  0xc1200001,
  0xc1280001,
  0xc1280001,
  0xc1280001,
  0xc1300001,
  0xc1300001,
  0xc1300001,
  0xc1380001,
  0xc1a00001,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xc1200001,
  0xc1200001,
  0xc1200001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x80123456,
  0x006dcbaa,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x80000000,
  0x006dcba9,
  0x80123455,
  0x80123456,
  0x80923456,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x802468ac,
  0x80923455,
  0x80123457,
  0x80800000,
  0x00000000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x806dcbaa,
  0x80000001,
  0x807fffff,
  0x80800000,
  0x81000000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80923456,
  0x80ffffff,
  0x80800001,
  0x80000001,
  0x007fffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123455,
  0x007ffffe,
  0x80000000,
  0x80000001,
  0x80800001,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123457,
  0x80800000,
  0x80000002,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00c00000,
  0x01200000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00d23456,
  0x01200000,
  0x00c00001,
  0x00c00000,
  0x00400000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x00adcbaa,
  0x00400001,
  0x00bfffff,
  0x3f3fffff,
  0x3f3fffff,
  0x3f9fffff,
  0x3fa00000,
  0x3fa00000,
  0x3fdfffff,
  0x3fe00000,
  0x3fe00001,
  0x40100000,
  0x412c0000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f3fffff,
  0x3f3fffff,
  0x3f3fffff,
  0x3f3fffff,
  0x3f3fffff,
  0x3e7fffff,
  0x3e7ffffd,
  0x3e7ffff9,
  0xbe7fffff,
  0xbe800002,
  0xbe800006,
  0xbf400001,
  0xc1140000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f3fffff,
  0x3f3fffff,
  0x3f3fffff,
  0x3f400000,
  0x3f400000,
  0x3fa00000,
  0x3fa00000,
  0x3fa00000,
  0x3fe00000,
  0x3fe00000,
  0x3fe00001,
  0x40100000,
  0x412c0000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f400000,
  0x3f400000,
  0x3f400000,
  0x3f400000,
  0x3f400000,
  0x3e800001,
  0x3e800000,
  0x3e7ffffc,
  0xbe7ffffc,
  0xbe800000,
  0xbe800004,
  0xbf400000,
  0xc1140000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f400000,
  0x3f400000,
  0x3f400000,
  0x3f400002,
  0x3f400002,
  0x3fa00000,
  0x3fa00001,
  0x3fa00001,
  0x3fe00000,
  0x3fe00001,
  0x3fe00002,
  0x40100000,
  0x412c0000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f400002,
  0x3f400002,
  0x3f400002,
  0x3f400002,
  0x3f400001,
  0x3e800004,
  0x3e800003,
  0x3e800001,
  0xbe7ffff6,
  0xbe7ffffa,
  0xbe800001,
  0xbf3ffffe,
  0xc1140000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f400001,
  0x3f400001,
  0x3f400001,
  0x3fbfffff,
  0x3fbfffff,
  0x3fffffff,
  0x3fffffff,
  0x40000000,
  0x401fffff,
  0x40200000,
  0x40200000,
  0x40400000,
  0x41380000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3fbfffff,
  0x3fbfffff,
  0x3fbfffff,
  0x3fbfffff,
  0x3fbfffff,
  0x3f7fffff,
  0x3f7ffffe,
  0x3f7ffffe,
  0x3effffff,
  0x3efffffd,
  0x3efffff9,
  0xb3c00000,
  0xc1080000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3fbfffff,
  0x3fbfffff,
  0x3fbfffff,
  0x3fc00000,
  0x3fc00000,
  0x40000000,
  0x40000000,
  0x40000000,
  0x40200000,
  0x40200000,
  0x40200000,
  0x40400000,
  0x41380000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3fc00000,
  0x3fc00000,
  0x3fc00000,
  0x3fc00000,
  0x3fc00000,
  0x3f800000,
  0x3f800000,
  0x3f7fffff,
  0x3f000001,
  0x3f000000,
  0x3efffffc,
  0x00000000,
  0xc1080000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3fc00000,
  0x3fc00000,
  0x3fc00000,
  0x3fc00002,
  0x3fc00002,
  0x40000001,
  0x40000001,
  0x40000001,
  0x40200000,
  0x40200001,
  0x40200001,
  0x40400001,
  0x41380000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3fc00002,
  0x3fc00002,
  0x3fc00002,
  0x3fc00002,
  0x3fc00001,
  0x3f800002,
  0x3f800002,
  0x3f800001,
  0x3f000004,
  0x3f000003,
  0x3f000001,
  0x34400000,
  0xc1080000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3fc00001,
  0x3fc00001,
  0x3fc00001,
  0x40100000,
  0x40100000,
  0x40300000,
  0x40300000,
  0x40300000,
  0x40500000,
  0x40500000,
  0x40500000,
  0x40700000,
  0x41440000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x40100000,
  0x40100000,
  0x40100000,
  0x40100000,
  0x40100000,
  0x3fe00000,
  0x3fe00000,
  0x3fe00000,
  0x3fa00000,
  0x3fa00000,
  0x3f9fffff,
  0x3f400000,
  0xc0f80000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x40100000,
  0x40100000,
  0x40100000,
  0x41700000,
  0x41700000,
  0x41780000,
  0x41780000,
  0x41780000,
  0x41800000,
  0x41800000,
  0x41800000,
  0x41840000,
  0x41c80000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x41700000,
  0x41700000,
  0x41700000,
  0x41700000,
  0x41700000,
  0x41680000,
  0x41680000,
  0x41680000,
  0x41600000,
  0x41600000,
  0x41600000,
  0x41580000,
  0x40a00000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x41700000,
  0x41700000,
  0x41700000,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x001b4e81,
  0x009b4e81,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x002d82d7,
  0x009b4e80,
  0x001b4e82,
  0x001b4e81,
  0x8064b17f,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x00091a2b,
  0x8064b17e,
  0x001b4e80,
  0x00bffffe,
  0x011fffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00d23454,
  0x011fffff,
  0x00c00000,
  0x00bffffe,
  0x003ffffe,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x00adcba8,
  0x00400000,
  0x00bffffe,
  0x00000002,
  0x00800002,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123458,
  0x00800000,
  0x00000002,
  0x00000002,
  0x807ffffe,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123454,
  0x807ffffe,
  0x00000000,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80c00000,
  0x80400000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x80adcbaa,
  0x80400001,
  0x80bfffff,
  0x80c00000,
  0x81200000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80d23456,
  0x81200000,
  0x80c00001,
  0xbf3fffff,
  0xbf3fffff,
  0xbe7fffff,
  0xbe7ffffd,
  0xbe7ffff9,
  0x3e7fffff,
  0x3e800002,
  0x3e800006,
  0x3f400001,
  0x41140000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf3fffff,
  0xbf3fffff,
  0xbf3fffff,
  0xbf3fffff,
  0xbf3fffff,
  0xbf9fffff,
  0xbfa00000,
  0xbfa00000,
  0xbfdfffff,
  0xbfe00000,
  0xbfe00001,
  0xc0100000,
  0xc12c0000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf3fffff,
  0xbf3fffff,
  0xbf3fffff,
  0xbf400000,
  0xbf400000,
  0xbe800001,
  0xbe800000,
  0xbe7ffffc,
  0x3e7ffffc,
  0x3e800000,
  0x3e800004,
  0x3f400000,
  0x41140000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf400000,
  0xbf400000,
  0xbf400000,
  0xbf400000,
  0xbf400000,
  0xbfa00000,
  0xbfa00000,
  0xbfa00000,
  0xbfe00000,
  0xbfe00000,
  0xbfe00001,
  0xc0100000,
  0xc12c0000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf400000,
  0xbf400000,
  0xbf400000,
  0xbf400002,
  0xbf400001,
  0xbe800004,
  0xbe800003,
  0xbe800001,
  0x3e7ffff6,
  0x3e7ffffa,
  0x3e800001,
  0x3f3ffffe,
  0x41140000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf400001,
  0xbf400001,
  0xbf400001,
  0xbf400002,
  0xbf400002,
  0xbfa00000,
  0xbfa00001,
  0xbfa00001,
  0xbfe00000,
  0xbfe00001,
  0xbfe00002,
  0xc0100000,
  0xc12c0000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf400002,
  0xbf400002,
  0xbf400002,
  0xbfbfffff,
  0xbfbfffff,
  0xbf7fffff,
  0xbf7ffffe,
  0xbf7ffffe,
  0xbeffffff,
  0xbefffffd,
  0xbefffff9,
  0x33c00000,
  0x41080000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbfbfffff,
  0xbfbfffff,
  0xbfbfffff,
  0xbfbfffff,
  0xbfbfffff,
  0xbfffffff,
  0xbfffffff,
  0xc0000000,
  0xc01fffff,
  0xc0200000,
  0xc0200000,
  0xc0400000,
  0xc1380000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbfbfffff,
  0xbfbfffff,
  0xbfbfffff,
  0xbfc00000,
  0xbfc00000,
  0xbf800000,
  0xbf800000,
  0xbf7fffff,
  0xbf000001,
  0xbf000000,
  0xbefffffc,
  0x00000000,
  0x41080000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbfc00000,
  0xbfc00000,
  0xbfc00000,
  0xbfc00000,
  0xbfc00000,
  0xc0000000,
  0xc0000000,
  0xc0000000,
  0xc0200000,
  0xc0200000,
  0xc0200000,
  0xc0400000,
  0xc1380000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbfc00000,
  0xbfc00000,
  0xbfc00000,
  0xbfc00002,
  0xbfc00001,
  0xbf800002,
  0xbf800002,
  0xbf800001,
  0xbf000004,
  0xbf000003,
  0xbf000001,
  0xb4400000,
  0x41080000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbfc00001,
  0xbfc00001,
  0xbfc00001,
  0xbfc00002,
  0xbfc00002,
  0xc0000001,
  0xc0000001,
  0xc0000001,
  0xc0200000,
  0xc0200001,
  0xc0200001,
  0xc0400001,
  0xc1380000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbfc00002,
  0xbfc00002,
  0xbfc00002,
  0xc0100000,
  0xc0100000,
  0xbfe00000,
  0xbfe00000,
  0xbfe00000,
  0xbfa00000,
  0xbfa00000,
  0xbf9fffff,
  0xbf400000,
  0x40f80000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xc0100000,
  0xc0100000,
  0xc0100000,
  0xc0100000,
  0xc0100000,
  0xc0300000,
  0xc0300000,
  0xc0300000,
  0xc0500000,
  0xc0500000,
  0xc0500000,
  0xc0700000,
  0xc1440000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xc0100000,
  0xc0100000,
  0xc0100000,
  0xc1700000,
  0xc1700000,
  0xc1680000,
  0xc1680000,
  0xc1680000,
  0xc1600000,
  0xc1600000,
  0xc1600000,
  0xc1580000,
  0xc0a00000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xc1700000,
  0xc1700000,
  0xc1700000,
  0xc1700000,
  0xc1700000,
  0xc1780000,
  0xc1780000,
  0xc1780000,
  0xc1800000,
  0xc1800000,
  0xc1800000,
  0xc1840000,
  0xc1c80000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xc1700000,
  0xc1700000,
  0xc1700000,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x801b4e81,
  0x0064b17f,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x80091a2b,
  0x0064b17e,
  0x801b4e80,
  0x801b4e81,
  0x809b4e81,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x802d82d7,
  0x809b4e80,
  0x801b4e82,
  0x80bffffe,
  0x803ffffe,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x80adcba8,
  0x80400000,
  0x80bffffe,
  0x80bffffe,
  0x811fffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80d23454,
  0x811fffff,
  0x80c00000,
  0x80000002,
  0x007ffffe,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123454,
  0x007ffffe,
  0x80000000,
  0x80000002,
  0x80800002,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123458,
  0x80800000,
  0x80000002,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x02200000,
  0x02300000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x0222468b,
  0x02300000,
  0x02200000,
  0x02200000,
  0x02100000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x021db975,
  0x02100000,
  0x02200000,
  0x409fffff,
  0x409fffff,
  0x40afffff,
  0x40afffff,
  0x40b00000,
  0x40bfffff,
  0x40bfffff,
  0x40c00000,
  0x40cfffff,
  0x41700000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x409fffff,
  0x409fffff,
  0x409fffff,
  0x409fffff,
  0x409fffff,
  0x408fffff,
  0x408fffff,
  0x408fffff,
  0x407fffff,
  0x407fffff,
  0x407ffffe,
  0x405fffff,
  0xc0a00001,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x409fffff,
  0x409fffff,
  0x409fffff,
  0x40a00000,
  0x40a00000,
  0x40b00000,
  0x40b00000,
  0x40b00000,
  0x40c00000,
  0x40c00000,
  0x40c00000,
  0x40d00000,
  0x41700000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x40a00000,
  0x40a00000,
  0x40a00000,
  0x40a00000,
  0x40a00000,
  0x40900000,
  0x40900000,
  0x40900000,
  0x40800000,
  0x40800000,
  0x40800000,
  0x40600000,
  0xc0a00000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x40a00000,
  0x40a00000,
  0x40a00000,
  0x40a00001,
  0x40a00001,
  0x40b00001,
  0x40b00001,
  0x40b00001,
  0x40c00001,
  0x40c00001,
  0x40c00002,
  0x40d00001,
  0x41700001,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x40a00001,
  0x40a00001,
  0x40a00001,
  0x40a00001,
  0x40a00001,
  0x40900001,
  0x40900001,
  0x40900001,
  0x40800001,
  0x40800001,
  0x40800001,
  0x40600002,
  0xc09fffff,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x40a00001,
  0x40a00001,
  0x40a00001,
  0x411fffff,
  0x411fffff,
  0x4127ffff,
  0x4127ffff,
  0x4127ffff,
  0x412fffff,
  0x412fffff,
  0x41300000,
  0x4137ffff,
  0x41a00000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x411fffff,
  0x411fffff,
  0x411fffff,
  0x411fffff,
  0x411fffff,
  0x4117ffff,
  0x4117ffff,
  0x4117ffff,
  0x410fffff,
  0x410fffff,
  0x410fffff,
  0x4107ffff,
  0xb5200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x411fffff,
  0x411fffff,
  0x411fffff,
  0x41200000,
  0x41200000,
  0x41280000,
  0x41280000,
  0x41280000,
  0x41300000,
  0x41300000,
  0x41300000,
  0x41380000,
  0x41a00000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x41200000,
  0x41200000,
  0x41200000,
  0x41200000,
  0x41200000,
  0x41180000,
  0x41180000,
  0x41180000,
  0x41100000,
  0x41100000,
  0x41100000,
  0x41080000,
  0x00000000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x41200000,
  0x41200000,
  0x41200000,
  0x41200001,
  0x41200001,
  0x41280001,
  0x41280001,
  0x41280001,
  0x41300001,
  0x41300001,
  0x41300001,
  0x41380001,
  0x41a00001,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x41200001,
  0x41200001,
  0x41200001,
  0x41200001,
  0x41200001,
  0x41180001,
  0x41180001,
  0x41180001,
  0x41100001,
  0x41100001,
  0x41100001,
  0x41080001,
  0x35a00000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x41200001,
  0x41200001,
  0x41200001,
  0x41700000,
  0x41700000,
  0x41780000,
  0x41780000,
  0x41780000,
  0x41800000,
  0x41800000,
  0x41800000,
  0x41840000,
  0x41c80000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x41700000,
  0x41700000,
  0x41700000,
  0x41700000,
  0x41700000,
  0x41680000,
  0x41680000,
  0x41680000,
  0x41600000,
  0x41600000,
  0x41600000,
  0x41580000,
  0x40a00000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x41700000,
  0x41700000,
  0x41700000,
  0x42c80000,
  0x42c80000,
  0x42c90000,
  0x42c90000,
  0x42c90000,
  0x42ca0000,
  0x42ca0000,
  0x42ca0000,
  0x42cb0000,
  0x42dc0000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x42c80000,
  0x42c80000,
  0x42c80000,
  0x42c80000,
  0x42c80000,
  0x42c70000,
  0x42c70000,
  0x42c70000,
  0x42c60000,
  0x42c60000,
  0x42c60000,
  0x42c50000,
  0x42b40000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x42c80000,
  0x42c80000,
  0x42c80000,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x00b60b5c,
  0x011b05ae,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00c83fb2,
  0x011b05ae,
  0x00b60b5d,
  0x00b60b5c,
  0x00360b5c,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x00a3d706,
  0x00360b5d,
  0x00b60b5b,
  0x021fffff,
  0x022fffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x0222468a,
  0x022fffff,
  0x021fffff,
  0x021fffff,
  0x020fffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x021db974,
  0x020fffff,
  0x021fffff,
  0x0000000a,
  0x0080000a,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123460,
  0x00800009,
  0x0000000b,
  0x0000000a,
  0x807ffff6,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x8012344c,
  0x807ffff5,
  0x00000009,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x82200000,
  0x82100000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x821db975,
  0x82100000,
  0x82200000,
  0x82200000,
  0x82300000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x8222468b,
  0x82300000,
  0x82200000,
  0xc09fffff,
  0xc09fffff,
  0xc08fffff,
  0xc08fffff,
  0xc08fffff,
  0xc07fffff,
  0xc07fffff,
  0xc07ffffe,
  0xc05fffff,
  0x40a00001,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xc09fffff,
  0xc09fffff,
  0xc09fffff,
  0xc09fffff,
  0xc09fffff,
  0xc0afffff,
  0xc0afffff,
  0xc0b00000,
  0xc0bfffff,
  0xc0bfffff,
  0xc0c00000,
  0xc0cfffff,
  0xc1700000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xc09fffff,
  0xc09fffff,
  0xc09fffff,
  0xc0a00000,
  0xc0a00000,
  0xc0900000,
  0xc0900000,
  0xc0900000,
  0xc0800000,
  0xc0800000,
  0xc0800000,
  0xc0600000,
  0x40a00000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xc0a00000,
  0xc0a00000,
  0xc0a00000,
  0xc0a00000,
  0xc0a00000,
  0xc0b00000,
  0xc0b00000,
  0xc0b00000,
  0xc0c00000,
  0xc0c00000,
  0xc0c00000,
  0xc0d00000,
  0xc1700000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xc0a00000,
  0xc0a00000,
  0xc0a00000,
  0xc0a00001,
  0xc0a00001,
  0xc0900001,
  0xc0900001,
  0xc0900001,
  0xc0800001,
  0xc0800001,
  0xc0800001,
  0xc0600002,
  0x409fffff,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xc0a00001,
  0xc0a00001,
  0xc0a00001,
  0xc0a00001,
  0xc0a00001,
  0xc0b00001,
  0xc0b00001,
  0xc0b00001,
  0xc0c00001,
  0xc0c00001,
  0xc0c00002,
  0xc0d00001,
  0xc1700001,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xc0a00001,
  0xc0a00001,
  0xc0a00001,
  0xc11fffff,
  0xc11fffff,
  0xc117ffff,
  0xc117ffff,
  0xc117ffff,
  0xc10fffff,
  0xc10fffff,
  0xc10fffff,
  0xc107ffff,
  0x35200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xc11fffff,
  0xc11fffff,
  0xc11fffff,
  0xc11fffff,
  0xc11fffff,
  0xc127ffff,
  0xc127ffff,
  0xc127ffff,
  0xc12fffff,
  0xc12fffff,
  0xc1300000,
  0xc137ffff,
  0xc1a00000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xc11fffff,
  0xc11fffff,
  0xc11fffff,
  0xc1200000,
  0xc1200000,
  0xc1180000,
  0xc1180000,
  0xc1180000,
  0xc1100000,
  0xc1100000,
  0xc1100000,
  0xc1080000,
  0x00000000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xc1200000,
  0xc1200000,
  0xc1200000,
  0xc1200000,
  0xc1200000,
  0xc1280000,
  0xc1280000,
  0xc1280000,
  0xc1300000,
  0xc1300000,
  0xc1300000,
  0xc1380000,
  0xc1a00000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xc1200000,
  0xc1200000,
  0xc1200000,
  0xc1200001,
  0xc1200001,
  0xc1180001,
  0xc1180001,
  0xc1180001,
  0xc1100001,
  0xc1100001,
  0xc1100001,
  0xc1080001,
  0xb5a00000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xc1200001,
  0xc1200001,
  0xc1200001,
  0xc1200001,
  0xc1200001,
  0xc1280001,
  0xc1280001,
  0xc1280001,
  0xc1300001,
  0xc1300001,
  0xc1300001,
  0xc1380001,
  0xc1a00001,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xc1200001,
  0xc1200001,
  0xc1200001,
  0xc1700000,
  0xc1700000,
  0xc1680000,
  0xc1680000,
  0xc1680000,
  0xc1600000,
  0xc1600000,
  0xc1600000,
  0xc1580000,
  0xc0a00000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xc1700000,
  0xc1700000,
  0xc1700000,
  0xc1700000,
  0xc1700000,
  0xc1780000,
  0xc1780000,
  0xc1780000,
  0xc1800000,
  0xc1800000,
  0xc1800000,
  0xc1840000,
  0xc1c80000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xc1700000,
  0xc1700000,
  0xc1700000,
  0xc2c80000,
  0xc2c80000,
  0xc2c70000,
  0xc2c70000,
  0xc2c70000,
  0xc2c60000,
  0xc2c60000,
  0xc2c60000,
  0xc2c50000,
  0xc2b40000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xc2c80000,
  0xc2c80000,
  0xc2c80000,
  0xc2c80000,
  0xc2c80000,
  0xc2c90000,
  0xc2c90000,
  0xc2c90000,
  0xc2ca0000,
  0xc2ca0000,
  0xc2ca0000,
  0xc2cb0000,
  0xc2dc0000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xc2c80000,
  0xc2c80000,
  0xc2c80000,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x80b60b5c,
  0x80360b5c,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x80a3d706,
  0x80360b5d,
  0x80b60b5b,
  0x80b60b5c,
  0x811b05ae,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80c83fb2,
  0x811b05ae,
  0x80b60b5d,
  0x821fffff,
  0x820fffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x821db974,
  0x820fffff,
  0x821fffff,
  0x821fffff,
  0x822fffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x8222468a,
  0x822fffff,
  0x821fffff,
  0x8000000a,
  0x007ffff6,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x0012344c,
  0x007ffff5,
  0x80000009,
  0x8000000a,
  0x8080000a,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123460,
  0x80800009,
  0x8000000b,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00091a2b,
  0x00891a2b,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x001b4e81,
  0x00891a2a,
  0x00091a2c,
  0x00091a2b,
  0x8076e5d5,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80091a2b,
  0x8076e5d4,
  0x00091a2a,
  0x00091a2b,
  0x00891a2b,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x001b4e81,
  0x00891a2a,
  0x00091a2c,
  0x00091a2b,
  0x8076e5d5,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80091a2b,
  0x8076e5d4,
  0x00091a2a,
  0x00091a2b,
  0x00891a2b,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x001b4e81,
  0x00891a2a,
  0x00091a2c,
  0x00091a2b,
  0x8076e5d5,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80091a2b,
  0x8076e5d4,
  0x00091a2a,
  0x00123456,
  0x00923456,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x002468ac,
  0x00923455,
  0x00123457,
  0x00123456,
  0x806dcbaa,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80000000,
  0x806dcba9,
  0x00123455,
  0x00123456,
  0x00923456,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x002468ac,
  0x00923455,
  0x00123457,
  0x00123456,
  0x806dcbaa,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x00000000,
  0x806dcba9,
  0x00123455,
  0x00123456,
  0x00923456,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x002468ac,
  0x00923455,
  0x00123457,
  0x00123456,
  0x806dcbaa,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x00000000,
  0x806dcba9,
  0x00123455,
  0x001b4e81,
  0x009b4e81,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x002d82d7,
  0x009b4e80,
  0x001b4e82,
  0x001b4e81,
  0x8064b17f,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x00091a2b,
  0x8064b17e,
  0x001b4e80,
  0x00b60b5c,
  0x011b05ae,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00c83fb2,
  0x011b05ae,
  0x00b60b5d,
  0x00b60b5c,
  0x00360b5c,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x00a3d706,
  0x00360b5d,
  0x00b60b5b,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80091a2b,
  0x0076e5d5,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00091a2b,
  0x0076e5d4,
  0x80091a2a,
  0x80091a2b,
  0x80891a2b,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x801b4e81,
  0x80891a2a,
  0x80091a2c,
  0x80091a2b,
  0x0076e5d5,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00091a2b,
  0x0076e5d4,
  0x80091a2a,
  0x80091a2b,
  0x80891a2b,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x801b4e81,
  0x80891a2a,
  0x80091a2c,
  0x80091a2b,
  0x0076e5d5,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00091a2b,
  0x0076e5d4,
  0x80091a2a,
  0x80091a2b,
  0x80891a2b,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x801b4e81,
  0x80891a2a,
  0x80091a2c,
  0x80123456,
  0x006dcbaa,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00000000,
  0x006dcba9,
  0x80123455,
  0x80123456,
  0x80923456,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x802468ac,
  0x80923455,
  0x80123457,
  0x80123456,
  0x006dcbaa,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00000000,
  0x006dcba9,
  0x80123455,
  0x80123456,
  0x80923456,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x802468ac,
  0x80923455,
  0x80123457,
  0x80123456,
  0x006dcbaa,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x80000000,
  0x006dcba9,
  0x80123455,
  0x80123456,
  0x80923456,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x802468ac,
  0x80923455,
  0x80123457,
  0x801b4e81,
  0x0064b17f,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x80091a2b,
  0x0064b17e,
  0x801b4e80,
  0x801b4e81,
  0x809b4e81,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x802d82d7,
  0x809b4e80,
  0x801b4e82,
  0x80b60b5c,
  0x80360b5c,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x80a3d706,
  0x80360b5d,
  0x80b60b5b,
  0x80b60b5c,
  0x811b05ae,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80c83fb2,
  0x811b05ae,
  0x80b60b5d,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x003fffff,
  0x00bfffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00523455,
  0x00bffffe,
  0x00400000,
  0x003fffff,
  0x80400001,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x002dcba9,
  0x80400000,
  0x003ffffe,
  0x00400000,
  0x00c00000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00523456,
  0x00bffffe,
  0x00400000,
  0x00400000,
  0x80400000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x002dcbaa,
  0x80400000,
  0x003ffffe,
  0x00400000,
  0x00c00000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00523456,
  0x00bfffff,
  0x00400001,
  0x00400000,
  0x80400000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x002dcbaa,
  0x803fffff,
  0x003fffff,
  0x007fffff,
  0x00ffffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00923455,
  0x00fffffe,
  0x00800000,
  0x007fffff,
  0x80000001,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x006dcba9,
  0x80000000,
  0x007ffffe,
  0x007fffff,
  0x00ffffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00923455,
  0x00fffffe,
  0x00800000,
  0x007fffff,
  0x80000001,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x006dcba9,
  0x00000000,
  0x007ffffe,
  0x00800000,
  0x01000000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00923456,
  0x00ffffff,
  0x00800001,
  0x00800000,
  0x80000000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x006dcbaa,
  0x00000001,
  0x007fffff,
  0x00bffffe,
  0x011fffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00d23454,
  0x011fffff,
  0x00c00000,
  0x00bffffe,
  0x003ffffe,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x00adcba8,
  0x00400000,
  0x00bffffe,
  0x021fffff,
  0x022fffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x0222468a,
  0x022fffff,
  0x021fffff,
  0x021fffff,
  0x020fffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x021db974,
  0x020fffff,
  0x021fffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x803fffff,
  0x00400001,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x802dcba9,
  0x00400000,
  0x803ffffe,
  0x803fffff,
  0x80bfffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80523455,
  0x80bffffe,
  0x80400000,
  0x80400000,
  0x00400000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x802dcbaa,
  0x00400000,
  0x803ffffe,
  0x80400000,
  0x80c00000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80523456,
  0x80bffffe,
  0x80400000,
  0x80400000,
  0x00400000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x802dcbaa,
  0x003fffff,
  0x803fffff,
  0x80400000,
  0x80c00000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80523456,
  0x80bfffff,
  0x80400001,
  0x807fffff,
  0x00000001,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x806dcba9,
  0x00000000,
  0x807ffffe,
  0x807fffff,
  0x80ffffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80923455,
  0x80fffffe,
  0x80800000,
  0x807fffff,
  0x00000001,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x806dcba9,
  0x00000000,
  0x807ffffe,
  0x807fffff,
  0x80ffffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80923455,
  0x80fffffe,
  0x80800000,
  0x80800000,
  0x00000000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x806dcbaa,
  0x80000001,
  0x807fffff,
  0x80800000,
  0x81000000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80923456,
  0x80ffffff,
  0x80800001,
  0x80bffffe,
  0x803ffffe,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x80adcba8,
  0x80400000,
  0x80bffffe,
  0x80bffffe,
  0x811fffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80d23454,
  0x811fffff,
  0x80c00000,
  0x821fffff,
  0x820fffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x821db974,
  0x820fffff,
  0x821fffff,
  0x821fffff,
  0x822fffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x8222468a,
  0x822fffff,
  0x821fffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x00800000,
  0x00000002,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807ffffe,
  0x80000000,
  0x00000001,
  0x00800001,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123457,
  0x00800000,
  0x00000002,
  0x00000001,
  0x807fffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123455,
  0x807ffffe,
  0x80000000,
  0x00000001,
  0x00800001,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123457,
  0x00800000,
  0x00000002,
  0x00000001,
  0x807fffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123455,
  0x807ffffe,
  0x80000000,
  0x00000001,
  0x00800001,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123457,
  0x00800000,
  0x00000002,
  0x00000001,
  0x807fffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123455,
  0x807ffffe,
  0x00000000,
  0x00000001,
  0x00800001,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123457,
  0x00800000,
  0x00000002,
  0x00000001,
  0x807fffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123455,
  0x807ffffe,
  0x00000000,
  0x00000002,
  0x00800002,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123458,
  0x00800000,
  0x00000002,
  0x00000002,
  0x807ffffe,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123454,
  0x807ffffe,
  0x00000000,
  0x0000000a,
  0x0080000a,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123460,
  0x00800009,
  0x0000000b,
  0x0000000a,
  0x807ffff6,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x8012344c,
  0x807ffff5,
  0x00000009,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007ffffe,
  0x00000000,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x80800000,
  0x80000002,
  0x80000001,
  0x007fffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123455,
  0x007ffffe,
  0x00000000,
  0x80000001,
  0x80800001,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123457,
  0x80800000,
  0x80000002,
  0x80000001,
  0x007fffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123455,
  0x007ffffe,
  0x00000000,
  0x80000001,
  0x80800001,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123457,
  0x80800000,
  0x80000002,
  0x80000001,
  0x007fffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123455,
  0x007ffffe,
  0x00000000,
  0x80000001,
  0x80800001,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123457,
  0x80800000,
  0x80000002,
  0x80000001,
  0x007fffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123455,
  0x007ffffe,
  0x80000000,
  0x80000001,
  0x80800001,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123457,
  0x80800000,
  0x80000002,
  0x80000002,
  0x007ffffe,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123454,
  0x007ffffe,
  0x80000000,
  0x80000002,
  0x80800002,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123458,
  0x80800000,
  0x80000002,
  0x8000000a,
  0x007ffff6,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x0012344c,
  0x007ffff5,
  0x80000009,
  0x8000000a,
  0x8080000a,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123460,
  0x80800009,
  0x8000000b,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80400000,
  0x00400000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x802dcbaa,
  0x003fffff,
  0x803fffff,
  0x80400000,
  0x80c00000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80523456,
  0x80bfffff,
  0x80400001,
  0x80400000,
  0x00400000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x802dcbaa,
  0x003fffff,
  0x803fffff,
  0x80400000,
  0x80c00000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80523456,
  0x80bfffff,
  0x80400001,
  0x80400000,
  0x00400000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x802dcbaa,
  0x003ffffe,
  0x80400000,
  0x80400000,
  0x80c00000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80523456,
  0x80c00000,
  0x80400002,
  0x80800000,
  0x00000000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x806dcbaa,
  0x80000000,
  0x807ffffe,
  0x80800000,
  0x81000000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80923456,
  0x80fffffe,
  0x80800000,
  0x80800000,
  0x00000000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x806dcbaa,
  0x80000001,
  0x807fffff,
  0x80800000,
  0x81000000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80923456,
  0x80ffffff,
  0x80800001,
  0x80800001,
  0x80000001,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x806dcbab,
  0x80000002,
  0x80800000,
  0x80800001,
  0x81000000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80923457,
  0x81000000,
  0x80800002,
  0x80c00000,
  0x80400000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x80adcbaa,
  0x80400001,
  0x80bfffff,
  0x80c00000,
  0x81200000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80d23456,
  0x81200000,
  0x80c00001,
  0x82200000,
  0x82100000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x821db975,
  0x82100000,
  0x82200000,
  0x82200000,
  0x82300000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x8222468b,
  0x82300000,
  0x82200000,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00400000,
  0x00c00000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00523456,
  0x00bfffff,
  0x00400001,
  0x00400000,
  0x80400000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x002dcbaa,
  0x803fffff,
  0x003fffff,
  0x00400000,
  0x00c00000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00523456,
  0x00bfffff,
  0x00400001,
  0x00400000,
  0x80400000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x002dcbaa,
  0x803fffff,
  0x003fffff,
  0x00400000,
  0x00c00000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00523456,
  0x00c00000,
  0x00400002,
  0x00400000,
  0x80400000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x002dcbaa,
  0x803ffffe,
  0x00400000,
  0x00800000,
  0x01000000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00923456,
  0x00fffffe,
  0x00800000,
  0x00800000,
  0x80000000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x006dcbaa,
  0x00000000,
  0x007ffffe,
  0x00800000,
  0x01000000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00923456,
  0x00ffffff,
  0x00800001,
  0x00800000,
  0x00000000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x006dcbaa,
  0x00000001,
  0x007fffff,
  0x00800001,
  0x01000000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00923457,
  0x01000000,
  0x00800002,
  0x00800001,
  0x00000001,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x006dcbab,
  0x00000002,
  0x00800000,
  0x00c00000,
  0x01200000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00d23456,
  0x01200000,
  0x00c00001,
  0x00c00000,
  0x00400000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x00adcbaa,
  0x00400001,
  0x00bfffff,
  0x02200000,
  0x02300000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x0222468b,
  0x02300000,
  0x02200000,
  0x02200000,
  0x02100000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x021db975,
  0x02100000,
  0x02200000,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80400000,
  0x00400000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x802dcbaa,
  0x003fffff,
  0x803fffff,
  0x80400000,
  0x80c00000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80523456,
  0x80bfffff,
  0x80400001,
  0xbe7ffffe,
  0xbe7ffffe,
  0x3e800000,
  0x3e800001,
  0x3e800003,
  0x3f3fffff,
  0x3f400000,
  0x3f400002,
  0x3fa00000,
  0x411c0000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbe7ffffe,
  0xbe7ffffe,
  0xbe7ffffe,
  0xbe7ffffe,
  0xbe7ffffe,
  0xbf3fffff,
  0xbf400000,
  0xbf400001,
  0xbf9fffff,
  0xbfa00000,
  0xbfa00001,
  0xbfe00000,
  0xc1240000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbe7ffffe,
  0xbe7ffffe,
  0xbe7ffffe,
  0xbe7fffff,
  0xbe7fffff,
  0x3e7fffff,
  0x3e800000,
  0x3e800002,
  0x3f3fffff,
  0x3f400000,
  0x3f400002,
  0x3fa00000,
  0x411c0000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbe7fffff,
  0xbe7fffff,
  0xbe7fffff,
  0xbe7fffff,
  0xbe7fffff,
  0xbf3fffff,
  0xbf400000,
  0xbf400001,
  0xbf9fffff,
  0xbfa00000,
  0xbfa00001,
  0xbfe00000,
  0xc1240000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbe7fffff,
  0xbe7fffff,
  0xbe7fffff,
  0xbe800000,
  0xbe800000,
  0x3e7ffffd,
  0x3e7fffff,
  0x3e800002,
  0x3f3fffff,
  0x3f400000,
  0x3f400002,
  0x3fa00000,
  0x411c0000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbe800000,
  0xbe800000,
  0xbe800000,
  0xbe800000,
  0xbe800000,
  0xbf400000,
  0xbf400000,
  0xbf400001,
  0xbfa00000,
  0xbfa00000,
  0xbfa00001,
  0xbfe00000,
  0xc1240000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbe800000,
  0xbe800000,
  0xbe800000,
  0xbefffffe,
  0xbefffffe,
  0x32ffffff,
  0x33800000,
  0x34000000,
  0x3f000000,
  0x3f000001,
  0x3f000003,
  0x3f800000,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbefffffe,
  0xbefffffe,
  0xbefffffe,
  0xbefffffe,
  0xbefffffe,
  0xbf7fffff,
  0xbf7fffff,
  0xbf800000,
  0xbfbfffff,
  0xbfc00000,
  0xbfc00001,
  0xc0000000,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbefffffe,
  0xbefffffe,
  0xbefffffe,
  0xbeffffff,
  0xbeffffff,
  0x00000000,
  0x33000000,
  0x33c00000,
  0x3effffff,
  0x3f000000,
  0x3f000002,
  0x3f800000,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbf7fffff,
  0xbf800000,
  0xbf800000,
  0xbfbfffff,
  0xbfc00000,
  0xbfc00001,
  0xc0000000,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbf000000,
  0xbf000000,
  0xb37fffff,
  0xb2fffffe,
  0x33000001,
  0x3efffffd,
  0x3effffff,
  0x3f000002,
  0x3f800000,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf800000,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xbfc00000,
  0xbfc00001,
  0xc0000000,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf3fffff,
  0xbf3fffff,
  0xbe7fffff,
  0xbe7ffffd,
  0xbe7ffff9,
  0x3e7fffff,
  0x3e800002,
  0x3e800006,
  0x3f400001,
  0x41140000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf3fffff,
  0xbf3fffff,
  0xbf3fffff,
  0xbf3fffff,
  0xbf3fffff,
  0xbf9fffff,
  0xbfa00000,
  0xbfa00000,
  0xbfdfffff,
  0xbfe00000,
  0xbfe00001,
  0xc0100000,
  0xc12c0000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf3fffff,
  0xbf3fffff,
  0xbf3fffff,
  0xc09fffff,
  0xc09fffff,
  0xc08fffff,
  0xc08fffff,
  0xc08fffff,
  0xc07fffff,
  0xc07fffff,
  0xc07ffffe,
  0xc05fffff,
  0x40a00001,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xc09fffff,
  0xc09fffff,
  0xc09fffff,
  0xc09fffff,
  0xc09fffff,
  0xc0afffff,
  0xc0afffff,
  0xc0b00000,
  0xc0bfffff,
  0xc0bfffff,
  0xc0c00000,
  0xc0cfffff,
  0xc1700000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xc09fffff,
  0xc09fffff,
  0xc09fffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x80091a2b,
  0x0076e5d5,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00091a2b,
  0x0076e5d4,
  0x80091a2a,
  0x80091a2b,
  0x80891a2b,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x801b4e81,
  0x80891a2a,
  0x80091a2c,
  0x803fffff,
  0x00400001,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x802dcba9,
  0x00400000,
  0x803ffffe,
  0x803fffff,
  0x80bfffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80523455,
  0x80bffffe,
  0x80400000,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00400000,
  0x00c00000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00523456,
  0x00bfffff,
  0x00400001,
  0x00400000,
  0x80400000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x002dcbaa,
  0x803fffff,
  0x003fffff,
  0x3e7ffffe,
  0x3e7ffffe,
  0x3f3fffff,
  0x3f400000,
  0x3f400001,
  0x3f9fffff,
  0x3fa00000,
  0x3fa00001,
  0x3fe00000,
  0x41240000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3e7ffffe,
  0x3e7ffffe,
  0x3e7ffffe,
  0x3e7ffffe,
  0x3e7ffffe,
  0xbe800000,
  0xbe800001,
  0xbe800003,
  0xbf3fffff,
  0xbf400000,
  0xbf400002,
  0xbfa00000,
  0xc11c0000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3e7ffffe,
  0x3e7ffffe,
  0x3e7ffffe,
  0x3e7fffff,
  0x3e7fffff,
  0x3f3fffff,
  0x3f400000,
  0x3f400001,
  0x3f9fffff,
  0x3fa00000,
  0x3fa00001,
  0x3fe00000,
  0x41240000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3e7fffff,
  0x3e7fffff,
  0x3e7fffff,
  0x3e7fffff,
  0x3e7fffff,
  0xbe7fffff,
  0xbe800000,
  0xbe800002,
  0xbf3fffff,
  0xbf400000,
  0xbf400002,
  0xbfa00000,
  0xc11c0000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3e7fffff,
  0x3e7fffff,
  0x3e7fffff,
  0x3e800000,
  0x3e800000,
  0x3f400000,
  0x3f400000,
  0x3f400001,
  0x3fa00000,
  0x3fa00000,
  0x3fa00001,
  0x3fe00000,
  0x41240000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3e800000,
  0x3e800000,
  0x3e800000,
  0x3e800000,
  0x3e800000,
  0xbe7ffffd,
  0xbe7fffff,
  0xbe800002,
  0xbf3fffff,
  0xbf400000,
  0xbf400002,
  0xbfa00000,
  0xc11c0000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3e800000,
  0x3e800000,
  0x3e800000,
  0x3efffffe,
  0x3efffffe,
  0x3f7fffff,
  0x3f7fffff,
  0x3f800000,
  0x3fbfffff,
  0x3fc00000,
  0x3fc00001,
  0x40000000,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3efffffe,
  0x3efffffe,
  0x3efffffe,
  0x3efffffe,
  0x3efffffe,
  0xb2ffffff,
  0xb3800000,
  0xb4000000,
  0xbf000000,
  0xbf000001,
  0xbf000003,
  0xbf800000,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3efffffe,
  0x3efffffe,
  0x3efffffe,
  0x3effffff,
  0x3effffff,
  0x3f7fffff,
  0x3f800000,
  0x3f800000,
  0x3fbfffff,
  0x3fc00000,
  0x3fc00001,
  0x40000000,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x00000000,
  0xb3000000,
  0xb3c00000,
  0xbeffffff,
  0xbf000000,
  0xbf000002,
  0xbf800000,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3f000000,
  0x3f000000,
  0x3f800000,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x3fc00000,
  0x3fc00001,
  0x40000000,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x337fffff,
  0x32fffffe,
  0xb3000001,
  0xbefffffd,
  0xbeffffff,
  0xbf000002,
  0xbf800000,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f3fffff,
  0x3f3fffff,
  0x3f9fffff,
  0x3fa00000,
  0x3fa00000,
  0x3fdfffff,
  0x3fe00000,
  0x3fe00001,
  0x40100000,
  0x412c0000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f3fffff,
  0x3f3fffff,
  0x3f3fffff,
  0x3f3fffff,
  0x3f3fffff,
  0x3e7fffff,
  0x3e7ffffd,
  0x3e7ffff9,
  0xbe7fffff,
  0xbe800002,
  0xbe800006,
  0xbf400001,
  0xc1140000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f3fffff,
  0x3f3fffff,
  0x3f3fffff,
  0x409fffff,
  0x409fffff,
  0x40afffff,
  0x40afffff,
  0x40b00000,
  0x40bfffff,
  0x40bfffff,
  0x40c00000,
  0x40cfffff,
  0x41700000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x409fffff,
  0x409fffff,
  0x409fffff,
  0x409fffff,
  0x409fffff,
  0x408fffff,
  0x408fffff,
  0x408fffff,
  0x407fffff,
  0x407fffff,
  0x407ffffe,
  0x405fffff,
  0xc0a00001,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x409fffff,
  0x409fffff,
  0x409fffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x00091a2b,
  0x00891a2b,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x001b4e81,
  0x00891a2a,
  0x00091a2c,
  0x00091a2b,
  0x8076e5d5,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80091a2b,
  0x8076e5d4,
  0x00091a2a,
  0x003fffff,
  0x00bfffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00523455,
  0x00bffffe,
  0x00400000,
  0x003fffff,
  0x80400001,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x002dcba9,
  0x80400000,
  0x003ffffe,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80400000,
  0x00400000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x802dcbaa,
  0x003fffff,
  0x803fffff,
  0x80400000,
  0x80c00000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80523456,
  0x80bfffff,
  0x80400001,
  0xbe7fffff,
  0xbe7fffff,
  0x3e7fffff,
  0x3e800000,
  0x3e800002,
  0x3f3fffff,
  0x3f400000,
  0x3f400002,
  0x3fa00000,
  0x411c0000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbe7fffff,
  0xbe7fffff,
  0xbe7fffff,
  0xbe7fffff,
  0xbe7fffff,
  0xbf3fffff,
  0xbf400000,
  0xbf400001,
  0xbf9fffff,
  0xbfa00000,
  0xbfa00001,
  0xbfe00000,
  0xc1240000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbe7fffff,
  0xbe7fffff,
  0xbe7fffff,
  0xbe800000,
  0xbe800000,
  0x3e7ffffe,
  0x3e800000,
  0x3e800002,
  0x3f3fffff,
  0x3f400000,
  0x3f400002,
  0x3fa00000,
  0x411c0000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbe800000,
  0xbe800000,
  0xbe800000,
  0xbe800000,
  0xbe800000,
  0xbf400000,
  0xbf400000,
  0xbf400001,
  0xbfa00000,
  0xbfa00000,
  0xbfa00001,
  0xbfe00000,
  0xc1240000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbe800000,
  0xbe800000,
  0xbe800000,
  0xbe800001,
  0xbe800001,
  0x3e7ffffc,
  0x3e7ffffe,
  0x3e800001,
  0x3f3ffffe,
  0x3f400000,
  0x3f400002,
  0x3fa00000,
  0x411c0000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbe800001,
  0xbe800001,
  0xbe800001,
  0xbe800001,
  0xbe800001,
  0xbf400000,
  0xbf400000,
  0xbf400002,
  0xbfa00000,
  0xbfa00000,
  0xbfa00001,
  0xbfe00000,
  0xc1240000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbe800001,
  0xbe800001,
  0xbe800001,
  0xbeffffff,
  0xbeffffff,
  0x00000000,
  0x33000000,
  0x33c00000,
  0x3effffff,
  0x3f000000,
  0x3f000002,
  0x3f800000,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbf7fffff,
  0xbf800000,
  0xbf800000,
  0xbfbfffff,
  0xbfc00000,
  0xbfc00001,
  0xc0000000,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbf000000,
  0xbf000000,
  0xb3000000,
  0x00000000,
  0x33800000,
  0x3efffffe,
  0x3f000000,
  0x3f000002,
  0x3f800000,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbfc00000,
  0xbfc00000,
  0xbfc00001,
  0xc0000000,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000001,
  0xbf000001,
  0xb3c00000,
  0xb3800000,
  0x00000000,
  0x3efffffc,
  0x3efffffe,
  0x3f000001,
  0x3f7fffff,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf800000,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xbfc00000,
  0xbfc00002,
  0xc0000000,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf400000,
  0xbf400000,
  0xbe800001,
  0xbe800000,
  0xbe7ffffc,
  0x3e7ffffc,
  0x3e800000,
  0x3e800004,
  0x3f400000,
  0x41140000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf400000,
  0xbf400000,
  0xbf400000,
  0xbf400000,
  0xbf400000,
  0xbfa00000,
  0xbfa00000,
  0xbfa00000,
  0xbfe00000,
  0xbfe00000,
  0xbfe00001,
  0xc0100000,
  0xc12c0000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf400000,
  0xbf400000,
  0xbf400000,
  0xc0a00000,
  0xc0a00000,
  0xc0900000,
  0xc0900000,
  0xc0900000,
  0xc0800000,
  0xc0800000,
  0xc0800000,
  0xc0600000,
  0x40a00000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xc0a00000,
  0xc0a00000,
  0xc0a00000,
  0xc0a00000,
  0xc0a00000,
  0xc0b00000,
  0xc0b00000,
  0xc0b00000,
  0xc0c00000,
  0xc0c00000,
  0xc0c00000,
  0xc0d00000,
  0xc1700000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xc0a00000,
  0xc0a00000,
  0xc0a00000,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x80091a2b,
  0x0076e5d5,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00091a2b,
  0x0076e5d4,
  0x80091a2a,
  0x80091a2b,
  0x80891a2b,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x801b4e81,
  0x80891a2a,
  0x80091a2c,
  0x80400000,
  0x00400000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x802dcbaa,
  0x00400000,
  0x803ffffe,
  0x80400000,
  0x80c00000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80523456,
  0x80bffffe,
  0x80400000,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007ffffe,
  0x00000000,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x80800000,
  0x80000002,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00400000,
  0x00c00000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00523456,
  0x00bfffff,
  0x00400001,
  0x00400000,
  0x80400000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x002dcbaa,
  0x803fffff,
  0x003fffff,
  0x3e7fffff,
  0x3e7fffff,
  0x3f3fffff,
  0x3f400000,
  0x3f400001,
  0x3f9fffff,
  0x3fa00000,
  0x3fa00001,
  0x3fe00000,
  0x41240000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3e7fffff,
  0x3e7fffff,
  0x3e7fffff,
  0x3e7fffff,
  0x3e7fffff,
  0xbe7fffff,
  0xbe800000,
  0xbe800002,
  0xbf3fffff,
  0xbf400000,
  0xbf400002,
  0xbfa00000,
  0xc11c0000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3e7fffff,
  0x3e7fffff,
  0x3e7fffff,
  0x3e800000,
  0x3e800000,
  0x3f400000,
  0x3f400000,
  0x3f400001,
  0x3fa00000,
  0x3fa00000,
  0x3fa00001,
  0x3fe00000,
  0x41240000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3e800000,
  0x3e800000,
  0x3e800000,
  0x3e800000,
  0x3e800000,
  0xbe7ffffe,
  0xbe800000,
  0xbe800002,
  0xbf3fffff,
  0xbf400000,
  0xbf400002,
  0xbfa00000,
  0xc11c0000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3e800000,
  0x3e800000,
  0x3e800000,
  0x3e800001,
  0x3e800001,
  0x3f400000,
  0x3f400000,
  0x3f400002,
  0x3fa00000,
  0x3fa00000,
  0x3fa00001,
  0x3fe00000,
  0x41240000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3e800001,
  0x3e800001,
  0x3e800001,
  0x3e800001,
  0x3e800001,
  0xbe7ffffc,
  0xbe7ffffe,
  0xbe800001,
  0xbf3ffffe,
  0xbf400000,
  0xbf400002,
  0xbfa00000,
  0xc11c0000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3e800001,
  0x3e800001,
  0x3e800001,
  0x3effffff,
  0x3effffff,
  0x3f7fffff,
  0x3f800000,
  0x3f800000,
  0x3fbfffff,
  0x3fc00000,
  0x3fc00001,
  0x40000000,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x00000000,
  0xb3000000,
  0xb3c00000,
  0xbeffffff,
  0xbf000000,
  0xbf000002,
  0xbf800000,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3f000000,
  0x3f000000,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3fc00000,
  0x3fc00000,
  0x3fc00001,
  0x40000000,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x33000000,
  0x00000000,
  0xb3800000,
  0xbefffffe,
  0xbf000000,
  0xbf000002,
  0xbf800000,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000001,
  0x3f000001,
  0x3f800000,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x3fc00000,
  0x3fc00002,
  0x40000000,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x33c00000,
  0x33800000,
  0x00000000,
  0xbefffffc,
  0xbefffffe,
  0xbf000001,
  0xbf7fffff,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f400000,
  0x3f400000,
  0x3fa00000,
  0x3fa00000,
  0x3fa00000,
  0x3fe00000,
  0x3fe00000,
  0x3fe00001,
  0x40100000,
  0x412c0000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f400000,
  0x3f400000,
  0x3f400000,
  0x3f400000,
  0x3f400000,
  0x3e800001,
  0x3e800000,
  0x3e7ffffc,
  0xbe7ffffc,
  0xbe800000,
  0xbe800004,
  0xbf400000,
  0xc1140000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f400000,
  0x3f400000,
  0x3f400000,
  0x40a00000,
  0x40a00000,
  0x40b00000,
  0x40b00000,
  0x40b00000,
  0x40c00000,
  0x40c00000,
  0x40c00000,
  0x40d00000,
  0x41700000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x40a00000,
  0x40a00000,
  0x40a00000,
  0x40a00000,
  0x40a00000,
  0x40900000,
  0x40900000,
  0x40900000,
  0x40800000,
  0x40800000,
  0x40800000,
  0x40600000,
  0xc0a00000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x40a00000,
  0x40a00000,
  0x40a00000,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x00091a2b,
  0x00891a2b,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x001b4e81,
  0x00891a2a,
  0x00091a2c,
  0x00091a2b,
  0x8076e5d5,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80091a2b,
  0x8076e5d4,
  0x00091a2a,
  0x00400000,
  0x00c00000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00523456,
  0x00bffffe,
  0x00400000,
  0x00400000,
  0x80400000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x002dcbaa,
  0x80400000,
  0x003ffffe,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x00800000,
  0x00000002,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807ffffe,
  0x80000000,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80400000,
  0x00400000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x802dcbaa,
  0x003ffffe,
  0x80400000,
  0x80400000,
  0x80c00000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80523456,
  0x80c00000,
  0x80400002,
  0xbe800000,
  0xbe800000,
  0x3e7ffffd,
  0x3e7fffff,
  0x3e800002,
  0x3f3fffff,
  0x3f400000,
  0x3f400002,
  0x3fa00000,
  0x411c0000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbe800000,
  0xbe800000,
  0xbe800000,
  0xbe800000,
  0xbe800000,
  0xbf400000,
  0xbf400000,
  0xbf400001,
  0xbfa00000,
  0xbfa00000,
  0xbfa00001,
  0xbfe00000,
  0xc1240000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbe800000,
  0xbe800000,
  0xbe800000,
  0xbe800001,
  0xbe800001,
  0x3e7ffffc,
  0x3e7ffffe,
  0x3e800001,
  0x3f3ffffe,
  0x3f400000,
  0x3f400002,
  0x3fa00000,
  0x411c0000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbe800001,
  0xbe800001,
  0xbe800001,
  0xbe800001,
  0xbe800001,
  0xbf400000,
  0xbf400000,
  0xbf400002,
  0xbfa00000,
  0xbfa00000,
  0xbfa00001,
  0xbfe00000,
  0xc1240000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbe800001,
  0xbe800001,
  0xbe800001,
  0xbe800002,
  0xbe800002,
  0x3e7ffffa,
  0x3e7ffffc,
  0x3e800000,
  0x3f3ffffe,
  0x3f3fffff,
  0x3f400001,
  0x3f9fffff,
  0x411c0000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbe800002,
  0xbe800002,
  0xbe800002,
  0xbe800002,
  0xbe800002,
  0xbf400001,
  0xbf400001,
  0xbf400002,
  0xbfa00000,
  0xbfa00001,
  0xbfa00002,
  0xbfe00001,
  0xc1240000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbe800002,
  0xbe800002,
  0xbe800002,
  0xbf000000,
  0xbf000000,
  0xb37fffff,
  0xb2fffffe,
  0x33000001,
  0x3efffffd,
  0x3effffff,
  0x3f000002,
  0x3f800000,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf800000,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xbfc00000,
  0xbfc00001,
  0xc0000000,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000001,
  0xbf000001,
  0xb3c00000,
  0xb3800000,
  0x00000000,
  0x3efffffc,
  0x3efffffe,
  0x3f000001,
  0x3f7fffff,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf800000,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xbfc00000,
  0xbfc00002,
  0xc0000000,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf000002,
  0xbf000002,
  0xb4200000,
  0xb4000000,
  0xb3800001,
  0x3efffffa,
  0x3efffffc,
  0x3f000000,
  0x3f7ffffe,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf000002,
  0xbf000002,
  0xbf000002,
  0xbf000002,
  0xbf000002,
  0xbf800001,
  0xbf800001,
  0xbf800002,
  0xbfc00001,
  0xbfc00001,
  0xbfc00002,
  0xc0000001,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf000002,
  0xbf000002,
  0xbf000002,
  0xbf400002,
  0xbf400001,
  0xbe800004,
  0xbe800003,
  0xbe800001,
  0x3e7ffff6,
  0x3e7ffffa,
  0x3e800001,
  0x3f3ffffe,
  0x41140000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf400001,
  0xbf400001,
  0xbf400001,
  0xbf400002,
  0xbf400002,
  0xbfa00000,
  0xbfa00001,
  0xbfa00001,
  0xbfe00000,
  0xbfe00001,
  0xbfe00002,
  0xc0100000,
  0xc12c0000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf400002,
  0xbf400002,
  0xbf400002,
  0xc0a00001,
  0xc0a00001,
  0xc0900001,
  0xc0900001,
  0xc0900001,
  0xc0800001,
  0xc0800001,
  0xc0800001,
  0xc0600002,
  0x409fffff,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xc0a00001,
  0xc0a00001,
  0xc0a00001,
  0xc0a00001,
  0xc0a00001,
  0xc0b00001,
  0xc0b00001,
  0xc0b00001,
  0xc0c00001,
  0xc0c00001,
  0xc0c00002,
  0xc0d00001,
  0xc1700001,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xc0a00001,
  0xc0a00001,
  0xc0a00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x80091a2b,
  0x0076e5d5,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00091a2b,
  0x0076e5d4,
  0x80091a2a,
  0x80091a2b,
  0x80891a2b,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x801b4e81,
  0x80891a2a,
  0x80091a2c,
  0x80400000,
  0x00400000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x802dcbaa,
  0x003fffff,
  0x803fffff,
  0x80400000,
  0x80c00000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80523456,
  0x80bfffff,
  0x80400001,
  0x80000001,
  0x007fffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123455,
  0x007ffffe,
  0x00000000,
  0x80000001,
  0x80800001,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123457,
  0x80800000,
  0x80000002,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00400000,
  0x00c00000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00523456,
  0x00c00000,
  0x00400002,
  0x00400000,
  0x80400000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x002dcbaa,
  0x803ffffe,
  0x00400000,
  0x3e800000,
  0x3e800000,
  0x3f400000,
  0x3f400000,
  0x3f400001,
  0x3fa00000,
  0x3fa00000,
  0x3fa00001,
  0x3fe00000,
  0x41240000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3e800000,
  0x3e800000,
  0x3e800000,
  0x3e800000,
  0x3e800000,
  0xbe7ffffd,
  0xbe7fffff,
  0xbe800002,
  0xbf3fffff,
  0xbf400000,
  0xbf400002,
  0xbfa00000,
  0xc11c0000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3e800000,
  0x3e800000,
  0x3e800000,
  0x3e800001,
  0x3e800001,
  0x3f400000,
  0x3f400000,
  0x3f400002,
  0x3fa00000,
  0x3fa00000,
  0x3fa00001,
  0x3fe00000,
  0x41240000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3e800001,
  0x3e800001,
  0x3e800001,
  0x3e800001,
  0x3e800001,
  0xbe7ffffc,
  0xbe7ffffe,
  0xbe800001,
  0xbf3ffffe,
  0xbf400000,
  0xbf400002,
  0xbfa00000,
  0xc11c0000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3e800001,
  0x3e800001,
  0x3e800001,
  0x3e800002,
  0x3e800002,
  0x3f400001,
  0x3f400001,
  0x3f400002,
  0x3fa00000,
  0x3fa00001,
  0x3fa00002,
  0x3fe00001,
  0x41240000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3e800002,
  0x3e800002,
  0x3e800002,
  0x3e800002,
  0x3e800002,
  0xbe7ffffa,
  0xbe7ffffc,
  0xbe800000,
  0xbf3ffffe,
  0xbf3fffff,
  0xbf400001,
  0xbf9fffff,
  0xc11c0000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3e800002,
  0x3e800002,
  0x3e800002,
  0x3f000000,
  0x3f000000,
  0x3f800000,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x3fc00000,
  0x3fc00001,
  0x40000000,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x337fffff,
  0x32fffffe,
  0xb3000001,
  0xbefffffd,
  0xbeffffff,
  0xbf000002,
  0xbf800000,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000001,
  0x3f000001,
  0x3f800000,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x3fc00000,
  0x3fc00002,
  0x40000000,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x33c00000,
  0x33800000,
  0x00000000,
  0xbefffffc,
  0xbefffffe,
  0xbf000001,
  0xbf7fffff,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f000002,
  0x3f000002,
  0x3f800001,
  0x3f800001,
  0x3f800002,
  0x3fc00001,
  0x3fc00001,
  0x3fc00002,
  0x40000001,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f000002,
  0x3f000002,
  0x3f000002,
  0x3f000002,
  0x3f000002,
  0x34200000,
  0x34000000,
  0x33800001,
  0xbefffffa,
  0xbefffffc,
  0xbf000000,
  0xbf7ffffe,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f000002,
  0x3f000002,
  0x3f000002,
  0x3f400002,
  0x3f400002,
  0x3fa00000,
  0x3fa00001,
  0x3fa00001,
  0x3fe00000,
  0x3fe00001,
  0x3fe00002,
  0x40100000,
  0x412c0000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f400002,
  0x3f400002,
  0x3f400002,
  0x3f400002,
  0x3f400001,
  0x3e800004,
  0x3e800003,
  0x3e800001,
  0xbe7ffff6,
  0xbe7ffffa,
  0xbe800001,
  0xbf3ffffe,
  0xc1140000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f400001,
  0x3f400001,
  0x3f400001,
  0x40a00001,
  0x40a00001,
  0x40b00001,
  0x40b00001,
  0x40b00001,
  0x40c00001,
  0x40c00001,
  0x40c00002,
  0x40d00001,
  0x41700001,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x40a00001,
  0x40a00001,
  0x40a00001,
  0x40a00001,
  0x40a00001,
  0x40900001,
  0x40900001,
  0x40900001,
  0x40800001,
  0x40800001,
  0x40800001,
  0x40600002,
  0xc09fffff,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x40a00001,
  0x40a00001,
  0x40a00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x00091a2b,
  0x00891a2b,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x001b4e81,
  0x00891a2a,
  0x00091a2c,
  0x00091a2b,
  0x8076e5d5,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80091a2b,
  0x8076e5d4,
  0x00091a2a,
  0x00400000,
  0x00c00000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00523456,
  0x00bfffff,
  0x00400001,
  0x00400000,
  0x80400000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x002dcbaa,
  0x803fffff,
  0x003fffff,
  0x00000001,
  0x00800001,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123457,
  0x00800000,
  0x00000002,
  0x00000001,
  0x807fffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123455,
  0x807ffffe,
  0x80000000,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80800000,
  0x00000000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x806dcbaa,
  0x80000000,
  0x807ffffe,
  0x80800000,
  0x81000000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80923456,
  0x80fffffe,
  0x80800000,
  0xbefffffe,
  0xbefffffe,
  0x32ffffff,
  0x33800000,
  0x34000000,
  0x3f000000,
  0x3f000001,
  0x3f000003,
  0x3f800000,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbefffffe,
  0xbefffffe,
  0xbefffffe,
  0xbefffffe,
  0xbefffffe,
  0xbf7fffff,
  0xbf7fffff,
  0xbf800000,
  0xbfbfffff,
  0xbfc00000,
  0xbfc00001,
  0xc0000000,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbefffffe,
  0xbefffffe,
  0xbefffffe,
  0xbeffffff,
  0xbeffffff,
  0x00000000,
  0x33000000,
  0x33c00000,
  0x3effffff,
  0x3f000000,
  0x3f000002,
  0x3f800000,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbf7fffff,
  0xbf800000,
  0xbf800000,
  0xbfbfffff,
  0xbfc00000,
  0xbfc00001,
  0xc0000000,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbf000000,
  0xbf000000,
  0xb37fffff,
  0xb2fffffe,
  0x33000001,
  0x3efffffd,
  0x3effffff,
  0x3f000002,
  0x3f800000,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf800000,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xbfc00000,
  0xbfc00001,
  0xc0000000,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf7ffffe,
  0xbf7ffffe,
  0xbefffffd,
  0xbefffffc,
  0xbefffffa,
  0x337fffff,
  0x34000000,
  0x34800000,
  0x3f000002,
  0x41100000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf7ffffe,
  0xbf7ffffe,
  0xbf7ffffe,
  0xbf7ffffe,
  0xbf7ffffe,
  0xbfbfffff,
  0xbfbfffff,
  0xbfc00000,
  0xbfffffff,
  0xbfffffff,
  0xc0000000,
  0xc0200000,
  0xc1300000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf7ffffe,
  0xbf7ffffe,
  0xbf7ffffe,
  0xbf7fffff,
  0xbf7fffff,
  0xbeffffff,
  0xbefffffe,
  0xbefffffc,
  0x00000000,
  0x33800000,
  0x34400000,
  0x3f000001,
  0x41100000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf7fffff,
  0xbf7fffff,
  0xbf7fffff,
  0xbf7fffff,
  0xbf7fffff,
  0xbfbfffff,
  0xbfc00000,
  0xbfc00000,
  0xbfffffff,
  0xc0000000,
  0xc0000000,
  0xc0200000,
  0xc1300000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf7fffff,
  0xbf7fffff,
  0xbf7fffff,
  0xbf800000,
  0xbf800000,
  0xbf000001,
  0xbf000001,
  0xbf000000,
  0xb3ffffff,
  0xb37ffffe,
  0x33800001,
  0x3efffffe,
  0x41100000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbfc00000,
  0xbfc00000,
  0xbfc00001,
  0xc0000000,
  0xc0000000,
  0xc0000001,
  0xc0200000,
  0xc1300000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbfbfffff,
  0xbfbfffff,
  0xbf7fffff,
  0xbf7ffffe,
  0xbf7ffffe,
  0xbeffffff,
  0xbefffffd,
  0xbefffff9,
  0x33c00000,
  0x41080000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbfbfffff,
  0xbfbfffff,
  0xbfbfffff,
  0xbfbfffff,
  0xbfbfffff,
  0xbfffffff,
  0xbfffffff,
  0xc0000000,
  0xc01fffff,
  0xc0200000,
  0xc0200000,
  0xc0400000,
  0xc1380000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbfbfffff,
  0xbfbfffff,
  0xbfbfffff,
  0xc11fffff,
  0xc11fffff,
  0xc117ffff,
  0xc117ffff,
  0xc117ffff,
  0xc10fffff,
  0xc10fffff,
  0xc10fffff,
  0xc107ffff,
  0x35200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xc11fffff,
  0xc11fffff,
  0xc11fffff,
  0xc11fffff,
  0xc11fffff,
  0xc127ffff,
  0xc127ffff,
  0xc127ffff,
  0xc12fffff,
  0xc12fffff,
  0xc1300000,
  0xc137ffff,
  0xc1a00000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xc11fffff,
  0xc11fffff,
  0xc11fffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x80123456,
  0x006dcbaa,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00000000,
  0x006dcba9,
  0x80123455,
  0x80123456,
  0x80923456,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x802468ac,
  0x80923455,
  0x80123457,
  0x807fffff,
  0x00000001,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x806dcba9,
  0x00000000,
  0x807ffffe,
  0x807fffff,
  0x80ffffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80923455,
  0x80fffffe,
  0x80800000,
  0x80000001,
  0x007fffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123455,
  0x007ffffe,
  0x00000000,
  0x80000001,
  0x80800001,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123457,
  0x80800000,
  0x80000002,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00800000,
  0x01000000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00923456,
  0x00fffffe,
  0x00800000,
  0x00800000,
  0x80000000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x006dcbaa,
  0x00000000,
  0x007ffffe,
  0x3efffffe,
  0x3efffffe,
  0x3f7fffff,
  0x3f7fffff,
  0x3f800000,
  0x3fbfffff,
  0x3fc00000,
  0x3fc00001,
  0x40000000,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3efffffe,
  0x3efffffe,
  0x3efffffe,
  0x3efffffe,
  0x3efffffe,
  0xb2ffffff,
  0xb3800000,
  0xb4000000,
  0xbf000000,
  0xbf000001,
  0xbf000003,
  0xbf800000,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3efffffe,
  0x3efffffe,
  0x3efffffe,
  0x3effffff,
  0x3effffff,
  0x3f7fffff,
  0x3f800000,
  0x3f800000,
  0x3fbfffff,
  0x3fc00000,
  0x3fc00001,
  0x40000000,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x00000000,
  0xb3000000,
  0xb3c00000,
  0xbeffffff,
  0xbf000000,
  0xbf000002,
  0xbf800000,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3f000000,
  0x3f000000,
  0x3f800000,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x3fc00000,
  0x3fc00001,
  0x40000000,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x337fffff,
  0x32fffffe,
  0xb3000001,
  0xbefffffd,
  0xbeffffff,
  0xbf000002,
  0xbf800000,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f7ffffe,
  0x3f7ffffe,
  0x3fbfffff,
  0x3fbfffff,
  0x3fc00000,
  0x3fffffff,
  0x3fffffff,
  0x40000000,
  0x40200000,
  0x41300000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f7ffffe,
  0x3f7ffffe,
  0x3f7ffffe,
  0x3f7ffffe,
  0x3f7ffffe,
  0x3efffffd,
  0x3efffffc,
  0x3efffffa,
  0xb37fffff,
  0xb4000000,
  0xb4800000,
  0xbf000002,
  0xc1100000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f7ffffe,
  0x3f7ffffe,
  0x3f7ffffe,
  0x3f7fffff,
  0x3f7fffff,
  0x3fbfffff,
  0x3fc00000,
  0x3fc00000,
  0x3fffffff,
  0x40000000,
  0x40000000,
  0x40200000,
  0x41300000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f7fffff,
  0x3f7fffff,
  0x3f7fffff,
  0x3f7fffff,
  0x3f7fffff,
  0x3effffff,
  0x3efffffe,
  0x3efffffc,
  0x00000000,
  0xb3800000,
  0xb4400000,
  0xbf000001,
  0xc1100000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f7fffff,
  0x3f7fffff,
  0x3f7fffff,
  0x3f800000,
  0x3f800000,
  0x3fc00000,
  0x3fc00000,
  0x3fc00001,
  0x40000000,
  0x40000000,
  0x40000001,
  0x40200000,
  0x41300000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3f000001,
  0x3f000001,
  0x3f000000,
  0x33ffffff,
  0x337ffffe,
  0xb3800001,
  0xbefffffe,
  0xc1100000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3fbfffff,
  0x3fbfffff,
  0x3fffffff,
  0x3fffffff,
  0x40000000,
  0x401fffff,
  0x40200000,
  0x40200000,
  0x40400000,
  0x41380000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3fbfffff,
  0x3fbfffff,
  0x3fbfffff,
  0x3fbfffff,
  0x3fbfffff,
  0x3f7fffff,
  0x3f7ffffe,
  0x3f7ffffe,
  0x3effffff,
  0x3efffffd,
  0x3efffff9,
  0xb3c00000,
  0xc1080000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3fbfffff,
  0x3fbfffff,
  0x3fbfffff,
  0x411fffff,
  0x411fffff,
  0x4127ffff,
  0x4127ffff,
  0x4127ffff,
  0x412fffff,
  0x412fffff,
  0x41300000,
  0x4137ffff,
  0x41a00000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x411fffff,
  0x411fffff,
  0x411fffff,
  0x411fffff,
  0x411fffff,
  0x4117ffff,
  0x4117ffff,
  0x4117ffff,
  0x410fffff,
  0x410fffff,
  0x410fffff,
  0x4107ffff,
  0xb5200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x411fffff,
  0x411fffff,
  0x411fffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x00123456,
  0x00923456,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x002468ac,
  0x00923455,
  0x00123457,
  0x00123456,
  0x806dcbaa,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80000000,
  0x806dcba9,
  0x00123455,
  0x007fffff,
  0x00ffffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00923455,
  0x00fffffe,
  0x00800000,
  0x007fffff,
  0x80000001,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x006dcba9,
  0x80000000,
  0x007ffffe,
  0x00000001,
  0x00800001,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123457,
  0x00800000,
  0x00000002,
  0x00000001,
  0x807fffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123455,
  0x807ffffe,
  0x80000000,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80800000,
  0x00000000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x806dcbaa,
  0x80000001,
  0x807fffff,
  0x80800000,
  0x81000000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80923456,
  0x80ffffff,
  0x80800001,
  0xbeffffff,
  0xbeffffff,
  0x00000000,
  0x33000000,
  0x33c00000,
  0x3effffff,
  0x3f000000,
  0x3f000002,
  0x3f800000,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbf7fffff,
  0xbf800000,
  0xbf800000,
  0xbfbfffff,
  0xbfc00000,
  0xbfc00001,
  0xc0000000,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbf000000,
  0xbf000000,
  0xb3000000,
  0x00000000,
  0x33800000,
  0x3efffffe,
  0x3f000000,
  0x3f000002,
  0x3f800000,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbfc00000,
  0xbfc00000,
  0xbfc00001,
  0xc0000000,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000001,
  0xbf000001,
  0xb3c00000,
  0xb3800000,
  0x00000000,
  0x3efffffc,
  0x3efffffe,
  0x3f000001,
  0x3f7fffff,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf800000,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xbfc00000,
  0xbfc00002,
  0xc0000000,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf7fffff,
  0xbf7fffff,
  0xbeffffff,
  0xbefffffe,
  0xbefffffc,
  0x00000000,
  0x33800000,
  0x34400000,
  0x3f000001,
  0x41100000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf7fffff,
  0xbf7fffff,
  0xbf7fffff,
  0xbf7fffff,
  0xbf7fffff,
  0xbfbfffff,
  0xbfc00000,
  0xbfc00000,
  0xbfffffff,
  0xc0000000,
  0xc0000000,
  0xc0200000,
  0xc1300000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf7fffff,
  0xbf7fffff,
  0xbf7fffff,
  0xbf800000,
  0xbf800000,
  0xbf000000,
  0xbf000000,
  0xbefffffe,
  0xb3800000,
  0x00000000,
  0x34000000,
  0x3f000000,
  0x41100000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbfc00000,
  0xbfc00000,
  0xbfc00000,
  0xc0000000,
  0xc0000000,
  0xc0000000,
  0xc0200000,
  0xc1300000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbf800001,
  0xbf800001,
  0xbf000002,
  0xbf000002,
  0xbf000001,
  0xb4400000,
  0xb4000000,
  0x00000000,
  0x3efffffc,
  0x41100000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf800001,
  0xbf800001,
  0xbf800001,
  0xbf800001,
  0xbf800001,
  0xbfc00001,
  0xbfc00001,
  0xbfc00002,
  0xc0000000,
  0xc0000000,
  0xc0000001,
  0xc0200000,
  0xc1300000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf800001,
  0xbf800001,
  0xbf800001,
  0xbfc00000,
  0xbfc00000,
  0xbf800000,
  0xbf800000,
  0xbf7fffff,
  0xbf000001,
  0xbf000000,
  0xbefffffc,
  0x00000000,
  0x41080000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbfc00000,
  0xbfc00000,
  0xbfc00000,
  0xbfc00000,
  0xbfc00000,
  0xc0000000,
  0xc0000000,
  0xc0000000,
  0xc0200000,
  0xc0200000,
  0xc0200000,
  0xc0400000,
  0xc1380000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbfc00000,
  0xbfc00000,
  0xbfc00000,
  0xc1200000,
  0xc1200000,
  0xc1180000,
  0xc1180000,
  0xc1180000,
  0xc1100000,
  0xc1100000,
  0xc1100000,
  0xc1080000,
  0x00000000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xc1200000,
  0xc1200000,
  0xc1200000,
  0xc1200000,
  0xc1200000,
  0xc1280000,
  0xc1280000,
  0xc1280000,
  0xc1300000,
  0xc1300000,
  0xc1300000,
  0xc1380000,
  0xc1a00000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xc1200000,
  0xc1200000,
  0xc1200000,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x80123456,
  0x006dcbaa,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00000000,
  0x006dcba9,
  0x80123455,
  0x80123456,
  0x80923456,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x802468ac,
  0x80923455,
  0x80123457,
  0x807fffff,
  0x00000001,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x806dcba9,
  0x00000000,
  0x807ffffe,
  0x807fffff,
  0x80ffffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80923455,
  0x80fffffe,
  0x80800000,
  0x80000001,
  0x007fffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123455,
  0x007ffffe,
  0x00000000,
  0x80000001,
  0x80800001,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123457,
  0x80800000,
  0x80000002,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00800000,
  0x01000000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00923456,
  0x00ffffff,
  0x00800001,
  0x00800000,
  0x00000000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x006dcbaa,
  0x00000001,
  0x007fffff,
  0x3effffff,
  0x3effffff,
  0x3f7fffff,
  0x3f800000,
  0x3f800000,
  0x3fbfffff,
  0x3fc00000,
  0x3fc00001,
  0x40000000,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x00000000,
  0xb3000000,
  0xb3c00000,
  0xbeffffff,
  0xbf000000,
  0xbf000002,
  0xbf800000,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3f000000,
  0x3f000000,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3fc00000,
  0x3fc00000,
  0x3fc00001,
  0x40000000,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x33000000,
  0x00000000,
  0xb3800000,
  0xbefffffe,
  0xbf000000,
  0xbf000002,
  0xbf800000,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000001,
  0x3f000001,
  0x3f800000,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x3fc00000,
  0x3fc00002,
  0x40000000,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x33c00000,
  0x33800000,
  0x00000000,
  0xbefffffc,
  0xbefffffe,
  0xbf000001,
  0xbf7fffff,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f7fffff,
  0x3f7fffff,
  0x3fbfffff,
  0x3fc00000,
  0x3fc00000,
  0x3fffffff,
  0x40000000,
  0x40000000,
  0x40200000,
  0x41300000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f7fffff,
  0x3f7fffff,
  0x3f7fffff,
  0x3f7fffff,
  0x3f7fffff,
  0x3effffff,
  0x3efffffe,
  0x3efffffc,
  0x00000000,
  0xb3800000,
  0xb4400000,
  0xbf000001,
  0xc1100000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f7fffff,
  0x3f7fffff,
  0x3f7fffff,
  0x3f800000,
  0x3f800000,
  0x3fc00000,
  0x3fc00000,
  0x3fc00000,
  0x40000000,
  0x40000000,
  0x40000000,
  0x40200000,
  0x41300000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3f000000,
  0x3f000000,
  0x3efffffe,
  0x33800000,
  0x00000000,
  0xb4000000,
  0xbf000000,
  0xc1100000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3f800001,
  0x3f800001,
  0x3fc00001,
  0x3fc00001,
  0x3fc00002,
  0x40000000,
  0x40000000,
  0x40000001,
  0x40200000,
  0x41300000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f800001,
  0x3f800001,
  0x3f800001,
  0x3f800001,
  0x3f800001,
  0x3f000002,
  0x3f000002,
  0x3f000001,
  0x34400000,
  0x34000000,
  0x00000000,
  0xbefffffc,
  0xc1100000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f800001,
  0x3f800001,
  0x3f800001,
  0x3fc00000,
  0x3fc00000,
  0x40000000,
  0x40000000,
  0x40000000,
  0x40200000,
  0x40200000,
  0x40200000,
  0x40400000,
  0x41380000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3fc00000,
  0x3fc00000,
  0x3fc00000,
  0x3fc00000,
  0x3fc00000,
  0x3f800000,
  0x3f800000,
  0x3f7fffff,
  0x3f000001,
  0x3f000000,
  0x3efffffc,
  0x00000000,
  0xc1080000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3fc00000,
  0x3fc00000,
  0x3fc00000,
  0x41200000,
  0x41200000,
  0x41280000,
  0x41280000,
  0x41280000,
  0x41300000,
  0x41300000,
  0x41300000,
  0x41380000,
  0x41a00000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x41200000,
  0x41200000,
  0x41200000,
  0x41200000,
  0x41200000,
  0x41180000,
  0x41180000,
  0x41180000,
  0x41100000,
  0x41100000,
  0x41100000,
  0x41080000,
  0x00000000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x41200000,
  0x41200000,
  0x41200000,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x00123456,
  0x00923456,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x002468ac,
  0x00923455,
  0x00123457,
  0x00123456,
  0x806dcbaa,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x00000000,
  0x806dcba9,
  0x00123455,
  0x007fffff,
  0x00ffffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00923455,
  0x00fffffe,
  0x00800000,
  0x007fffff,
  0x80000001,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x006dcba9,
  0x00000000,
  0x007ffffe,
  0x00000001,
  0x00800001,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123457,
  0x00800000,
  0x00000002,
  0x00000001,
  0x807fffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123455,
  0x807ffffe,
  0x00000000,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80800001,
  0x80000001,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x806dcbab,
  0x80000002,
  0x80800000,
  0x80800001,
  0x81000000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80923457,
  0x81000000,
  0x80800002,
  0xbf000000,
  0xbf000000,
  0xb37fffff,
  0xb2fffffe,
  0x33000001,
  0x3efffffd,
  0x3effffff,
  0x3f000002,
  0x3f800000,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf800000,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xbfc00000,
  0xbfc00001,
  0xc0000000,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000001,
  0xbf000001,
  0xb3c00000,
  0xb3800000,
  0x00000000,
  0x3efffffc,
  0x3efffffe,
  0x3f000001,
  0x3f7fffff,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf800000,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xbfc00000,
  0xbfc00002,
  0xc0000000,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf000002,
  0xbf000002,
  0xb4200000,
  0xb4000000,
  0xb3800001,
  0x3efffffa,
  0x3efffffc,
  0x3f000000,
  0x3f7ffffe,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf000002,
  0xbf000002,
  0xbf000002,
  0xbf000002,
  0xbf000002,
  0xbf800001,
  0xbf800001,
  0xbf800002,
  0xbfc00001,
  0xbfc00001,
  0xbfc00002,
  0xc0000001,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf000002,
  0xbf000002,
  0xbf000002,
  0xbf800000,
  0xbf800000,
  0xbf000001,
  0xbf000001,
  0xbf000000,
  0xb3ffffff,
  0xb37ffffe,
  0x33800001,
  0x3efffffe,
  0x41100000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbfc00000,
  0xbfc00000,
  0xbfc00001,
  0xc0000000,
  0xc0000000,
  0xc0000001,
  0xc0200000,
  0xc1300000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbf800001,
  0xbf800001,
  0xbf000002,
  0xbf000002,
  0xbf000001,
  0xb4400000,
  0xb4000000,
  0x00000000,
  0x3efffffc,
  0x41100000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf800001,
  0xbf800001,
  0xbf800001,
  0xbf800001,
  0xbf800001,
  0xbfc00001,
  0xbfc00001,
  0xbfc00002,
  0xc0000000,
  0xc0000000,
  0xc0000001,
  0xc0200000,
  0xc1300000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf800001,
  0xbf800001,
  0xbf800001,
  0xbf800002,
  0xbf800002,
  0xbf000005,
  0xbf000004,
  0xbf000003,
  0xb4a00000,
  0xb4800000,
  0xb4000001,
  0x3efffff8,
  0x41100000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf800002,
  0xbf800002,
  0xbf800002,
  0xbf800002,
  0xbf800002,
  0xbfc00002,
  0xbfc00002,
  0xbfc00003,
  0xc0000001,
  0xc0000001,
  0xc0000002,
  0xc0200001,
  0xc1300000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf800002,
  0xbf800002,
  0xbf800002,
  0xbfc00002,
  0xbfc00001,
  0xbf800002,
  0xbf800002,
  0xbf800001,
  0xbf000004,
  0xbf000003,
  0xbf000001,
  0xb4400000,
  0x41080000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbfc00001,
  0xbfc00001,
  0xbfc00001,
  0xbfc00002,
  0xbfc00002,
  0xc0000001,
  0xc0000001,
  0xc0000001,
  0xc0200000,
  0xc0200001,
  0xc0200001,
  0xc0400001,
  0xc1380000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbfc00002,
  0xbfc00002,
  0xbfc00002,
  0xc1200001,
  0xc1200001,
  0xc1180001,
  0xc1180001,
  0xc1180001,
  0xc1100001,
  0xc1100001,
  0xc1100001,
  0xc1080001,
  0xb5a00000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xc1200001,
  0xc1200001,
  0xc1200001,
  0xc1200001,
  0xc1200001,
  0xc1280001,
  0xc1280001,
  0xc1280001,
  0xc1300001,
  0xc1300001,
  0xc1300001,
  0xc1380001,
  0xc1a00001,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xc1200001,
  0xc1200001,
  0xc1200001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x80123456,
  0x006dcbaa,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x80000000,
  0x006dcba9,
  0x80123455,
  0x80123456,
  0x80923456,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x802468ac,
  0x80923455,
  0x80123457,
  0x80800000,
  0x00000000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x806dcbaa,
  0x80000001,
  0x807fffff,
  0x80800000,
  0x81000000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80923456,
  0x80ffffff,
  0x80800001,
  0x80000001,
  0x007fffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123455,
  0x007ffffe,
  0x80000000,
  0x80000001,
  0x80800001,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123457,
  0x80800000,
  0x80000002,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00800001,
  0x01000000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00923457,
  0x01000000,
  0x00800002,
  0x00800001,
  0x00000001,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x006dcbab,
  0x00000002,
  0x00800000,
  0x3f000000,
  0x3f000000,
  0x3f800000,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x3fc00000,
  0x3fc00001,
  0x40000000,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x337fffff,
  0x32fffffe,
  0xb3000001,
  0xbefffffd,
  0xbeffffff,
  0xbf000002,
  0xbf800000,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000001,
  0x3f000001,
  0x3f800000,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x3fc00000,
  0x3fc00002,
  0x40000000,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x33c00000,
  0x33800000,
  0x00000000,
  0xbefffffc,
  0xbefffffe,
  0xbf000001,
  0xbf7fffff,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f000002,
  0x3f000002,
  0x3f800001,
  0x3f800001,
  0x3f800002,
  0x3fc00001,
  0x3fc00001,
  0x3fc00002,
  0x40000001,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f000002,
  0x3f000002,
  0x3f000002,
  0x3f000002,
  0x3f000002,
  0x34200000,
  0x34000000,
  0x33800001,
  0xbefffffa,
  0xbefffffc,
  0xbf000000,
  0xbf7ffffe,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f000002,
  0x3f000002,
  0x3f000002,
  0x3f800000,
  0x3f800000,
  0x3fc00000,
  0x3fc00000,
  0x3fc00001,
  0x40000000,
  0x40000000,
  0x40000001,
  0x40200000,
  0x41300000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3f000001,
  0x3f000001,
  0x3f000000,
  0x33ffffff,
  0x337ffffe,
  0xb3800001,
  0xbefffffe,
  0xc1100000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3f800001,
  0x3f800001,
  0x3fc00001,
  0x3fc00001,
  0x3fc00002,
  0x40000000,
  0x40000000,
  0x40000001,
  0x40200000,
  0x41300000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f800001,
  0x3f800001,
  0x3f800001,
  0x3f800001,
  0x3f800001,
  0x3f000002,
  0x3f000002,
  0x3f000001,
  0x34400000,
  0x34000000,
  0x00000000,
  0xbefffffc,
  0xc1100000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f800001,
  0x3f800001,
  0x3f800001,
  0x3f800002,
  0x3f800002,
  0x3fc00002,
  0x3fc00002,
  0x3fc00003,
  0x40000001,
  0x40000001,
  0x40000002,
  0x40200001,
  0x41300000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f800002,
  0x3f800002,
  0x3f800002,
  0x3f800002,
  0x3f800002,
  0x3f000005,
  0x3f000004,
  0x3f000003,
  0x34a00000,
  0x34800000,
  0x34000001,
  0xbefffff8,
  0xc1100000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f800002,
  0x3f800002,
  0x3f800002,
  0x3fc00002,
  0x3fc00002,
  0x40000001,
  0x40000001,
  0x40000001,
  0x40200000,
  0x40200001,
  0x40200001,
  0x40400001,
  0x41380000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3fc00002,
  0x3fc00002,
  0x3fc00002,
  0x3fc00002,
  0x3fc00001,
  0x3f800002,
  0x3f800002,
  0x3f800001,
  0x3f000004,
  0x3f000003,
  0x3f000001,
  0x34400000,
  0xc1080000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3fc00001,
  0x3fc00001,
  0x3fc00001,
  0x41200001,
  0x41200001,
  0x41280001,
  0x41280001,
  0x41280001,
  0x41300001,
  0x41300001,
  0x41300001,
  0x41380001,
  0x41a00001,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x41200001,
  0x41200001,
  0x41200001,
  0x41200001,
  0x41200001,
  0x41180001,
  0x41180001,
  0x41180001,
  0x41100001,
  0x41100001,
  0x41100001,
  0x41080001,
  0x35a00000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x41200001,
  0x41200001,
  0x41200001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x00123456,
  0x00923456,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x002468ac,
  0x00923455,
  0x00123457,
  0x00123456,
  0x806dcbaa,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x00000000,
  0x806dcba9,
  0x00123455,
  0x00800000,
  0x01000000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00923456,
  0x00ffffff,
  0x00800001,
  0x00800000,
  0x80000000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x006dcbaa,
  0x00000001,
  0x007fffff,
  0x00000001,
  0x00800001,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123457,
  0x00800000,
  0x00000002,
  0x00000001,
  0x807fffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123455,
  0x807ffffe,
  0x00000000,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80c00000,
  0x80400000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x80adcbaa,
  0x80400001,
  0x80bfffff,
  0x80c00000,
  0x81200000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80d23456,
  0x81200000,
  0x80c00001,
  0xbf3fffff,
  0xbf3fffff,
  0xbe7fffff,
  0xbe7ffffd,
  0xbe7ffff9,
  0x3e7fffff,
  0x3e800002,
  0x3e800006,
  0x3f400001,
  0x41140000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf3fffff,
  0xbf3fffff,
  0xbf3fffff,
  0xbf3fffff,
  0xbf3fffff,
  0xbf9fffff,
  0xbfa00000,
  0xbfa00000,
  0xbfdfffff,
  0xbfe00000,
  0xbfe00001,
  0xc0100000,
  0xc12c0000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf3fffff,
  0xbf3fffff,
  0xbf3fffff,
  0xbf400000,
  0xbf400000,
  0xbe800001,
  0xbe800000,
  0xbe7ffffc,
  0x3e7ffffc,
  0x3e800000,
  0x3e800004,
  0x3f400000,
  0x41140000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf400000,
  0xbf400000,
  0xbf400000,
  0xbf400000,
  0xbf400000,
  0xbfa00000,
  0xbfa00000,
  0xbfa00000,
  0xbfe00000,
  0xbfe00000,
  0xbfe00001,
  0xc0100000,
  0xc12c0000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf400000,
  0xbf400000,
  0xbf400000,
  0xbf400002,
  0xbf400001,
  0xbe800004,
  0xbe800003,
  0xbe800001,
  0x3e7ffff6,
  0x3e7ffffa,
  0x3e800001,
  0x3f3ffffe,
  0x41140000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf400001,
  0xbf400001,
  0xbf400001,
  0xbf400002,
  0xbf400002,
  0xbfa00000,
  0xbfa00001,
  0xbfa00001,
  0xbfe00000,
  0xbfe00001,
  0xbfe00002,
  0xc0100000,
  0xc12c0000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf400002,
  0xbf400002,
  0xbf400002,
  0xbfbfffff,
  0xbfbfffff,
  0xbf7fffff,
  0xbf7ffffe,
  0xbf7ffffe,
  0xbeffffff,
  0xbefffffd,
  0xbefffff9,
  0x33c00000,
  0x41080000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbfbfffff,
  0xbfbfffff,
  0xbfbfffff,
  0xbfbfffff,
  0xbfbfffff,
  0xbfffffff,
  0xbfffffff,
  0xc0000000,
  0xc01fffff,
  0xc0200000,
  0xc0200000,
  0xc0400000,
  0xc1380000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbfbfffff,
  0xbfbfffff,
  0xbfbfffff,
  0xbfc00000,
  0xbfc00000,
  0xbf800000,
  0xbf800000,
  0xbf7fffff,
  0xbf000001,
  0xbf000000,
  0xbefffffc,
  0x00000000,
  0x41080000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbfc00000,
  0xbfc00000,
  0xbfc00000,
  0xbfc00000,
  0xbfc00000,
  0xc0000000,
  0xc0000000,
  0xc0000000,
  0xc0200000,
  0xc0200000,
  0xc0200000,
  0xc0400000,
  0xc1380000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbfc00000,
  0xbfc00000,
  0xbfc00000,
  0xbfc00002,
  0xbfc00001,
  0xbf800002,
  0xbf800002,
  0xbf800001,
  0xbf000004,
  0xbf000003,
  0xbf000001,
  0xb4400000,
  0x41080000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbfc00001,
  0xbfc00001,
  0xbfc00001,
  0xbfc00002,
  0xbfc00002,
  0xc0000001,
  0xc0000001,
  0xc0000001,
  0xc0200000,
  0xc0200001,
  0xc0200001,
  0xc0400001,
  0xc1380000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbfc00002,
  0xbfc00002,
  0xbfc00002,
  0xc0100000,
  0xc0100000,
  0xbfe00000,
  0xbfe00000,
  0xbfe00000,
  0xbfa00000,
  0xbfa00000,
  0xbf9fffff,
  0xbf400000,
  0x40f80000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xc0100000,
  0xc0100000,
  0xc0100000,
  0xc0100000,
  0xc0100000,
  0xc0300000,
  0xc0300000,
  0xc0300000,
  0xc0500000,
  0xc0500000,
  0xc0500000,
  0xc0700000,
  0xc1440000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xc0100000,
  0xc0100000,
  0xc0100000,
  0xc1700000,
  0xc1700000,
  0xc1680000,
  0xc1680000,
  0xc1680000,
  0xc1600000,
  0xc1600000,
  0xc1600000,
  0xc1580000,
  0xc0a00000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xc1700000,
  0xc1700000,
  0xc1700000,
  0xc1700000,
  0xc1700000,
  0xc1780000,
  0xc1780000,
  0xc1780000,
  0xc1800000,
  0xc1800000,
  0xc1800000,
  0xc1840000,
  0xc1c80000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xc1700000,
  0xc1700000,
  0xc1700000,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x801b4e81,
  0x0064b17f,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x80091a2b,
  0x0064b17e,
  0x801b4e80,
  0x801b4e81,
  0x809b4e81,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x802d82d7,
  0x809b4e80,
  0x801b4e82,
  0x80bffffe,
  0x803ffffe,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x80adcba8,
  0x80400000,
  0x80bffffe,
  0x80bffffe,
  0x811fffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80d23454,
  0x811fffff,
  0x80c00000,
  0x80000002,
  0x007ffffe,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123454,
  0x007ffffe,
  0x80000000,
  0x80000002,
  0x80800002,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123458,
  0x80800000,
  0x80000002,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00c00000,
  0x01200000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00d23456,
  0x01200000,
  0x00c00001,
  0x00c00000,
  0x00400000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x00adcbaa,
  0x00400001,
  0x00bfffff,
  0x3f3fffff,
  0x3f3fffff,
  0x3f9fffff,
  0x3fa00000,
  0x3fa00000,
  0x3fdfffff,
  0x3fe00000,
  0x3fe00001,
  0x40100000,
  0x412c0000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f3fffff,
  0x3f3fffff,
  0x3f3fffff,
  0x3f3fffff,
  0x3f3fffff,
  0x3e7fffff,
  0x3e7ffffd,
  0x3e7ffff9,
  0xbe7fffff,
  0xbe800002,
  0xbe800006,
  0xbf400001,
  0xc1140000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f3fffff,
  0x3f3fffff,
  0x3f3fffff,
  0x3f400000,
  0x3f400000,
  0x3fa00000,
  0x3fa00000,
  0x3fa00000,
  0x3fe00000,
  0x3fe00000,
  0x3fe00001,
  0x40100000,
  0x412c0000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f400000,
  0x3f400000,
  0x3f400000,
  0x3f400000,
  0x3f400000,
  0x3e800001,
  0x3e800000,
  0x3e7ffffc,
  0xbe7ffffc,
  0xbe800000,
  0xbe800004,
  0xbf400000,
  0xc1140000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f400000,
  0x3f400000,
  0x3f400000,
  0x3f400002,
  0x3f400002,
  0x3fa00000,
  0x3fa00001,
  0x3fa00001,
  0x3fe00000,
  0x3fe00001,
  0x3fe00002,
  0x40100000,
  0x412c0000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f400002,
  0x3f400002,
  0x3f400002,
  0x3f400002,
  0x3f400001,
  0x3e800004,
  0x3e800003,
  0x3e800001,
  0xbe7ffff6,
  0xbe7ffffa,
  0xbe800001,
  0xbf3ffffe,
  0xc1140000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f400001,
  0x3f400001,
  0x3f400001,
  0x3fbfffff,
  0x3fbfffff,
  0x3fffffff,
  0x3fffffff,
  0x40000000,
  0x401fffff,
  0x40200000,
  0x40200000,
  0x40400000,
  0x41380000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3fbfffff,
  0x3fbfffff,
  0x3fbfffff,
  0x3fbfffff,
  0x3fbfffff,
  0x3f7fffff,
  0x3f7ffffe,
  0x3f7ffffe,
  0x3effffff,
  0x3efffffd,
  0x3efffff9,
  0xb3c00000,
  0xc1080000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3fbfffff,
  0x3fbfffff,
  0x3fbfffff,
  0x3fc00000,
  0x3fc00000,
  0x40000000,
  0x40000000,
  0x40000000,
  0x40200000,
  0x40200000,
  0x40200000,
  0x40400000,
  0x41380000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3fc00000,
  0x3fc00000,
  0x3fc00000,
  0x3fc00000,
  0x3fc00000,
  0x3f800000,
  0x3f800000,
  0x3f7fffff,
  0x3f000001,
  0x3f000000,
  0x3efffffc,
  0x00000000,
  0xc1080000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3fc00000,
  0x3fc00000,
  0x3fc00000,
  0x3fc00002,
  0x3fc00002,
  0x40000001,
  0x40000001,
  0x40000001,
  0x40200000,
  0x40200001,
  0x40200001,
  0x40400001,
  0x41380000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3fc00002,
  0x3fc00002,
  0x3fc00002,
  0x3fc00002,
  0x3fc00001,
  0x3f800002,
  0x3f800002,
  0x3f800001,
  0x3f000004,
  0x3f000003,
  0x3f000001,
  0x34400000,
  0xc1080000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3fc00001,
  0x3fc00001,
  0x3fc00001,
  0x40100000,
  0x40100000,
  0x40300000,
  0x40300000,
  0x40300000,
  0x40500000,
  0x40500000,
  0x40500000,
  0x40700000,
  0x41440000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x40100000,
  0x40100000,
  0x40100000,
  0x40100000,
  0x40100000,
  0x3fe00000,
  0x3fe00000,
  0x3fe00000,
  0x3fa00000,
  0x3fa00000,
  0x3f9fffff,
  0x3f400000,
  0xc0f80000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x40100000,
  0x40100000,
  0x40100000,
  0x41700000,
  0x41700000,
  0x41780000,
  0x41780000,
  0x41780000,
  0x41800000,
  0x41800000,
  0x41800000,
  0x41840000,
  0x41c80000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x41700000,
  0x41700000,
  0x41700000,
  0x41700000,
  0x41700000,
  0x41680000,
  0x41680000,
  0x41680000,
  0x41600000,
  0x41600000,
  0x41600000,
  0x41580000,
  0x40a00000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x41700000,
  0x41700000,
  0x41700000,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x001b4e81,
  0x009b4e81,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x002d82d7,
  0x009b4e80,
  0x001b4e82,
  0x001b4e81,
  0x8064b17f,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x00091a2b,
  0x8064b17e,
  0x001b4e80,
  0x00bffffe,
  0x011fffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00d23454,
  0x011fffff,
  0x00c00000,
  0x00bffffe,
  0x003ffffe,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x00adcba8,
  0x00400000,
  0x00bffffe,
  0x00000002,
  0x00800002,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123458,
  0x00800000,
  0x00000002,
  0x00000002,
  0x807ffffe,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123454,
  0x807ffffe,
  0x00000000,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x82200000,
  0x82100000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x821db975,
  0x82100000,
  0x82200000,
  0x82200000,
  0x82300000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x8222468b,
  0x82300000,
  0x82200000,
  0xc09fffff,
  0xc09fffff,
  0xc08fffff,
  0xc08fffff,
  0xc08fffff,
  0xc07fffff,
  0xc07fffff,
  0xc07ffffe,
  0xc05fffff,
  0x40a00001,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xc09fffff,
  0xc09fffff,
  0xc09fffff,
  0xc09fffff,
  0xc09fffff,
  0xc0afffff,
  0xc0afffff,
  0xc0b00000,
  0xc0bfffff,
  0xc0bfffff,
  0xc0c00000,
  0xc0cfffff,
  0xc1700000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xc09fffff,
  0xc09fffff,
  0xc09fffff,
  0xc0a00000,
  0xc0a00000,
  0xc0900000,
  0xc0900000,
  0xc0900000,
  0xc0800000,
  0xc0800000,
  0xc0800000,
  0xc0600000,
  0x40a00000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xc0a00000,
  0xc0a00000,
  0xc0a00000,
  0xc0a00000,
  0xc0a00000,
  0xc0b00000,
  0xc0b00000,
  0xc0b00000,
  0xc0c00000,
  0xc0c00000,
  0xc0c00000,
  0xc0d00000,
  0xc1700000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xc0a00000,
  0xc0a00000,
  0xc0a00000,
  0xc0a00001,
  0xc0a00001,
  0xc0900001,
  0xc0900001,
  0xc0900001,
  0xc0800001,
  0xc0800001,
  0xc0800001,
  0xc0600002,
  0x409fffff,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xc0a00001,
  0xc0a00001,
  0xc0a00001,
  0xc0a00001,
  0xc0a00001,
  0xc0b00001,
  0xc0b00001,
  0xc0b00001,
  0xc0c00001,
  0xc0c00001,
  0xc0c00002,
  0xc0d00001,
  0xc1700001,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xc0a00001,
  0xc0a00001,
  0xc0a00001,
  0xc11fffff,
  0xc11fffff,
  0xc117ffff,
  0xc117ffff,
  0xc117ffff,
  0xc10fffff,
  0xc10fffff,
  0xc10fffff,
  0xc107ffff,
  0x35200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xc11fffff,
  0xc11fffff,
  0xc11fffff,
  0xc11fffff,
  0xc11fffff,
  0xc127ffff,
  0xc127ffff,
  0xc127ffff,
  0xc12fffff,
  0xc12fffff,
  0xc1300000,
  0xc137ffff,
  0xc1a00000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xc11fffff,
  0xc11fffff,
  0xc11fffff,
  0xc1200000,
  0xc1200000,
  0xc1180000,
  0xc1180000,
  0xc1180000,
  0xc1100000,
  0xc1100000,
  0xc1100000,
  0xc1080000,
  0x00000000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xc1200000,
  0xc1200000,
  0xc1200000,
  0xc1200000,
  0xc1200000,
  0xc1280000,
  0xc1280000,
  0xc1280000,
  0xc1300000,
  0xc1300000,
  0xc1300000,
  0xc1380000,
  0xc1a00000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xc1200000,
  0xc1200000,
  0xc1200000,
  0xc1200001,
  0xc1200001,
  0xc1180001,
  0xc1180001,
  0xc1180001,
  0xc1100001,
  0xc1100001,
  0xc1100001,
  0xc1080001,
  0xb5a00000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xc1200001,
  0xc1200001,
  0xc1200001,
  0xc1200001,
  0xc1200001,
  0xc1280001,
  0xc1280001,
  0xc1280001,
  0xc1300001,
  0xc1300001,
  0xc1300001,
  0xc1380001,
  0xc1a00001,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xc1200001,
  0xc1200001,
  0xc1200001,
  0xc1700000,
  0xc1700000,
  0xc1680000,
  0xc1680000,
  0xc1680000,
  0xc1600000,
  0xc1600000,
  0xc1600000,
  0xc1580000,
  0xc0a00000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xc1700000,
  0xc1700000,
  0xc1700000,
  0xc1700000,
  0xc1700000,
  0xc1780000,
  0xc1780000,
  0xc1780000,
  0xc1800000,
  0xc1800000,
  0xc1800000,
  0xc1840000,
  0xc1c80000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xc1700000,
  0xc1700000,
  0xc1700000,
  0xc2c80000,
  0xc2c80000,
  0xc2c70000,
  0xc2c70000,
  0xc2c70000,
  0xc2c60000,
  0xc2c60000,
  0xc2c60000,
  0xc2c50000,
  0xc2b40000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xc2c80000,
  0xc2c80000,
  0xc2c80000,
  0xc2c80000,
  0xc2c80000,
  0xc2c90000,
  0xc2c90000,
  0xc2c90000,
  0xc2ca0000,
  0xc2ca0000,
  0xc2ca0000,
  0xc2cb0000,
  0xc2dc0000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xc2c80000,
  0xc2c80000,
  0xc2c80000,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x80b60b5c,
  0x80360b5c,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x80a3d706,
  0x80360b5d,
  0x80b60b5b,
  0x80b60b5c,
  0x811b05ae,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80c83fb2,
  0x811b05ae,
  0x80b60b5d,
  0x821fffff,
  0x820fffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x821db974,
  0x820fffff,
  0x821fffff,
  0x821fffff,
  0x822fffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x8222468a,
  0x822fffff,
  0x821fffff,
  0x8000000a,
  0x007ffff6,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x0012344c,
  0x007ffff5,
  0x80000009,
  0x8000000a,
  0x8080000a,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123460,
  0x80800009,
  0x8000000b,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x02200000,
  0x02300000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x0222468b,
  0x02300000,
  0x02200000,
  0x02200000,
  0x02100000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x021db975,
  0x02100000,
  0x02200000,
  0x409fffff,
  0x409fffff,
  0x40afffff,
  0x40afffff,
  0x40b00000,
  0x40bfffff,
  0x40bfffff,
  0x40c00000,
  0x40cfffff,
  0x41700000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x409fffff,
  0x409fffff,
  0x409fffff,
  0x409fffff,
  0x409fffff,
  0x408fffff,
  0x408fffff,
  0x408fffff,
  0x407fffff,
  0x407fffff,
  0x407ffffe,
  0x405fffff,
  0xc0a00001,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x409fffff,
  0x409fffff,
  0x409fffff,
  0x40a00000,
  0x40a00000,
  0x40b00000,
  0x40b00000,
  0x40b00000,
  0x40c00000,
  0x40c00000,
  0x40c00000,
  0x40d00000,
  0x41700000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x40a00000,
  0x40a00000,
  0x40a00000,
  0x40a00000,
  0x40a00000,
  0x40900000,
  0x40900000,
  0x40900000,
  0x40800000,
  0x40800000,
  0x40800000,
  0x40600000,
  0xc0a00000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x40a00000,
  0x40a00000,
  0x40a00000,
  0x40a00001,
  0x40a00001,
  0x40b00001,
  0x40b00001,
  0x40b00001,
  0x40c00001,
  0x40c00001,
  0x40c00002,
  0x40d00001,
  0x41700001,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x40a00001,
  0x40a00001,
  0x40a00001,
  0x40a00001,
  0x40a00001,
  0x40900001,
  0x40900001,
  0x40900001,
  0x40800001,
  0x40800001,
  0x40800001,
  0x40600002,
  0xc09fffff,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x40a00001,
  0x40a00001,
  0x40a00001,
  0x411fffff,
  0x411fffff,
  0x4127ffff,
  0x4127ffff,
  0x4127ffff,
  0x412fffff,
  0x412fffff,
  0x41300000,
  0x4137ffff,
  0x41a00000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x411fffff,
  0x411fffff,
  0x411fffff,
  0x411fffff,
  0x411fffff,
  0x4117ffff,
  0x4117ffff,
  0x4117ffff,
  0x410fffff,
  0x410fffff,
  0x410fffff,
  0x4107ffff,
  0xb5200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x411fffff,
  0x411fffff,
  0x411fffff,
  0x41200000,
  0x41200000,
  0x41280000,
  0x41280000,
  0x41280000,
  0x41300000,
  0x41300000,
  0x41300000,
  0x41380000,
  0x41a00000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x41200000,
  0x41200000,
  0x41200000,
  0x41200000,
  0x41200000,
  0x41180000,
  0x41180000,
  0x41180000,
  0x41100000,
  0x41100000,
  0x41100000,
  0x41080000,
  0x00000000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x41200000,
  0x41200000,
  0x41200000,
  0x41200001,
  0x41200001,
  0x41280001,
  0x41280001,
  0x41280001,
  0x41300001,
  0x41300001,
  0x41300001,
  0x41380001,
  0x41a00001,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x41200001,
  0x41200001,
  0x41200001,
  0x41200001,
  0x41200001,
  0x41180001,
  0x41180001,
  0x41180001,
  0x41100001,
  0x41100001,
  0x41100001,
  0x41080001,
  0x35a00000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x41200001,
  0x41200001,
  0x41200001,
  0x41700000,
  0x41700000,
  0x41780000,
  0x41780000,
  0x41780000,
  0x41800000,
  0x41800000,
  0x41800000,
  0x41840000,
  0x41c80000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x41700000,
  0x41700000,
  0x41700000,
  0x41700000,
  0x41700000,
  0x41680000,
  0x41680000,
  0x41680000,
  0x41600000,
  0x41600000,
  0x41600000,
  0x41580000,
  0x40a00000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x41700000,
  0x41700000,
  0x41700000,
  0x42c80000,
  0x42c80000,
  0x42c90000,
  0x42c90000,
  0x42c90000,
  0x42ca0000,
  0x42ca0000,
  0x42ca0000,
  0x42cb0000,
  0x42dc0000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x42c80000,
  0x42c80000,
  0x42c80000,
  0x42c80000,
  0x42c80000,
  0x42c70000,
  0x42c70000,
  0x42c70000,
  0x42c60000,
  0x42c60000,
  0x42c60000,
  0x42c50000,
  0x42b40000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x42c80000,
  0x42c80000,
  0x42c80000,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x00b60b5c,
  0x011b05ae,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00c83fb2,
  0x011b05ae,
  0x00b60b5d,
  0x00b60b5c,
  0x00360b5c,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x00a3d706,
  0x00360b5d,
  0x00b60b5b,
  0x021fffff,
  0x022fffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x0222468a,
  0x022fffff,
  0x021fffff,
  0x021fffff,
  0x020fffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x021db974,
  0x020fffff,
  0x021fffff,
  0x0000000a,
  0x0080000a,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123460,
  0x00800009,
  0x0000000b,
  0x0000000a,
  0x807ffff6,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x8012344c,
  0x807ffff5,
  0x00000009,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80091a2b,
  0x0076e5d5,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00091a2b,
  0x0076e5d4,
  0x80091a2a,
  0x80091a2b,
  0x80891a2b,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x801b4e81,
  0x80891a2a,
  0x80091a2c,
  0x80091a2b,
  0x0076e5d5,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00091a2b,
  0x0076e5d4,
  0x80091a2a,
  0x80091a2b,
  0x80891a2b,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x801b4e81,
  0x80891a2a,
  0x80091a2c,
  0x80091a2b,
  0x0076e5d5,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00091a2b,
  0x0076e5d4,
  0x80091a2a,
  0x80091a2b,
  0x80891a2b,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x801b4e81,
  0x80891a2a,
  0x80091a2c,
  0x80123456,
  0x006dcbaa,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00000000,
  0x006dcba9,
  0x80123455,
  0x80123456,
  0x80923456,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x802468ac,
  0x80923455,
  0x80123457,
  0x80123456,
  0x006dcbaa,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00000000,
  0x006dcba9,
  0x80123455,
  0x80123456,
  0x80923456,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x802468ac,
  0x80923455,
  0x80123457,
  0x80123456,
  0x006dcbaa,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x80000000,
  0x006dcba9,
  0x80123455,
  0x80123456,
  0x80923456,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x802468ac,
  0x80923455,
  0x80123457,
  0x801b4e81,
  0x0064b17f,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x80091a2b,
  0x0064b17e,
  0x801b4e80,
  0x801b4e81,
  0x809b4e81,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x802d82d7,
  0x809b4e80,
  0x801b4e82,
  0x80b60b5c,
  0x80360b5c,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x80a3d706,
  0x80360b5d,
  0x80b60b5b,
  0x80b60b5c,
  0x811b05ae,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80c83fb2,
  0x811b05ae,
  0x80b60b5d,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00091a2b,
  0x00891a2b,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x001b4e81,
  0x00891a2a,
  0x00091a2c,
  0x00091a2b,
  0x8076e5d5,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80091a2b,
  0x8076e5d4,
  0x00091a2a,
  0x00091a2b,
  0x00891a2b,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x001b4e81,
  0x00891a2a,
  0x00091a2c,
  0x00091a2b,
  0x8076e5d5,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80091a2b,
  0x8076e5d4,
  0x00091a2a,
  0x00091a2b,
  0x00891a2b,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x001b4e81,
  0x00891a2a,
  0x00091a2c,
  0x00091a2b,
  0x8076e5d5,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80091a2b,
  0x8076e5d4,
  0x00091a2a,
  0x00123456,
  0x00923456,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x002468ac,
  0x00923455,
  0x00123457,
  0x00123456,
  0x806dcbaa,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80000000,
  0x806dcba9,
  0x00123455,
  0x00123456,
  0x00923456,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x002468ac,
  0x00923455,
  0x00123457,
  0x00123456,
  0x806dcbaa,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x00000000,
  0x806dcba9,
  0x00123455,
  0x00123456,
  0x00923456,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x002468ac,
  0x00923455,
  0x00123457,
  0x00123456,
  0x806dcbaa,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x00000000,
  0x806dcba9,
  0x00123455,
  0x001b4e81,
  0x009b4e81,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x002d82d7,
  0x009b4e80,
  0x001b4e82,
  0x001b4e81,
  0x8064b17f,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x00091a2b,
  0x8064b17e,
  0x001b4e80,
  0x00b60b5c,
  0x011b05ae,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00c83fb2,
  0x011b05ae,
  0x00b60b5d,
  0x00b60b5c,
  0x00360b5c,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x00a3d706,
  0x00360b5d,
  0x00b60b5b,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x803fffff,
  0x00400001,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x802dcba9,
  0x00400000,
  0x803ffffe,
  0x803fffff,
  0x80bfffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80523455,
  0x80bffffe,
  0x80400000,
  0x80400000,
  0x00400000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x802dcbaa,
  0x00400000,
  0x803ffffe,
  0x80400000,
  0x80c00000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80523456,
  0x80bffffe,
  0x80400000,
  0x80400000,
  0x00400000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x802dcbaa,
  0x003fffff,
  0x803fffff,
  0x80400000,
  0x80c00000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80523456,
  0x80bfffff,
  0x80400001,
  0x807fffff,
  0x00000001,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x806dcba9,
  0x00000000,
  0x807ffffe,
  0x807fffff,
  0x80ffffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80923455,
  0x80fffffe,
  0x80800000,
  0x807fffff,
  0x00000001,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x806dcba9,
  0x00000000,
  0x807ffffe,
  0x807fffff,
  0x80ffffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80923455,
  0x80fffffe,
  0x80800000,
  0x80800000,
  0x00000000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x806dcbaa,
  0x80000001,
  0x807fffff,
  0x80800000,
  0x81000000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80923456,
  0x80ffffff,
  0x80800001,
  0x80bffffe,
  0x803ffffe,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x80adcba8,
  0x80400000,
  0x80bffffe,
  0x80bffffe,
  0x811fffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80d23454,
  0x811fffff,
  0x80c00000,
  0x821fffff,
  0x820fffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x821db974,
  0x820fffff,
  0x821fffff,
  0x821fffff,
  0x822fffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x8222468a,
  0x822fffff,
  0x821fffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x003fffff,
  0x00bfffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00523455,
  0x00bffffe,
  0x00400000,
  0x003fffff,
  0x80400001,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x002dcba9,
  0x80400000,
  0x003ffffe,
  0x00400000,
  0x00c00000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00523456,
  0x00bffffe,
  0x00400000,
  0x00400000,
  0x80400000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x002dcbaa,
  0x80400000,
  0x003ffffe,
  0x00400000,
  0x00c00000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00523456,
  0x00bfffff,
  0x00400001,
  0x00400000,
  0x80400000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x002dcbaa,
  0x803fffff,
  0x003fffff,
  0x007fffff,
  0x00ffffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00923455,
  0x00fffffe,
  0x00800000,
  0x007fffff,
  0x80000001,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x006dcba9,
  0x80000000,
  0x007ffffe,
  0x007fffff,
  0x00ffffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00923455,
  0x00fffffe,
  0x00800000,
  0x007fffff,
  0x80000001,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x006dcba9,
  0x00000000,
  0x007ffffe,
  0x00800000,
  0x01000000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00923456,
  0x00ffffff,
  0x00800001,
  0x00800000,
  0x80000000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x006dcbaa,
  0x00000001,
  0x007fffff,
  0x00bffffe,
  0x011fffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00d23454,
  0x011fffff,
  0x00c00000,
  0x00bffffe,
  0x003ffffe,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x00adcba8,
  0x00400000,
  0x00bffffe,
  0x021fffff,
  0x022fffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x0222468a,
  0x022fffff,
  0x021fffff,
  0x021fffff,
  0x020fffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x021db974,
  0x020fffff,
  0x021fffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007ffffe,
  0x00000000,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x80800000,
  0x80000002,
  0x80000001,
  0x007fffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123455,
  0x007ffffe,
  0x00000000,
  0x80000001,
  0x80800001,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123457,
  0x80800000,
  0x80000002,
  0x80000001,
  0x007fffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123455,
  0x007ffffe,
  0x00000000,
  0x80000001,
  0x80800001,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123457,
  0x80800000,
  0x80000002,
  0x80000001,
  0x007fffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123455,
  0x007ffffe,
  0x00000000,
  0x80000001,
  0x80800001,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123457,
  0x80800000,
  0x80000002,
  0x80000001,
  0x007fffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123455,
  0x007ffffe,
  0x80000000,
  0x80000001,
  0x80800001,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123457,
  0x80800000,
  0x80000002,
  0x80000002,
  0x007ffffe,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123454,
  0x007ffffe,
  0x80000000,
  0x80000002,
  0x80800002,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123458,
  0x80800000,
  0x80000002,
  0x8000000a,
  0x007ffff6,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x0012344c,
  0x007ffff5,
  0x80000009,
  0x8000000a,
  0x8080000a,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123460,
  0x80800009,
  0x8000000b,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x00800000,
  0x00000002,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807ffffe,
  0x80000000,
  0x00000001,
  0x00800001,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123457,
  0x00800000,
  0x00000002,
  0x00000001,
  0x807fffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123455,
  0x807ffffe,
  0x80000000,
  0x00000001,
  0x00800001,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123457,
  0x00800000,
  0x00000002,
  0x00000001,
  0x807fffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123455,
  0x807ffffe,
  0x80000000,
  0x00000001,
  0x00800001,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123457,
  0x00800000,
  0x00000002,
  0x00000001,
  0x807fffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123455,
  0x807ffffe,
  0x00000000,
  0x00000001,
  0x00800001,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123457,
  0x00800000,
  0x00000002,
  0x00000001,
  0x807fffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123455,
  0x807ffffe,
  0x00000000,
  0x00000002,
  0x00800002,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123458,
  0x00800000,
  0x00000002,
  0x00000002,
  0x807ffffe,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123454,
  0x807ffffe,
  0x00000000,
  0x0000000a,
  0x0080000a,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123460,
  0x00800009,
  0x0000000b,
  0x0000000a,
  0x807ffff6,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x8012344c,
  0x807ffff5,
  0x00000009,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
};
const unsigned kExpectedCount_fmadd_s = 54872;

const uint64_t kExpected_fmax_d[] = {
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0010000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0010000000000000,
  0x0010000000000000,
  0x0010000000000000,
  0x0010000000000000,
  0x0010000000000000,
  0x0010000000000000,
  0x0010000000000000,
  0x0010000000000000,
  0x0010000000000000,
  0x0010000000000000,
  0x0010000000000000,
  0x0010000000000000,
  0x0010000000000000,
  0x0010000000000000,
  0x0010000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x0010000000000000,
  0x0010000000000000,
  0x0010000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x4024000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x000123456789abcd,
  0x000123456789abcd,
  0x000123456789abcd,
  0x000123456789abcd,
  0x000123456789abcd,
  0x000123456789abcd,
  0x000123456789abcd,
  0x000123456789abcd,
  0x000123456789abcd,
  0x000123456789abcd,
  0x000123456789abcd,
  0x000123456789abcd,
  0x000123456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x000123456789abcd,
  0x000123456789abcd,
  0x000123456789abcd,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000fffffffffffff,
  0x000fffffffffffff,
  0x000fffffffffffff,
  0x000fffffffffffff,
  0x000fffffffffffff,
  0x000fffffffffffff,
  0x000fffffffffffff,
  0x000fffffffffffff,
  0x000fffffffffffff,
  0x000fffffffffffff,
  0x000fffffffffffff,
  0x000fffffffffffff,
  0x000fffffffffffff,
  0x000fffffffffffff,
  0x000fffffffffffff,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x000fffffffffffff,
  0x000fffffffffffff,
  0x000fffffffffffff,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000001,
  0x0000000000000001,
  0x0000000000000001,
  0x0000000000000001,
  0x0000000000000001,
  0x0000000000000001,
  0x0000000000000001,
  0x0000000000000001,
  0x0000000000000001,
  0x0000000000000001,
  0x0000000000000001,
  0x0000000000000001,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x0000000000000001,
  0x0000000000000001,
  0x0000000000000001,
  0x0000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0x8010000000000000,
  0x8010000000000000,
  0x8010000000000000,
  0x8010000000000000,
  0x8010000000000000,
  0x8010000000000000,
  0x8010000000000000,
  0x8010000000000000,
  0x8010000000000000,
  0x8010000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x8010000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xbfdfffffffffffff,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xbfe0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xbfe0000000000001,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xbfefffffffffffff,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xbff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000001,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xbff0000000000001,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xbff8000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xc024000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xffefffffffffffff,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x800123456789abcd,
  0x800123456789abcd,
  0x800123456789abcd,
  0x800123456789abcd,
  0x800123456789abcd,
  0x800123456789abcd,
  0x800123456789abcd,
  0x800123456789abcd,
  0x800123456789abcd,
  0x800123456789abcd,
  0x800123456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x800123456789abcd,
  0x800123456789abcd,
  0x800123456789abcd,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x800fffffffffffff,
  0x800fffffffffffff,
  0x800fffffffffffff,
  0x800fffffffffffff,
  0x800fffffffffffff,
  0x800fffffffffffff,
  0x800fffffffffffff,
  0x800fffffffffffff,
  0x800fffffffffffff,
  0x800fffffffffffff,
  0x800fffffffffffff,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x800fffffffffffff,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8000000000000001,
  0x8000000000000001,
  0x8000000000000001,
  0x8000000000000001,
  0x8000000000000001,
  0x8000000000000001,
  0x8000000000000001,
  0x8000000000000001,
  0x8000000000000001,
  0x8000000000000001,
  0x8000000000000001,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x8000000000000001,
  0x8000000000000001,
  0x8000000000000001,
  0x8000000000000001,
};
const unsigned kExpectedCount_fmax_d = 1444;

const uint32_t kExpected_fmax_s[] = {
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x00000000,
  0x00000000,
  0x00000000,
  0x00000000,
  0x00000000,
  0x00000000,
  0x00000000,
  0x00000000,
  0x00000000,
  0xffcfffff,
  0x00000000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x00000000,
  0x00000000,
  0x00000000,
  0x00800000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00800000,
  0x00800000,
  0x00800000,
  0x00800000,
  0x00800000,
  0x00800000,
  0x00800000,
  0x00800000,
  0x00800000,
  0x00800000,
  0x00800000,
  0x00800000,
  0x00800000,
  0xffcfffff,
  0x00800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x00800000,
  0x00800000,
  0x00800000,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0xffcfffff,
  0x3effffff,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0xffcfffff,
  0x3f000000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0xffcfffff,
  0x3f000001,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f7fffff,
  0x3f7fffff,
  0x3f7fffff,
  0x3f7fffff,
  0x3f7fffff,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f7fffff,
  0x3f7fffff,
  0x3f7fffff,
  0x3f7fffff,
  0x3f7fffff,
  0x3f7fffff,
  0x3f7fffff,
  0x3f7fffff,
  0x3f7fffff,
  0x3f7fffff,
  0x3f7fffff,
  0x3f7fffff,
  0x3f7fffff,
  0xffcfffff,
  0x3f7fffff,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f7fffff,
  0x3f7fffff,
  0x3f7fffff,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0xffcfffff,
  0x3f800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3f800001,
  0x3f800001,
  0x3f800001,
  0x3f800001,
  0x3f800001,
  0x3f800001,
  0x3f800001,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f800001,
  0x3f800001,
  0x3f800001,
  0x3f800001,
  0x3f800001,
  0x3f800001,
  0x3f800001,
  0x3f800001,
  0x3f800001,
  0x3f800001,
  0x3f800001,
  0x3f800001,
  0x3f800001,
  0xffcfffff,
  0x3f800001,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f800001,
  0x3f800001,
  0x3f800001,
  0x3fc00000,
  0x3fc00000,
  0x3fc00000,
  0x3fc00000,
  0x3fc00000,
  0x3fc00000,
  0x3fc00000,
  0x3fc00000,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3fc00000,
  0x3fc00000,
  0x3fc00000,
  0x3fc00000,
  0x3fc00000,
  0x3fc00000,
  0x3fc00000,
  0x3fc00000,
  0x3fc00000,
  0x3fc00000,
  0x3fc00000,
  0x3fc00000,
  0x3fc00000,
  0xffcfffff,
  0x3fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3fc00000,
  0x3fc00000,
  0x3fc00000,
  0x41200000,
  0x41200000,
  0x41200000,
  0x41200000,
  0x41200000,
  0x41200000,
  0x41200000,
  0x41200000,
  0x41200000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x41200000,
  0x41200000,
  0x41200000,
  0x41200000,
  0x41200000,
  0x41200000,
  0x41200000,
  0x41200000,
  0x41200000,
  0x41200000,
  0x41200000,
  0x41200000,
  0x41200000,
  0xffcfffff,
  0x41200000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x41200000,
  0x41200000,
  0x41200000,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7f800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x00123456,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00123456,
  0x00123456,
  0x00123456,
  0x00123456,
  0x00123456,
  0x00123456,
  0x00123456,
  0x00123456,
  0x00123456,
  0x00123456,
  0x00123456,
  0xffcfffff,
  0x00123456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x00123456,
  0x00123456,
  0x00123456,
  0x007fffff,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x007fffff,
  0x007fffff,
  0x007fffff,
  0x007fffff,
  0x007fffff,
  0x007fffff,
  0x007fffff,
  0x007fffff,
  0x007fffff,
  0x007fffff,
  0x007fffff,
  0x007fffff,
  0x007fffff,
  0xffcfffff,
  0x007fffff,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x007fffff,
  0x007fffff,
  0x007fffff,
  0x00000001,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000001,
  0x00000001,
  0x00000001,
  0x00000001,
  0x00000001,
  0x00000001,
  0x00000001,
  0x00000001,
  0x00000001,
  0x00000001,
  0xffcfffff,
  0x00000001,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x00000001,
  0x00000001,
  0x00000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80000000,
  0x80000000,
  0x80000000,
  0x80000000,
  0x80000000,
  0x80000000,
  0x80000000,
  0x80000000,
  0x80000000,
  0xffcfffff,
  0x80000000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80000000,
  0x80000000,
  0x80000000,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0x80800000,
  0x80800000,
  0x80800000,
  0x80800000,
  0x80800000,
  0x80800000,
  0x80800000,
  0x80800000,
  0xffcfffff,
  0x80800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xffcfffff,
  0xbeffffff,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xffcfffff,
  0xbf000000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xffcfffff,
  0xbf000001,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf7fffff,
  0xbf7fffff,
  0xbf7fffff,
  0xbf7fffff,
  0xffcfffff,
  0xbf7fffff,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xffcfffff,
  0xbf800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbf800001,
  0xbf800001,
  0xffcfffff,
  0xbf800001,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xbfc00000,
  0xffcfffff,
  0xbfc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xc1200000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80123456,
  0x80123456,
  0x80123456,
  0x80123456,
  0x80123456,
  0x80123456,
  0x80123456,
  0x80123456,
  0x80123456,
  0xffcfffff,
  0x80123456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x80123456,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x807fffff,
  0x807fffff,
  0x807fffff,
  0x807fffff,
  0x807fffff,
  0x807fffff,
  0x807fffff,
  0x807fffff,
  0x807fffff,
  0xffcfffff,
  0x807fffff,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80000001,
  0x80000001,
  0x80000001,
  0x80000001,
  0x80000001,
  0x80000001,
  0x80000001,
  0x80000001,
  0x80000001,
  0xffcfffff,
  0x80000001,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80000001,
  0x80000001,
  0x80000001,
};
const unsigned kExpectedCount_fmax_s = 1444;

const uint64_t kExpected_fmaxnm_d[] = {
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0xfff923456789abcd,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0010000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x0010000000000000,
  0x0010000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0010000000000000,
  0x0010000000000000,
  0x0010000000000000,
  0x0010000000000000,
  0x0010000000000000,
  0x0010000000000000,
  0x0010000000000000,
  0x0010000000000000,
  0x0010000000000000,
  0x0010000000000000,
  0x0010000000000000,
  0x0010000000000000,
  0x0010000000000000,
  0x0010000000000000,
  0x0010000000000000,
  0x0010000000000000,
  0x0010000000000000,
  0xfff923456789abcd,
  0x0010000000000000,
  0x0010000000000000,
  0x0010000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0xfff923456789abcd,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0xfff923456789abcd,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0xfff923456789abcd,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0xfff923456789abcd,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0xfff923456789abcd,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0xfff923456789abcd,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0xfff923456789abcd,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0xfff923456789abcd,
  0x4024000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0xfff923456789abcd,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0xfff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0xfff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000123456789abcd,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x000123456789abcd,
  0x000123456789abcd,
  0x000123456789abcd,
  0x000123456789abcd,
  0x000123456789abcd,
  0x000123456789abcd,
  0x000123456789abcd,
  0x000123456789abcd,
  0x000123456789abcd,
  0x000123456789abcd,
  0x000123456789abcd,
  0x000123456789abcd,
  0x000123456789abcd,
  0x000123456789abcd,
  0x000123456789abcd,
  0xfff923456789abcd,
  0x000123456789abcd,
  0x000123456789abcd,
  0x000123456789abcd,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x000fffffffffffff,
  0x000fffffffffffff,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000fffffffffffff,
  0x000fffffffffffff,
  0x000fffffffffffff,
  0x000fffffffffffff,
  0x000fffffffffffff,
  0x000fffffffffffff,
  0x000fffffffffffff,
  0x000fffffffffffff,
  0x000fffffffffffff,
  0x000fffffffffffff,
  0x000fffffffffffff,
  0x000fffffffffffff,
  0x000fffffffffffff,
  0x000fffffffffffff,
  0x000fffffffffffff,
  0x000fffffffffffff,
  0x000fffffffffffff,
  0xfff923456789abcd,
  0x000fffffffffffff,
  0x000fffffffffffff,
  0x000fffffffffffff,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x0000000000000001,
  0x0000000000000001,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000001,
  0x0000000000000001,
  0x0000000000000001,
  0x0000000000000001,
  0x0000000000000001,
  0x0000000000000001,
  0x0000000000000001,
  0x0000000000000001,
  0x0000000000000001,
  0x0000000000000001,
  0x0000000000000001,
  0x0000000000000001,
  0x0000000000000001,
  0x0000000000000001,
  0xfff923456789abcd,
  0x0000000000000001,
  0x0000000000000001,
  0x0000000000000001,
  0x0000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0xfff923456789abcd,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x8010000000000000,
  0x8010000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0x8010000000000000,
  0x8010000000000000,
  0x8010000000000000,
  0x8010000000000000,
  0x8010000000000000,
  0x8010000000000000,
  0x8010000000000000,
  0x8010000000000000,
  0x8010000000000000,
  0x8010000000000000,
  0x8010000000000000,
  0x8010000000000000,
  0xfff923456789abcd,
  0x8010000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xfff923456789abcd,
  0xbfdfffffffffffff,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xfff923456789abcd,
  0xbfe0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xfff923456789abcd,
  0xbfe0000000000001,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xfff923456789abcd,
  0xbfefffffffffffff,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xfff923456789abcd,
  0xbff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0xbff0000000000001,
  0xbff0000000000001,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000001,
  0xfff923456789abcd,
  0xbff0000000000001,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xfff923456789abcd,
  0xbff8000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xfff923456789abcd,
  0xc024000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xfff923456789abcd,
  0xffefffffffffffff,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x800123456789abcd,
  0x800123456789abcd,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x800123456789abcd,
  0x800123456789abcd,
  0x800123456789abcd,
  0x800123456789abcd,
  0x800123456789abcd,
  0x800123456789abcd,
  0x800123456789abcd,
  0x800123456789abcd,
  0x800123456789abcd,
  0x800123456789abcd,
  0x800123456789abcd,
  0x800123456789abcd,
  0x800123456789abcd,
  0xfff923456789abcd,
  0x800123456789abcd,
  0x800123456789abcd,
  0x800123456789abcd,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x800fffffffffffff,
  0x800fffffffffffff,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x800fffffffffffff,
  0x800fffffffffffff,
  0x800fffffffffffff,
  0x800fffffffffffff,
  0x800fffffffffffff,
  0x800fffffffffffff,
  0x800fffffffffffff,
  0x800fffffffffffff,
  0x800fffffffffffff,
  0x800fffffffffffff,
  0x800fffffffffffff,
  0x800fffffffffffff,
  0x800fffffffffffff,
  0xfff923456789abcd,
  0x800fffffffffffff,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x8000000000000001,
  0x8000000000000001,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8000000000000001,
  0x8000000000000001,
  0x8000000000000001,
  0x8000000000000001,
  0x8000000000000001,
  0x8000000000000001,
  0x8000000000000001,
  0x8000000000000001,
  0x8000000000000001,
  0x8000000000000001,
  0x8000000000000001,
  0x8000000000000001,
  0x8000000000000001,
  0xfff923456789abcd,
  0x8000000000000001,
  0x8000000000000001,
  0x8000000000000001,
  0x8000000000000001,
};
const unsigned kExpectedCount_fmaxnm_d = 1444;

const uint32_t kExpected_fmaxnm_s[] = {
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x00000000,
  0x00000000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x00000000,
  0x00000000,
  0x00000000,
  0x00000000,
  0x00000000,
  0x00000000,
  0x00000000,
  0x00000000,
  0x00000000,
  0xffcfffff,
  0x00000000,
  0x00000000,
  0x00000000,
  0xffd23456,
  0xffc00001,
  0x00000000,
  0x00000000,
  0x00000000,
  0x00800000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x00800000,
  0x00800000,
  0x7fd23456,
  0x7fc00001,
  0x00800000,
  0x00800000,
  0x00800000,
  0x00800000,
  0x00800000,
  0x00800000,
  0x00800000,
  0x00800000,
  0x00800000,
  0x00800000,
  0x00800000,
  0x00800000,
  0x00800000,
  0xffcfffff,
  0x00800000,
  0x00800000,
  0x00800000,
  0xffd23456,
  0xffc00001,
  0x00800000,
  0x00800000,
  0x00800000,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x3effffff,
  0x3effffff,
  0x7fd23456,
  0x7fc00001,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0xffcfffff,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0xffd23456,
  0xffc00001,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x3f000000,
  0x3f000000,
  0x7fd23456,
  0x7fc00001,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0xffcfffff,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0xffd23456,
  0xffc00001,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x3f000001,
  0x3f000001,
  0x7fd23456,
  0x7fc00001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0xffcfffff,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0xffd23456,
  0xffc00001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f7fffff,
  0x3f7fffff,
  0x3f7fffff,
  0x3f7fffff,
  0x3f7fffff,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x3f7fffff,
  0x3f7fffff,
  0x7fd23456,
  0x7fc00001,
  0x3f7fffff,
  0x3f7fffff,
  0x3f7fffff,
  0x3f7fffff,
  0x3f7fffff,
  0x3f7fffff,
  0x3f7fffff,
  0x3f7fffff,
  0x3f7fffff,
  0x3f7fffff,
  0x3f7fffff,
  0x3f7fffff,
  0x3f7fffff,
  0xffcfffff,
  0x3f7fffff,
  0x3f7fffff,
  0x3f7fffff,
  0xffd23456,
  0xffc00001,
  0x3f7fffff,
  0x3f7fffff,
  0x3f7fffff,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x3f800000,
  0x3f800000,
  0x7fd23456,
  0x7fc00001,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0xffcfffff,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0xffd23456,
  0xffc00001,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3f800001,
  0x3f800001,
  0x3f800001,
  0x3f800001,
  0x3f800001,
  0x3f800001,
  0x3f800001,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x3f800001,
  0x3f800001,
  0x7fd23456,
  0x7fc00001,
  0x3f800001,
  0x3f800001,
  0x3f800001,
  0x3f800001,
  0x3f800001,
  0x3f800001,
  0x3f800001,
  0x3f800001,
  0x3f800001,
  0x3f800001,
  0x3f800001,
  0x3f800001,
  0x3f800001,
  0xffcfffff,
  0x3f800001,
  0x3f800001,
  0x3f800001,
  0xffd23456,
  0xffc00001,
  0x3f800001,
  0x3f800001,
  0x3f800001,
  0x3fc00000,
  0x3fc00000,
  0x3fc00000,
  0x3fc00000,
  0x3fc00000,
  0x3fc00000,
  0x3fc00000,
  0x3fc00000,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x3fc00000,
  0x3fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3fc00000,
  0x3fc00000,
  0x3fc00000,
  0x3fc00000,
  0x3fc00000,
  0x3fc00000,
  0x3fc00000,
  0x3fc00000,
  0x3fc00000,
  0x3fc00000,
  0x3fc00000,
  0x3fc00000,
  0x3fc00000,
  0xffcfffff,
  0x3fc00000,
  0x3fc00000,
  0x3fc00000,
  0xffd23456,
  0xffc00001,
  0x3fc00000,
  0x3fc00000,
  0x3fc00000,
  0x41200000,
  0x41200000,
  0x41200000,
  0x41200000,
  0x41200000,
  0x41200000,
  0x41200000,
  0x41200000,
  0x41200000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x41200000,
  0x41200000,
  0x7fd23456,
  0x7fc00001,
  0x41200000,
  0x41200000,
  0x41200000,
  0x41200000,
  0x41200000,
  0x41200000,
  0x41200000,
  0x41200000,
  0x41200000,
  0x41200000,
  0x41200000,
  0x41200000,
  0x41200000,
  0xffcfffff,
  0x41200000,
  0x41200000,
  0x41200000,
  0xffd23456,
  0xffc00001,
  0x41200000,
  0x41200000,
  0x41200000,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0x7fc00000,
  0x7fc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x00123456,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x00123456,
  0x00123456,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00123456,
  0x00123456,
  0x00123456,
  0x00123456,
  0x00123456,
  0x00123456,
  0x00123456,
  0x00123456,
  0x00123456,
  0x00123456,
  0x00123456,
  0xffcfffff,
  0x00123456,
  0x00123456,
  0x00123456,
  0xffd23456,
  0xffc00001,
  0x00123456,
  0x00123456,
  0x00123456,
  0x007fffff,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x007fffff,
  0x007fffff,
  0x7fd23456,
  0x7fc00001,
  0x007fffff,
  0x007fffff,
  0x007fffff,
  0x007fffff,
  0x007fffff,
  0x007fffff,
  0x007fffff,
  0x007fffff,
  0x007fffff,
  0x007fffff,
  0x007fffff,
  0x007fffff,
  0x007fffff,
  0xffcfffff,
  0x007fffff,
  0x007fffff,
  0x007fffff,
  0xffd23456,
  0xffc00001,
  0x007fffff,
  0x007fffff,
  0x007fffff,
  0x00000001,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x00000001,
  0x00000001,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000001,
  0x00000001,
  0x00000001,
  0x00000001,
  0x00000001,
  0x00000001,
  0x00000001,
  0x00000001,
  0x00000001,
  0x00000001,
  0xffcfffff,
  0x00000001,
  0x00000001,
  0x00000001,
  0xffd23456,
  0xffc00001,
  0x00000001,
  0x00000001,
  0x00000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x80000000,
  0x80000000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80000000,
  0x80000000,
  0x80000000,
  0x80000000,
  0x80000000,
  0x80000000,
  0x80000000,
  0x80000000,
  0x80000000,
  0xffcfffff,
  0x80000000,
  0x80000000,
  0x80000000,
  0xffd23456,
  0xffc00001,
  0x80000000,
  0x80000000,
  0x80000000,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x80800000,
  0x80800000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0x80800000,
  0x80800000,
  0x80800000,
  0x80800000,
  0x80800000,
  0x80800000,
  0x80800000,
  0x80800000,
  0xffcfffff,
  0x80800000,
  0x80800000,
  0x80800000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0xbeffffff,
  0xbeffffff,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xffcfffff,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0xbf000000,
  0xbf000000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xffcfffff,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0xbf000001,
  0xbf000001,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xffcfffff,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0xbf7fffff,
  0xbf7fffff,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf7fffff,
  0xbf7fffff,
  0xbf7fffff,
  0xbf7fffff,
  0xffcfffff,
  0xbf7fffff,
  0xbf7fffff,
  0xbf7fffff,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0xbf800000,
  0xbf800000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xffcfffff,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0xbf800001,
  0xbf800001,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbf800001,
  0xbf800001,
  0xffcfffff,
  0xbf800001,
  0xbf800001,
  0xbf800001,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0xbfc00000,
  0xbfc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xbfc00000,
  0xffcfffff,
  0xbfc00000,
  0xbfc00000,
  0xbfc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0xc1200000,
  0xc1200000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xc1200000,
  0xc1200000,
  0xc1200000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0xff800000,
  0xff800000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0xffc00000,
  0xffc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffc00000,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x80123456,
  0x80123456,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80123456,
  0x80123456,
  0x80123456,
  0x80123456,
  0x80123456,
  0x80123456,
  0x80123456,
  0x80123456,
  0x80123456,
  0xffcfffff,
  0x80123456,
  0x80123456,
  0x80123456,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x80123456,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x807fffff,
  0x807fffff,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x807fffff,
  0x807fffff,
  0x807fffff,
  0x807fffff,
  0x807fffff,
  0x807fffff,
  0x807fffff,
  0x807fffff,
  0x807fffff,
  0xffcfffff,
  0x807fffff,
  0x807fffff,
  0x807fffff,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x80000001,
  0x80000001,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80000001,
  0x80000001,
  0x80000001,
  0x80000001,
  0x80000001,
  0x80000001,
  0x80000001,
  0x80000001,
  0x80000001,
  0xffcfffff,
  0x80000001,
  0x80000001,
  0x80000001,
  0xffd23456,
  0xffc00001,
  0x80000001,
  0x80000001,
  0x80000001,
};
const unsigned kExpectedCount_fmaxnm_s = 1444;

const uint64_t kExpected_fmin_d[] = {
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x0010000000000000,
  0x0010000000000000,
  0x0010000000000000,
  0x0010000000000000,
  0x0010000000000000,
  0x0010000000000000,
  0x0010000000000000,
  0x0010000000000000,
  0x0010000000000000,
  0x0010000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x0010000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x3fdfffffffffffff,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x3fe0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x3fe0000000000001,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x3fefffffffffffff,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x3ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x3ff0000000000001,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x3ff8000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x4024000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7fefffffffffffff,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x000123456789abcd,
  0x000123456789abcd,
  0x000123456789abcd,
  0x000123456789abcd,
  0x000123456789abcd,
  0x000123456789abcd,
  0x000123456789abcd,
  0x000123456789abcd,
  0x000123456789abcd,
  0x000123456789abcd,
  0x000123456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x000123456789abcd,
  0x000123456789abcd,
  0x000123456789abcd,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x000fffffffffffff,
  0x000fffffffffffff,
  0x000fffffffffffff,
  0x000fffffffffffff,
  0x000fffffffffffff,
  0x000fffffffffffff,
  0x000fffffffffffff,
  0x000fffffffffffff,
  0x000fffffffffffff,
  0x000fffffffffffff,
  0x000fffffffffffff,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x000fffffffffffff,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0000000000000001,
  0x0000000000000001,
  0x0000000000000001,
  0x0000000000000001,
  0x0000000000000001,
  0x0000000000000001,
  0x0000000000000001,
  0x0000000000000001,
  0x0000000000000001,
  0x0000000000000001,
  0x0000000000000001,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x0000000000000001,
  0x0000000000000001,
  0x0000000000000001,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8010000000000000,
  0x8010000000000000,
  0x8010000000000000,
  0x8010000000000000,
  0x8010000000000000,
  0x8010000000000000,
  0x8010000000000000,
  0x8010000000000000,
  0x8010000000000000,
  0x8010000000000000,
  0x8010000000000000,
  0x8010000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x8010000000000000,
  0x8010000000000000,
  0x8010000000000000,
  0x8010000000000000,
  0x8010000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x8010000000000000,
  0x8010000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000001,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xc024000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800123456789abcd,
  0x800123456789abcd,
  0x800123456789abcd,
  0x800123456789abcd,
  0x800123456789abcd,
  0x800123456789abcd,
  0x800123456789abcd,
  0x800123456789abcd,
  0x800123456789abcd,
  0x800123456789abcd,
  0x800123456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x800123456789abcd,
  0x800123456789abcd,
  0x800123456789abcd,
  0x800123456789abcd,
  0x800123456789abcd,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x800fffffffffffff,
  0x800fffffffffffff,
  0x800fffffffffffff,
  0x800fffffffffffff,
  0x800fffffffffffff,
  0x800fffffffffffff,
  0x800fffffffffffff,
  0x800fffffffffffff,
  0x800fffffffffffff,
  0x800fffffffffffff,
  0x800fffffffffffff,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x800fffffffffffff,
  0x800fffffffffffff,
  0x800fffffffffffff,
  0x800fffffffffffff,
  0x800fffffffffffff,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800fffffffffffff,
  0x800fffffffffffff,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8000000000000001,
  0x8000000000000001,
  0x8000000000000001,
  0x8000000000000001,
  0x8000000000000001,
  0x8000000000000001,
  0x8000000000000001,
  0x8000000000000001,
  0x8000000000000001,
  0x8000000000000001,
  0x8000000000000001,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x8000000000000001,
  0x8000000000000001,
  0x8000000000000001,
  0x8000000000000001,
  0x8000000000000001,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
};
const unsigned kExpectedCount_fmin_d = 1444;

const uint32_t kExpected_fmin_s[] = {
  0x00000000,
  0x00000000,
  0x00000000,
  0x00000000,
  0x00000000,
  0x00000000,
  0x00000000,
  0x00000000,
  0x00000000,
  0x00000000,
  0x7fcfffff,
  0x00000000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00000000,
  0x00000000,
  0x00000000,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x00800000,
  0x00800000,
  0x00800000,
  0x00800000,
  0x00800000,
  0x00800000,
  0x00800000,
  0x00800000,
  0x7fcfffff,
  0x00800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x7fcfffff,
  0x3effffff,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x7fcfffff,
  0x3f000000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x7fcfffff,
  0x3f000001,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f7fffff,
  0x3f7fffff,
  0x3f7fffff,
  0x3f7fffff,
  0x7fcfffff,
  0x3f7fffff,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x7fcfffff,
  0x3f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3f800001,
  0x3f800001,
  0x7fcfffff,
  0x3f800001,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x3fc00000,
  0x7fcfffff,
  0x3fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x41200000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x00000000,
  0x00123456,
  0x00123456,
  0x00123456,
  0x00123456,
  0x00123456,
  0x00123456,
  0x00123456,
  0x00123456,
  0x00123456,
  0x7fcfffff,
  0x00123456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x00123456,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x007fffff,
  0x007fffff,
  0x007fffff,
  0x007fffff,
  0x007fffff,
  0x007fffff,
  0x007fffff,
  0x007fffff,
  0x007fffff,
  0x7fcfffff,
  0x007fffff,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00000001,
  0x00000001,
  0x00000001,
  0x00000001,
  0x00000001,
  0x00000001,
  0x00000001,
  0x00000001,
  0x00000001,
  0x7fcfffff,
  0x00000001,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00000001,
  0x00000001,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80000000,
  0x80000000,
  0x80000000,
  0x80000000,
  0x80000000,
  0x80000000,
  0x80000000,
  0x80000000,
  0x80000000,
  0x80000000,
  0x7fcfffff,
  0x80000000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x80000000,
  0x80000000,
  0x80000000,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80800000,
  0x80800000,
  0x80800000,
  0x80800000,
  0x80800000,
  0x80800000,
  0x80800000,
  0x80800000,
  0x80800000,
  0x80800000,
  0x7fcfffff,
  0x80800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x80800000,
  0x80800000,
  0x80800000,
  0x80800000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80800000,
  0x80800000,
  0x80800000,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0x7fcfffff,
  0xbeffffff,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0x7fcfffff,
  0xbf000000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0x7fcfffff,
  0xbf000001,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf7fffff,
  0xbf7fffff,
  0xbf7fffff,
  0xbf7fffff,
  0xbf7fffff,
  0xbf7fffff,
  0xbf7fffff,
  0xbf7fffff,
  0xbf7fffff,
  0xbf7fffff,
  0x7fcfffff,
  0xbf7fffff,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf7fffff,
  0xbf7fffff,
  0xbf7fffff,
  0xbf7fffff,
  0xbf7fffff,
  0xbf7fffff,
  0xbf7fffff,
  0xbf7fffff,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf7fffff,
  0xbf7fffff,
  0xbf7fffff,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0x7fcfffff,
  0xbf800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbf800001,
  0xbf800001,
  0xbf800001,
  0xbf800001,
  0xbf800001,
  0xbf800001,
  0xbf800001,
  0xbf800001,
  0xbf800001,
  0xbf800001,
  0x7fcfffff,
  0xbf800001,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf800001,
  0xbf800001,
  0xbf800001,
  0xbf800001,
  0xbf800001,
  0xbf800001,
  0xbf800001,
  0xbf800001,
  0xbf800001,
  0xbf800001,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf800001,
  0xbf800001,
  0xbf800001,
  0xbfc00000,
  0xbfc00000,
  0xbfc00000,
  0xbfc00000,
  0xbfc00000,
  0xbfc00000,
  0xbfc00000,
  0xbfc00000,
  0xbfc00000,
  0xbfc00000,
  0x7fcfffff,
  0xbfc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbfc00000,
  0xbfc00000,
  0xbfc00000,
  0xbfc00000,
  0xbfc00000,
  0xbfc00000,
  0xbfc00000,
  0xbfc00000,
  0xbfc00000,
  0xbfc00000,
  0xbfc00000,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbfc00000,
  0xbfc00000,
  0xbfc00000,
  0xc1200000,
  0xc1200000,
  0xc1200000,
  0xc1200000,
  0xc1200000,
  0xc1200000,
  0xc1200000,
  0xc1200000,
  0xc1200000,
  0xc1200000,
  0x7fcfffff,
  0xc1200000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xc1200000,
  0xc1200000,
  0xc1200000,
  0xc1200000,
  0xc1200000,
  0xc1200000,
  0xc1200000,
  0xc1200000,
  0xc1200000,
  0xc1200000,
  0xc1200000,
  0xc1200000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xc1200000,
  0xc1200000,
  0xc1200000,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0xff800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x80123456,
  0x80123456,
  0x80123456,
  0x80123456,
  0x80123456,
  0x80123456,
  0x80123456,
  0x80123456,
  0x80123456,
  0x80123456,
  0x7fcfffff,
  0x80123456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x80123456,
  0x80123456,
  0x80123456,
  0x80123456,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80123456,
  0x807fffff,
  0x807fffff,
  0x807fffff,
  0x807fffff,
  0x807fffff,
  0x807fffff,
  0x807fffff,
  0x807fffff,
  0x807fffff,
  0x807fffff,
  0x7fcfffff,
  0x807fffff,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x807fffff,
  0x807fffff,
  0x807fffff,
  0x807fffff,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x807fffff,
  0x807fffff,
  0x807fffff,
  0x80000001,
  0x80000001,
  0x80000001,
  0x80000001,
  0x80000001,
  0x80000001,
  0x80000001,
  0x80000001,
  0x80000001,
  0x80000001,
  0x7fcfffff,
  0x80000001,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x80000001,
  0x80000001,
  0x80000001,
  0x80000001,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
};
const unsigned kExpectedCount_fmin_s = 1444;

const uint64_t kExpected_fminnm_d[] = {
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x7ff923456789abcd,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x0010000000000000,
  0x0010000000000000,
  0x0010000000000000,
  0x0010000000000000,
  0x0010000000000000,
  0x0010000000000000,
  0x0010000000000000,
  0x0010000000000000,
  0x0010000000000000,
  0x0010000000000000,
  0x0010000000000000,
  0x0010000000000000,
  0x7ff923456789abcd,
  0x0010000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0x0010000000000000,
  0x0010000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x7ff923456789abcd,
  0x3fdfffffffffffff,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x7ff923456789abcd,
  0x3fe0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x7ff923456789abcd,
  0x3fe0000000000001,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x7ff923456789abcd,
  0x3fefffffffffffff,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x7ff923456789abcd,
  0x3ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x7ff923456789abcd,
  0x3ff0000000000001,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x7ff923456789abcd,
  0x3ff8000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x7ff923456789abcd,
  0x4024000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7ff923456789abcd,
  0x7fefffffffffffff,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x000123456789abcd,
  0x000123456789abcd,
  0x000123456789abcd,
  0x000123456789abcd,
  0x000123456789abcd,
  0x000123456789abcd,
  0x000123456789abcd,
  0x000123456789abcd,
  0x000123456789abcd,
  0x000123456789abcd,
  0x000123456789abcd,
  0x000123456789abcd,
  0x000123456789abcd,
  0x7ff923456789abcd,
  0x000123456789abcd,
  0x000123456789abcd,
  0x000123456789abcd,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0x000123456789abcd,
  0x000123456789abcd,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x000fffffffffffff,
  0x000fffffffffffff,
  0x000fffffffffffff,
  0x000fffffffffffff,
  0x000fffffffffffff,
  0x000fffffffffffff,
  0x000fffffffffffff,
  0x000fffffffffffff,
  0x000fffffffffffff,
  0x000fffffffffffff,
  0x000fffffffffffff,
  0x000fffffffffffff,
  0x000fffffffffffff,
  0x7ff923456789abcd,
  0x000fffffffffffff,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0x000fffffffffffff,
  0x000fffffffffffff,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0000000000000001,
  0x0000000000000001,
  0x0000000000000001,
  0x0000000000000001,
  0x0000000000000001,
  0x0000000000000001,
  0x0000000000000001,
  0x0000000000000001,
  0x0000000000000001,
  0x0000000000000001,
  0x0000000000000001,
  0x0000000000000001,
  0x0000000000000001,
  0x7ff923456789abcd,
  0x0000000000000001,
  0x0000000000000001,
  0x0000000000000001,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0x0000000000000001,
  0x0000000000000001,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x7ff923456789abcd,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8010000000000000,
  0x8010000000000000,
  0x8010000000000000,
  0x8010000000000000,
  0x8010000000000000,
  0x8010000000000000,
  0x8010000000000000,
  0x8010000000000000,
  0x8010000000000000,
  0x8010000000000000,
  0x8010000000000000,
  0x8010000000000000,
  0x8010000000000000,
  0x8010000000000000,
  0x7ff923456789abcd,
  0x8010000000000000,
  0x8010000000000000,
  0x8010000000000000,
  0x8010000000000000,
  0x8010000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0x8010000000000000,
  0x8010000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x8010000000000000,
  0x8010000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0x7ff923456789abcd,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0x7ff923456789abcd,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0x7ff923456789abcd,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0x7ff923456789abcd,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0x7ff923456789abcd,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000001,
  0x7ff923456789abcd,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xbff0000000000001,
  0xbff0000000000001,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0x7ff923456789abcd,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0x7ff923456789abcd,
  0xc024000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0x7ff923456789abcd,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800123456789abcd,
  0x800123456789abcd,
  0x800123456789abcd,
  0x800123456789abcd,
  0x800123456789abcd,
  0x800123456789abcd,
  0x800123456789abcd,
  0x800123456789abcd,
  0x800123456789abcd,
  0x800123456789abcd,
  0x800123456789abcd,
  0x800123456789abcd,
  0x800123456789abcd,
  0x7ff923456789abcd,
  0x800123456789abcd,
  0x800123456789abcd,
  0x800123456789abcd,
  0x800123456789abcd,
  0x800123456789abcd,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800123456789abcd,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x800fffffffffffff,
  0x800fffffffffffff,
  0x800fffffffffffff,
  0x800fffffffffffff,
  0x800fffffffffffff,
  0x800fffffffffffff,
  0x800fffffffffffff,
  0x800fffffffffffff,
  0x800fffffffffffff,
  0x800fffffffffffff,
  0x800fffffffffffff,
  0x800fffffffffffff,
  0x800fffffffffffff,
  0x7ff923456789abcd,
  0x800fffffffffffff,
  0x800fffffffffffff,
  0x800fffffffffffff,
  0x800fffffffffffff,
  0x800fffffffffffff,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0x800fffffffffffff,
  0x800fffffffffffff,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800fffffffffffff,
  0x800fffffffffffff,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8000000000000001,
  0x8000000000000001,
  0x8000000000000001,
  0x8000000000000001,
  0x8000000000000001,
  0x8000000000000001,
  0x8000000000000001,
  0x8000000000000001,
  0x8000000000000001,
  0x8000000000000001,
  0x8000000000000001,
  0x8000000000000001,
  0x8000000000000001,
  0x7ff923456789abcd,
  0x8000000000000001,
  0x8000000000000001,
  0x8000000000000001,
  0x8000000000000001,
  0x8000000000000001,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0x8000000000000001,
  0x8000000000000001,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
};
const unsigned kExpectedCount_fminnm_d = 1444;

const uint32_t kExpected_fminnm_s[] = {
  0x00000000,
  0x00000000,
  0x00000000,
  0x00000000,
  0x00000000,
  0x00000000,
  0x00000000,
  0x00000000,
  0x00000000,
  0x00000000,
  0x7fcfffff,
  0x00000000,
  0x00000000,
  0x00000000,
  0x7fd23456,
  0x7fc00001,
  0x00000000,
  0x00000000,
  0x00000000,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0x00000000,
  0x00000000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x00800000,
  0x00800000,
  0x00800000,
  0x00800000,
  0x00800000,
  0x00800000,
  0x00800000,
  0x00800000,
  0x7fcfffff,
  0x00800000,
  0x00800000,
  0x00800000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0x00800000,
  0x00800000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x7fcfffff,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0x3effffff,
  0x3effffff,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x7fcfffff,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0x3f000000,
  0x3f000000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x7fcfffff,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0x3f000001,
  0x3f000001,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f7fffff,
  0x3f7fffff,
  0x3f7fffff,
  0x3f7fffff,
  0x7fcfffff,
  0x3f7fffff,
  0x3f7fffff,
  0x3f7fffff,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0x3f7fffff,
  0x3f7fffff,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x7fcfffff,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0x3f800000,
  0x3f800000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3f800001,
  0x3f800001,
  0x7fcfffff,
  0x3f800001,
  0x3f800001,
  0x3f800001,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0x3f800001,
  0x3f800001,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x3fc00000,
  0x7fcfffff,
  0x3fc00000,
  0x3fc00000,
  0x3fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0x3fc00000,
  0x3fc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x41200000,
  0x41200000,
  0x41200000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0x41200000,
  0x41200000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0x7f800000,
  0x7f800000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0x7fc00000,
  0x7fc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x00000000,
  0x00123456,
  0x00123456,
  0x00123456,
  0x00123456,
  0x00123456,
  0x00123456,
  0x00123456,
  0x00123456,
  0x00123456,
  0x7fcfffff,
  0x00123456,
  0x00123456,
  0x00123456,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x00123456,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0x00123456,
  0x00123456,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x007fffff,
  0x007fffff,
  0x007fffff,
  0x007fffff,
  0x007fffff,
  0x007fffff,
  0x007fffff,
  0x007fffff,
  0x007fffff,
  0x7fcfffff,
  0x007fffff,
  0x007fffff,
  0x007fffff,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0x007fffff,
  0x007fffff,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00000001,
  0x00000001,
  0x00000001,
  0x00000001,
  0x00000001,
  0x00000001,
  0x00000001,
  0x00000001,
  0x00000001,
  0x7fcfffff,
  0x00000001,
  0x00000001,
  0x00000001,
  0x7fd23456,
  0x7fc00001,
  0x00000001,
  0x00000001,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0x00000001,
  0x00000001,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80000000,
  0x80000000,
  0x80000000,
  0x80000000,
  0x80000000,
  0x80000000,
  0x80000000,
  0x80000000,
  0x80000000,
  0x80000000,
  0x7fcfffff,
  0x80000000,
  0x80000000,
  0x80000000,
  0x7fd23456,
  0x7fc00001,
  0x80000000,
  0x80000000,
  0x80000000,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0x80000000,
  0x80000000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80800000,
  0x80800000,
  0x80800000,
  0x80800000,
  0x80800000,
  0x80800000,
  0x80800000,
  0x80800000,
  0x80800000,
  0x80800000,
  0x7fcfffff,
  0x80800000,
  0x80800000,
  0x80800000,
  0x7fd23456,
  0x7fc00001,
  0x80800000,
  0x80800000,
  0x80800000,
  0x80800000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0x80800000,
  0x80800000,
  0xffd23456,
  0xffc00001,
  0x80800000,
  0x80800000,
  0x80800000,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0x7fcfffff,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0x7fd23456,
  0x7fc00001,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xbeffffff,
  0xbeffffff,
  0xffd23456,
  0xffc00001,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0x7fcfffff,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0x7fd23456,
  0x7fc00001,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xbf000000,
  0xbf000000,
  0xffd23456,
  0xffc00001,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0x7fcfffff,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0x7fd23456,
  0x7fc00001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xbf000001,
  0xbf000001,
  0xffd23456,
  0xffc00001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf7fffff,
  0xbf7fffff,
  0xbf7fffff,
  0xbf7fffff,
  0xbf7fffff,
  0xbf7fffff,
  0xbf7fffff,
  0xbf7fffff,
  0xbf7fffff,
  0xbf7fffff,
  0x7fcfffff,
  0xbf7fffff,
  0xbf7fffff,
  0xbf7fffff,
  0x7fd23456,
  0x7fc00001,
  0xbf7fffff,
  0xbf7fffff,
  0xbf7fffff,
  0xbf7fffff,
  0xbf7fffff,
  0xbf7fffff,
  0xbf7fffff,
  0xbf7fffff,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xbf7fffff,
  0xbf7fffff,
  0xffd23456,
  0xffc00001,
  0xbf7fffff,
  0xbf7fffff,
  0xbf7fffff,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0x7fcfffff,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0x7fd23456,
  0x7fc00001,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xbf800000,
  0xbf800000,
  0xffd23456,
  0xffc00001,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbf800001,
  0xbf800001,
  0xbf800001,
  0xbf800001,
  0xbf800001,
  0xbf800001,
  0xbf800001,
  0xbf800001,
  0xbf800001,
  0xbf800001,
  0x7fcfffff,
  0xbf800001,
  0xbf800001,
  0xbf800001,
  0x7fd23456,
  0x7fc00001,
  0xbf800001,
  0xbf800001,
  0xbf800001,
  0xbf800001,
  0xbf800001,
  0xbf800001,
  0xbf800001,
  0xbf800001,
  0xbf800001,
  0xbf800001,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xbf800001,
  0xbf800001,
  0xffd23456,
  0xffc00001,
  0xbf800001,
  0xbf800001,
  0xbf800001,
  0xbfc00000,
  0xbfc00000,
  0xbfc00000,
  0xbfc00000,
  0xbfc00000,
  0xbfc00000,
  0xbfc00000,
  0xbfc00000,
  0xbfc00000,
  0xbfc00000,
  0x7fcfffff,
  0xbfc00000,
  0xbfc00000,
  0xbfc00000,
  0x7fd23456,
  0x7fc00001,
  0xbfc00000,
  0xbfc00000,
  0xbfc00000,
  0xbfc00000,
  0xbfc00000,
  0xbfc00000,
  0xbfc00000,
  0xbfc00000,
  0xbfc00000,
  0xbfc00000,
  0xbfc00000,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xbfc00000,
  0xbfc00000,
  0xffd23456,
  0xffc00001,
  0xbfc00000,
  0xbfc00000,
  0xbfc00000,
  0xc1200000,
  0xc1200000,
  0xc1200000,
  0xc1200000,
  0xc1200000,
  0xc1200000,
  0xc1200000,
  0xc1200000,
  0xc1200000,
  0xc1200000,
  0x7fcfffff,
  0xc1200000,
  0xc1200000,
  0xc1200000,
  0x7fd23456,
  0x7fc00001,
  0xc1200000,
  0xc1200000,
  0xc1200000,
  0xc1200000,
  0xc1200000,
  0xc1200000,
  0xc1200000,
  0xc1200000,
  0xc1200000,
  0xc1200000,
  0xc1200000,
  0xc1200000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xc1200000,
  0xc1200000,
  0xffd23456,
  0xffc00001,
  0xc1200000,
  0xc1200000,
  0xc1200000,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0xffc00000,
  0xffc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffc00000,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x80123456,
  0x80123456,
  0x80123456,
  0x80123456,
  0x80123456,
  0x80123456,
  0x80123456,
  0x80123456,
  0x80123456,
  0x80123456,
  0x7fcfffff,
  0x80123456,
  0x80123456,
  0x80123456,
  0x7fd23456,
  0x7fc00001,
  0x80123456,
  0x80123456,
  0x80123456,
  0x80123456,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0x80123456,
  0x80123456,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80123456,
  0x807fffff,
  0x807fffff,
  0x807fffff,
  0x807fffff,
  0x807fffff,
  0x807fffff,
  0x807fffff,
  0x807fffff,
  0x807fffff,
  0x807fffff,
  0x7fcfffff,
  0x807fffff,
  0x807fffff,
  0x807fffff,
  0x7fd23456,
  0x7fc00001,
  0x807fffff,
  0x807fffff,
  0x807fffff,
  0x807fffff,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0x807fffff,
  0x807fffff,
  0xffd23456,
  0xffc00001,
  0x807fffff,
  0x807fffff,
  0x807fffff,
  0x80000001,
  0x80000001,
  0x80000001,
  0x80000001,
  0x80000001,
  0x80000001,
  0x80000001,
  0x80000001,
  0x80000001,
  0x80000001,
  0x7fcfffff,
  0x80000001,
  0x80000001,
  0x80000001,
  0x7fd23456,
  0x7fc00001,
  0x80000001,
  0x80000001,
  0x80000001,
  0x80000001,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0x80000001,
  0x80000001,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
};
const unsigned kExpectedCount_fminnm_s = 1444;

const uint64_t kExpected_fmov_d[] = {
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff123456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff123456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
};
const unsigned kExpectedCount_fmov_d = 38;

const uint32_t kExpected_fmov_s[] = {
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7f8fffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7f923456,
  0x7f800001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xff8fffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xff923456,
  0xff800001,
  0x80123456,
  0x807fffff,
  0x80000001,
};
const unsigned kExpectedCount_fmov_s = 38;

const uint64_t kExpected_fmsub_d[] = {
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8008000000000000,
  0x0008000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8006dcba98765433,
  0x0007ffffffffffff,
  0x8007ffffffffffff,
  0x8008000000000000,
  0x8018000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800923456789abcd,
  0x8017ffffffffffff,
  0x8008000000000001,
  0x8008000000000000,
  0x0008000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8006dcba98765433,
  0x0007ffffffffffff,
  0x8007ffffffffffff,
  0x8008000000000000,
  0x8018000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800923456789abcd,
  0x8017ffffffffffff,
  0x8008000000000001,
  0x8008000000000000,
  0x0008000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8006dcba98765434,
  0x0007fffffffffffe,
  0x8008000000000000,
  0x8008000000000000,
  0x8018000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800923456789abce,
  0x8018000000000000,
  0x8008000000000002,
  0x8010000000000000,
  0x0000000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x800edcba98765432,
  0x8000000000000000,
  0x800ffffffffffffe,
  0x8010000000000000,
  0x8020000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x801123456789abcc,
  0x801ffffffffffffe,
  0x8010000000000000,
  0x8010000000000000,
  0x0000000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x800edcba98765433,
  0x8000000000000001,
  0x800fffffffffffff,
  0x8010000000000000,
  0x8020000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x801123456789abcd,
  0x801fffffffffffff,
  0x8010000000000001,
  0x8010000000000001,
  0x8000000000000001,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x800edcba98765434,
  0x8000000000000002,
  0x8010000000000000,
  0x8010000000000001,
  0x8020000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x801123456789abce,
  0x8020000000000000,
  0x8010000000000002,
  0x8018000000000000,
  0x8008000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8016dcba98765433,
  0x8008000000000001,
  0x8017ffffffffffff,
  0x8018000000000000,
  0x8024000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x801923456789abcd,
  0x8024000000000000,
  0x8018000000000001,
  0x8044000000000000,
  0x8042000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8043db97530eca86,
  0x8042000000000000,
  0x8044000000000000,
  0x8044000000000000,
  0x8046000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x80442468acf1357a,
  0x8046000000000000,
  0x8044000000000000,
  0xc00fffffffffffff,
  0xc00fffffffffffff,
  0xc00bffffffffffff,
  0xc00bffffffffffff,
  0xc00bffffffffffff,
  0xc007ffffffffffff,
  0xc007ffffffffffff,
  0xc007fffffffffffe,
  0xc003ffffffffffff,
  0x4018000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc00fffffffffffff,
  0xc00fffffffffffff,
  0xc00fffffffffffff,
  0xc00fffffffffffff,
  0xc00fffffffffffff,
  0xc011ffffffffffff,
  0xc012000000000000,
  0xc012000000000000,
  0xc013ffffffffffff,
  0xc014000000000000,
  0xc014000000000000,
  0xc016000000000000,
  0xc02c000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc00fffffffffffff,
  0xc00fffffffffffff,
  0xc00fffffffffffff,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0008000000000000,
  0x0018000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000923456789abcd,
  0x0017ffffffffffff,
  0x0008000000000001,
  0x0008000000000000,
  0x8008000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0006dcba98765433,
  0x8007ffffffffffff,
  0x0007ffffffffffff,
  0x0008000000000000,
  0x0018000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000923456789abcd,
  0x0017ffffffffffff,
  0x0008000000000001,
  0x0008000000000000,
  0x8008000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0006dcba98765433,
  0x8007ffffffffffff,
  0x0007ffffffffffff,
  0x0008000000000000,
  0x0018000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000923456789abce,
  0x0018000000000000,
  0x0008000000000002,
  0x0008000000000000,
  0x8008000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0006dcba98765434,
  0x8007fffffffffffe,
  0x0008000000000000,
  0x0010000000000000,
  0x0020000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x001123456789abcc,
  0x001ffffffffffffe,
  0x0010000000000000,
  0x0010000000000000,
  0x8000000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x000edcba98765432,
  0x0000000000000000,
  0x000ffffffffffffe,
  0x0010000000000000,
  0x0020000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x001123456789abcd,
  0x001fffffffffffff,
  0x0010000000000001,
  0x0010000000000000,
  0x0000000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x000edcba98765433,
  0x0000000000000001,
  0x000fffffffffffff,
  0x0010000000000001,
  0x0020000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x001123456789abce,
  0x0020000000000000,
  0x0010000000000002,
  0x0010000000000001,
  0x0000000000000001,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x000edcba98765434,
  0x0000000000000002,
  0x0010000000000000,
  0x0018000000000000,
  0x0024000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x001923456789abcd,
  0x0024000000000000,
  0x0018000000000001,
  0x0018000000000000,
  0x0008000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0016dcba98765433,
  0x0008000000000001,
  0x0017ffffffffffff,
  0x0044000000000000,
  0x0046000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x00442468acf1357a,
  0x0046000000000000,
  0x0044000000000000,
  0x0044000000000000,
  0x0042000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0043db97530eca86,
  0x0042000000000000,
  0x0044000000000000,
  0x400fffffffffffff,
  0x400fffffffffffff,
  0x4011ffffffffffff,
  0x4012000000000000,
  0x4012000000000000,
  0x4013ffffffffffff,
  0x4014000000000000,
  0x4014000000000000,
  0x4016000000000000,
  0x402c000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x400fffffffffffff,
  0x400fffffffffffff,
  0x400fffffffffffff,
  0x400fffffffffffff,
  0x400fffffffffffff,
  0x400bffffffffffff,
  0x400bffffffffffff,
  0x400bffffffffffff,
  0x4007ffffffffffff,
  0x4007ffffffffffff,
  0x4007fffffffffffe,
  0x4003ffffffffffff,
  0xc018000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x400fffffffffffff,
  0x400fffffffffffff,
  0x400fffffffffffff,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8008000000000000,
  0x0008000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8006dcba98765433,
  0x0007ffffffffffff,
  0x8007ffffffffffff,
  0x8008000000000000,
  0x8018000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800923456789abcd,
  0x8017ffffffffffff,
  0x8008000000000001,
  0xbfcffffffffffffe,
  0xbfcffffffffffffe,
  0x3fd0000000000000,
  0x3fd0000000000001,
  0x3fd0000000000003,
  0x3fe7ffffffffffff,
  0x3fe8000000000000,
  0x3fe8000000000002,
  0x3ff4000000000000,
  0x4023800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfcffffffffffffe,
  0xbfcffffffffffffe,
  0xbfcffffffffffffe,
  0xbfcffffffffffffe,
  0xbfcffffffffffffe,
  0xbfe7ffffffffffff,
  0xbfe8000000000000,
  0xbfe8000000000001,
  0xbff3ffffffffffff,
  0xbff4000000000000,
  0xbff4000000000001,
  0xbffc000000000000,
  0xc024800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfcffffffffffffe,
  0xbfcffffffffffffe,
  0xbfcffffffffffffe,
  0xbfcfffffffffffff,
  0xbfcfffffffffffff,
  0x3fcfffffffffffff,
  0x3fd0000000000000,
  0x3fd0000000000002,
  0x3fe7ffffffffffff,
  0x3fe8000000000000,
  0x3fe8000000000002,
  0x3ff4000000000000,
  0x4023800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfcfffffffffffff,
  0xbfcfffffffffffff,
  0xbfcfffffffffffff,
  0xbfcfffffffffffff,
  0xbfcfffffffffffff,
  0xbfe7ffffffffffff,
  0xbfe8000000000000,
  0xbfe8000000000001,
  0xbff3ffffffffffff,
  0xbff4000000000000,
  0xbff4000000000001,
  0xbffc000000000000,
  0xc024800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfcfffffffffffff,
  0xbfcfffffffffffff,
  0xbfcfffffffffffff,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0x3fcffffffffffffd,
  0x3fcfffffffffffff,
  0x3fd0000000000002,
  0x3fe7ffffffffffff,
  0x3fe8000000000000,
  0x3fe8000000000002,
  0x3ff4000000000000,
  0x4023800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbfe8000000000001,
  0xbff4000000000000,
  0xbff4000000000000,
  0xbff4000000000001,
  0xbffc000000000000,
  0xc024800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfdffffffffffffe,
  0xbfdffffffffffffe,
  0x3c8fffffffffffff,
  0x3ca0000000000000,
  0x3cb0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000003,
  0x3ff0000000000000,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfdffffffffffffe,
  0xbfdffffffffffffe,
  0xbfdffffffffffffe,
  0xbfdffffffffffffe,
  0xbfdffffffffffffe,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff7ffffffffffff,
  0xbff8000000000000,
  0xbff8000000000001,
  0xc000000000000000,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfdffffffffffffe,
  0xbfdffffffffffffe,
  0xbfdffffffffffffe,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0x0000000000000000,
  0x3c90000000000000,
  0x3ca8000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000002,
  0x3ff0000000000000,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff7ffffffffffff,
  0xbff8000000000000,
  0xbff8000000000001,
  0xc000000000000000,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbc9fffffffffffff,
  0xbc8ffffffffffffe,
  0x3c90000000000001,
  0x3fdffffffffffffd,
  0x3fdfffffffffffff,
  0x3fe0000000000002,
  0x3ff0000000000000,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000001,
  0xc000000000000000,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe7ffffffffffff,
  0xbfe7ffffffffffff,
  0xbfcfffffffffffff,
  0xbfcffffffffffffd,
  0xbfcffffffffffff9,
  0x3fcfffffffffffff,
  0x3fd0000000000002,
  0x3fd0000000000006,
  0x3fe8000000000001,
  0x4022800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe7ffffffffffff,
  0xbfe7ffffffffffff,
  0xbfe7ffffffffffff,
  0xbfe7ffffffffffff,
  0xbfe7ffffffffffff,
  0xbff3ffffffffffff,
  0xbff4000000000000,
  0xbff4000000000000,
  0xbffbffffffffffff,
  0xbffc000000000000,
  0xbffc000000000001,
  0xc002000000000000,
  0xc025800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe7ffffffffffff,
  0xbfe7ffffffffffff,
  0xbfe7ffffffffffff,
  0xc013ffffffffffff,
  0xc013ffffffffffff,
  0xc011ffffffffffff,
  0xc011ffffffffffff,
  0xc011ffffffffffff,
  0xc00fffffffffffff,
  0xc00fffffffffffff,
  0xc00ffffffffffffe,
  0xc00bffffffffffff,
  0x4014000000000001,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc013ffffffffffff,
  0xc013ffffffffffff,
  0xc013ffffffffffff,
  0xc013ffffffffffff,
  0xc013ffffffffffff,
  0xc015ffffffffffff,
  0xc015ffffffffffff,
  0xc016000000000000,
  0xc017ffffffffffff,
  0xc017ffffffffffff,
  0xc018000000000000,
  0xc019ffffffffffff,
  0xc02e000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc013ffffffffffff,
  0xc013ffffffffffff,
  0xc013ffffffffffff,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0x7fe0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x800091a2b3c4d5e6,
  0x000f6e5d4c3b2a1a,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000091a2b3c4d5e7,
  0x000f6e5d4c3b2a19,
  0x800091a2b3c4d5e5,
  0x800091a2b3c4d5e6,
  0x801091a2b3c4d5e6,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x8001b4e81b4e81b3,
  0x801091a2b3c4d5e5,
  0x800091a2b3c4d5e7,
  0x8007ffffffffffff,
  0x0008000000000001,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8006dcba98765432,
  0x0008000000000000,
  0x8007fffffffffffe,
  0x8007ffffffffffff,
  0x8017ffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800923456789abcc,
  0x8017fffffffffffe,
  0x8008000000000000,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0008000000000000,
  0x0018000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000923456789abcd,
  0x0017ffffffffffff,
  0x0008000000000001,
  0x0008000000000000,
  0x8008000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0006dcba98765433,
  0x8007ffffffffffff,
  0x0007ffffffffffff,
  0x3fcffffffffffffe,
  0x3fcffffffffffffe,
  0x3fe7ffffffffffff,
  0x3fe8000000000000,
  0x3fe8000000000001,
  0x3ff3ffffffffffff,
  0x3ff4000000000000,
  0x3ff4000000000001,
  0x3ffc000000000000,
  0x4024800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fcffffffffffffe,
  0x3fcffffffffffffe,
  0x3fcffffffffffffe,
  0x3fcffffffffffffe,
  0x3fcffffffffffffe,
  0xbfd0000000000000,
  0xbfd0000000000001,
  0xbfd0000000000003,
  0xbfe7ffffffffffff,
  0xbfe8000000000000,
  0xbfe8000000000002,
  0xbff4000000000000,
  0xc023800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fcffffffffffffe,
  0x3fcffffffffffffe,
  0x3fcffffffffffffe,
  0x3fcfffffffffffff,
  0x3fcfffffffffffff,
  0x3fe7ffffffffffff,
  0x3fe8000000000000,
  0x3fe8000000000001,
  0x3ff3ffffffffffff,
  0x3ff4000000000000,
  0x3ff4000000000001,
  0x3ffc000000000000,
  0x4024800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fcfffffffffffff,
  0x3fcfffffffffffff,
  0x3fcfffffffffffff,
  0x3fcfffffffffffff,
  0x3fcfffffffffffff,
  0xbfcfffffffffffff,
  0xbfd0000000000000,
  0xbfd0000000000002,
  0xbfe7ffffffffffff,
  0xbfe8000000000000,
  0xbfe8000000000002,
  0xbff4000000000000,
  0xc023800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fcfffffffffffff,
  0x3fcfffffffffffff,
  0x3fcfffffffffffff,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3fe8000000000001,
  0x3ff4000000000000,
  0x3ff4000000000000,
  0x3ff4000000000001,
  0x3ffc000000000000,
  0x4024800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0xbfcffffffffffffd,
  0xbfcfffffffffffff,
  0xbfd0000000000002,
  0xbfe7ffffffffffff,
  0xbfe8000000000000,
  0xbfe8000000000002,
  0xbff4000000000000,
  0xc023800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fdffffffffffffe,
  0x3fdffffffffffffe,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff7ffffffffffff,
  0x3ff8000000000000,
  0x3ff8000000000001,
  0x4000000000000000,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fdffffffffffffe,
  0x3fdffffffffffffe,
  0x3fdffffffffffffe,
  0x3fdffffffffffffe,
  0x3fdffffffffffffe,
  0xbc8fffffffffffff,
  0xbca0000000000000,
  0xbcb0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000003,
  0xbff0000000000000,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fdffffffffffffe,
  0x3fdffffffffffffe,
  0x3fdffffffffffffe,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff7ffffffffffff,
  0x3ff8000000000000,
  0x3ff8000000000001,
  0x4000000000000000,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x0000000000000000,
  0xbc90000000000000,
  0xbca8000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000002,
  0xbff0000000000000,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000001,
  0x4000000000000000,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3c9fffffffffffff,
  0x3c8ffffffffffffe,
  0xbc90000000000001,
  0xbfdffffffffffffd,
  0xbfdfffffffffffff,
  0xbfe0000000000002,
  0xbff0000000000000,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe7ffffffffffff,
  0x3fe7ffffffffffff,
  0x3ff3ffffffffffff,
  0x3ff4000000000000,
  0x3ff4000000000000,
  0x3ffbffffffffffff,
  0x3ffc000000000000,
  0x3ffc000000000001,
  0x4002000000000000,
  0x4025800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe7ffffffffffff,
  0x3fe7ffffffffffff,
  0x3fe7ffffffffffff,
  0x3fe7ffffffffffff,
  0x3fe7ffffffffffff,
  0x3fcfffffffffffff,
  0x3fcffffffffffffd,
  0x3fcffffffffffff9,
  0xbfcfffffffffffff,
  0xbfd0000000000002,
  0xbfd0000000000006,
  0xbfe8000000000001,
  0xc022800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe7ffffffffffff,
  0x3fe7ffffffffffff,
  0x3fe7ffffffffffff,
  0x4013ffffffffffff,
  0x4013ffffffffffff,
  0x4015ffffffffffff,
  0x4015ffffffffffff,
  0x4016000000000000,
  0x4017ffffffffffff,
  0x4017ffffffffffff,
  0x4018000000000000,
  0x4019ffffffffffff,
  0x402e000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x4013ffffffffffff,
  0x4013ffffffffffff,
  0x4013ffffffffffff,
  0x4013ffffffffffff,
  0x4013ffffffffffff,
  0x4011ffffffffffff,
  0x4011ffffffffffff,
  0x4011ffffffffffff,
  0x400fffffffffffff,
  0x400fffffffffffff,
  0x400ffffffffffffe,
  0x400bffffffffffff,
  0xc014000000000001,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x4013ffffffffffff,
  0x4013ffffffffffff,
  0x4013ffffffffffff,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0xffe0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x000091a2b3c4d5e6,
  0x001091a2b3c4d5e6,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0001b4e81b4e81b3,
  0x001091a2b3c4d5e5,
  0x000091a2b3c4d5e7,
  0x000091a2b3c4d5e6,
  0x800f6e5d4c3b2a1a,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800091a2b3c4d5e7,
  0x800f6e5d4c3b2a19,
  0x000091a2b3c4d5e5,
  0x0007ffffffffffff,
  0x0017ffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000923456789abcc,
  0x0017fffffffffffe,
  0x0008000000000000,
  0x0007ffffffffffff,
  0x8008000000000001,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0006dcba98765432,
  0x8008000000000000,
  0x0007fffffffffffe,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8008000000000000,
  0x0008000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8006dcba98765433,
  0x0007ffffffffffff,
  0x8007ffffffffffff,
  0x8008000000000000,
  0x8018000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800923456789abcd,
  0x8017ffffffffffff,
  0x8008000000000001,
  0xbfcfffffffffffff,
  0xbfcfffffffffffff,
  0x3fcfffffffffffff,
  0x3fd0000000000000,
  0x3fd0000000000002,
  0x3fe7ffffffffffff,
  0x3fe8000000000000,
  0x3fe8000000000002,
  0x3ff4000000000000,
  0x4023800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfcfffffffffffff,
  0xbfcfffffffffffff,
  0xbfcfffffffffffff,
  0xbfcfffffffffffff,
  0xbfcfffffffffffff,
  0xbfe7ffffffffffff,
  0xbfe8000000000000,
  0xbfe8000000000001,
  0xbff3ffffffffffff,
  0xbff4000000000000,
  0xbff4000000000001,
  0xbffc000000000000,
  0xc024800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfcfffffffffffff,
  0xbfcfffffffffffff,
  0xbfcfffffffffffff,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0x3fcffffffffffffe,
  0x3fd0000000000000,
  0x3fd0000000000002,
  0x3fe7ffffffffffff,
  0x3fe8000000000000,
  0x3fe8000000000002,
  0x3ff4000000000000,
  0x4023800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbfe8000000000001,
  0xbff4000000000000,
  0xbff4000000000000,
  0xbff4000000000001,
  0xbffc000000000000,
  0xc024800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000001,
  0xbfd0000000000001,
  0x3fcffffffffffffc,
  0x3fcffffffffffffe,
  0x3fd0000000000001,
  0x3fe7fffffffffffe,
  0x3fe8000000000000,
  0x3fe8000000000002,
  0x3ff4000000000000,
  0x4023800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfd0000000000001,
  0xbfd0000000000001,
  0xbfd0000000000001,
  0xbfd0000000000001,
  0xbfd0000000000001,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbfe8000000000002,
  0xbff4000000000000,
  0xbff4000000000000,
  0xbff4000000000001,
  0xbffc000000000000,
  0xc024800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfd0000000000001,
  0xbfd0000000000001,
  0xbfd0000000000001,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0x0000000000000000,
  0x3c90000000000000,
  0x3ca8000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000002,
  0x3ff0000000000000,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff7ffffffffffff,
  0xbff8000000000000,
  0xbff8000000000001,
  0xc000000000000000,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbc90000000000000,
  0x0000000000000000,
  0x3ca0000000000000,
  0x3fdffffffffffffe,
  0x3fe0000000000000,
  0x3fe0000000000002,
  0x3ff0000000000000,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000001,
  0xc000000000000000,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbca8000000000000,
  0xbca0000000000000,
  0x0000000000000000,
  0x3fdffffffffffffc,
  0x3fdffffffffffffe,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000002,
  0xc000000000000000,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbfd0000000000001,
  0xbfd0000000000000,
  0xbfcffffffffffffc,
  0x3fcffffffffffffc,
  0x3fd0000000000000,
  0x3fd0000000000004,
  0x3fe8000000000000,
  0x4022800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbff4000000000000,
  0xbff4000000000000,
  0xbff4000000000000,
  0xbffc000000000000,
  0xbffc000000000000,
  0xbffc000000000001,
  0xc002000000000000,
  0xc025800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xc014000000000000,
  0xc014000000000000,
  0xc012000000000000,
  0xc012000000000000,
  0xc012000000000000,
  0xc010000000000000,
  0xc010000000000000,
  0xc010000000000000,
  0xc00c000000000000,
  0x4014000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc014000000000000,
  0xc014000000000000,
  0xc014000000000000,
  0xc014000000000000,
  0xc014000000000000,
  0xc016000000000000,
  0xc016000000000000,
  0xc016000000000000,
  0xc018000000000000,
  0xc018000000000000,
  0xc018000000000000,
  0xc01a000000000000,
  0xc02e000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc014000000000000,
  0xc014000000000000,
  0xc014000000000000,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0x7fdfffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x800091a2b3c4d5e6,
  0x000f6e5d4c3b2a1a,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000091a2b3c4d5e6,
  0x000f6e5d4c3b2a18,
  0x800091a2b3c4d5e6,
  0x800091a2b3c4d5e6,
  0x801091a2b3c4d5e6,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x8001b4e81b4e81b4,
  0x801091a2b3c4d5e6,
  0x800091a2b3c4d5e8,
  0x8008000000000000,
  0x0008000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8006dcba98765432,
  0x0008000000000000,
  0x8007fffffffffffe,
  0x8008000000000000,
  0x8018000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800923456789abcc,
  0x8017fffffffffffe,
  0x8008000000000000,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcc,
  0x000ffffffffffffe,
  0x0000000000000000,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abce,
  0x8010000000000000,
  0x8000000000000002,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0008000000000000,
  0x0018000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000923456789abcd,
  0x0017ffffffffffff,
  0x0008000000000001,
  0x0008000000000000,
  0x8008000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0006dcba98765433,
  0x8007ffffffffffff,
  0x0007ffffffffffff,
  0x3fcfffffffffffff,
  0x3fcfffffffffffff,
  0x3fe7ffffffffffff,
  0x3fe8000000000000,
  0x3fe8000000000001,
  0x3ff3ffffffffffff,
  0x3ff4000000000000,
  0x3ff4000000000001,
  0x3ffc000000000000,
  0x4024800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fcfffffffffffff,
  0x3fcfffffffffffff,
  0x3fcfffffffffffff,
  0x3fcfffffffffffff,
  0x3fcfffffffffffff,
  0xbfcfffffffffffff,
  0xbfd0000000000000,
  0xbfd0000000000002,
  0xbfe7ffffffffffff,
  0xbfe8000000000000,
  0xbfe8000000000002,
  0xbff4000000000000,
  0xc023800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fcfffffffffffff,
  0x3fcfffffffffffff,
  0x3fcfffffffffffff,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3fe8000000000001,
  0x3ff4000000000000,
  0x3ff4000000000000,
  0x3ff4000000000001,
  0x3ffc000000000000,
  0x4024800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0xbfcffffffffffffe,
  0xbfd0000000000000,
  0xbfd0000000000002,
  0xbfe7ffffffffffff,
  0xbfe8000000000000,
  0xbfe8000000000002,
  0xbff4000000000000,
  0xc023800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000001,
  0x3fd0000000000001,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3fe8000000000002,
  0x3ff4000000000000,
  0x3ff4000000000000,
  0x3ff4000000000001,
  0x3ffc000000000000,
  0x4024800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fd0000000000001,
  0x3fd0000000000001,
  0x3fd0000000000001,
  0x3fd0000000000001,
  0x3fd0000000000001,
  0xbfcffffffffffffc,
  0xbfcffffffffffffe,
  0xbfd0000000000001,
  0xbfe7fffffffffffe,
  0xbfe8000000000000,
  0xbfe8000000000002,
  0xbff4000000000000,
  0xc023800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fd0000000000001,
  0x3fd0000000000001,
  0x3fd0000000000001,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff7ffffffffffff,
  0x3ff8000000000000,
  0x3ff8000000000001,
  0x4000000000000000,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x0000000000000000,
  0xbc90000000000000,
  0xbca8000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000002,
  0xbff0000000000000,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000001,
  0x4000000000000000,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3c90000000000000,
  0x0000000000000000,
  0xbca0000000000000,
  0xbfdffffffffffffe,
  0xbfe0000000000000,
  0xbfe0000000000002,
  0xbff0000000000000,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000002,
  0x4000000000000000,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3ca8000000000000,
  0x3ca0000000000000,
  0x0000000000000000,
  0xbfdffffffffffffc,
  0xbfdffffffffffffe,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3ff4000000000000,
  0x3ff4000000000000,
  0x3ff4000000000000,
  0x3ffc000000000000,
  0x3ffc000000000000,
  0x3ffc000000000001,
  0x4002000000000000,
  0x4025800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3fd0000000000001,
  0x3fd0000000000000,
  0x3fcffffffffffffc,
  0xbfcffffffffffffc,
  0xbfd0000000000000,
  0xbfd0000000000004,
  0xbfe8000000000000,
  0xc022800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x4014000000000000,
  0x4014000000000000,
  0x4016000000000000,
  0x4016000000000000,
  0x4016000000000000,
  0x4018000000000000,
  0x4018000000000000,
  0x4018000000000000,
  0x401a000000000000,
  0x402e000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x4014000000000000,
  0x4014000000000000,
  0x4014000000000000,
  0x4014000000000000,
  0x4014000000000000,
  0x4012000000000000,
  0x4012000000000000,
  0x4012000000000000,
  0x4010000000000000,
  0x4010000000000000,
  0x4010000000000000,
  0x400c000000000000,
  0xc014000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x4014000000000000,
  0x4014000000000000,
  0x4014000000000000,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0xffdfffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x000091a2b3c4d5e6,
  0x001091a2b3c4d5e6,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0001b4e81b4e81b4,
  0x001091a2b3c4d5e6,
  0x000091a2b3c4d5e8,
  0x000091a2b3c4d5e6,
  0x800f6e5d4c3b2a1a,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800091a2b3c4d5e6,
  0x800f6e5d4c3b2a18,
  0x000091a2b3c4d5e6,
  0x0008000000000000,
  0x0018000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000923456789abcc,
  0x0017fffffffffffe,
  0x0008000000000000,
  0x0008000000000000,
  0x8008000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0006dcba98765432,
  0x8008000000000000,
  0x0007fffffffffffe,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abce,
  0x0010000000000000,
  0x0000000000000002,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcc,
  0x800ffffffffffffe,
  0x8000000000000000,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8008000000000000,
  0x0008000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8006dcba98765434,
  0x0007fffffffffffe,
  0x8008000000000000,
  0x8008000000000000,
  0x8018000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800923456789abce,
  0x8018000000000000,
  0x8008000000000002,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0x3fcffffffffffffd,
  0x3fcfffffffffffff,
  0x3fd0000000000002,
  0x3fe7ffffffffffff,
  0x3fe8000000000000,
  0x3fe8000000000002,
  0x3ff4000000000000,
  0x4023800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbfe8000000000001,
  0xbff4000000000000,
  0xbff4000000000000,
  0xbff4000000000001,
  0xbffc000000000000,
  0xc024800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000001,
  0xbfd0000000000001,
  0x3fcffffffffffffc,
  0x3fcffffffffffffe,
  0x3fd0000000000001,
  0x3fe7fffffffffffe,
  0x3fe8000000000000,
  0x3fe8000000000002,
  0x3ff4000000000000,
  0x4023800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfd0000000000001,
  0xbfd0000000000001,
  0xbfd0000000000001,
  0xbfd0000000000001,
  0xbfd0000000000001,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbfe8000000000002,
  0xbff4000000000000,
  0xbff4000000000000,
  0xbff4000000000001,
  0xbffc000000000000,
  0xc024800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfd0000000000001,
  0xbfd0000000000001,
  0xbfd0000000000001,
  0xbfd0000000000002,
  0xbfd0000000000002,
  0x3fcffffffffffffa,
  0x3fcffffffffffffc,
  0x3fd0000000000000,
  0x3fe7fffffffffffe,
  0x3fe7ffffffffffff,
  0x3fe8000000000001,
  0x3ff3ffffffffffff,
  0x4023800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfd0000000000002,
  0xbfd0000000000002,
  0xbfd0000000000002,
  0xbfd0000000000002,
  0xbfd0000000000002,
  0xbfe8000000000001,
  0xbfe8000000000001,
  0xbfe8000000000002,
  0xbff4000000000000,
  0xbff4000000000001,
  0xbff4000000000002,
  0xbffc000000000001,
  0xc024800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfd0000000000002,
  0xbfd0000000000002,
  0xbfd0000000000002,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbc9fffffffffffff,
  0xbc8ffffffffffffe,
  0x3c90000000000001,
  0x3fdffffffffffffd,
  0x3fdfffffffffffff,
  0x3fe0000000000002,
  0x3ff0000000000000,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000001,
  0xc000000000000000,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbca8000000000000,
  0xbca0000000000000,
  0x0000000000000000,
  0x3fdffffffffffffc,
  0x3fdffffffffffffe,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000002,
  0xc000000000000000,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000002,
  0xbfe0000000000002,
  0xbcb4000000000000,
  0xbcb0000000000000,
  0xbca0000000000001,
  0x3fdffffffffffffa,
  0x3fdffffffffffffc,
  0x3fe0000000000000,
  0x3feffffffffffffe,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe0000000000002,
  0xbfe0000000000002,
  0xbfe0000000000002,
  0xbfe0000000000002,
  0xbfe0000000000002,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000002,
  0xbff8000000000001,
  0xbff8000000000001,
  0xbff8000000000002,
  0xc000000000000001,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe0000000000002,
  0xbfe0000000000002,
  0xbfe0000000000002,
  0xbfe8000000000002,
  0xbfe8000000000001,
  0xbfd0000000000004,
  0xbfd0000000000003,
  0xbfd0000000000001,
  0x3fcffffffffffff6,
  0x3fcffffffffffffa,
  0x3fd0000000000001,
  0x3fe7fffffffffffe,
  0x4022800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe8000000000001,
  0xbfe8000000000001,
  0xbfe8000000000001,
  0xbfe8000000000002,
  0xbfe8000000000002,
  0xbff4000000000000,
  0xbff4000000000001,
  0xbff4000000000001,
  0xbffc000000000000,
  0xbffc000000000001,
  0xbffc000000000002,
  0xc002000000000000,
  0xc025800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe8000000000002,
  0xbfe8000000000002,
  0xbfe8000000000002,
  0xc014000000000001,
  0xc014000000000001,
  0xc012000000000001,
  0xc012000000000001,
  0xc012000000000001,
  0xc010000000000001,
  0xc010000000000001,
  0xc010000000000001,
  0xc00c000000000002,
  0x4013ffffffffffff,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc014000000000001,
  0xc014000000000001,
  0xc014000000000001,
  0xc014000000000001,
  0xc014000000000001,
  0xc016000000000001,
  0xc016000000000001,
  0xc016000000000001,
  0xc018000000000001,
  0xc018000000000001,
  0xc018000000000002,
  0xc01a000000000001,
  0xc02e000000000001,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc014000000000001,
  0xc014000000000001,
  0xc014000000000001,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0x7fdffffffffffffd,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x800091a2b3c4d5e7,
  0x000f6e5d4c3b2a19,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000091a2b3c4d5e6,
  0x000f6e5d4c3b2a18,
  0x800091a2b3c4d5e6,
  0x800091a2b3c4d5e7,
  0x801091a2b3c4d5e7,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x8001b4e81b4e81b4,
  0x801091a2b3c4d5e6,
  0x800091a2b3c4d5e8,
  0x8008000000000000,
  0x0008000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8006dcba98765433,
  0x0007ffffffffffff,
  0x8007ffffffffffff,
  0x8008000000000000,
  0x8018000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800923456789abcd,
  0x8017ffffffffffff,
  0x8008000000000001,
  0x8000000000000001,
  0x000fffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcc,
  0x000ffffffffffffe,
  0x0000000000000000,
  0x8000000000000001,
  0x8010000000000001,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abce,
  0x8010000000000000,
  0x8000000000000002,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0008000000000000,
  0x0018000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000923456789abce,
  0x0018000000000000,
  0x0008000000000002,
  0x0008000000000000,
  0x8008000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0006dcba98765434,
  0x8007fffffffffffe,
  0x0008000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3fe8000000000001,
  0x3ff4000000000000,
  0x3ff4000000000000,
  0x3ff4000000000001,
  0x3ffc000000000000,
  0x4024800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0xbfcffffffffffffd,
  0xbfcfffffffffffff,
  0xbfd0000000000002,
  0xbfe7ffffffffffff,
  0xbfe8000000000000,
  0xbfe8000000000002,
  0xbff4000000000000,
  0xc023800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000001,
  0x3fd0000000000001,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3fe8000000000002,
  0x3ff4000000000000,
  0x3ff4000000000000,
  0x3ff4000000000001,
  0x3ffc000000000000,
  0x4024800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fd0000000000001,
  0x3fd0000000000001,
  0x3fd0000000000001,
  0x3fd0000000000001,
  0x3fd0000000000001,
  0xbfcffffffffffffc,
  0xbfcffffffffffffe,
  0xbfd0000000000001,
  0xbfe7fffffffffffe,
  0xbfe8000000000000,
  0xbfe8000000000002,
  0xbff4000000000000,
  0xc023800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fd0000000000001,
  0x3fd0000000000001,
  0x3fd0000000000001,
  0x3fd0000000000002,
  0x3fd0000000000002,
  0x3fe8000000000001,
  0x3fe8000000000001,
  0x3fe8000000000002,
  0x3ff4000000000000,
  0x3ff4000000000001,
  0x3ff4000000000002,
  0x3ffc000000000001,
  0x4024800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fd0000000000002,
  0x3fd0000000000002,
  0x3fd0000000000002,
  0x3fd0000000000002,
  0x3fd0000000000002,
  0xbfcffffffffffffa,
  0xbfcffffffffffffc,
  0xbfd0000000000000,
  0xbfe7fffffffffffe,
  0xbfe7ffffffffffff,
  0xbfe8000000000001,
  0xbff3ffffffffffff,
  0xc023800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fd0000000000002,
  0x3fd0000000000002,
  0x3fd0000000000002,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000001,
  0x4000000000000000,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3c9fffffffffffff,
  0x3c8ffffffffffffe,
  0xbc90000000000001,
  0xbfdffffffffffffd,
  0xbfdfffffffffffff,
  0xbfe0000000000002,
  0xbff0000000000000,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000002,
  0x4000000000000000,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3ca8000000000000,
  0x3ca0000000000000,
  0x0000000000000000,
  0xbfdffffffffffffc,
  0xbfdffffffffffffe,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000002,
  0x3fe0000000000002,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000002,
  0x3ff8000000000001,
  0x3ff8000000000001,
  0x3ff8000000000002,
  0x4000000000000001,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe0000000000002,
  0x3fe0000000000002,
  0x3fe0000000000002,
  0x3fe0000000000002,
  0x3fe0000000000002,
  0x3cb4000000000000,
  0x3cb0000000000000,
  0x3ca0000000000001,
  0xbfdffffffffffffa,
  0xbfdffffffffffffc,
  0xbfe0000000000000,
  0xbfeffffffffffffe,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe0000000000002,
  0x3fe0000000000002,
  0x3fe0000000000002,
  0x3fe8000000000002,
  0x3fe8000000000002,
  0x3ff4000000000000,
  0x3ff4000000000001,
  0x3ff4000000000001,
  0x3ffc000000000000,
  0x3ffc000000000001,
  0x3ffc000000000002,
  0x4002000000000000,
  0x4025800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe8000000000002,
  0x3fe8000000000002,
  0x3fe8000000000002,
  0x3fe8000000000002,
  0x3fe8000000000001,
  0x3fd0000000000004,
  0x3fd0000000000003,
  0x3fd0000000000001,
  0xbfcffffffffffff6,
  0xbfcffffffffffffa,
  0xbfd0000000000001,
  0xbfe7fffffffffffe,
  0xc022800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe8000000000001,
  0x3fe8000000000001,
  0x3fe8000000000001,
  0x4014000000000001,
  0x4014000000000001,
  0x4016000000000001,
  0x4016000000000001,
  0x4016000000000001,
  0x4018000000000001,
  0x4018000000000001,
  0x4018000000000002,
  0x401a000000000001,
  0x402e000000000001,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x4014000000000001,
  0x4014000000000001,
  0x4014000000000001,
  0x4014000000000001,
  0x4014000000000001,
  0x4012000000000001,
  0x4012000000000001,
  0x4012000000000001,
  0x4010000000000001,
  0x4010000000000001,
  0x4010000000000001,
  0x400c000000000002,
  0xc013ffffffffffff,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x4014000000000001,
  0x4014000000000001,
  0x4014000000000001,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0xffdffffffffffffd,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x000091a2b3c4d5e7,
  0x001091a2b3c4d5e7,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0001b4e81b4e81b4,
  0x001091a2b3c4d5e6,
  0x000091a2b3c4d5e8,
  0x000091a2b3c4d5e7,
  0x800f6e5d4c3b2a19,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800091a2b3c4d5e6,
  0x800f6e5d4c3b2a18,
  0x000091a2b3c4d5e6,
  0x0008000000000000,
  0x0018000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000923456789abcd,
  0x0017ffffffffffff,
  0x0008000000000001,
  0x0008000000000000,
  0x8008000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0006dcba98765433,
  0x8007ffffffffffff,
  0x0007ffffffffffff,
  0x0000000000000001,
  0x0010000000000001,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abce,
  0x0010000000000000,
  0x0000000000000002,
  0x0000000000000001,
  0x800fffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcc,
  0x800ffffffffffffe,
  0x8000000000000000,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8010000000000000,
  0x0000000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x800edcba98765432,
  0x8000000000000000,
  0x800ffffffffffffe,
  0x8010000000000000,
  0x8020000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x801123456789abcc,
  0x801ffffffffffffe,
  0x8010000000000000,
  0xbfdffffffffffffe,
  0xbfdffffffffffffe,
  0x3c8fffffffffffff,
  0x3ca0000000000000,
  0x3cb0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000003,
  0x3ff0000000000000,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfdffffffffffffe,
  0xbfdffffffffffffe,
  0xbfdffffffffffffe,
  0xbfdffffffffffffe,
  0xbfdffffffffffffe,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff7ffffffffffff,
  0xbff8000000000000,
  0xbff8000000000001,
  0xc000000000000000,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfdffffffffffffe,
  0xbfdffffffffffffe,
  0xbfdffffffffffffe,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0x0000000000000000,
  0x3c90000000000000,
  0x3ca8000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000002,
  0x3ff0000000000000,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff7ffffffffffff,
  0xbff8000000000000,
  0xbff8000000000001,
  0xc000000000000000,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbc9fffffffffffff,
  0xbc8ffffffffffffe,
  0x3c90000000000001,
  0x3fdffffffffffffd,
  0x3fdfffffffffffff,
  0x3fe0000000000002,
  0x3ff0000000000000,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000001,
  0xc000000000000000,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfeffffffffffffe,
  0xbfeffffffffffffe,
  0xbfdffffffffffffd,
  0xbfdffffffffffffc,
  0xbfdffffffffffffa,
  0x3c9fffffffffffff,
  0x3cb0000000000000,
  0x3cc0000000000000,
  0x3fe0000000000002,
  0x4022000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfeffffffffffffe,
  0xbfeffffffffffffe,
  0xbfeffffffffffffe,
  0xbfeffffffffffffe,
  0xbfeffffffffffffe,
  0xbff7ffffffffffff,
  0xbff7ffffffffffff,
  0xbff8000000000000,
  0xbfffffffffffffff,
  0xbfffffffffffffff,
  0xc000000000000000,
  0xc004000000000000,
  0xc026000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfeffffffffffffe,
  0xbfeffffffffffffe,
  0xbfeffffffffffffe,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfdfffffffffffff,
  0xbfdffffffffffffe,
  0xbfdffffffffffffc,
  0x0000000000000000,
  0x3ca0000000000000,
  0x3cb8000000000000,
  0x3fe0000000000001,
  0x4022000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbff7ffffffffffff,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbfffffffffffffff,
  0xc000000000000000,
  0xc000000000000000,
  0xc004000000000000,
  0xc026000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000000,
  0xbcafffffffffffff,
  0xbc9ffffffffffffe,
  0x3ca0000000000001,
  0x3fdffffffffffffe,
  0x4022000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000001,
  0xc000000000000000,
  0xc000000000000000,
  0xc000000000000001,
  0xc004000000000000,
  0xc026000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff7ffffffffffff,
  0xbff7ffffffffffff,
  0xbfefffffffffffff,
  0xbfeffffffffffffe,
  0xbfeffffffffffffe,
  0xbfdfffffffffffff,
  0xbfdffffffffffffd,
  0xbfdffffffffffff9,
  0x3ca8000000000000,
  0x4021000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbff7ffffffffffff,
  0xbff7ffffffffffff,
  0xbff7ffffffffffff,
  0xbff7ffffffffffff,
  0xbff7ffffffffffff,
  0xbfffffffffffffff,
  0xbfffffffffffffff,
  0xc000000000000000,
  0xc003ffffffffffff,
  0xc004000000000000,
  0xc004000000000000,
  0xc008000000000000,
  0xc027000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbff7ffffffffffff,
  0xbff7ffffffffffff,
  0xbff7ffffffffffff,
  0xc023ffffffffffff,
  0xc023ffffffffffff,
  0xc022ffffffffffff,
  0xc022ffffffffffff,
  0xc022ffffffffffff,
  0xc021ffffffffffff,
  0xc021ffffffffffff,
  0xc021ffffffffffff,
  0xc020ffffffffffff,
  0x3cd4000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc023ffffffffffff,
  0xc023ffffffffffff,
  0xc023ffffffffffff,
  0xc023ffffffffffff,
  0xc023ffffffffffff,
  0xc024ffffffffffff,
  0xc024ffffffffffff,
  0xc024ffffffffffff,
  0xc025ffffffffffff,
  0xc025ffffffffffff,
  0xc026000000000000,
  0xc026ffffffffffff,
  0xc034000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc023ffffffffffff,
  0xc023ffffffffffff,
  0xc023ffffffffffff,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0x7c9fffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x800123456789abcd,
  0x000edcba98765433,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0000000000000000,
  0x000edcba98765432,
  0x800123456789abcc,
  0x800123456789abcd,
  0x801123456789abcd,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x8002468acf13579a,
  0x801123456789abcc,
  0x800123456789abce,
  0x800fffffffffffff,
  0x0000000000000001,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x800edcba98765432,
  0x0000000000000000,
  0x800ffffffffffffe,
  0x800fffffffffffff,
  0x801fffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x801123456789abcc,
  0x801ffffffffffffe,
  0x8010000000000000,
  0x8000000000000001,
  0x000fffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcc,
  0x000ffffffffffffe,
  0x0000000000000000,
  0x8000000000000001,
  0x8010000000000001,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abce,
  0x8010000000000000,
  0x8000000000000002,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0010000000000000,
  0x0020000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x001123456789abcc,
  0x001ffffffffffffe,
  0x0010000000000000,
  0x0010000000000000,
  0x8000000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x000edcba98765432,
  0x0000000000000000,
  0x000ffffffffffffe,
  0x3fdffffffffffffe,
  0x3fdffffffffffffe,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff7ffffffffffff,
  0x3ff8000000000000,
  0x3ff8000000000001,
  0x4000000000000000,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fdffffffffffffe,
  0x3fdffffffffffffe,
  0x3fdffffffffffffe,
  0x3fdffffffffffffe,
  0x3fdffffffffffffe,
  0xbc8fffffffffffff,
  0xbca0000000000000,
  0xbcb0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000003,
  0xbff0000000000000,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fdffffffffffffe,
  0x3fdffffffffffffe,
  0x3fdffffffffffffe,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff7ffffffffffff,
  0x3ff8000000000000,
  0x3ff8000000000001,
  0x4000000000000000,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x0000000000000000,
  0xbc90000000000000,
  0xbca8000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000002,
  0xbff0000000000000,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000001,
  0x4000000000000000,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3c9fffffffffffff,
  0x3c8ffffffffffffe,
  0xbc90000000000001,
  0xbfdffffffffffffd,
  0xbfdfffffffffffff,
  0xbfe0000000000002,
  0xbff0000000000000,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3feffffffffffffe,
  0x3feffffffffffffe,
  0x3ff7ffffffffffff,
  0x3ff7ffffffffffff,
  0x3ff8000000000000,
  0x3fffffffffffffff,
  0x3fffffffffffffff,
  0x4000000000000000,
  0x4004000000000000,
  0x4026000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3feffffffffffffe,
  0x3feffffffffffffe,
  0x3feffffffffffffe,
  0x3feffffffffffffe,
  0x3feffffffffffffe,
  0x3fdffffffffffffd,
  0x3fdffffffffffffc,
  0x3fdffffffffffffa,
  0xbc9fffffffffffff,
  0xbcb0000000000000,
  0xbcc0000000000000,
  0xbfe0000000000002,
  0xc022000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3feffffffffffffe,
  0x3feffffffffffffe,
  0x3feffffffffffffe,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3ff7ffffffffffff,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3fffffffffffffff,
  0x4000000000000000,
  0x4000000000000000,
  0x4004000000000000,
  0x4026000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fdfffffffffffff,
  0x3fdffffffffffffe,
  0x3fdffffffffffffc,
  0x0000000000000000,
  0xbca0000000000000,
  0xbcb8000000000000,
  0xbfe0000000000001,
  0xc022000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000001,
  0x4000000000000000,
  0x4000000000000000,
  0x4000000000000001,
  0x4004000000000000,
  0x4026000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000000,
  0x3cafffffffffffff,
  0x3c9ffffffffffffe,
  0xbca0000000000001,
  0xbfdffffffffffffe,
  0xc022000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff7ffffffffffff,
  0x3ff7ffffffffffff,
  0x3fffffffffffffff,
  0x3fffffffffffffff,
  0x4000000000000000,
  0x4003ffffffffffff,
  0x4004000000000000,
  0x4004000000000000,
  0x4008000000000000,
  0x4027000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3ff7ffffffffffff,
  0x3ff7ffffffffffff,
  0x3ff7ffffffffffff,
  0x3ff7ffffffffffff,
  0x3ff7ffffffffffff,
  0x3fefffffffffffff,
  0x3feffffffffffffe,
  0x3feffffffffffffe,
  0x3fdfffffffffffff,
  0x3fdffffffffffffd,
  0x3fdffffffffffff9,
  0xbca8000000000000,
  0xc021000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3ff7ffffffffffff,
  0x3ff7ffffffffffff,
  0x3ff7ffffffffffff,
  0x4023ffffffffffff,
  0x4023ffffffffffff,
  0x4024ffffffffffff,
  0x4024ffffffffffff,
  0x4024ffffffffffff,
  0x4025ffffffffffff,
  0x4025ffffffffffff,
  0x4026000000000000,
  0x4026ffffffffffff,
  0x4034000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x4023ffffffffffff,
  0x4023ffffffffffff,
  0x4023ffffffffffff,
  0x4023ffffffffffff,
  0x4023ffffffffffff,
  0x4022ffffffffffff,
  0x4022ffffffffffff,
  0x4022ffffffffffff,
  0x4021ffffffffffff,
  0x4021ffffffffffff,
  0x4021ffffffffffff,
  0x4020ffffffffffff,
  0xbcd4000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x4023ffffffffffff,
  0x4023ffffffffffff,
  0x4023ffffffffffff,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0xfc9fffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x001123456789abcd,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0002468acf13579a,
  0x001123456789abcc,
  0x000123456789abce,
  0x000123456789abcd,
  0x800edcba98765433,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x8000000000000000,
  0x800edcba98765432,
  0x000123456789abcc,
  0x000fffffffffffff,
  0x001fffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x001123456789abcc,
  0x001ffffffffffffe,
  0x0010000000000000,
  0x000fffffffffffff,
  0x8000000000000001,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x000edcba98765432,
  0x8000000000000000,
  0x000ffffffffffffe,
  0x0000000000000001,
  0x0010000000000001,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abce,
  0x0010000000000000,
  0x0000000000000002,
  0x0000000000000001,
  0x800fffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcc,
  0x800ffffffffffffe,
  0x8000000000000000,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8010000000000000,
  0x0000000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x800edcba98765433,
  0x8000000000000001,
  0x800fffffffffffff,
  0x8010000000000000,
  0x8020000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x801123456789abcd,
  0x801fffffffffffff,
  0x8010000000000001,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0x0000000000000000,
  0x3c90000000000000,
  0x3ca8000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000002,
  0x3ff0000000000000,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff7ffffffffffff,
  0xbff8000000000000,
  0xbff8000000000001,
  0xc000000000000000,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbc90000000000000,
  0x0000000000000000,
  0x3ca0000000000000,
  0x3fdffffffffffffe,
  0x3fe0000000000000,
  0x3fe0000000000002,
  0x3ff0000000000000,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000001,
  0xc000000000000000,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbca8000000000000,
  0xbca0000000000000,
  0x0000000000000000,
  0x3fdffffffffffffc,
  0x3fdffffffffffffe,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000002,
  0xc000000000000000,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfdfffffffffffff,
  0xbfdffffffffffffe,
  0xbfdffffffffffffc,
  0x0000000000000000,
  0x3ca0000000000000,
  0x3cb8000000000000,
  0x3fe0000000000001,
  0x4022000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbff7ffffffffffff,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbfffffffffffffff,
  0xc000000000000000,
  0xc000000000000000,
  0xc004000000000000,
  0xc026000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfdffffffffffffe,
  0xbca0000000000000,
  0x0000000000000000,
  0x3cb0000000000000,
  0x3fe0000000000000,
  0x4022000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xc000000000000000,
  0xc000000000000000,
  0xc000000000000000,
  0xc004000000000000,
  0xc026000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbfe0000000000002,
  0xbfe0000000000002,
  0xbfe0000000000001,
  0xbcb8000000000000,
  0xbcb0000000000000,
  0x0000000000000000,
  0x3fdffffffffffffc,
  0x4022000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff8000000000001,
  0xbff8000000000001,
  0xbff8000000000002,
  0xc000000000000000,
  0xc000000000000000,
  0xc000000000000001,
  0xc004000000000000,
  0xc026000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbfefffffffffffff,
  0xbfe0000000000001,
  0xbfe0000000000000,
  0xbfdffffffffffffc,
  0x0000000000000000,
  0x4021000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xc000000000000000,
  0xc000000000000000,
  0xc000000000000000,
  0xc004000000000000,
  0xc004000000000000,
  0xc004000000000000,
  0xc008000000000000,
  0xc027000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc023000000000000,
  0xc023000000000000,
  0xc023000000000000,
  0xc022000000000000,
  0xc022000000000000,
  0xc022000000000000,
  0xc021000000000000,
  0x0000000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc025000000000000,
  0xc025000000000000,
  0xc025000000000000,
  0xc026000000000000,
  0xc026000000000000,
  0xc026000000000000,
  0xc027000000000000,
  0xc034000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0x0000000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x800123456789abcd,
  0x000edcba98765433,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0000000000000000,
  0x000edcba98765432,
  0x800123456789abcc,
  0x800123456789abcd,
  0x801123456789abcd,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x8002468acf13579a,
  0x801123456789abcc,
  0x800123456789abce,
  0x800fffffffffffff,
  0x0000000000000001,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x800edcba98765432,
  0x0000000000000000,
  0x800ffffffffffffe,
  0x800fffffffffffff,
  0x801fffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x801123456789abcc,
  0x801ffffffffffffe,
  0x8010000000000000,
  0x8000000000000001,
  0x000fffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcc,
  0x000ffffffffffffe,
  0x0000000000000000,
  0x8000000000000001,
  0x8010000000000001,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abce,
  0x8010000000000000,
  0x8000000000000002,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0010000000000000,
  0x0020000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x001123456789abcd,
  0x001fffffffffffff,
  0x0010000000000001,
  0x0010000000000000,
  0x0000000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x000edcba98765433,
  0x0000000000000001,
  0x000fffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff7ffffffffffff,
  0x3ff8000000000000,
  0x3ff8000000000001,
  0x4000000000000000,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x0000000000000000,
  0xbc90000000000000,
  0xbca8000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000002,
  0xbff0000000000000,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000001,
  0x4000000000000000,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3c90000000000000,
  0x0000000000000000,
  0xbca0000000000000,
  0xbfdffffffffffffe,
  0xbfe0000000000000,
  0xbfe0000000000002,
  0xbff0000000000000,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000002,
  0x4000000000000000,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3ca8000000000000,
  0x3ca0000000000000,
  0x0000000000000000,
  0xbfdffffffffffffc,
  0xbfdffffffffffffe,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3ff7ffffffffffff,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3fffffffffffffff,
  0x4000000000000000,
  0x4000000000000000,
  0x4004000000000000,
  0x4026000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fdfffffffffffff,
  0x3fdffffffffffffe,
  0x3fdffffffffffffc,
  0x0000000000000000,
  0xbca0000000000000,
  0xbcb8000000000000,
  0xbfe0000000000001,
  0xc022000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x4000000000000000,
  0x4000000000000000,
  0x4000000000000000,
  0x4004000000000000,
  0x4026000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fdffffffffffffe,
  0x3ca0000000000000,
  0x0000000000000000,
  0xbcb0000000000000,
  0xbfe0000000000000,
  0xc022000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff8000000000001,
  0x3ff8000000000001,
  0x3ff8000000000002,
  0x4000000000000000,
  0x4000000000000000,
  0x4000000000000001,
  0x4004000000000000,
  0x4026000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3fe0000000000002,
  0x3fe0000000000002,
  0x3fe0000000000001,
  0x3cb8000000000000,
  0x3cb0000000000000,
  0x0000000000000000,
  0xbfdffffffffffffc,
  0xc022000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x4000000000000000,
  0x4000000000000000,
  0x4000000000000000,
  0x4004000000000000,
  0x4004000000000000,
  0x4004000000000000,
  0x4008000000000000,
  0x4027000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3fefffffffffffff,
  0x3fe0000000000001,
  0x3fe0000000000000,
  0x3fdffffffffffffc,
  0x0000000000000000,
  0xc021000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4025000000000000,
  0x4025000000000000,
  0x4025000000000000,
  0x4026000000000000,
  0x4026000000000000,
  0x4026000000000000,
  0x4027000000000000,
  0x4034000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4023000000000000,
  0x4023000000000000,
  0x4023000000000000,
  0x4022000000000000,
  0x4022000000000000,
  0x4022000000000000,
  0x4021000000000000,
  0x0000000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x0000000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x001123456789abcd,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0002468acf13579a,
  0x001123456789abcc,
  0x000123456789abce,
  0x000123456789abcd,
  0x800edcba98765433,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0000000000000000,
  0x800edcba98765432,
  0x000123456789abcc,
  0x000fffffffffffff,
  0x001fffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x001123456789abcc,
  0x001ffffffffffffe,
  0x0010000000000000,
  0x000fffffffffffff,
  0x8000000000000001,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x000edcba98765432,
  0x0000000000000000,
  0x000ffffffffffffe,
  0x0000000000000001,
  0x0010000000000001,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abce,
  0x0010000000000000,
  0x0000000000000002,
  0x0000000000000001,
  0x800fffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcc,
  0x800ffffffffffffe,
  0x0000000000000000,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8010000000000001,
  0x8000000000000001,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x800edcba98765434,
  0x8000000000000002,
  0x8010000000000000,
  0x8010000000000001,
  0x8020000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x801123456789abce,
  0x8020000000000000,
  0x8010000000000002,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbc9fffffffffffff,
  0xbc8ffffffffffffe,
  0x3c90000000000001,
  0x3fdffffffffffffd,
  0x3fdfffffffffffff,
  0x3fe0000000000002,
  0x3ff0000000000000,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000001,
  0xc000000000000000,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbca8000000000000,
  0xbca0000000000000,
  0x0000000000000000,
  0x3fdffffffffffffc,
  0x3fdffffffffffffe,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000002,
  0xc000000000000000,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000002,
  0xbfe0000000000002,
  0xbcb4000000000000,
  0xbcb0000000000000,
  0xbca0000000000001,
  0x3fdffffffffffffa,
  0x3fdffffffffffffc,
  0x3fe0000000000000,
  0x3feffffffffffffe,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe0000000000002,
  0xbfe0000000000002,
  0xbfe0000000000002,
  0xbfe0000000000002,
  0xbfe0000000000002,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000002,
  0xbff8000000000001,
  0xbff8000000000001,
  0xbff8000000000002,
  0xc000000000000001,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe0000000000002,
  0xbfe0000000000002,
  0xbfe0000000000002,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000000,
  0xbcafffffffffffff,
  0xbc9ffffffffffffe,
  0x3ca0000000000001,
  0x3fdffffffffffffe,
  0x4022000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000001,
  0xc000000000000000,
  0xc000000000000000,
  0xc000000000000001,
  0xc004000000000000,
  0xc026000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbfe0000000000002,
  0xbfe0000000000002,
  0xbfe0000000000001,
  0xbcb8000000000000,
  0xbcb0000000000000,
  0x0000000000000000,
  0x3fdffffffffffffc,
  0x4022000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff8000000000001,
  0xbff8000000000001,
  0xbff8000000000002,
  0xc000000000000000,
  0xc000000000000000,
  0xc000000000000001,
  0xc004000000000000,
  0xc026000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000002,
  0xbff0000000000002,
  0xbfe0000000000005,
  0xbfe0000000000004,
  0xbfe0000000000003,
  0xbcc4000000000000,
  0xbcc0000000000000,
  0xbcb0000000000001,
  0x3fdffffffffffff8,
  0x4022000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbff0000000000002,
  0xbff0000000000002,
  0xbff0000000000002,
  0xbff0000000000002,
  0xbff0000000000002,
  0xbff8000000000002,
  0xbff8000000000002,
  0xbff8000000000003,
  0xc000000000000001,
  0xc000000000000001,
  0xc000000000000002,
  0xc004000000000001,
  0xc026000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbff0000000000002,
  0xbff0000000000002,
  0xbff0000000000002,
  0xbff8000000000002,
  0xbff8000000000001,
  0xbff0000000000002,
  0xbff0000000000002,
  0xbff0000000000001,
  0xbfe0000000000004,
  0xbfe0000000000003,
  0xbfe0000000000001,
  0xbcb8000000000000,
  0x4021000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbff8000000000001,
  0xbff8000000000001,
  0xbff8000000000001,
  0xbff8000000000002,
  0xbff8000000000002,
  0xc000000000000001,
  0xc000000000000001,
  0xc000000000000001,
  0xc004000000000000,
  0xc004000000000001,
  0xc004000000000001,
  0xc008000000000001,
  0xc027000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbff8000000000002,
  0xbff8000000000002,
  0xbff8000000000002,
  0xc024000000000001,
  0xc024000000000001,
  0xc023000000000001,
  0xc023000000000001,
  0xc023000000000001,
  0xc022000000000001,
  0xc022000000000001,
  0xc022000000000001,
  0xc021000000000001,
  0xbce4000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc024000000000001,
  0xc024000000000001,
  0xc024000000000001,
  0xc024000000000001,
  0xc024000000000001,
  0xc025000000000001,
  0xc025000000000001,
  0xc025000000000001,
  0xc026000000000001,
  0xc026000000000001,
  0xc026000000000001,
  0xc027000000000001,
  0xc034000000000001,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc024000000000001,
  0xc024000000000001,
  0xc024000000000001,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfcafffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x800123456789abcd,
  0x000edcba98765433,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8000000000000000,
  0x000edcba98765432,
  0x800123456789abcc,
  0x800123456789abcd,
  0x801123456789abcd,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x8002468acf13579a,
  0x801123456789abcc,
  0x800123456789abce,
  0x8010000000000000,
  0x0000000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x800edcba98765433,
  0x8000000000000001,
  0x800fffffffffffff,
  0x8010000000000000,
  0x8020000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x801123456789abcd,
  0x801fffffffffffff,
  0x8010000000000001,
  0x8000000000000001,
  0x000fffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcc,
  0x000ffffffffffffe,
  0x8000000000000000,
  0x8000000000000001,
  0x8010000000000001,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abce,
  0x8010000000000000,
  0x8000000000000002,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0010000000000001,
  0x0020000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x001123456789abce,
  0x0020000000000000,
  0x0010000000000002,
  0x0010000000000001,
  0x0000000000000001,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x000edcba98765434,
  0x0000000000000002,
  0x0010000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000001,
  0x4000000000000000,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3c9fffffffffffff,
  0x3c8ffffffffffffe,
  0xbc90000000000001,
  0xbfdffffffffffffd,
  0xbfdfffffffffffff,
  0xbfe0000000000002,
  0xbff0000000000000,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000002,
  0x4000000000000000,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3ca8000000000000,
  0x3ca0000000000000,
  0x0000000000000000,
  0xbfdffffffffffffc,
  0xbfdffffffffffffe,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000002,
  0x3fe0000000000002,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000002,
  0x3ff8000000000001,
  0x3ff8000000000001,
  0x3ff8000000000002,
  0x4000000000000001,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe0000000000002,
  0x3fe0000000000002,
  0x3fe0000000000002,
  0x3fe0000000000002,
  0x3fe0000000000002,
  0x3cb4000000000000,
  0x3cb0000000000000,
  0x3ca0000000000001,
  0xbfdffffffffffffa,
  0xbfdffffffffffffc,
  0xbfe0000000000000,
  0xbfeffffffffffffe,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe0000000000002,
  0x3fe0000000000002,
  0x3fe0000000000002,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000001,
  0x4000000000000000,
  0x4000000000000000,
  0x4000000000000001,
  0x4004000000000000,
  0x4026000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000000,
  0x3cafffffffffffff,
  0x3c9ffffffffffffe,
  0xbca0000000000001,
  0xbfdffffffffffffe,
  0xc022000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff8000000000001,
  0x3ff8000000000001,
  0x3ff8000000000002,
  0x4000000000000000,
  0x4000000000000000,
  0x4000000000000001,
  0x4004000000000000,
  0x4026000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3fe0000000000002,
  0x3fe0000000000002,
  0x3fe0000000000001,
  0x3cb8000000000000,
  0x3cb0000000000000,
  0x0000000000000000,
  0xbfdffffffffffffc,
  0xc022000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000002,
  0x3ff0000000000002,
  0x3ff8000000000002,
  0x3ff8000000000002,
  0x3ff8000000000003,
  0x4000000000000001,
  0x4000000000000001,
  0x4000000000000002,
  0x4004000000000001,
  0x4026000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3ff0000000000002,
  0x3ff0000000000002,
  0x3ff0000000000002,
  0x3ff0000000000002,
  0x3ff0000000000002,
  0x3fe0000000000005,
  0x3fe0000000000004,
  0x3fe0000000000003,
  0x3cc4000000000000,
  0x3cc0000000000000,
  0x3cb0000000000001,
  0xbfdffffffffffff8,
  0xc022000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3ff0000000000002,
  0x3ff0000000000002,
  0x3ff0000000000002,
  0x3ff8000000000002,
  0x3ff8000000000002,
  0x4000000000000001,
  0x4000000000000001,
  0x4000000000000001,
  0x4004000000000000,
  0x4004000000000001,
  0x4004000000000001,
  0x4008000000000001,
  0x4027000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3ff8000000000002,
  0x3ff8000000000002,
  0x3ff8000000000002,
  0x3ff8000000000002,
  0x3ff8000000000001,
  0x3ff0000000000002,
  0x3ff0000000000002,
  0x3ff0000000000001,
  0x3fe0000000000004,
  0x3fe0000000000003,
  0x3fe0000000000001,
  0x3cb8000000000000,
  0xc021000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3ff8000000000001,
  0x3ff8000000000001,
  0x3ff8000000000001,
  0x4024000000000001,
  0x4024000000000001,
  0x4025000000000001,
  0x4025000000000001,
  0x4025000000000001,
  0x4026000000000001,
  0x4026000000000001,
  0x4026000000000001,
  0x4027000000000001,
  0x4034000000000001,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x4024000000000001,
  0x4024000000000001,
  0x4024000000000001,
  0x4024000000000001,
  0x4024000000000001,
  0x4023000000000001,
  0x4023000000000001,
  0x4023000000000001,
  0x4022000000000001,
  0x4022000000000001,
  0x4022000000000001,
  0x4021000000000001,
  0x3ce4000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x4024000000000001,
  0x4024000000000001,
  0x4024000000000001,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7cafffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x001123456789abcd,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0002468acf13579a,
  0x001123456789abcc,
  0x000123456789abce,
  0x000123456789abcd,
  0x800edcba98765433,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0000000000000000,
  0x800edcba98765432,
  0x000123456789abcc,
  0x0010000000000000,
  0x0020000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x001123456789abcd,
  0x001fffffffffffff,
  0x0010000000000001,
  0x0010000000000000,
  0x8000000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x000edcba98765433,
  0x0000000000000001,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0010000000000001,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abce,
  0x0010000000000000,
  0x0000000000000002,
  0x0000000000000001,
  0x800fffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcc,
  0x800ffffffffffffe,
  0x0000000000000000,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8018000000000000,
  0x8008000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8016dcba98765433,
  0x8008000000000001,
  0x8017ffffffffffff,
  0x8018000000000000,
  0x8024000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x801923456789abcd,
  0x8024000000000000,
  0x8018000000000001,
  0xbfe7ffffffffffff,
  0xbfe7ffffffffffff,
  0xbfcfffffffffffff,
  0xbfcffffffffffffd,
  0xbfcffffffffffff9,
  0x3fcfffffffffffff,
  0x3fd0000000000002,
  0x3fd0000000000006,
  0x3fe8000000000001,
  0x4022800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe7ffffffffffff,
  0xbfe7ffffffffffff,
  0xbfe7ffffffffffff,
  0xbfe7ffffffffffff,
  0xbfe7ffffffffffff,
  0xbff3ffffffffffff,
  0xbff4000000000000,
  0xbff4000000000000,
  0xbffbffffffffffff,
  0xbffc000000000000,
  0xbffc000000000001,
  0xc002000000000000,
  0xc025800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe7ffffffffffff,
  0xbfe7ffffffffffff,
  0xbfe7ffffffffffff,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbfd0000000000001,
  0xbfd0000000000000,
  0xbfcffffffffffffc,
  0x3fcffffffffffffc,
  0x3fd0000000000000,
  0x3fd0000000000004,
  0x3fe8000000000000,
  0x4022800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbff4000000000000,
  0xbff4000000000000,
  0xbff4000000000000,
  0xbffc000000000000,
  0xbffc000000000000,
  0xbffc000000000001,
  0xc002000000000000,
  0xc025800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbfe8000000000002,
  0xbfe8000000000001,
  0xbfd0000000000004,
  0xbfd0000000000003,
  0xbfd0000000000001,
  0x3fcffffffffffff6,
  0x3fcffffffffffffa,
  0x3fd0000000000001,
  0x3fe7fffffffffffe,
  0x4022800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe8000000000001,
  0xbfe8000000000001,
  0xbfe8000000000001,
  0xbfe8000000000002,
  0xbfe8000000000002,
  0xbff4000000000000,
  0xbff4000000000001,
  0xbff4000000000001,
  0xbffc000000000000,
  0xbffc000000000001,
  0xbffc000000000002,
  0xc002000000000000,
  0xc025800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe8000000000002,
  0xbfe8000000000002,
  0xbfe8000000000002,
  0xbff7ffffffffffff,
  0xbff7ffffffffffff,
  0xbfefffffffffffff,
  0xbfeffffffffffffe,
  0xbfeffffffffffffe,
  0xbfdfffffffffffff,
  0xbfdffffffffffffd,
  0xbfdffffffffffff9,
  0x3ca8000000000000,
  0x4021000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbff7ffffffffffff,
  0xbff7ffffffffffff,
  0xbff7ffffffffffff,
  0xbff7ffffffffffff,
  0xbff7ffffffffffff,
  0xbfffffffffffffff,
  0xbfffffffffffffff,
  0xc000000000000000,
  0xc003ffffffffffff,
  0xc004000000000000,
  0xc004000000000000,
  0xc008000000000000,
  0xc027000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbff7ffffffffffff,
  0xbff7ffffffffffff,
  0xbff7ffffffffffff,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbfefffffffffffff,
  0xbfe0000000000001,
  0xbfe0000000000000,
  0xbfdffffffffffffc,
  0x0000000000000000,
  0x4021000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xc000000000000000,
  0xc000000000000000,
  0xc000000000000000,
  0xc004000000000000,
  0xc004000000000000,
  0xc004000000000000,
  0xc008000000000000,
  0xc027000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000002,
  0xbff8000000000001,
  0xbff0000000000002,
  0xbff0000000000002,
  0xbff0000000000001,
  0xbfe0000000000004,
  0xbfe0000000000003,
  0xbfe0000000000001,
  0xbcb8000000000000,
  0x4021000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbff8000000000001,
  0xbff8000000000001,
  0xbff8000000000001,
  0xbff8000000000002,
  0xbff8000000000002,
  0xc000000000000001,
  0xc000000000000001,
  0xc000000000000001,
  0xc004000000000000,
  0xc004000000000001,
  0xc004000000000001,
  0xc008000000000001,
  0xc027000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbff8000000000002,
  0xbff8000000000002,
  0xbff8000000000002,
  0xc002000000000000,
  0xc002000000000000,
  0xbffc000000000000,
  0xbffc000000000000,
  0xbffc000000000000,
  0xbff4000000000000,
  0xbff4000000000000,
  0xbff3ffffffffffff,
  0xbfe8000000000000,
  0x401f000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc002000000000000,
  0xc002000000000000,
  0xc002000000000000,
  0xc002000000000000,
  0xc002000000000000,
  0xc006000000000000,
  0xc006000000000000,
  0xc006000000000000,
  0xc00a000000000000,
  0xc00a000000000000,
  0xc00a000000000000,
  0xc00e000000000000,
  0xc028800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc002000000000000,
  0xc002000000000000,
  0xc002000000000000,
  0xc02e000000000000,
  0xc02e000000000000,
  0xc02d000000000000,
  0xc02d000000000000,
  0xc02d000000000000,
  0xc02c000000000000,
  0xc02c000000000000,
  0xc02c000000000000,
  0xc02b000000000000,
  0xc014000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc02e000000000000,
  0xc02e000000000000,
  0xc02e000000000000,
  0xc02e000000000000,
  0xc02e000000000000,
  0xc02f000000000000,
  0xc02f000000000000,
  0xc02f000000000000,
  0xc030000000000000,
  0xc030000000000000,
  0xc030000000000000,
  0xc030800000000000,
  0xc039000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc02e000000000000,
  0xc02e000000000000,
  0xc02e000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xffdfffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x8001b4e81b4e81b4,
  0x000e4b17e4b17e4c,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x800091a2b3c4d5e6,
  0x000e4b17e4b17e4c,
  0x8001b4e81b4e81b2,
  0x8001b4e81b4e81b4,
  0x8011b4e81b4e81b4,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x8002d82d82d82d80,
  0x8011b4e81b4e81b2,
  0x8001b4e81b4e81b4,
  0x8017fffffffffffe,
  0x8007fffffffffffe,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8016dcba98765432,
  0x8008000000000000,
  0x8017fffffffffffe,
  0x8017fffffffffffe,
  0x8023ffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x801923456789abcc,
  0x8023ffffffffffff,
  0x8018000000000000,
  0x8000000000000002,
  0x000ffffffffffffe,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcc,
  0x000ffffffffffffe,
  0x8000000000000000,
  0x8000000000000002,
  0x8010000000000002,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abce,
  0x8010000000000000,
  0x8000000000000002,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0018000000000000,
  0x0024000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x001923456789abcd,
  0x0024000000000000,
  0x0018000000000001,
  0x0018000000000000,
  0x0008000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0016dcba98765433,
  0x0008000000000001,
  0x0017ffffffffffff,
  0x3fe7ffffffffffff,
  0x3fe7ffffffffffff,
  0x3ff3ffffffffffff,
  0x3ff4000000000000,
  0x3ff4000000000000,
  0x3ffbffffffffffff,
  0x3ffc000000000000,
  0x3ffc000000000001,
  0x4002000000000000,
  0x4025800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe7ffffffffffff,
  0x3fe7ffffffffffff,
  0x3fe7ffffffffffff,
  0x3fe7ffffffffffff,
  0x3fe7ffffffffffff,
  0x3fcfffffffffffff,
  0x3fcffffffffffffd,
  0x3fcffffffffffff9,
  0xbfcfffffffffffff,
  0xbfd0000000000002,
  0xbfd0000000000006,
  0xbfe8000000000001,
  0xc022800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe7ffffffffffff,
  0x3fe7ffffffffffff,
  0x3fe7ffffffffffff,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3ff4000000000000,
  0x3ff4000000000000,
  0x3ff4000000000000,
  0x3ffc000000000000,
  0x3ffc000000000000,
  0x3ffc000000000001,
  0x4002000000000000,
  0x4025800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3fd0000000000001,
  0x3fd0000000000000,
  0x3fcffffffffffffc,
  0xbfcffffffffffffc,
  0xbfd0000000000000,
  0xbfd0000000000004,
  0xbfe8000000000000,
  0xc022800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3fe8000000000002,
  0x3fe8000000000002,
  0x3ff4000000000000,
  0x3ff4000000000001,
  0x3ff4000000000001,
  0x3ffc000000000000,
  0x3ffc000000000001,
  0x3ffc000000000002,
  0x4002000000000000,
  0x4025800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe8000000000002,
  0x3fe8000000000002,
  0x3fe8000000000002,
  0x3fe8000000000002,
  0x3fe8000000000001,
  0x3fd0000000000004,
  0x3fd0000000000003,
  0x3fd0000000000001,
  0xbfcffffffffffff6,
  0xbfcffffffffffffa,
  0xbfd0000000000001,
  0xbfe7fffffffffffe,
  0xc022800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe8000000000001,
  0x3fe8000000000001,
  0x3fe8000000000001,
  0x3ff7ffffffffffff,
  0x3ff7ffffffffffff,
  0x3fffffffffffffff,
  0x3fffffffffffffff,
  0x4000000000000000,
  0x4003ffffffffffff,
  0x4004000000000000,
  0x4004000000000000,
  0x4008000000000000,
  0x4027000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3ff7ffffffffffff,
  0x3ff7ffffffffffff,
  0x3ff7ffffffffffff,
  0x3ff7ffffffffffff,
  0x3ff7ffffffffffff,
  0x3fefffffffffffff,
  0x3feffffffffffffe,
  0x3feffffffffffffe,
  0x3fdfffffffffffff,
  0x3fdffffffffffffd,
  0x3fdffffffffffff9,
  0xbca8000000000000,
  0xc021000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3ff7ffffffffffff,
  0x3ff7ffffffffffff,
  0x3ff7ffffffffffff,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x4000000000000000,
  0x4000000000000000,
  0x4000000000000000,
  0x4004000000000000,
  0x4004000000000000,
  0x4004000000000000,
  0x4008000000000000,
  0x4027000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3fefffffffffffff,
  0x3fe0000000000001,
  0x3fe0000000000000,
  0x3fdffffffffffffc,
  0x0000000000000000,
  0xc021000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000002,
  0x3ff8000000000002,
  0x4000000000000001,
  0x4000000000000001,
  0x4000000000000001,
  0x4004000000000000,
  0x4004000000000001,
  0x4004000000000001,
  0x4008000000000001,
  0x4027000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3ff8000000000002,
  0x3ff8000000000002,
  0x3ff8000000000002,
  0x3ff8000000000002,
  0x3ff8000000000001,
  0x3ff0000000000002,
  0x3ff0000000000002,
  0x3ff0000000000001,
  0x3fe0000000000004,
  0x3fe0000000000003,
  0x3fe0000000000001,
  0x3cb8000000000000,
  0xc021000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3ff8000000000001,
  0x3ff8000000000001,
  0x3ff8000000000001,
  0x4002000000000000,
  0x4002000000000000,
  0x4006000000000000,
  0x4006000000000000,
  0x4006000000000000,
  0x400a000000000000,
  0x400a000000000000,
  0x400a000000000000,
  0x400e000000000000,
  0x4028800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x4002000000000000,
  0x4002000000000000,
  0x4002000000000000,
  0x4002000000000000,
  0x4002000000000000,
  0x3ffc000000000000,
  0x3ffc000000000000,
  0x3ffc000000000000,
  0x3ff4000000000000,
  0x3ff4000000000000,
  0x3ff3ffffffffffff,
  0x3fe8000000000000,
  0xc01f000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x4002000000000000,
  0x4002000000000000,
  0x4002000000000000,
  0x402e000000000000,
  0x402e000000000000,
  0x402f000000000000,
  0x402f000000000000,
  0x402f000000000000,
  0x4030000000000000,
  0x4030000000000000,
  0x4030000000000000,
  0x4030800000000000,
  0x4039000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x402e000000000000,
  0x402e000000000000,
  0x402e000000000000,
  0x402e000000000000,
  0x402e000000000000,
  0x402d000000000000,
  0x402d000000000000,
  0x402d000000000000,
  0x402c000000000000,
  0x402c000000000000,
  0x402c000000000000,
  0x402b000000000000,
  0x4014000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x402e000000000000,
  0x402e000000000000,
  0x402e000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7fdfffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x0001b4e81b4e81b4,
  0x0011b4e81b4e81b4,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0002d82d82d82d80,
  0x0011b4e81b4e81b2,
  0x0001b4e81b4e81b4,
  0x0001b4e81b4e81b4,
  0x800e4b17e4b17e4c,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x000091a2b3c4d5e6,
  0x800e4b17e4b17e4c,
  0x0001b4e81b4e81b2,
  0x0017fffffffffffe,
  0x0023ffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x001923456789abcc,
  0x0023ffffffffffff,
  0x0018000000000000,
  0x0017fffffffffffe,
  0x0007fffffffffffe,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0016dcba98765432,
  0x0008000000000000,
  0x0017fffffffffffe,
  0x0000000000000002,
  0x0010000000000002,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abce,
  0x0010000000000000,
  0x0000000000000002,
  0x0000000000000002,
  0x800ffffffffffffe,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcc,
  0x800ffffffffffffe,
  0x0000000000000000,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8044000000000000,
  0x8042000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8043db97530eca86,
  0x8042000000000000,
  0x8044000000000000,
  0x8044000000000000,
  0x8046000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x80442468acf1357a,
  0x8046000000000000,
  0x8044000000000000,
  0xc013ffffffffffff,
  0xc013ffffffffffff,
  0xc011ffffffffffff,
  0xc011ffffffffffff,
  0xc011ffffffffffff,
  0xc00fffffffffffff,
  0xc00fffffffffffff,
  0xc00ffffffffffffe,
  0xc00bffffffffffff,
  0x4014000000000001,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc013ffffffffffff,
  0xc013ffffffffffff,
  0xc013ffffffffffff,
  0xc013ffffffffffff,
  0xc013ffffffffffff,
  0xc015ffffffffffff,
  0xc015ffffffffffff,
  0xc016000000000000,
  0xc017ffffffffffff,
  0xc017ffffffffffff,
  0xc018000000000000,
  0xc019ffffffffffff,
  0xc02e000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc013ffffffffffff,
  0xc013ffffffffffff,
  0xc013ffffffffffff,
  0xc014000000000000,
  0xc014000000000000,
  0xc012000000000000,
  0xc012000000000000,
  0xc012000000000000,
  0xc010000000000000,
  0xc010000000000000,
  0xc010000000000000,
  0xc00c000000000000,
  0x4014000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc014000000000000,
  0xc014000000000000,
  0xc014000000000000,
  0xc014000000000000,
  0xc014000000000000,
  0xc016000000000000,
  0xc016000000000000,
  0xc016000000000000,
  0xc018000000000000,
  0xc018000000000000,
  0xc018000000000000,
  0xc01a000000000000,
  0xc02e000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc014000000000000,
  0xc014000000000000,
  0xc014000000000000,
  0xc014000000000001,
  0xc014000000000001,
  0xc012000000000001,
  0xc012000000000001,
  0xc012000000000001,
  0xc010000000000001,
  0xc010000000000001,
  0xc010000000000001,
  0xc00c000000000002,
  0x4013ffffffffffff,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc014000000000001,
  0xc014000000000001,
  0xc014000000000001,
  0xc014000000000001,
  0xc014000000000001,
  0xc016000000000001,
  0xc016000000000001,
  0xc016000000000001,
  0xc018000000000001,
  0xc018000000000001,
  0xc018000000000002,
  0xc01a000000000001,
  0xc02e000000000001,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc014000000000001,
  0xc014000000000001,
  0xc014000000000001,
  0xc023ffffffffffff,
  0xc023ffffffffffff,
  0xc022ffffffffffff,
  0xc022ffffffffffff,
  0xc022ffffffffffff,
  0xc021ffffffffffff,
  0xc021ffffffffffff,
  0xc021ffffffffffff,
  0xc020ffffffffffff,
  0x3cd4000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc023ffffffffffff,
  0xc023ffffffffffff,
  0xc023ffffffffffff,
  0xc023ffffffffffff,
  0xc023ffffffffffff,
  0xc024ffffffffffff,
  0xc024ffffffffffff,
  0xc024ffffffffffff,
  0xc025ffffffffffff,
  0xc025ffffffffffff,
  0xc026000000000000,
  0xc026ffffffffffff,
  0xc034000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc023ffffffffffff,
  0xc023ffffffffffff,
  0xc023ffffffffffff,
  0xc024000000000000,
  0xc024000000000000,
  0xc023000000000000,
  0xc023000000000000,
  0xc023000000000000,
  0xc022000000000000,
  0xc022000000000000,
  0xc022000000000000,
  0xc021000000000000,
  0x0000000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc025000000000000,
  0xc025000000000000,
  0xc025000000000000,
  0xc026000000000000,
  0xc026000000000000,
  0xc026000000000000,
  0xc027000000000000,
  0xc034000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc024000000000001,
  0xc024000000000001,
  0xc023000000000001,
  0xc023000000000001,
  0xc023000000000001,
  0xc022000000000001,
  0xc022000000000001,
  0xc022000000000001,
  0xc021000000000001,
  0xbce4000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc024000000000001,
  0xc024000000000001,
  0xc024000000000001,
  0xc024000000000001,
  0xc024000000000001,
  0xc025000000000001,
  0xc025000000000001,
  0xc025000000000001,
  0xc026000000000001,
  0xc026000000000001,
  0xc026000000000001,
  0xc027000000000001,
  0xc034000000000001,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc024000000000001,
  0xc024000000000001,
  0xc024000000000001,
  0xc02e000000000000,
  0xc02e000000000000,
  0xc02d000000000000,
  0xc02d000000000000,
  0xc02d000000000000,
  0xc02c000000000000,
  0xc02c000000000000,
  0xc02c000000000000,
  0xc02b000000000000,
  0xc014000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc02e000000000000,
  0xc02e000000000000,
  0xc02e000000000000,
  0xc02e000000000000,
  0xc02e000000000000,
  0xc02f000000000000,
  0xc02f000000000000,
  0xc02f000000000000,
  0xc030000000000000,
  0xc030000000000000,
  0xc030000000000000,
  0xc030800000000000,
  0xc039000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc02e000000000000,
  0xc02e000000000000,
  0xc02e000000000000,
  0xc059000000000000,
  0xc059000000000000,
  0xc058e00000000000,
  0xc058e00000000000,
  0xc058e00000000000,
  0xc058c00000000000,
  0xc058c00000000000,
  0xc058c00000000000,
  0xc058a00000000000,
  0xc056800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc059000000000000,
  0xc059000000000000,
  0xc059000000000000,
  0xc059000000000000,
  0xc059000000000000,
  0xc059200000000000,
  0xc059200000000000,
  0xc059200000000000,
  0xc059400000000000,
  0xc059400000000000,
  0xc059400000000000,
  0xc059600000000000,
  0xc05b800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc059000000000000,
  0xc059000000000000,
  0xc059000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x800b60b60b60b602,
  0x00049f49f49f49fe,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x800a3d70a3d70a35,
  0x00049f49f49f49fd,
  0x800b60b60b60b601,
  0x800b60b60b60b602,
  0x801b60b60b60b602,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800c83fb72ea61cf,
  0x801b60b60b60b601,
  0x800b60b60b60b603,
  0x8043ffffffffffff,
  0x8041ffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8043db97530eca85,
  0x8041ffffffffffff,
  0x8043ffffffffffff,
  0x8043ffffffffffff,
  0x8045ffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x80442468acf13578,
  0x8045ffffffffffff,
  0x8043ffffffffffff,
  0x800000000000000a,
  0x000ffffffffffff6,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abc3,
  0x000ffffffffffff5,
  0x8000000000000009,
  0x800000000000000a,
  0x801000000000000a,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abd7,
  0x8010000000000009,
  0x800000000000000b,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0044000000000000,
  0x0046000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x00442468acf1357a,
  0x0046000000000000,
  0x0044000000000000,
  0x0044000000000000,
  0x0042000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0043db97530eca86,
  0x0042000000000000,
  0x0044000000000000,
  0x4013ffffffffffff,
  0x4013ffffffffffff,
  0x4015ffffffffffff,
  0x4015ffffffffffff,
  0x4016000000000000,
  0x4017ffffffffffff,
  0x4017ffffffffffff,
  0x4018000000000000,
  0x4019ffffffffffff,
  0x402e000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x4013ffffffffffff,
  0x4013ffffffffffff,
  0x4013ffffffffffff,
  0x4013ffffffffffff,
  0x4013ffffffffffff,
  0x4011ffffffffffff,
  0x4011ffffffffffff,
  0x4011ffffffffffff,
  0x400fffffffffffff,
  0x400fffffffffffff,
  0x400ffffffffffffe,
  0x400bffffffffffff,
  0xc014000000000001,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x4013ffffffffffff,
  0x4013ffffffffffff,
  0x4013ffffffffffff,
  0x4014000000000000,
  0x4014000000000000,
  0x4016000000000000,
  0x4016000000000000,
  0x4016000000000000,
  0x4018000000000000,
  0x4018000000000000,
  0x4018000000000000,
  0x401a000000000000,
  0x402e000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x4014000000000000,
  0x4014000000000000,
  0x4014000000000000,
  0x4014000000000000,
  0x4014000000000000,
  0x4012000000000000,
  0x4012000000000000,
  0x4012000000000000,
  0x4010000000000000,
  0x4010000000000000,
  0x4010000000000000,
  0x400c000000000000,
  0xc014000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x4014000000000000,
  0x4014000000000000,
  0x4014000000000000,
  0x4014000000000001,
  0x4014000000000001,
  0x4016000000000001,
  0x4016000000000001,
  0x4016000000000001,
  0x4018000000000001,
  0x4018000000000001,
  0x4018000000000002,
  0x401a000000000001,
  0x402e000000000001,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x4014000000000001,
  0x4014000000000001,
  0x4014000000000001,
  0x4014000000000001,
  0x4014000000000001,
  0x4012000000000001,
  0x4012000000000001,
  0x4012000000000001,
  0x4010000000000001,
  0x4010000000000001,
  0x4010000000000001,
  0x400c000000000002,
  0xc013ffffffffffff,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x4014000000000001,
  0x4014000000000001,
  0x4014000000000001,
  0x4023ffffffffffff,
  0x4023ffffffffffff,
  0x4024ffffffffffff,
  0x4024ffffffffffff,
  0x4024ffffffffffff,
  0x4025ffffffffffff,
  0x4025ffffffffffff,
  0x4026000000000000,
  0x4026ffffffffffff,
  0x4034000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x4023ffffffffffff,
  0x4023ffffffffffff,
  0x4023ffffffffffff,
  0x4023ffffffffffff,
  0x4023ffffffffffff,
  0x4022ffffffffffff,
  0x4022ffffffffffff,
  0x4022ffffffffffff,
  0x4021ffffffffffff,
  0x4021ffffffffffff,
  0x4021ffffffffffff,
  0x4020ffffffffffff,
  0xbcd4000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x4023ffffffffffff,
  0x4023ffffffffffff,
  0x4023ffffffffffff,
  0x4024000000000000,
  0x4024000000000000,
  0x4025000000000000,
  0x4025000000000000,
  0x4025000000000000,
  0x4026000000000000,
  0x4026000000000000,
  0x4026000000000000,
  0x4027000000000000,
  0x4034000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4023000000000000,
  0x4023000000000000,
  0x4023000000000000,
  0x4022000000000000,
  0x4022000000000000,
  0x4022000000000000,
  0x4021000000000000,
  0x0000000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4024000000000001,
  0x4024000000000001,
  0x4025000000000001,
  0x4025000000000001,
  0x4025000000000001,
  0x4026000000000001,
  0x4026000000000001,
  0x4026000000000001,
  0x4027000000000001,
  0x4034000000000001,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x4024000000000001,
  0x4024000000000001,
  0x4024000000000001,
  0x4024000000000001,
  0x4024000000000001,
  0x4023000000000001,
  0x4023000000000001,
  0x4023000000000001,
  0x4022000000000001,
  0x4022000000000001,
  0x4022000000000001,
  0x4021000000000001,
  0x3ce4000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x4024000000000001,
  0x4024000000000001,
  0x4024000000000001,
  0x402e000000000000,
  0x402e000000000000,
  0x402f000000000000,
  0x402f000000000000,
  0x402f000000000000,
  0x4030000000000000,
  0x4030000000000000,
  0x4030000000000000,
  0x4030800000000000,
  0x4039000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x402e000000000000,
  0x402e000000000000,
  0x402e000000000000,
  0x402e000000000000,
  0x402e000000000000,
  0x402d000000000000,
  0x402d000000000000,
  0x402d000000000000,
  0x402c000000000000,
  0x402c000000000000,
  0x402c000000000000,
  0x402b000000000000,
  0x4014000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x402e000000000000,
  0x402e000000000000,
  0x402e000000000000,
  0x4059000000000000,
  0x4059000000000000,
  0x4059200000000000,
  0x4059200000000000,
  0x4059200000000000,
  0x4059400000000000,
  0x4059400000000000,
  0x4059400000000000,
  0x4059600000000000,
  0x405b800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x4059000000000000,
  0x4059000000000000,
  0x4059000000000000,
  0x4059000000000000,
  0x4059000000000000,
  0x4058e00000000000,
  0x4058e00000000000,
  0x4058e00000000000,
  0x4058c00000000000,
  0x4058c00000000000,
  0x4058c00000000000,
  0x4058a00000000000,
  0x4056800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x4059000000000000,
  0x4059000000000000,
  0x4059000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x000b60b60b60b602,
  0x001b60b60b60b602,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000c83fb72ea61cf,
  0x001b60b60b60b601,
  0x000b60b60b60b603,
  0x000b60b60b60b602,
  0x80049f49f49f49fe,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x000a3d70a3d70a35,
  0x80049f49f49f49fd,
  0x000b60b60b60b601,
  0x0043ffffffffffff,
  0x0045ffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x00442468acf13578,
  0x0045ffffffffffff,
  0x0043ffffffffffff,
  0x0043ffffffffffff,
  0x0041ffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0043db97530eca85,
  0x0041ffffffffffff,
  0x0043ffffffffffff,
  0x000000000000000a,
  0x001000000000000a,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abd7,
  0x0010000000000009,
  0x000000000000000b,
  0x000000000000000a,
  0x800ffffffffffff6,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abc3,
  0x800ffffffffffff5,
  0x0000000000000009,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0xc00fffffffffffff,
  0xc00fffffffffffff,
  0xc00bffffffffffff,
  0xc00bffffffffffff,
  0xc00bffffffffffff,
  0xc007ffffffffffff,
  0xc007ffffffffffff,
  0xc007fffffffffffe,
  0xc003ffffffffffff,
  0x4018000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc00fffffffffffff,
  0xc00fffffffffffff,
  0xc00fffffffffffff,
  0xc00fffffffffffff,
  0xc00fffffffffffff,
  0xc011ffffffffffff,
  0xc012000000000000,
  0xc012000000000000,
  0xc013ffffffffffff,
  0xc014000000000000,
  0xc014000000000000,
  0xc016000000000000,
  0xc02c000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc00fffffffffffff,
  0xc00fffffffffffff,
  0xc00fffffffffffff,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0x7fe0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0x7fdfffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0x7fdffffffffffffd,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0x7c9fffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0x0000000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfcafffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xffdfffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xbfd23456789abccf,
  0xbfd23456789abccf,
  0x3fcb97530eca865f,
  0x3fcb97530eca8661,
  0x3fcb97530eca8665,
  0x3fe6e5d4c3b2a197,
  0x3fe6e5d4c3b2a198,
  0x3fe6e5d4c3b2a19a,
  0x3ff372ea61d950cc,
  0x40236e5d4c3b2a1a,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfd23456789abccf,
  0xbfd23456789abccf,
  0xbfd23456789abccf,
  0xbfd23456789abccf,
  0xbfd23456789abccf,
  0xbfe91a2b3c4d5e67,
  0xbfe91a2b3c4d5e68,
  0xbfe91a2b3c4d5e69,
  0xbff48d159e26af33,
  0xbff48d159e26af34,
  0xbff48d159e26af35,
  0xbffc8d159e26af34,
  0xc02491a2b3c4d5e6,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfd23456789abccf,
  0xbfd23456789abccf,
  0xbfd23456789abccf,
  0xc00ffffffffffffd,
  0xc00ffffffffffffd,
  0xc00bfffffffffffd,
  0xc00bfffffffffffd,
  0xc00bfffffffffffd,
  0xc007fffffffffffd,
  0xc007fffffffffffd,
  0xc007fffffffffffd,
  0xc003fffffffffffd,
  0x4018000000000001,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc00ffffffffffffd,
  0xc00ffffffffffffd,
  0xc00ffffffffffffd,
  0xc00ffffffffffffd,
  0xc00ffffffffffffd,
  0xc011fffffffffffe,
  0xc011ffffffffffff,
  0xc011ffffffffffff,
  0xc013fffffffffffe,
  0xc013ffffffffffff,
  0xc013ffffffffffff,
  0xc015ffffffffffff,
  0xc02bffffffffffff,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc00ffffffffffffd,
  0xc00ffffffffffffd,
  0xc00ffffffffffffd,
  0xbccfffffffffffff,
  0xbccfffffffffffff,
  0x3fdfffffffffffef,
  0x3fdffffffffffff0,
  0x3fdffffffffffff2,
  0x3feffffffffffff7,
  0x3feffffffffffff8,
  0x3feffffffffffffa,
  0x3ff7fffffffffffc,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbccfffffffffffff,
  0xbccfffffffffffff,
  0xbccfffffffffffff,
  0xbccfffffffffffff,
  0xbccfffffffffffff,
  0xbfe0000000000007,
  0xbfe0000000000008,
  0xbfe0000000000009,
  0xbff0000000000003,
  0xbff0000000000004,
  0xbff0000000000005,
  0xbff8000000000004,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbccfffffffffffff,
  0xbccfffffffffffff,
  0xbccfffffffffffff,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x400fffffffffffff,
  0x400fffffffffffff,
  0x4011ffffffffffff,
  0x4012000000000000,
  0x4012000000000000,
  0x4013ffffffffffff,
  0x4014000000000000,
  0x4014000000000000,
  0x4016000000000000,
  0x402c000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x400fffffffffffff,
  0x400fffffffffffff,
  0x400fffffffffffff,
  0x400fffffffffffff,
  0x400fffffffffffff,
  0x400bffffffffffff,
  0x400bffffffffffff,
  0x400bffffffffffff,
  0x4007ffffffffffff,
  0x4007ffffffffffff,
  0x4007fffffffffffe,
  0x4003ffffffffffff,
  0xc018000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x400fffffffffffff,
  0x400fffffffffffff,
  0x400fffffffffffff,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0xffe0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0xffdfffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0xffdffffffffffffd,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0xfc9fffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x0000000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7cafffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7fdfffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x3fd23456789abccf,
  0x3fd23456789abccf,
  0x3fe91a2b3c4d5e67,
  0x3fe91a2b3c4d5e68,
  0x3fe91a2b3c4d5e69,
  0x3ff48d159e26af33,
  0x3ff48d159e26af34,
  0x3ff48d159e26af35,
  0x3ffc8d159e26af34,
  0x402491a2b3c4d5e6,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fd23456789abccf,
  0x3fd23456789abccf,
  0x3fd23456789abccf,
  0x3fd23456789abccf,
  0x3fd23456789abccf,
  0xbfcb97530eca865f,
  0xbfcb97530eca8661,
  0xbfcb97530eca8665,
  0xbfe6e5d4c3b2a197,
  0xbfe6e5d4c3b2a198,
  0xbfe6e5d4c3b2a19a,
  0xbff372ea61d950cc,
  0xc0236e5d4c3b2a1a,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fd23456789abccf,
  0x3fd23456789abccf,
  0x3fd23456789abccf,
  0x400ffffffffffffd,
  0x400ffffffffffffd,
  0x4011fffffffffffe,
  0x4011ffffffffffff,
  0x4011ffffffffffff,
  0x4013fffffffffffe,
  0x4013ffffffffffff,
  0x4013ffffffffffff,
  0x4015ffffffffffff,
  0x402bffffffffffff,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x400ffffffffffffd,
  0x400ffffffffffffd,
  0x400ffffffffffffd,
  0x400ffffffffffffd,
  0x400ffffffffffffd,
  0x400bfffffffffffd,
  0x400bfffffffffffd,
  0x400bfffffffffffd,
  0x4007fffffffffffd,
  0x4007fffffffffffd,
  0x4007fffffffffffd,
  0x4003fffffffffffd,
  0xc018000000000001,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x400ffffffffffffd,
  0x400ffffffffffffd,
  0x400ffffffffffffd,
  0x3ccfffffffffffff,
  0x3ccfffffffffffff,
  0x3fe0000000000007,
  0x3fe0000000000008,
  0x3fe0000000000009,
  0x3ff0000000000003,
  0x3ff0000000000004,
  0x3ff0000000000005,
  0x3ff8000000000004,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3ccfffffffffffff,
  0x3ccfffffffffffff,
  0x3ccfffffffffffff,
  0x3ccfffffffffffff,
  0x3ccfffffffffffff,
  0xbfdfffffffffffef,
  0xbfdffffffffffff0,
  0xbfdffffffffffff2,
  0xbfeffffffffffff7,
  0xbfeffffffffffff8,
  0xbfeffffffffffffa,
  0xbff7fffffffffffc,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3ccfffffffffffff,
  0x3ccfffffffffffff,
  0x3ccfffffffffffff,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x800091a2b3c4d5e6,
  0x000f6e5d4c3b2a1a,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000091a2b3c4d5e7,
  0x000f6e5d4c3b2a19,
  0x800091a2b3c4d5e5,
  0x800091a2b3c4d5e6,
  0x801091a2b3c4d5e6,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x8001b4e81b4e81b3,
  0x801091a2b3c4d5e5,
  0x800091a2b3c4d5e7,
  0x800091a2b3c4d5e6,
  0x000f6e5d4c3b2a1a,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000091a2b3c4d5e6,
  0x000f6e5d4c3b2a18,
  0x800091a2b3c4d5e6,
  0x800091a2b3c4d5e6,
  0x801091a2b3c4d5e6,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x8001b4e81b4e81b4,
  0x801091a2b3c4d5e6,
  0x800091a2b3c4d5e8,
  0x800091a2b3c4d5e7,
  0x000f6e5d4c3b2a19,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000091a2b3c4d5e6,
  0x000f6e5d4c3b2a18,
  0x800091a2b3c4d5e6,
  0x800091a2b3c4d5e7,
  0x801091a2b3c4d5e7,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x8001b4e81b4e81b4,
  0x801091a2b3c4d5e6,
  0x800091a2b3c4d5e8,
  0x800123456789abcd,
  0x000edcba98765433,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0000000000000000,
  0x000edcba98765432,
  0x800123456789abcc,
  0x800123456789abcd,
  0x801123456789abcd,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x8002468acf13579a,
  0x801123456789abcc,
  0x800123456789abce,
  0x800123456789abcd,
  0x000edcba98765433,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0000000000000000,
  0x000edcba98765432,
  0x800123456789abcc,
  0x800123456789abcd,
  0x801123456789abcd,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x8002468acf13579a,
  0x801123456789abcc,
  0x800123456789abce,
  0x800123456789abcd,
  0x000edcba98765433,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8000000000000000,
  0x000edcba98765432,
  0x800123456789abcc,
  0x800123456789abcd,
  0x801123456789abcd,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x8002468acf13579a,
  0x801123456789abcc,
  0x800123456789abce,
  0x8001b4e81b4e81b4,
  0x000e4b17e4b17e4c,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x800091a2b3c4d5e6,
  0x000e4b17e4b17e4c,
  0x8001b4e81b4e81b2,
  0x8001b4e81b4e81b4,
  0x8011b4e81b4e81b4,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x8002d82d82d82d80,
  0x8011b4e81b4e81b2,
  0x8001b4e81b4e81b4,
  0x800b60b60b60b602,
  0x00049f49f49f49fe,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x800a3d70a3d70a35,
  0x00049f49f49f49fd,
  0x800b60b60b60b601,
  0x800b60b60b60b602,
  0x801b60b60b60b602,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800c83fb72ea61cf,
  0x801b60b60b60b601,
  0x800b60b60b60b603,
  0xbfd23456789abccf,
  0xbfd23456789abccf,
  0x3fcb97530eca865f,
  0x3fcb97530eca8661,
  0x3fcb97530eca8665,
  0x3fe6e5d4c3b2a197,
  0x3fe6e5d4c3b2a198,
  0x3fe6e5d4c3b2a19a,
  0x3ff372ea61d950cc,
  0x40236e5d4c3b2a1a,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfd23456789abccf,
  0xbfd23456789abccf,
  0xbfd23456789abccf,
  0xbfd23456789abccf,
  0xbfd23456789abccf,
  0xbfe91a2b3c4d5e67,
  0xbfe91a2b3c4d5e68,
  0xbfe91a2b3c4d5e69,
  0xbff48d159e26af33,
  0xbff48d159e26af34,
  0xbff48d159e26af35,
  0xbffc8d159e26af34,
  0xc02491a2b3c4d5e6,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfd23456789abccf,
  0xbfd23456789abccf,
  0xbfd23456789abccf,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x000091a2b3c4d5e6,
  0x001091a2b3c4d5e6,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0001b4e81b4e81b3,
  0x001091a2b3c4d5e5,
  0x000091a2b3c4d5e7,
  0x000091a2b3c4d5e6,
  0x800f6e5d4c3b2a1a,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800091a2b3c4d5e7,
  0x800f6e5d4c3b2a19,
  0x000091a2b3c4d5e5,
  0x000091a2b3c4d5e6,
  0x001091a2b3c4d5e6,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0001b4e81b4e81b4,
  0x001091a2b3c4d5e6,
  0x000091a2b3c4d5e8,
  0x000091a2b3c4d5e6,
  0x800f6e5d4c3b2a1a,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800091a2b3c4d5e6,
  0x800f6e5d4c3b2a18,
  0x000091a2b3c4d5e6,
  0x000091a2b3c4d5e7,
  0x001091a2b3c4d5e7,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0001b4e81b4e81b4,
  0x001091a2b3c4d5e6,
  0x000091a2b3c4d5e8,
  0x000091a2b3c4d5e7,
  0x800f6e5d4c3b2a19,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800091a2b3c4d5e6,
  0x800f6e5d4c3b2a18,
  0x000091a2b3c4d5e6,
  0x000123456789abcd,
  0x001123456789abcd,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0002468acf13579a,
  0x001123456789abcc,
  0x000123456789abce,
  0x000123456789abcd,
  0x800edcba98765433,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x8000000000000000,
  0x800edcba98765432,
  0x000123456789abcc,
  0x000123456789abcd,
  0x001123456789abcd,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0002468acf13579a,
  0x001123456789abcc,
  0x000123456789abce,
  0x000123456789abcd,
  0x800edcba98765433,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0000000000000000,
  0x800edcba98765432,
  0x000123456789abcc,
  0x000123456789abcd,
  0x001123456789abcd,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0002468acf13579a,
  0x001123456789abcc,
  0x000123456789abce,
  0x000123456789abcd,
  0x800edcba98765433,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0000000000000000,
  0x800edcba98765432,
  0x000123456789abcc,
  0x0001b4e81b4e81b4,
  0x0011b4e81b4e81b4,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0002d82d82d82d80,
  0x0011b4e81b4e81b2,
  0x0001b4e81b4e81b4,
  0x0001b4e81b4e81b4,
  0x800e4b17e4b17e4c,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x000091a2b3c4d5e6,
  0x800e4b17e4b17e4c,
  0x0001b4e81b4e81b2,
  0x000b60b60b60b602,
  0x001b60b60b60b602,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000c83fb72ea61cf,
  0x001b60b60b60b601,
  0x000b60b60b60b603,
  0x000b60b60b60b602,
  0x80049f49f49f49fe,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x000a3d70a3d70a35,
  0x80049f49f49f49fd,
  0x000b60b60b60b601,
  0x3fd23456789abccf,
  0x3fd23456789abccf,
  0x3fe91a2b3c4d5e67,
  0x3fe91a2b3c4d5e68,
  0x3fe91a2b3c4d5e69,
  0x3ff48d159e26af33,
  0x3ff48d159e26af34,
  0x3ff48d159e26af35,
  0x3ffc8d159e26af34,
  0x402491a2b3c4d5e6,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fd23456789abccf,
  0x3fd23456789abccf,
  0x3fd23456789abccf,
  0x3fd23456789abccf,
  0x3fd23456789abccf,
  0xbfcb97530eca865f,
  0xbfcb97530eca8661,
  0xbfcb97530eca8665,
  0xbfe6e5d4c3b2a197,
  0xbfe6e5d4c3b2a198,
  0xbfe6e5d4c3b2a19a,
  0xbff372ea61d950cc,
  0xc0236e5d4c3b2a1a,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fd23456789abccf,
  0x3fd23456789abccf,
  0x3fd23456789abccf,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8007ffffffffffff,
  0x0008000000000001,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8006dcba98765432,
  0x0008000000000000,
  0x8007fffffffffffe,
  0x8007ffffffffffff,
  0x8017ffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800923456789abcc,
  0x8017fffffffffffe,
  0x8008000000000000,
  0x8008000000000000,
  0x0008000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8006dcba98765432,
  0x0008000000000000,
  0x8007fffffffffffe,
  0x8008000000000000,
  0x8018000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800923456789abcc,
  0x8017fffffffffffe,
  0x8008000000000000,
  0x8008000000000000,
  0x0008000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8006dcba98765433,
  0x0007ffffffffffff,
  0x8007ffffffffffff,
  0x8008000000000000,
  0x8018000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800923456789abcd,
  0x8017ffffffffffff,
  0x8008000000000001,
  0x800fffffffffffff,
  0x0000000000000001,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x800edcba98765432,
  0x0000000000000000,
  0x800ffffffffffffe,
  0x800fffffffffffff,
  0x801fffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x801123456789abcc,
  0x801ffffffffffffe,
  0x8010000000000000,
  0x800fffffffffffff,
  0x0000000000000001,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x800edcba98765432,
  0x0000000000000000,
  0x800ffffffffffffe,
  0x800fffffffffffff,
  0x801fffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x801123456789abcc,
  0x801ffffffffffffe,
  0x8010000000000000,
  0x8010000000000000,
  0x0000000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x800edcba98765433,
  0x8000000000000001,
  0x800fffffffffffff,
  0x8010000000000000,
  0x8020000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x801123456789abcd,
  0x801fffffffffffff,
  0x8010000000000001,
  0x8017fffffffffffe,
  0x8007fffffffffffe,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8016dcba98765432,
  0x8008000000000000,
  0x8017fffffffffffe,
  0x8017fffffffffffe,
  0x8023ffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x801923456789abcc,
  0x8023ffffffffffff,
  0x8018000000000000,
  0x8043ffffffffffff,
  0x8041ffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8043db97530eca85,
  0x8041ffffffffffff,
  0x8043ffffffffffff,
  0x8043ffffffffffff,
  0x8045ffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x80442468acf13578,
  0x8045ffffffffffff,
  0x8043ffffffffffff,
  0xc00ffffffffffffd,
  0xc00ffffffffffffd,
  0xc00bfffffffffffd,
  0xc00bfffffffffffd,
  0xc00bfffffffffffd,
  0xc007fffffffffffd,
  0xc007fffffffffffd,
  0xc007fffffffffffd,
  0xc003fffffffffffd,
  0x4018000000000001,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc00ffffffffffffd,
  0xc00ffffffffffffd,
  0xc00ffffffffffffd,
  0xc00ffffffffffffd,
  0xc00ffffffffffffd,
  0xc011fffffffffffe,
  0xc011ffffffffffff,
  0xc011ffffffffffff,
  0xc013fffffffffffe,
  0xc013ffffffffffff,
  0xc013ffffffffffff,
  0xc015ffffffffffff,
  0xc02bffffffffffff,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc00ffffffffffffd,
  0xc00ffffffffffffd,
  0xc00ffffffffffffd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0007ffffffffffff,
  0x0017ffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000923456789abcc,
  0x0017fffffffffffe,
  0x0008000000000000,
  0x0007ffffffffffff,
  0x8008000000000001,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0006dcba98765432,
  0x8008000000000000,
  0x0007fffffffffffe,
  0x0008000000000000,
  0x0018000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000923456789abcc,
  0x0017fffffffffffe,
  0x0008000000000000,
  0x0008000000000000,
  0x8008000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0006dcba98765432,
  0x8008000000000000,
  0x0007fffffffffffe,
  0x0008000000000000,
  0x0018000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000923456789abcd,
  0x0017ffffffffffff,
  0x0008000000000001,
  0x0008000000000000,
  0x8008000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0006dcba98765433,
  0x8007ffffffffffff,
  0x0007ffffffffffff,
  0x000fffffffffffff,
  0x001fffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x001123456789abcc,
  0x001ffffffffffffe,
  0x0010000000000000,
  0x000fffffffffffff,
  0x8000000000000001,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x000edcba98765432,
  0x8000000000000000,
  0x000ffffffffffffe,
  0x000fffffffffffff,
  0x001fffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x001123456789abcc,
  0x001ffffffffffffe,
  0x0010000000000000,
  0x000fffffffffffff,
  0x8000000000000001,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x000edcba98765432,
  0x0000000000000000,
  0x000ffffffffffffe,
  0x0010000000000000,
  0x0020000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x001123456789abcd,
  0x001fffffffffffff,
  0x0010000000000001,
  0x0010000000000000,
  0x8000000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x000edcba98765433,
  0x0000000000000001,
  0x000fffffffffffff,
  0x0017fffffffffffe,
  0x0023ffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x001923456789abcc,
  0x0023ffffffffffff,
  0x0018000000000000,
  0x0017fffffffffffe,
  0x0007fffffffffffe,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0016dcba98765432,
  0x0008000000000000,
  0x0017fffffffffffe,
  0x0043ffffffffffff,
  0x0045ffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x00442468acf13578,
  0x0045ffffffffffff,
  0x0043ffffffffffff,
  0x0043ffffffffffff,
  0x0041ffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0043db97530eca85,
  0x0041ffffffffffff,
  0x0043ffffffffffff,
  0x400ffffffffffffd,
  0x400ffffffffffffd,
  0x4011fffffffffffe,
  0x4011ffffffffffff,
  0x4011ffffffffffff,
  0x4013fffffffffffe,
  0x4013ffffffffffff,
  0x4013ffffffffffff,
  0x4015ffffffffffff,
  0x402bffffffffffff,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x400ffffffffffffd,
  0x400ffffffffffffd,
  0x400ffffffffffffd,
  0x400ffffffffffffd,
  0x400ffffffffffffd,
  0x400bfffffffffffd,
  0x400bfffffffffffd,
  0x400bfffffffffffd,
  0x4007fffffffffffd,
  0x4007fffffffffffd,
  0x4007fffffffffffd,
  0x4003fffffffffffd,
  0xc018000000000001,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x400ffffffffffffd,
  0x400ffffffffffffd,
  0x400ffffffffffffd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcc,
  0x000ffffffffffffe,
  0x0000000000000000,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abce,
  0x8010000000000000,
  0x8000000000000002,
  0x8000000000000001,
  0x000fffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcc,
  0x000ffffffffffffe,
  0x0000000000000000,
  0x8000000000000001,
  0x8010000000000001,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abce,
  0x8010000000000000,
  0x8000000000000002,
  0x8000000000000001,
  0x000fffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcc,
  0x000ffffffffffffe,
  0x0000000000000000,
  0x8000000000000001,
  0x8010000000000001,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abce,
  0x8010000000000000,
  0x8000000000000002,
  0x8000000000000001,
  0x000fffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcc,
  0x000ffffffffffffe,
  0x0000000000000000,
  0x8000000000000001,
  0x8010000000000001,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abce,
  0x8010000000000000,
  0x8000000000000002,
  0x8000000000000001,
  0x000fffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcc,
  0x000ffffffffffffe,
  0x8000000000000000,
  0x8000000000000001,
  0x8010000000000001,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abce,
  0x8010000000000000,
  0x8000000000000002,
  0x8000000000000002,
  0x000ffffffffffffe,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcc,
  0x000ffffffffffffe,
  0x8000000000000000,
  0x8000000000000002,
  0x8010000000000002,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abce,
  0x8010000000000000,
  0x8000000000000002,
  0x800000000000000a,
  0x000ffffffffffff6,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abc3,
  0x000ffffffffffff5,
  0x8000000000000009,
  0x800000000000000a,
  0x801000000000000a,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abd7,
  0x8010000000000009,
  0x800000000000000b,
  0xbccfffffffffffff,
  0xbccfffffffffffff,
  0x3fdfffffffffffef,
  0x3fdffffffffffff0,
  0x3fdffffffffffff2,
  0x3feffffffffffff7,
  0x3feffffffffffff8,
  0x3feffffffffffffa,
  0x3ff7fffffffffffc,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbccfffffffffffff,
  0xbccfffffffffffff,
  0xbccfffffffffffff,
  0xbccfffffffffffff,
  0xbccfffffffffffff,
  0xbfe0000000000007,
  0xbfe0000000000008,
  0xbfe0000000000009,
  0xbff0000000000003,
  0xbff0000000000004,
  0xbff0000000000005,
  0xbff8000000000004,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbccfffffffffffff,
  0xbccfffffffffffff,
  0xbccfffffffffffff,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abce,
  0x0010000000000000,
  0x0000000000000002,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcc,
  0x800ffffffffffffe,
  0x8000000000000000,
  0x0000000000000001,
  0x0010000000000001,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abce,
  0x0010000000000000,
  0x0000000000000002,
  0x0000000000000001,
  0x800fffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcc,
  0x800ffffffffffffe,
  0x8000000000000000,
  0x0000000000000001,
  0x0010000000000001,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abce,
  0x0010000000000000,
  0x0000000000000002,
  0x0000000000000001,
  0x800fffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcc,
  0x800ffffffffffffe,
  0x8000000000000000,
  0x0000000000000001,
  0x0010000000000001,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abce,
  0x0010000000000000,
  0x0000000000000002,
  0x0000000000000001,
  0x800fffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcc,
  0x800ffffffffffffe,
  0x0000000000000000,
  0x0000000000000001,
  0x0010000000000001,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abce,
  0x0010000000000000,
  0x0000000000000002,
  0x0000000000000001,
  0x800fffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcc,
  0x800ffffffffffffe,
  0x0000000000000000,
  0x0000000000000002,
  0x0010000000000002,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abce,
  0x0010000000000000,
  0x0000000000000002,
  0x0000000000000002,
  0x800ffffffffffffe,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcc,
  0x800ffffffffffffe,
  0x0000000000000000,
  0x000000000000000a,
  0x001000000000000a,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abd7,
  0x0010000000000009,
  0x000000000000000b,
  0x000000000000000a,
  0x800ffffffffffff6,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abc3,
  0x800ffffffffffff5,
  0x0000000000000009,
  0x3ccfffffffffffff,
  0x3ccfffffffffffff,
  0x3fe0000000000007,
  0x3fe0000000000008,
  0x3fe0000000000009,
  0x3ff0000000000003,
  0x3ff0000000000004,
  0x3ff0000000000005,
  0x3ff8000000000004,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3ccfffffffffffff,
  0x3ccfffffffffffff,
  0x3ccfffffffffffff,
  0x3ccfffffffffffff,
  0x3ccfffffffffffff,
  0xbfdfffffffffffef,
  0xbfdffffffffffff0,
  0xbfdffffffffffff2,
  0xbfeffffffffffff7,
  0xbfeffffffffffff8,
  0xbfeffffffffffffa,
  0xbff7fffffffffffc,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3ccfffffffffffff,
  0x3ccfffffffffffff,
  0x3ccfffffffffffff,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0008000000000000,
  0x0018000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000923456789abcd,
  0x0017ffffffffffff,
  0x0008000000000001,
  0x0008000000000000,
  0x8008000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0006dcba98765433,
  0x8007ffffffffffff,
  0x0007ffffffffffff,
  0x0008000000000000,
  0x0018000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000923456789abcd,
  0x0017ffffffffffff,
  0x0008000000000001,
  0x0008000000000000,
  0x8008000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0006dcba98765433,
  0x8007ffffffffffff,
  0x0007ffffffffffff,
  0x0008000000000000,
  0x0018000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000923456789abce,
  0x0018000000000000,
  0x0008000000000002,
  0x0008000000000000,
  0x8008000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0006dcba98765434,
  0x8007fffffffffffe,
  0x0008000000000000,
  0x0010000000000000,
  0x0020000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x001123456789abcc,
  0x001ffffffffffffe,
  0x0010000000000000,
  0x0010000000000000,
  0x8000000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x000edcba98765432,
  0x0000000000000000,
  0x000ffffffffffffe,
  0x0010000000000000,
  0x0020000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x001123456789abcd,
  0x001fffffffffffff,
  0x0010000000000001,
  0x0010000000000000,
  0x0000000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x000edcba98765433,
  0x0000000000000001,
  0x000fffffffffffff,
  0x0010000000000001,
  0x0020000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x001123456789abce,
  0x0020000000000000,
  0x0010000000000002,
  0x0010000000000001,
  0x0000000000000001,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x000edcba98765434,
  0x0000000000000002,
  0x0010000000000000,
  0x0018000000000000,
  0x0024000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x001923456789abcd,
  0x0024000000000000,
  0x0018000000000001,
  0x0018000000000000,
  0x0008000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0016dcba98765433,
  0x0008000000000001,
  0x0017ffffffffffff,
  0x0044000000000000,
  0x0046000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x00442468acf1357a,
  0x0046000000000000,
  0x0044000000000000,
  0x0044000000000000,
  0x0042000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0043db97530eca86,
  0x0042000000000000,
  0x0044000000000000,
  0x400fffffffffffff,
  0x400fffffffffffff,
  0x4011ffffffffffff,
  0x4012000000000000,
  0x4012000000000000,
  0x4013ffffffffffff,
  0x4014000000000000,
  0x4014000000000000,
  0x4016000000000000,
  0x402c000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x400fffffffffffff,
  0x400fffffffffffff,
  0x400fffffffffffff,
  0x400fffffffffffff,
  0x400fffffffffffff,
  0x400bffffffffffff,
  0x400bffffffffffff,
  0x400bffffffffffff,
  0x4007ffffffffffff,
  0x4007ffffffffffff,
  0x4007fffffffffffe,
  0x4003ffffffffffff,
  0xc018000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x400fffffffffffff,
  0x400fffffffffffff,
  0x400fffffffffffff,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8008000000000000,
  0x0008000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8006dcba98765433,
  0x0007ffffffffffff,
  0x8007ffffffffffff,
  0x8008000000000000,
  0x8018000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800923456789abcd,
  0x8017ffffffffffff,
  0x8008000000000001,
  0x8008000000000000,
  0x0008000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8006dcba98765433,
  0x0007ffffffffffff,
  0x8007ffffffffffff,
  0x8008000000000000,
  0x8018000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800923456789abcd,
  0x8017ffffffffffff,
  0x8008000000000001,
  0x8008000000000000,
  0x0008000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8006dcba98765434,
  0x0007fffffffffffe,
  0x8008000000000000,
  0x8008000000000000,
  0x8018000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800923456789abce,
  0x8018000000000000,
  0x8008000000000002,
  0x8010000000000000,
  0x0000000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x800edcba98765432,
  0x8000000000000000,
  0x800ffffffffffffe,
  0x8010000000000000,
  0x8020000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x801123456789abcc,
  0x801ffffffffffffe,
  0x8010000000000000,
  0x8010000000000000,
  0x0000000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x800edcba98765433,
  0x8000000000000001,
  0x800fffffffffffff,
  0x8010000000000000,
  0x8020000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x801123456789abcd,
  0x801fffffffffffff,
  0x8010000000000001,
  0x8010000000000001,
  0x8000000000000001,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x800edcba98765434,
  0x8000000000000002,
  0x8010000000000000,
  0x8010000000000001,
  0x8020000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x801123456789abce,
  0x8020000000000000,
  0x8010000000000002,
  0x8018000000000000,
  0x8008000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8016dcba98765433,
  0x8008000000000001,
  0x8017ffffffffffff,
  0x8018000000000000,
  0x8024000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x801923456789abcd,
  0x8024000000000000,
  0x8018000000000001,
  0x8044000000000000,
  0x8042000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8043db97530eca86,
  0x8042000000000000,
  0x8044000000000000,
  0x8044000000000000,
  0x8046000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x80442468acf1357a,
  0x8046000000000000,
  0x8044000000000000,
  0xc00fffffffffffff,
  0xc00fffffffffffff,
  0xc00bffffffffffff,
  0xc00bffffffffffff,
  0xc00bffffffffffff,
  0xc007ffffffffffff,
  0xc007ffffffffffff,
  0xc007fffffffffffe,
  0xc003ffffffffffff,
  0x4018000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc00fffffffffffff,
  0xc00fffffffffffff,
  0xc00fffffffffffff,
  0xc00fffffffffffff,
  0xc00fffffffffffff,
  0xc011ffffffffffff,
  0xc012000000000000,
  0xc012000000000000,
  0xc013ffffffffffff,
  0xc014000000000000,
  0xc014000000000000,
  0xc016000000000000,
  0xc02c000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc00fffffffffffff,
  0xc00fffffffffffff,
  0xc00fffffffffffff,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0008000000000000,
  0x0018000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000923456789abcd,
  0x0017ffffffffffff,
  0x0008000000000001,
  0x0008000000000000,
  0x8008000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0006dcba98765433,
  0x8007ffffffffffff,
  0x0007ffffffffffff,
  0x3fcffffffffffffe,
  0x3fcffffffffffffe,
  0x3fe7ffffffffffff,
  0x3fe8000000000000,
  0x3fe8000000000001,
  0x3ff3ffffffffffff,
  0x3ff4000000000000,
  0x3ff4000000000001,
  0x3ffc000000000000,
  0x4024800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fcffffffffffffe,
  0x3fcffffffffffffe,
  0x3fcffffffffffffe,
  0x3fcffffffffffffe,
  0x3fcffffffffffffe,
  0xbfd0000000000000,
  0xbfd0000000000001,
  0xbfd0000000000003,
  0xbfe7ffffffffffff,
  0xbfe8000000000000,
  0xbfe8000000000002,
  0xbff4000000000000,
  0xc023800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fcffffffffffffe,
  0x3fcffffffffffffe,
  0x3fcffffffffffffe,
  0x3fcfffffffffffff,
  0x3fcfffffffffffff,
  0x3fe7ffffffffffff,
  0x3fe8000000000000,
  0x3fe8000000000001,
  0x3ff3ffffffffffff,
  0x3ff4000000000000,
  0x3ff4000000000001,
  0x3ffc000000000000,
  0x4024800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fcfffffffffffff,
  0x3fcfffffffffffff,
  0x3fcfffffffffffff,
  0x3fcfffffffffffff,
  0x3fcfffffffffffff,
  0xbfcfffffffffffff,
  0xbfd0000000000000,
  0xbfd0000000000002,
  0xbfe7ffffffffffff,
  0xbfe8000000000000,
  0xbfe8000000000002,
  0xbff4000000000000,
  0xc023800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fcfffffffffffff,
  0x3fcfffffffffffff,
  0x3fcfffffffffffff,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3fe8000000000001,
  0x3ff4000000000000,
  0x3ff4000000000000,
  0x3ff4000000000001,
  0x3ffc000000000000,
  0x4024800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0xbfcffffffffffffd,
  0xbfcfffffffffffff,
  0xbfd0000000000002,
  0xbfe7ffffffffffff,
  0xbfe8000000000000,
  0xbfe8000000000002,
  0xbff4000000000000,
  0xc023800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fdffffffffffffe,
  0x3fdffffffffffffe,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff7ffffffffffff,
  0x3ff8000000000000,
  0x3ff8000000000001,
  0x4000000000000000,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fdffffffffffffe,
  0x3fdffffffffffffe,
  0x3fdffffffffffffe,
  0x3fdffffffffffffe,
  0x3fdffffffffffffe,
  0xbc8fffffffffffff,
  0xbca0000000000000,
  0xbcb0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000003,
  0xbff0000000000000,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fdffffffffffffe,
  0x3fdffffffffffffe,
  0x3fdffffffffffffe,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff7ffffffffffff,
  0x3ff8000000000000,
  0x3ff8000000000001,
  0x4000000000000000,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x0000000000000000,
  0xbc90000000000000,
  0xbca8000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000002,
  0xbff0000000000000,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000001,
  0x4000000000000000,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3c9fffffffffffff,
  0x3c8ffffffffffffe,
  0xbc90000000000001,
  0xbfdffffffffffffd,
  0xbfdfffffffffffff,
  0xbfe0000000000002,
  0xbff0000000000000,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe7ffffffffffff,
  0x3fe7ffffffffffff,
  0x3ff3ffffffffffff,
  0x3ff4000000000000,
  0x3ff4000000000000,
  0x3ffbffffffffffff,
  0x3ffc000000000000,
  0x3ffc000000000001,
  0x4002000000000000,
  0x4025800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe7ffffffffffff,
  0x3fe7ffffffffffff,
  0x3fe7ffffffffffff,
  0x3fe7ffffffffffff,
  0x3fe7ffffffffffff,
  0x3fcfffffffffffff,
  0x3fcffffffffffffd,
  0x3fcffffffffffff9,
  0xbfcfffffffffffff,
  0xbfd0000000000002,
  0xbfd0000000000006,
  0xbfe8000000000001,
  0xc022800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe7ffffffffffff,
  0x3fe7ffffffffffff,
  0x3fe7ffffffffffff,
  0x4013ffffffffffff,
  0x4013ffffffffffff,
  0x4015ffffffffffff,
  0x4015ffffffffffff,
  0x4016000000000000,
  0x4017ffffffffffff,
  0x4017ffffffffffff,
  0x4018000000000000,
  0x4019ffffffffffff,
  0x402e000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x4013ffffffffffff,
  0x4013ffffffffffff,
  0x4013ffffffffffff,
  0x4013ffffffffffff,
  0x4013ffffffffffff,
  0x4011ffffffffffff,
  0x4011ffffffffffff,
  0x4011ffffffffffff,
  0x400fffffffffffff,
  0x400fffffffffffff,
  0x400ffffffffffffe,
  0x400bffffffffffff,
  0xc014000000000001,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x4013ffffffffffff,
  0x4013ffffffffffff,
  0x4013ffffffffffff,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0xffe0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x000091a2b3c4d5e6,
  0x001091a2b3c4d5e6,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0001b4e81b4e81b3,
  0x001091a2b3c4d5e5,
  0x000091a2b3c4d5e7,
  0x000091a2b3c4d5e6,
  0x800f6e5d4c3b2a1a,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800091a2b3c4d5e7,
  0x800f6e5d4c3b2a19,
  0x000091a2b3c4d5e5,
  0x0007ffffffffffff,
  0x0017ffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000923456789abcc,
  0x0017fffffffffffe,
  0x0008000000000000,
  0x0007ffffffffffff,
  0x8008000000000001,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0006dcba98765432,
  0x8008000000000000,
  0x0007fffffffffffe,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8008000000000000,
  0x0008000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8006dcba98765433,
  0x0007ffffffffffff,
  0x8007ffffffffffff,
  0x8008000000000000,
  0x8018000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800923456789abcd,
  0x8017ffffffffffff,
  0x8008000000000001,
  0xbfcffffffffffffe,
  0xbfcffffffffffffe,
  0x3fd0000000000000,
  0x3fd0000000000001,
  0x3fd0000000000003,
  0x3fe7ffffffffffff,
  0x3fe8000000000000,
  0x3fe8000000000002,
  0x3ff4000000000000,
  0x4023800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfcffffffffffffe,
  0xbfcffffffffffffe,
  0xbfcffffffffffffe,
  0xbfcffffffffffffe,
  0xbfcffffffffffffe,
  0xbfe7ffffffffffff,
  0xbfe8000000000000,
  0xbfe8000000000001,
  0xbff3ffffffffffff,
  0xbff4000000000000,
  0xbff4000000000001,
  0xbffc000000000000,
  0xc024800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfcffffffffffffe,
  0xbfcffffffffffffe,
  0xbfcffffffffffffe,
  0xbfcfffffffffffff,
  0xbfcfffffffffffff,
  0x3fcfffffffffffff,
  0x3fd0000000000000,
  0x3fd0000000000002,
  0x3fe7ffffffffffff,
  0x3fe8000000000000,
  0x3fe8000000000002,
  0x3ff4000000000000,
  0x4023800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfcfffffffffffff,
  0xbfcfffffffffffff,
  0xbfcfffffffffffff,
  0xbfcfffffffffffff,
  0xbfcfffffffffffff,
  0xbfe7ffffffffffff,
  0xbfe8000000000000,
  0xbfe8000000000001,
  0xbff3ffffffffffff,
  0xbff4000000000000,
  0xbff4000000000001,
  0xbffc000000000000,
  0xc024800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfcfffffffffffff,
  0xbfcfffffffffffff,
  0xbfcfffffffffffff,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0x3fcffffffffffffd,
  0x3fcfffffffffffff,
  0x3fd0000000000002,
  0x3fe7ffffffffffff,
  0x3fe8000000000000,
  0x3fe8000000000002,
  0x3ff4000000000000,
  0x4023800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbfe8000000000001,
  0xbff4000000000000,
  0xbff4000000000000,
  0xbff4000000000001,
  0xbffc000000000000,
  0xc024800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfdffffffffffffe,
  0xbfdffffffffffffe,
  0x3c8fffffffffffff,
  0x3ca0000000000000,
  0x3cb0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000003,
  0x3ff0000000000000,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfdffffffffffffe,
  0xbfdffffffffffffe,
  0xbfdffffffffffffe,
  0xbfdffffffffffffe,
  0xbfdffffffffffffe,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff7ffffffffffff,
  0xbff8000000000000,
  0xbff8000000000001,
  0xc000000000000000,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfdffffffffffffe,
  0xbfdffffffffffffe,
  0xbfdffffffffffffe,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0x0000000000000000,
  0x3c90000000000000,
  0x3ca8000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000002,
  0x3ff0000000000000,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff7ffffffffffff,
  0xbff8000000000000,
  0xbff8000000000001,
  0xc000000000000000,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbc9fffffffffffff,
  0xbc8ffffffffffffe,
  0x3c90000000000001,
  0x3fdffffffffffffd,
  0x3fdfffffffffffff,
  0x3fe0000000000002,
  0x3ff0000000000000,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000001,
  0xc000000000000000,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe7ffffffffffff,
  0xbfe7ffffffffffff,
  0xbfcfffffffffffff,
  0xbfcffffffffffffd,
  0xbfcffffffffffff9,
  0x3fcfffffffffffff,
  0x3fd0000000000002,
  0x3fd0000000000006,
  0x3fe8000000000001,
  0x4022800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe7ffffffffffff,
  0xbfe7ffffffffffff,
  0xbfe7ffffffffffff,
  0xbfe7ffffffffffff,
  0xbfe7ffffffffffff,
  0xbff3ffffffffffff,
  0xbff4000000000000,
  0xbff4000000000000,
  0xbffbffffffffffff,
  0xbffc000000000000,
  0xbffc000000000001,
  0xc002000000000000,
  0xc025800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe7ffffffffffff,
  0xbfe7ffffffffffff,
  0xbfe7ffffffffffff,
  0xc013ffffffffffff,
  0xc013ffffffffffff,
  0xc011ffffffffffff,
  0xc011ffffffffffff,
  0xc011ffffffffffff,
  0xc00fffffffffffff,
  0xc00fffffffffffff,
  0xc00ffffffffffffe,
  0xc00bffffffffffff,
  0x4014000000000001,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc013ffffffffffff,
  0xc013ffffffffffff,
  0xc013ffffffffffff,
  0xc013ffffffffffff,
  0xc013ffffffffffff,
  0xc015ffffffffffff,
  0xc015ffffffffffff,
  0xc016000000000000,
  0xc017ffffffffffff,
  0xc017ffffffffffff,
  0xc018000000000000,
  0xc019ffffffffffff,
  0xc02e000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc013ffffffffffff,
  0xc013ffffffffffff,
  0xc013ffffffffffff,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0x7fe0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x800091a2b3c4d5e6,
  0x000f6e5d4c3b2a1a,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000091a2b3c4d5e7,
  0x000f6e5d4c3b2a19,
  0x800091a2b3c4d5e5,
  0x800091a2b3c4d5e6,
  0x801091a2b3c4d5e6,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x8001b4e81b4e81b3,
  0x801091a2b3c4d5e5,
  0x800091a2b3c4d5e7,
  0x8007ffffffffffff,
  0x0008000000000001,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8006dcba98765432,
  0x0008000000000000,
  0x8007fffffffffffe,
  0x8007ffffffffffff,
  0x8017ffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800923456789abcc,
  0x8017fffffffffffe,
  0x8008000000000000,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0008000000000000,
  0x0018000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000923456789abcd,
  0x0017ffffffffffff,
  0x0008000000000001,
  0x0008000000000000,
  0x8008000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0006dcba98765433,
  0x8007ffffffffffff,
  0x0007ffffffffffff,
  0x3fcfffffffffffff,
  0x3fcfffffffffffff,
  0x3fe7ffffffffffff,
  0x3fe8000000000000,
  0x3fe8000000000001,
  0x3ff3ffffffffffff,
  0x3ff4000000000000,
  0x3ff4000000000001,
  0x3ffc000000000000,
  0x4024800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fcfffffffffffff,
  0x3fcfffffffffffff,
  0x3fcfffffffffffff,
  0x3fcfffffffffffff,
  0x3fcfffffffffffff,
  0xbfcfffffffffffff,
  0xbfd0000000000000,
  0xbfd0000000000002,
  0xbfe7ffffffffffff,
  0xbfe8000000000000,
  0xbfe8000000000002,
  0xbff4000000000000,
  0xc023800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fcfffffffffffff,
  0x3fcfffffffffffff,
  0x3fcfffffffffffff,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3fe8000000000001,
  0x3ff4000000000000,
  0x3ff4000000000000,
  0x3ff4000000000001,
  0x3ffc000000000000,
  0x4024800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0xbfcffffffffffffe,
  0xbfd0000000000000,
  0xbfd0000000000002,
  0xbfe7ffffffffffff,
  0xbfe8000000000000,
  0xbfe8000000000002,
  0xbff4000000000000,
  0xc023800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000001,
  0x3fd0000000000001,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3fe8000000000002,
  0x3ff4000000000000,
  0x3ff4000000000000,
  0x3ff4000000000001,
  0x3ffc000000000000,
  0x4024800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fd0000000000001,
  0x3fd0000000000001,
  0x3fd0000000000001,
  0x3fd0000000000001,
  0x3fd0000000000001,
  0xbfcffffffffffffc,
  0xbfcffffffffffffe,
  0xbfd0000000000001,
  0xbfe7fffffffffffe,
  0xbfe8000000000000,
  0xbfe8000000000002,
  0xbff4000000000000,
  0xc023800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fd0000000000001,
  0x3fd0000000000001,
  0x3fd0000000000001,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff7ffffffffffff,
  0x3ff8000000000000,
  0x3ff8000000000001,
  0x4000000000000000,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x0000000000000000,
  0xbc90000000000000,
  0xbca8000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000002,
  0xbff0000000000000,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000001,
  0x4000000000000000,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3c90000000000000,
  0x0000000000000000,
  0xbca0000000000000,
  0xbfdffffffffffffe,
  0xbfe0000000000000,
  0xbfe0000000000002,
  0xbff0000000000000,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000002,
  0x4000000000000000,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3ca8000000000000,
  0x3ca0000000000000,
  0x0000000000000000,
  0xbfdffffffffffffc,
  0xbfdffffffffffffe,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3ff4000000000000,
  0x3ff4000000000000,
  0x3ff4000000000000,
  0x3ffc000000000000,
  0x3ffc000000000000,
  0x3ffc000000000001,
  0x4002000000000000,
  0x4025800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3fd0000000000001,
  0x3fd0000000000000,
  0x3fcffffffffffffc,
  0xbfcffffffffffffc,
  0xbfd0000000000000,
  0xbfd0000000000004,
  0xbfe8000000000000,
  0xc022800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x4014000000000000,
  0x4014000000000000,
  0x4016000000000000,
  0x4016000000000000,
  0x4016000000000000,
  0x4018000000000000,
  0x4018000000000000,
  0x4018000000000000,
  0x401a000000000000,
  0x402e000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x4014000000000000,
  0x4014000000000000,
  0x4014000000000000,
  0x4014000000000000,
  0x4014000000000000,
  0x4012000000000000,
  0x4012000000000000,
  0x4012000000000000,
  0x4010000000000000,
  0x4010000000000000,
  0x4010000000000000,
  0x400c000000000000,
  0xc014000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x4014000000000000,
  0x4014000000000000,
  0x4014000000000000,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0xffdfffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x000091a2b3c4d5e6,
  0x001091a2b3c4d5e6,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0001b4e81b4e81b4,
  0x001091a2b3c4d5e6,
  0x000091a2b3c4d5e8,
  0x000091a2b3c4d5e6,
  0x800f6e5d4c3b2a1a,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800091a2b3c4d5e6,
  0x800f6e5d4c3b2a18,
  0x000091a2b3c4d5e6,
  0x0008000000000000,
  0x0018000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000923456789abcc,
  0x0017fffffffffffe,
  0x0008000000000000,
  0x0008000000000000,
  0x8008000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0006dcba98765432,
  0x8008000000000000,
  0x0007fffffffffffe,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abce,
  0x0010000000000000,
  0x0000000000000002,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcc,
  0x800ffffffffffffe,
  0x8000000000000000,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8008000000000000,
  0x0008000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8006dcba98765433,
  0x0007ffffffffffff,
  0x8007ffffffffffff,
  0x8008000000000000,
  0x8018000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800923456789abcd,
  0x8017ffffffffffff,
  0x8008000000000001,
  0xbfcfffffffffffff,
  0xbfcfffffffffffff,
  0x3fcfffffffffffff,
  0x3fd0000000000000,
  0x3fd0000000000002,
  0x3fe7ffffffffffff,
  0x3fe8000000000000,
  0x3fe8000000000002,
  0x3ff4000000000000,
  0x4023800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfcfffffffffffff,
  0xbfcfffffffffffff,
  0xbfcfffffffffffff,
  0xbfcfffffffffffff,
  0xbfcfffffffffffff,
  0xbfe7ffffffffffff,
  0xbfe8000000000000,
  0xbfe8000000000001,
  0xbff3ffffffffffff,
  0xbff4000000000000,
  0xbff4000000000001,
  0xbffc000000000000,
  0xc024800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfcfffffffffffff,
  0xbfcfffffffffffff,
  0xbfcfffffffffffff,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0x3fcffffffffffffe,
  0x3fd0000000000000,
  0x3fd0000000000002,
  0x3fe7ffffffffffff,
  0x3fe8000000000000,
  0x3fe8000000000002,
  0x3ff4000000000000,
  0x4023800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbfe8000000000001,
  0xbff4000000000000,
  0xbff4000000000000,
  0xbff4000000000001,
  0xbffc000000000000,
  0xc024800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000001,
  0xbfd0000000000001,
  0x3fcffffffffffffc,
  0x3fcffffffffffffe,
  0x3fd0000000000001,
  0x3fe7fffffffffffe,
  0x3fe8000000000000,
  0x3fe8000000000002,
  0x3ff4000000000000,
  0x4023800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfd0000000000001,
  0xbfd0000000000001,
  0xbfd0000000000001,
  0xbfd0000000000001,
  0xbfd0000000000001,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbfe8000000000002,
  0xbff4000000000000,
  0xbff4000000000000,
  0xbff4000000000001,
  0xbffc000000000000,
  0xc024800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfd0000000000001,
  0xbfd0000000000001,
  0xbfd0000000000001,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0x0000000000000000,
  0x3c90000000000000,
  0x3ca8000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000002,
  0x3ff0000000000000,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff7ffffffffffff,
  0xbff8000000000000,
  0xbff8000000000001,
  0xc000000000000000,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbc90000000000000,
  0x0000000000000000,
  0x3ca0000000000000,
  0x3fdffffffffffffe,
  0x3fe0000000000000,
  0x3fe0000000000002,
  0x3ff0000000000000,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000001,
  0xc000000000000000,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbca8000000000000,
  0xbca0000000000000,
  0x0000000000000000,
  0x3fdffffffffffffc,
  0x3fdffffffffffffe,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000002,
  0xc000000000000000,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbfd0000000000001,
  0xbfd0000000000000,
  0xbfcffffffffffffc,
  0x3fcffffffffffffc,
  0x3fd0000000000000,
  0x3fd0000000000004,
  0x3fe8000000000000,
  0x4022800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbff4000000000000,
  0xbff4000000000000,
  0xbff4000000000000,
  0xbffc000000000000,
  0xbffc000000000000,
  0xbffc000000000001,
  0xc002000000000000,
  0xc025800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xc014000000000000,
  0xc014000000000000,
  0xc012000000000000,
  0xc012000000000000,
  0xc012000000000000,
  0xc010000000000000,
  0xc010000000000000,
  0xc010000000000000,
  0xc00c000000000000,
  0x4014000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc014000000000000,
  0xc014000000000000,
  0xc014000000000000,
  0xc014000000000000,
  0xc014000000000000,
  0xc016000000000000,
  0xc016000000000000,
  0xc016000000000000,
  0xc018000000000000,
  0xc018000000000000,
  0xc018000000000000,
  0xc01a000000000000,
  0xc02e000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc014000000000000,
  0xc014000000000000,
  0xc014000000000000,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0x7fdfffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x800091a2b3c4d5e6,
  0x000f6e5d4c3b2a1a,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000091a2b3c4d5e6,
  0x000f6e5d4c3b2a18,
  0x800091a2b3c4d5e6,
  0x800091a2b3c4d5e6,
  0x801091a2b3c4d5e6,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x8001b4e81b4e81b4,
  0x801091a2b3c4d5e6,
  0x800091a2b3c4d5e8,
  0x8008000000000000,
  0x0008000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8006dcba98765432,
  0x0008000000000000,
  0x8007fffffffffffe,
  0x8008000000000000,
  0x8018000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800923456789abcc,
  0x8017fffffffffffe,
  0x8008000000000000,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcc,
  0x000ffffffffffffe,
  0x0000000000000000,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abce,
  0x8010000000000000,
  0x8000000000000002,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0008000000000000,
  0x0018000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000923456789abce,
  0x0018000000000000,
  0x0008000000000002,
  0x0008000000000000,
  0x8008000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0006dcba98765434,
  0x8007fffffffffffe,
  0x0008000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3fe8000000000001,
  0x3ff4000000000000,
  0x3ff4000000000000,
  0x3ff4000000000001,
  0x3ffc000000000000,
  0x4024800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0xbfcffffffffffffd,
  0xbfcfffffffffffff,
  0xbfd0000000000002,
  0xbfe7ffffffffffff,
  0xbfe8000000000000,
  0xbfe8000000000002,
  0xbff4000000000000,
  0xc023800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000001,
  0x3fd0000000000001,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3fe8000000000002,
  0x3ff4000000000000,
  0x3ff4000000000000,
  0x3ff4000000000001,
  0x3ffc000000000000,
  0x4024800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fd0000000000001,
  0x3fd0000000000001,
  0x3fd0000000000001,
  0x3fd0000000000001,
  0x3fd0000000000001,
  0xbfcffffffffffffc,
  0xbfcffffffffffffe,
  0xbfd0000000000001,
  0xbfe7fffffffffffe,
  0xbfe8000000000000,
  0xbfe8000000000002,
  0xbff4000000000000,
  0xc023800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fd0000000000001,
  0x3fd0000000000001,
  0x3fd0000000000001,
  0x3fd0000000000002,
  0x3fd0000000000002,
  0x3fe8000000000001,
  0x3fe8000000000001,
  0x3fe8000000000002,
  0x3ff4000000000000,
  0x3ff4000000000001,
  0x3ff4000000000002,
  0x3ffc000000000001,
  0x4024800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fd0000000000002,
  0x3fd0000000000002,
  0x3fd0000000000002,
  0x3fd0000000000002,
  0x3fd0000000000002,
  0xbfcffffffffffffa,
  0xbfcffffffffffffc,
  0xbfd0000000000000,
  0xbfe7fffffffffffe,
  0xbfe7ffffffffffff,
  0xbfe8000000000001,
  0xbff3ffffffffffff,
  0xc023800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fd0000000000002,
  0x3fd0000000000002,
  0x3fd0000000000002,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000001,
  0x4000000000000000,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3c9fffffffffffff,
  0x3c8ffffffffffffe,
  0xbc90000000000001,
  0xbfdffffffffffffd,
  0xbfdfffffffffffff,
  0xbfe0000000000002,
  0xbff0000000000000,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000002,
  0x4000000000000000,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3ca8000000000000,
  0x3ca0000000000000,
  0x0000000000000000,
  0xbfdffffffffffffc,
  0xbfdffffffffffffe,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000002,
  0x3fe0000000000002,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000002,
  0x3ff8000000000001,
  0x3ff8000000000001,
  0x3ff8000000000002,
  0x4000000000000001,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe0000000000002,
  0x3fe0000000000002,
  0x3fe0000000000002,
  0x3fe0000000000002,
  0x3fe0000000000002,
  0x3cb4000000000000,
  0x3cb0000000000000,
  0x3ca0000000000001,
  0xbfdffffffffffffa,
  0xbfdffffffffffffc,
  0xbfe0000000000000,
  0xbfeffffffffffffe,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe0000000000002,
  0x3fe0000000000002,
  0x3fe0000000000002,
  0x3fe8000000000002,
  0x3fe8000000000002,
  0x3ff4000000000000,
  0x3ff4000000000001,
  0x3ff4000000000001,
  0x3ffc000000000000,
  0x3ffc000000000001,
  0x3ffc000000000002,
  0x4002000000000000,
  0x4025800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe8000000000002,
  0x3fe8000000000002,
  0x3fe8000000000002,
  0x3fe8000000000002,
  0x3fe8000000000001,
  0x3fd0000000000004,
  0x3fd0000000000003,
  0x3fd0000000000001,
  0xbfcffffffffffff6,
  0xbfcffffffffffffa,
  0xbfd0000000000001,
  0xbfe7fffffffffffe,
  0xc022800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe8000000000001,
  0x3fe8000000000001,
  0x3fe8000000000001,
  0x4014000000000001,
  0x4014000000000001,
  0x4016000000000001,
  0x4016000000000001,
  0x4016000000000001,
  0x4018000000000001,
  0x4018000000000001,
  0x4018000000000002,
  0x401a000000000001,
  0x402e000000000001,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x4014000000000001,
  0x4014000000000001,
  0x4014000000000001,
  0x4014000000000001,
  0x4014000000000001,
  0x4012000000000001,
  0x4012000000000001,
  0x4012000000000001,
  0x4010000000000001,
  0x4010000000000001,
  0x4010000000000001,
  0x400c000000000002,
  0xc013ffffffffffff,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x4014000000000001,
  0x4014000000000001,
  0x4014000000000001,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0xffdffffffffffffd,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x000091a2b3c4d5e7,
  0x001091a2b3c4d5e7,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0001b4e81b4e81b4,
  0x001091a2b3c4d5e6,
  0x000091a2b3c4d5e8,
  0x000091a2b3c4d5e7,
  0x800f6e5d4c3b2a19,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800091a2b3c4d5e6,
  0x800f6e5d4c3b2a18,
  0x000091a2b3c4d5e6,
  0x0008000000000000,
  0x0018000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000923456789abcd,
  0x0017ffffffffffff,
  0x0008000000000001,
  0x0008000000000000,
  0x8008000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0006dcba98765433,
  0x8007ffffffffffff,
  0x0007ffffffffffff,
  0x0000000000000001,
  0x0010000000000001,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abce,
  0x0010000000000000,
  0x0000000000000002,
  0x0000000000000001,
  0x800fffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcc,
  0x800ffffffffffffe,
  0x8000000000000000,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8008000000000000,
  0x0008000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8006dcba98765434,
  0x0007fffffffffffe,
  0x8008000000000000,
  0x8008000000000000,
  0x8018000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800923456789abce,
  0x8018000000000000,
  0x8008000000000002,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0x3fcffffffffffffd,
  0x3fcfffffffffffff,
  0x3fd0000000000002,
  0x3fe7ffffffffffff,
  0x3fe8000000000000,
  0x3fe8000000000002,
  0x3ff4000000000000,
  0x4023800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbfe8000000000001,
  0xbff4000000000000,
  0xbff4000000000000,
  0xbff4000000000001,
  0xbffc000000000000,
  0xc024800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000001,
  0xbfd0000000000001,
  0x3fcffffffffffffc,
  0x3fcffffffffffffe,
  0x3fd0000000000001,
  0x3fe7fffffffffffe,
  0x3fe8000000000000,
  0x3fe8000000000002,
  0x3ff4000000000000,
  0x4023800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfd0000000000001,
  0xbfd0000000000001,
  0xbfd0000000000001,
  0xbfd0000000000001,
  0xbfd0000000000001,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbfe8000000000002,
  0xbff4000000000000,
  0xbff4000000000000,
  0xbff4000000000001,
  0xbffc000000000000,
  0xc024800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfd0000000000001,
  0xbfd0000000000001,
  0xbfd0000000000001,
  0xbfd0000000000002,
  0xbfd0000000000002,
  0x3fcffffffffffffa,
  0x3fcffffffffffffc,
  0x3fd0000000000000,
  0x3fe7fffffffffffe,
  0x3fe7ffffffffffff,
  0x3fe8000000000001,
  0x3ff3ffffffffffff,
  0x4023800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfd0000000000002,
  0xbfd0000000000002,
  0xbfd0000000000002,
  0xbfd0000000000002,
  0xbfd0000000000002,
  0xbfe8000000000001,
  0xbfe8000000000001,
  0xbfe8000000000002,
  0xbff4000000000000,
  0xbff4000000000001,
  0xbff4000000000002,
  0xbffc000000000001,
  0xc024800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfd0000000000002,
  0xbfd0000000000002,
  0xbfd0000000000002,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbc9fffffffffffff,
  0xbc8ffffffffffffe,
  0x3c90000000000001,
  0x3fdffffffffffffd,
  0x3fdfffffffffffff,
  0x3fe0000000000002,
  0x3ff0000000000000,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000001,
  0xc000000000000000,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbca8000000000000,
  0xbca0000000000000,
  0x0000000000000000,
  0x3fdffffffffffffc,
  0x3fdffffffffffffe,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000002,
  0xc000000000000000,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000002,
  0xbfe0000000000002,
  0xbcb4000000000000,
  0xbcb0000000000000,
  0xbca0000000000001,
  0x3fdffffffffffffa,
  0x3fdffffffffffffc,
  0x3fe0000000000000,
  0x3feffffffffffffe,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe0000000000002,
  0xbfe0000000000002,
  0xbfe0000000000002,
  0xbfe0000000000002,
  0xbfe0000000000002,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000002,
  0xbff8000000000001,
  0xbff8000000000001,
  0xbff8000000000002,
  0xc000000000000001,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe0000000000002,
  0xbfe0000000000002,
  0xbfe0000000000002,
  0xbfe8000000000002,
  0xbfe8000000000001,
  0xbfd0000000000004,
  0xbfd0000000000003,
  0xbfd0000000000001,
  0x3fcffffffffffff6,
  0x3fcffffffffffffa,
  0x3fd0000000000001,
  0x3fe7fffffffffffe,
  0x4022800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe8000000000001,
  0xbfe8000000000001,
  0xbfe8000000000001,
  0xbfe8000000000002,
  0xbfe8000000000002,
  0xbff4000000000000,
  0xbff4000000000001,
  0xbff4000000000001,
  0xbffc000000000000,
  0xbffc000000000001,
  0xbffc000000000002,
  0xc002000000000000,
  0xc025800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe8000000000002,
  0xbfe8000000000002,
  0xbfe8000000000002,
  0xc014000000000001,
  0xc014000000000001,
  0xc012000000000001,
  0xc012000000000001,
  0xc012000000000001,
  0xc010000000000001,
  0xc010000000000001,
  0xc010000000000001,
  0xc00c000000000002,
  0x4013ffffffffffff,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc014000000000001,
  0xc014000000000001,
  0xc014000000000001,
  0xc014000000000001,
  0xc014000000000001,
  0xc016000000000001,
  0xc016000000000001,
  0xc016000000000001,
  0xc018000000000001,
  0xc018000000000001,
  0xc018000000000002,
  0xc01a000000000001,
  0xc02e000000000001,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc014000000000001,
  0xc014000000000001,
  0xc014000000000001,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0x7fdffffffffffffd,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x800091a2b3c4d5e7,
  0x000f6e5d4c3b2a19,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000091a2b3c4d5e6,
  0x000f6e5d4c3b2a18,
  0x800091a2b3c4d5e6,
  0x800091a2b3c4d5e7,
  0x801091a2b3c4d5e7,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x8001b4e81b4e81b4,
  0x801091a2b3c4d5e6,
  0x800091a2b3c4d5e8,
  0x8008000000000000,
  0x0008000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8006dcba98765433,
  0x0007ffffffffffff,
  0x8007ffffffffffff,
  0x8008000000000000,
  0x8018000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800923456789abcd,
  0x8017ffffffffffff,
  0x8008000000000001,
  0x8000000000000001,
  0x000fffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcc,
  0x000ffffffffffffe,
  0x0000000000000000,
  0x8000000000000001,
  0x8010000000000001,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abce,
  0x8010000000000000,
  0x8000000000000002,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0010000000000000,
  0x0020000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x001123456789abcc,
  0x001ffffffffffffe,
  0x0010000000000000,
  0x0010000000000000,
  0x8000000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x000edcba98765432,
  0x0000000000000000,
  0x000ffffffffffffe,
  0x3fdffffffffffffe,
  0x3fdffffffffffffe,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff7ffffffffffff,
  0x3ff8000000000000,
  0x3ff8000000000001,
  0x4000000000000000,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fdffffffffffffe,
  0x3fdffffffffffffe,
  0x3fdffffffffffffe,
  0x3fdffffffffffffe,
  0x3fdffffffffffffe,
  0xbc8fffffffffffff,
  0xbca0000000000000,
  0xbcb0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000003,
  0xbff0000000000000,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fdffffffffffffe,
  0x3fdffffffffffffe,
  0x3fdffffffffffffe,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff7ffffffffffff,
  0x3ff8000000000000,
  0x3ff8000000000001,
  0x4000000000000000,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x0000000000000000,
  0xbc90000000000000,
  0xbca8000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000002,
  0xbff0000000000000,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000001,
  0x4000000000000000,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3c9fffffffffffff,
  0x3c8ffffffffffffe,
  0xbc90000000000001,
  0xbfdffffffffffffd,
  0xbfdfffffffffffff,
  0xbfe0000000000002,
  0xbff0000000000000,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3feffffffffffffe,
  0x3feffffffffffffe,
  0x3ff7ffffffffffff,
  0x3ff7ffffffffffff,
  0x3ff8000000000000,
  0x3fffffffffffffff,
  0x3fffffffffffffff,
  0x4000000000000000,
  0x4004000000000000,
  0x4026000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3feffffffffffffe,
  0x3feffffffffffffe,
  0x3feffffffffffffe,
  0x3feffffffffffffe,
  0x3feffffffffffffe,
  0x3fdffffffffffffd,
  0x3fdffffffffffffc,
  0x3fdffffffffffffa,
  0xbc9fffffffffffff,
  0xbcb0000000000000,
  0xbcc0000000000000,
  0xbfe0000000000002,
  0xc022000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3feffffffffffffe,
  0x3feffffffffffffe,
  0x3feffffffffffffe,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3ff7ffffffffffff,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3fffffffffffffff,
  0x4000000000000000,
  0x4000000000000000,
  0x4004000000000000,
  0x4026000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fdfffffffffffff,
  0x3fdffffffffffffe,
  0x3fdffffffffffffc,
  0x0000000000000000,
  0xbca0000000000000,
  0xbcb8000000000000,
  0xbfe0000000000001,
  0xc022000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000001,
  0x4000000000000000,
  0x4000000000000000,
  0x4000000000000001,
  0x4004000000000000,
  0x4026000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000000,
  0x3cafffffffffffff,
  0x3c9ffffffffffffe,
  0xbca0000000000001,
  0xbfdffffffffffffe,
  0xc022000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff7ffffffffffff,
  0x3ff7ffffffffffff,
  0x3fffffffffffffff,
  0x3fffffffffffffff,
  0x4000000000000000,
  0x4003ffffffffffff,
  0x4004000000000000,
  0x4004000000000000,
  0x4008000000000000,
  0x4027000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3ff7ffffffffffff,
  0x3ff7ffffffffffff,
  0x3ff7ffffffffffff,
  0x3ff7ffffffffffff,
  0x3ff7ffffffffffff,
  0x3fefffffffffffff,
  0x3feffffffffffffe,
  0x3feffffffffffffe,
  0x3fdfffffffffffff,
  0x3fdffffffffffffd,
  0x3fdffffffffffff9,
  0xbca8000000000000,
  0xc021000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3ff7ffffffffffff,
  0x3ff7ffffffffffff,
  0x3ff7ffffffffffff,
  0x4023ffffffffffff,
  0x4023ffffffffffff,
  0x4024ffffffffffff,
  0x4024ffffffffffff,
  0x4024ffffffffffff,
  0x4025ffffffffffff,
  0x4025ffffffffffff,
  0x4026000000000000,
  0x4026ffffffffffff,
  0x4034000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x4023ffffffffffff,
  0x4023ffffffffffff,
  0x4023ffffffffffff,
  0x4023ffffffffffff,
  0x4023ffffffffffff,
  0x4022ffffffffffff,
  0x4022ffffffffffff,
  0x4022ffffffffffff,
  0x4021ffffffffffff,
  0x4021ffffffffffff,
  0x4021ffffffffffff,
  0x4020ffffffffffff,
  0xbcd4000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x4023ffffffffffff,
  0x4023ffffffffffff,
  0x4023ffffffffffff,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0xfc9fffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x001123456789abcd,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0002468acf13579a,
  0x001123456789abcc,
  0x000123456789abce,
  0x000123456789abcd,
  0x800edcba98765433,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x8000000000000000,
  0x800edcba98765432,
  0x000123456789abcc,
  0x000fffffffffffff,
  0x001fffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x001123456789abcc,
  0x001ffffffffffffe,
  0x0010000000000000,
  0x000fffffffffffff,
  0x8000000000000001,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x000edcba98765432,
  0x8000000000000000,
  0x000ffffffffffffe,
  0x0000000000000001,
  0x0010000000000001,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abce,
  0x0010000000000000,
  0x0000000000000002,
  0x0000000000000001,
  0x800fffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcc,
  0x800ffffffffffffe,
  0x8000000000000000,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8010000000000000,
  0x0000000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x800edcba98765432,
  0x8000000000000000,
  0x800ffffffffffffe,
  0x8010000000000000,
  0x8020000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x801123456789abcc,
  0x801ffffffffffffe,
  0x8010000000000000,
  0xbfdffffffffffffe,
  0xbfdffffffffffffe,
  0x3c8fffffffffffff,
  0x3ca0000000000000,
  0x3cb0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000003,
  0x3ff0000000000000,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfdffffffffffffe,
  0xbfdffffffffffffe,
  0xbfdffffffffffffe,
  0xbfdffffffffffffe,
  0xbfdffffffffffffe,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff7ffffffffffff,
  0xbff8000000000000,
  0xbff8000000000001,
  0xc000000000000000,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfdffffffffffffe,
  0xbfdffffffffffffe,
  0xbfdffffffffffffe,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0x0000000000000000,
  0x3c90000000000000,
  0x3ca8000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000002,
  0x3ff0000000000000,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff7ffffffffffff,
  0xbff8000000000000,
  0xbff8000000000001,
  0xc000000000000000,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbc9fffffffffffff,
  0xbc8ffffffffffffe,
  0x3c90000000000001,
  0x3fdffffffffffffd,
  0x3fdfffffffffffff,
  0x3fe0000000000002,
  0x3ff0000000000000,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000001,
  0xc000000000000000,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfeffffffffffffe,
  0xbfeffffffffffffe,
  0xbfdffffffffffffd,
  0xbfdffffffffffffc,
  0xbfdffffffffffffa,
  0x3c9fffffffffffff,
  0x3cb0000000000000,
  0x3cc0000000000000,
  0x3fe0000000000002,
  0x4022000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfeffffffffffffe,
  0xbfeffffffffffffe,
  0xbfeffffffffffffe,
  0xbfeffffffffffffe,
  0xbfeffffffffffffe,
  0xbff7ffffffffffff,
  0xbff7ffffffffffff,
  0xbff8000000000000,
  0xbfffffffffffffff,
  0xbfffffffffffffff,
  0xc000000000000000,
  0xc004000000000000,
  0xc026000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfeffffffffffffe,
  0xbfeffffffffffffe,
  0xbfeffffffffffffe,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfdfffffffffffff,
  0xbfdffffffffffffe,
  0xbfdffffffffffffc,
  0x0000000000000000,
  0x3ca0000000000000,
  0x3cb8000000000000,
  0x3fe0000000000001,
  0x4022000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbff7ffffffffffff,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbfffffffffffffff,
  0xc000000000000000,
  0xc000000000000000,
  0xc004000000000000,
  0xc026000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000000,
  0xbcafffffffffffff,
  0xbc9ffffffffffffe,
  0x3ca0000000000001,
  0x3fdffffffffffffe,
  0x4022000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000001,
  0xc000000000000000,
  0xc000000000000000,
  0xc000000000000001,
  0xc004000000000000,
  0xc026000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff7ffffffffffff,
  0xbff7ffffffffffff,
  0xbfefffffffffffff,
  0xbfeffffffffffffe,
  0xbfeffffffffffffe,
  0xbfdfffffffffffff,
  0xbfdffffffffffffd,
  0xbfdffffffffffff9,
  0x3ca8000000000000,
  0x4021000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbff7ffffffffffff,
  0xbff7ffffffffffff,
  0xbff7ffffffffffff,
  0xbff7ffffffffffff,
  0xbff7ffffffffffff,
  0xbfffffffffffffff,
  0xbfffffffffffffff,
  0xc000000000000000,
  0xc003ffffffffffff,
  0xc004000000000000,
  0xc004000000000000,
  0xc008000000000000,
  0xc027000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbff7ffffffffffff,
  0xbff7ffffffffffff,
  0xbff7ffffffffffff,
  0xc023ffffffffffff,
  0xc023ffffffffffff,
  0xc022ffffffffffff,
  0xc022ffffffffffff,
  0xc022ffffffffffff,
  0xc021ffffffffffff,
  0xc021ffffffffffff,
  0xc021ffffffffffff,
  0xc020ffffffffffff,
  0x3cd4000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc023ffffffffffff,
  0xc023ffffffffffff,
  0xc023ffffffffffff,
  0xc023ffffffffffff,
  0xc023ffffffffffff,
  0xc024ffffffffffff,
  0xc024ffffffffffff,
  0xc024ffffffffffff,
  0xc025ffffffffffff,
  0xc025ffffffffffff,
  0xc026000000000000,
  0xc026ffffffffffff,
  0xc034000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc023ffffffffffff,
  0xc023ffffffffffff,
  0xc023ffffffffffff,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0x7c9fffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x800123456789abcd,
  0x000edcba98765433,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0000000000000000,
  0x000edcba98765432,
  0x800123456789abcc,
  0x800123456789abcd,
  0x801123456789abcd,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x8002468acf13579a,
  0x801123456789abcc,
  0x800123456789abce,
  0x800fffffffffffff,
  0x0000000000000001,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x800edcba98765432,
  0x0000000000000000,
  0x800ffffffffffffe,
  0x800fffffffffffff,
  0x801fffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x801123456789abcc,
  0x801ffffffffffffe,
  0x8010000000000000,
  0x8000000000000001,
  0x000fffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcc,
  0x000ffffffffffffe,
  0x0000000000000000,
  0x8000000000000001,
  0x8010000000000001,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abce,
  0x8010000000000000,
  0x8000000000000002,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0010000000000000,
  0x0020000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x001123456789abcd,
  0x001fffffffffffff,
  0x0010000000000001,
  0x0010000000000000,
  0x0000000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x000edcba98765433,
  0x0000000000000001,
  0x000fffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff7ffffffffffff,
  0x3ff8000000000000,
  0x3ff8000000000001,
  0x4000000000000000,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x0000000000000000,
  0xbc90000000000000,
  0xbca8000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000002,
  0xbff0000000000000,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000001,
  0x4000000000000000,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3c90000000000000,
  0x0000000000000000,
  0xbca0000000000000,
  0xbfdffffffffffffe,
  0xbfe0000000000000,
  0xbfe0000000000002,
  0xbff0000000000000,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000002,
  0x4000000000000000,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3ca8000000000000,
  0x3ca0000000000000,
  0x0000000000000000,
  0xbfdffffffffffffc,
  0xbfdffffffffffffe,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3ff7ffffffffffff,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3fffffffffffffff,
  0x4000000000000000,
  0x4000000000000000,
  0x4004000000000000,
  0x4026000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fdfffffffffffff,
  0x3fdffffffffffffe,
  0x3fdffffffffffffc,
  0x0000000000000000,
  0xbca0000000000000,
  0xbcb8000000000000,
  0xbfe0000000000001,
  0xc022000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x4000000000000000,
  0x4000000000000000,
  0x4000000000000000,
  0x4004000000000000,
  0x4026000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fdffffffffffffe,
  0x3ca0000000000000,
  0x0000000000000000,
  0xbcb0000000000000,
  0xbfe0000000000000,
  0xc022000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff8000000000001,
  0x3ff8000000000001,
  0x3ff8000000000002,
  0x4000000000000000,
  0x4000000000000000,
  0x4000000000000001,
  0x4004000000000000,
  0x4026000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3fe0000000000002,
  0x3fe0000000000002,
  0x3fe0000000000001,
  0x3cb8000000000000,
  0x3cb0000000000000,
  0x0000000000000000,
  0xbfdffffffffffffc,
  0xc022000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x4000000000000000,
  0x4000000000000000,
  0x4000000000000000,
  0x4004000000000000,
  0x4004000000000000,
  0x4004000000000000,
  0x4008000000000000,
  0x4027000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3fefffffffffffff,
  0x3fe0000000000001,
  0x3fe0000000000000,
  0x3fdffffffffffffc,
  0x0000000000000000,
  0xc021000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4025000000000000,
  0x4025000000000000,
  0x4025000000000000,
  0x4026000000000000,
  0x4026000000000000,
  0x4026000000000000,
  0x4027000000000000,
  0x4034000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4023000000000000,
  0x4023000000000000,
  0x4023000000000000,
  0x4022000000000000,
  0x4022000000000000,
  0x4022000000000000,
  0x4021000000000000,
  0x0000000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x0000000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x001123456789abcd,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0002468acf13579a,
  0x001123456789abcc,
  0x000123456789abce,
  0x000123456789abcd,
  0x800edcba98765433,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0000000000000000,
  0x800edcba98765432,
  0x000123456789abcc,
  0x000fffffffffffff,
  0x001fffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x001123456789abcc,
  0x001ffffffffffffe,
  0x0010000000000000,
  0x000fffffffffffff,
  0x8000000000000001,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x000edcba98765432,
  0x0000000000000000,
  0x000ffffffffffffe,
  0x0000000000000001,
  0x0010000000000001,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abce,
  0x0010000000000000,
  0x0000000000000002,
  0x0000000000000001,
  0x800fffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcc,
  0x800ffffffffffffe,
  0x0000000000000000,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8010000000000000,
  0x0000000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x800edcba98765433,
  0x8000000000000001,
  0x800fffffffffffff,
  0x8010000000000000,
  0x8020000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x801123456789abcd,
  0x801fffffffffffff,
  0x8010000000000001,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0x0000000000000000,
  0x3c90000000000000,
  0x3ca8000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000002,
  0x3ff0000000000000,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff7ffffffffffff,
  0xbff8000000000000,
  0xbff8000000000001,
  0xc000000000000000,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbc90000000000000,
  0x0000000000000000,
  0x3ca0000000000000,
  0x3fdffffffffffffe,
  0x3fe0000000000000,
  0x3fe0000000000002,
  0x3ff0000000000000,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000001,
  0xc000000000000000,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbca8000000000000,
  0xbca0000000000000,
  0x0000000000000000,
  0x3fdffffffffffffc,
  0x3fdffffffffffffe,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000002,
  0xc000000000000000,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfdfffffffffffff,
  0xbfdffffffffffffe,
  0xbfdffffffffffffc,
  0x0000000000000000,
  0x3ca0000000000000,
  0x3cb8000000000000,
  0x3fe0000000000001,
  0x4022000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbff7ffffffffffff,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbfffffffffffffff,
  0xc000000000000000,
  0xc000000000000000,
  0xc004000000000000,
  0xc026000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfdffffffffffffe,
  0xbca0000000000000,
  0x0000000000000000,
  0x3cb0000000000000,
  0x3fe0000000000000,
  0x4022000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xc000000000000000,
  0xc000000000000000,
  0xc000000000000000,
  0xc004000000000000,
  0xc026000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbfe0000000000002,
  0xbfe0000000000002,
  0xbfe0000000000001,
  0xbcb8000000000000,
  0xbcb0000000000000,
  0x0000000000000000,
  0x3fdffffffffffffc,
  0x4022000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff8000000000001,
  0xbff8000000000001,
  0xbff8000000000002,
  0xc000000000000000,
  0xc000000000000000,
  0xc000000000000001,
  0xc004000000000000,
  0xc026000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbfefffffffffffff,
  0xbfe0000000000001,
  0xbfe0000000000000,
  0xbfdffffffffffffc,
  0x0000000000000000,
  0x4021000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xc000000000000000,
  0xc000000000000000,
  0xc000000000000000,
  0xc004000000000000,
  0xc004000000000000,
  0xc004000000000000,
  0xc008000000000000,
  0xc027000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc023000000000000,
  0xc023000000000000,
  0xc023000000000000,
  0xc022000000000000,
  0xc022000000000000,
  0xc022000000000000,
  0xc021000000000000,
  0x0000000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc025000000000000,
  0xc025000000000000,
  0xc025000000000000,
  0xc026000000000000,
  0xc026000000000000,
  0xc026000000000000,
  0xc027000000000000,
  0xc034000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0x0000000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x800123456789abcd,
  0x000edcba98765433,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0000000000000000,
  0x000edcba98765432,
  0x800123456789abcc,
  0x800123456789abcd,
  0x801123456789abcd,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x8002468acf13579a,
  0x801123456789abcc,
  0x800123456789abce,
  0x800fffffffffffff,
  0x0000000000000001,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x800edcba98765432,
  0x0000000000000000,
  0x800ffffffffffffe,
  0x800fffffffffffff,
  0x801fffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x801123456789abcc,
  0x801ffffffffffffe,
  0x8010000000000000,
  0x8000000000000001,
  0x000fffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcc,
  0x000ffffffffffffe,
  0x0000000000000000,
  0x8000000000000001,
  0x8010000000000001,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abce,
  0x8010000000000000,
  0x8000000000000002,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0010000000000001,
  0x0020000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x001123456789abce,
  0x0020000000000000,
  0x0010000000000002,
  0x0010000000000001,
  0x0000000000000001,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x000edcba98765434,
  0x0000000000000002,
  0x0010000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000001,
  0x4000000000000000,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3c9fffffffffffff,
  0x3c8ffffffffffffe,
  0xbc90000000000001,
  0xbfdffffffffffffd,
  0xbfdfffffffffffff,
  0xbfe0000000000002,
  0xbff0000000000000,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000002,
  0x4000000000000000,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3ca8000000000000,
  0x3ca0000000000000,
  0x0000000000000000,
  0xbfdffffffffffffc,
  0xbfdffffffffffffe,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000002,
  0x3fe0000000000002,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000002,
  0x3ff8000000000001,
  0x3ff8000000000001,
  0x3ff8000000000002,
  0x4000000000000001,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe0000000000002,
  0x3fe0000000000002,
  0x3fe0000000000002,
  0x3fe0000000000002,
  0x3fe0000000000002,
  0x3cb4000000000000,
  0x3cb0000000000000,
  0x3ca0000000000001,
  0xbfdffffffffffffa,
  0xbfdffffffffffffc,
  0xbfe0000000000000,
  0xbfeffffffffffffe,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe0000000000002,
  0x3fe0000000000002,
  0x3fe0000000000002,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000001,
  0x4000000000000000,
  0x4000000000000000,
  0x4000000000000001,
  0x4004000000000000,
  0x4026000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000000,
  0x3cafffffffffffff,
  0x3c9ffffffffffffe,
  0xbca0000000000001,
  0xbfdffffffffffffe,
  0xc022000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff8000000000001,
  0x3ff8000000000001,
  0x3ff8000000000002,
  0x4000000000000000,
  0x4000000000000000,
  0x4000000000000001,
  0x4004000000000000,
  0x4026000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3fe0000000000002,
  0x3fe0000000000002,
  0x3fe0000000000001,
  0x3cb8000000000000,
  0x3cb0000000000000,
  0x0000000000000000,
  0xbfdffffffffffffc,
  0xc022000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000002,
  0x3ff0000000000002,
  0x3ff8000000000002,
  0x3ff8000000000002,
  0x3ff8000000000003,
  0x4000000000000001,
  0x4000000000000001,
  0x4000000000000002,
  0x4004000000000001,
  0x4026000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3ff0000000000002,
  0x3ff0000000000002,
  0x3ff0000000000002,
  0x3ff0000000000002,
  0x3ff0000000000002,
  0x3fe0000000000005,
  0x3fe0000000000004,
  0x3fe0000000000003,
  0x3cc4000000000000,
  0x3cc0000000000000,
  0x3cb0000000000001,
  0xbfdffffffffffff8,
  0xc022000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3ff0000000000002,
  0x3ff0000000000002,
  0x3ff0000000000002,
  0x3ff8000000000002,
  0x3ff8000000000002,
  0x4000000000000001,
  0x4000000000000001,
  0x4000000000000001,
  0x4004000000000000,
  0x4004000000000001,
  0x4004000000000001,
  0x4008000000000001,
  0x4027000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3ff8000000000002,
  0x3ff8000000000002,
  0x3ff8000000000002,
  0x3ff8000000000002,
  0x3ff8000000000001,
  0x3ff0000000000002,
  0x3ff0000000000002,
  0x3ff0000000000001,
  0x3fe0000000000004,
  0x3fe0000000000003,
  0x3fe0000000000001,
  0x3cb8000000000000,
  0xc021000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3ff8000000000001,
  0x3ff8000000000001,
  0x3ff8000000000001,
  0x4024000000000001,
  0x4024000000000001,
  0x4025000000000001,
  0x4025000000000001,
  0x4025000000000001,
  0x4026000000000001,
  0x4026000000000001,
  0x4026000000000001,
  0x4027000000000001,
  0x4034000000000001,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x4024000000000001,
  0x4024000000000001,
  0x4024000000000001,
  0x4024000000000001,
  0x4024000000000001,
  0x4023000000000001,
  0x4023000000000001,
  0x4023000000000001,
  0x4022000000000001,
  0x4022000000000001,
  0x4022000000000001,
  0x4021000000000001,
  0x3ce4000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x4024000000000001,
  0x4024000000000001,
  0x4024000000000001,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7cafffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x001123456789abcd,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0002468acf13579a,
  0x001123456789abcc,
  0x000123456789abce,
  0x000123456789abcd,
  0x800edcba98765433,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0000000000000000,
  0x800edcba98765432,
  0x000123456789abcc,
  0x0010000000000000,
  0x0020000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x001123456789abcd,
  0x001fffffffffffff,
  0x0010000000000001,
  0x0010000000000000,
  0x8000000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x000edcba98765433,
  0x0000000000000001,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0010000000000001,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abce,
  0x0010000000000000,
  0x0000000000000002,
  0x0000000000000001,
  0x800fffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcc,
  0x800ffffffffffffe,
  0x0000000000000000,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8010000000000001,
  0x8000000000000001,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x800edcba98765434,
  0x8000000000000002,
  0x8010000000000000,
  0x8010000000000001,
  0x8020000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x801123456789abce,
  0x8020000000000000,
  0x8010000000000002,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbc9fffffffffffff,
  0xbc8ffffffffffffe,
  0x3c90000000000001,
  0x3fdffffffffffffd,
  0x3fdfffffffffffff,
  0x3fe0000000000002,
  0x3ff0000000000000,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000001,
  0xc000000000000000,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbca8000000000000,
  0xbca0000000000000,
  0x0000000000000000,
  0x3fdffffffffffffc,
  0x3fdffffffffffffe,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000002,
  0xc000000000000000,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000002,
  0xbfe0000000000002,
  0xbcb4000000000000,
  0xbcb0000000000000,
  0xbca0000000000001,
  0x3fdffffffffffffa,
  0x3fdffffffffffffc,
  0x3fe0000000000000,
  0x3feffffffffffffe,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe0000000000002,
  0xbfe0000000000002,
  0xbfe0000000000002,
  0xbfe0000000000002,
  0xbfe0000000000002,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000002,
  0xbff8000000000001,
  0xbff8000000000001,
  0xbff8000000000002,
  0xc000000000000001,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe0000000000002,
  0xbfe0000000000002,
  0xbfe0000000000002,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000000,
  0xbcafffffffffffff,
  0xbc9ffffffffffffe,
  0x3ca0000000000001,
  0x3fdffffffffffffe,
  0x4022000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000001,
  0xc000000000000000,
  0xc000000000000000,
  0xc000000000000001,
  0xc004000000000000,
  0xc026000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbfe0000000000002,
  0xbfe0000000000002,
  0xbfe0000000000001,
  0xbcb8000000000000,
  0xbcb0000000000000,
  0x0000000000000000,
  0x3fdffffffffffffc,
  0x4022000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff8000000000001,
  0xbff8000000000001,
  0xbff8000000000002,
  0xc000000000000000,
  0xc000000000000000,
  0xc000000000000001,
  0xc004000000000000,
  0xc026000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000002,
  0xbff0000000000002,
  0xbfe0000000000005,
  0xbfe0000000000004,
  0xbfe0000000000003,
  0xbcc4000000000000,
  0xbcc0000000000000,
  0xbcb0000000000001,
  0x3fdffffffffffff8,
  0x4022000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbff0000000000002,
  0xbff0000000000002,
  0xbff0000000000002,
  0xbff0000000000002,
  0xbff0000000000002,
  0xbff8000000000002,
  0xbff8000000000002,
  0xbff8000000000003,
  0xc000000000000001,
  0xc000000000000001,
  0xc000000000000002,
  0xc004000000000001,
  0xc026000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbff0000000000002,
  0xbff0000000000002,
  0xbff0000000000002,
  0xbff8000000000002,
  0xbff8000000000001,
  0xbff0000000000002,
  0xbff0000000000002,
  0xbff0000000000001,
  0xbfe0000000000004,
  0xbfe0000000000003,
  0xbfe0000000000001,
  0xbcb8000000000000,
  0x4021000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbff8000000000001,
  0xbff8000000000001,
  0xbff8000000000001,
  0xbff8000000000002,
  0xbff8000000000002,
  0xc000000000000001,
  0xc000000000000001,
  0xc000000000000001,
  0xc004000000000000,
  0xc004000000000001,
  0xc004000000000001,
  0xc008000000000001,
  0xc027000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbff8000000000002,
  0xbff8000000000002,
  0xbff8000000000002,
  0xc024000000000001,
  0xc024000000000001,
  0xc023000000000001,
  0xc023000000000001,
  0xc023000000000001,
  0xc022000000000001,
  0xc022000000000001,
  0xc022000000000001,
  0xc021000000000001,
  0xbce4000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc024000000000001,
  0xc024000000000001,
  0xc024000000000001,
  0xc024000000000001,
  0xc024000000000001,
  0xc025000000000001,
  0xc025000000000001,
  0xc025000000000001,
  0xc026000000000001,
  0xc026000000000001,
  0xc026000000000001,
  0xc027000000000001,
  0xc034000000000001,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc024000000000001,
  0xc024000000000001,
  0xc024000000000001,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfcafffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x800123456789abcd,
  0x000edcba98765433,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8000000000000000,
  0x000edcba98765432,
  0x800123456789abcc,
  0x800123456789abcd,
  0x801123456789abcd,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x8002468acf13579a,
  0x801123456789abcc,
  0x800123456789abce,
  0x8010000000000000,
  0x0000000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x800edcba98765433,
  0x8000000000000001,
  0x800fffffffffffff,
  0x8010000000000000,
  0x8020000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x801123456789abcd,
  0x801fffffffffffff,
  0x8010000000000001,
  0x8000000000000001,
  0x000fffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcc,
  0x000ffffffffffffe,
  0x8000000000000000,
  0x8000000000000001,
  0x8010000000000001,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abce,
  0x8010000000000000,
  0x8000000000000002,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0018000000000000,
  0x0024000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x001923456789abcd,
  0x0024000000000000,
  0x0018000000000001,
  0x0018000000000000,
  0x0008000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0016dcba98765433,
  0x0008000000000001,
  0x0017ffffffffffff,
  0x3fe7ffffffffffff,
  0x3fe7ffffffffffff,
  0x3ff3ffffffffffff,
  0x3ff4000000000000,
  0x3ff4000000000000,
  0x3ffbffffffffffff,
  0x3ffc000000000000,
  0x3ffc000000000001,
  0x4002000000000000,
  0x4025800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe7ffffffffffff,
  0x3fe7ffffffffffff,
  0x3fe7ffffffffffff,
  0x3fe7ffffffffffff,
  0x3fe7ffffffffffff,
  0x3fcfffffffffffff,
  0x3fcffffffffffffd,
  0x3fcffffffffffff9,
  0xbfcfffffffffffff,
  0xbfd0000000000002,
  0xbfd0000000000006,
  0xbfe8000000000001,
  0xc022800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe7ffffffffffff,
  0x3fe7ffffffffffff,
  0x3fe7ffffffffffff,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3ff4000000000000,
  0x3ff4000000000000,
  0x3ff4000000000000,
  0x3ffc000000000000,
  0x3ffc000000000000,
  0x3ffc000000000001,
  0x4002000000000000,
  0x4025800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3fd0000000000001,
  0x3fd0000000000000,
  0x3fcffffffffffffc,
  0xbfcffffffffffffc,
  0xbfd0000000000000,
  0xbfd0000000000004,
  0xbfe8000000000000,
  0xc022800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3fe8000000000002,
  0x3fe8000000000002,
  0x3ff4000000000000,
  0x3ff4000000000001,
  0x3ff4000000000001,
  0x3ffc000000000000,
  0x3ffc000000000001,
  0x3ffc000000000002,
  0x4002000000000000,
  0x4025800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe8000000000002,
  0x3fe8000000000002,
  0x3fe8000000000002,
  0x3fe8000000000002,
  0x3fe8000000000001,
  0x3fd0000000000004,
  0x3fd0000000000003,
  0x3fd0000000000001,
  0xbfcffffffffffff6,
  0xbfcffffffffffffa,
  0xbfd0000000000001,
  0xbfe7fffffffffffe,
  0xc022800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe8000000000001,
  0x3fe8000000000001,
  0x3fe8000000000001,
  0x3ff7ffffffffffff,
  0x3ff7ffffffffffff,
  0x3fffffffffffffff,
  0x3fffffffffffffff,
  0x4000000000000000,
  0x4003ffffffffffff,
  0x4004000000000000,
  0x4004000000000000,
  0x4008000000000000,
  0x4027000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3ff7ffffffffffff,
  0x3ff7ffffffffffff,
  0x3ff7ffffffffffff,
  0x3ff7ffffffffffff,
  0x3ff7ffffffffffff,
  0x3fefffffffffffff,
  0x3feffffffffffffe,
  0x3feffffffffffffe,
  0x3fdfffffffffffff,
  0x3fdffffffffffffd,
  0x3fdffffffffffff9,
  0xbca8000000000000,
  0xc021000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3ff7ffffffffffff,
  0x3ff7ffffffffffff,
  0x3ff7ffffffffffff,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x4000000000000000,
  0x4000000000000000,
  0x4000000000000000,
  0x4004000000000000,
  0x4004000000000000,
  0x4004000000000000,
  0x4008000000000000,
  0x4027000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3fefffffffffffff,
  0x3fe0000000000001,
  0x3fe0000000000000,
  0x3fdffffffffffffc,
  0x0000000000000000,
  0xc021000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000002,
  0x3ff8000000000002,
  0x4000000000000001,
  0x4000000000000001,
  0x4000000000000001,
  0x4004000000000000,
  0x4004000000000001,
  0x4004000000000001,
  0x4008000000000001,
  0x4027000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3ff8000000000002,
  0x3ff8000000000002,
  0x3ff8000000000002,
  0x3ff8000000000002,
  0x3ff8000000000001,
  0x3ff0000000000002,
  0x3ff0000000000002,
  0x3ff0000000000001,
  0x3fe0000000000004,
  0x3fe0000000000003,
  0x3fe0000000000001,
  0x3cb8000000000000,
  0xc021000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3ff8000000000001,
  0x3ff8000000000001,
  0x3ff8000000000001,
  0x4002000000000000,
  0x4002000000000000,
  0x4006000000000000,
  0x4006000000000000,
  0x4006000000000000,
  0x400a000000000000,
  0x400a000000000000,
  0x400a000000000000,
  0x400e000000000000,
  0x4028800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x4002000000000000,
  0x4002000000000000,
  0x4002000000000000,
  0x4002000000000000,
  0x4002000000000000,
  0x3ffc000000000000,
  0x3ffc000000000000,
  0x3ffc000000000000,
  0x3ff4000000000000,
  0x3ff4000000000000,
  0x3ff3ffffffffffff,
  0x3fe8000000000000,
  0xc01f000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x4002000000000000,
  0x4002000000000000,
  0x4002000000000000,
  0x402e000000000000,
  0x402e000000000000,
  0x402f000000000000,
  0x402f000000000000,
  0x402f000000000000,
  0x4030000000000000,
  0x4030000000000000,
  0x4030000000000000,
  0x4030800000000000,
  0x4039000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x402e000000000000,
  0x402e000000000000,
  0x402e000000000000,
  0x402e000000000000,
  0x402e000000000000,
  0x402d000000000000,
  0x402d000000000000,
  0x402d000000000000,
  0x402c000000000000,
  0x402c000000000000,
  0x402c000000000000,
  0x402b000000000000,
  0x4014000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x402e000000000000,
  0x402e000000000000,
  0x402e000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7fdfffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x0001b4e81b4e81b4,
  0x0011b4e81b4e81b4,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0002d82d82d82d80,
  0x0011b4e81b4e81b2,
  0x0001b4e81b4e81b4,
  0x0001b4e81b4e81b4,
  0x800e4b17e4b17e4c,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x000091a2b3c4d5e6,
  0x800e4b17e4b17e4c,
  0x0001b4e81b4e81b2,
  0x0017fffffffffffe,
  0x0023ffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x001923456789abcc,
  0x0023ffffffffffff,
  0x0018000000000000,
  0x0017fffffffffffe,
  0x0007fffffffffffe,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0016dcba98765432,
  0x0008000000000000,
  0x0017fffffffffffe,
  0x0000000000000002,
  0x0010000000000002,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abce,
  0x0010000000000000,
  0x0000000000000002,
  0x0000000000000002,
  0x800ffffffffffffe,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcc,
  0x800ffffffffffffe,
  0x0000000000000000,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8018000000000000,
  0x8008000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8016dcba98765433,
  0x8008000000000001,
  0x8017ffffffffffff,
  0x8018000000000000,
  0x8024000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x801923456789abcd,
  0x8024000000000000,
  0x8018000000000001,
  0xbfe7ffffffffffff,
  0xbfe7ffffffffffff,
  0xbfcfffffffffffff,
  0xbfcffffffffffffd,
  0xbfcffffffffffff9,
  0x3fcfffffffffffff,
  0x3fd0000000000002,
  0x3fd0000000000006,
  0x3fe8000000000001,
  0x4022800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe7ffffffffffff,
  0xbfe7ffffffffffff,
  0xbfe7ffffffffffff,
  0xbfe7ffffffffffff,
  0xbfe7ffffffffffff,
  0xbff3ffffffffffff,
  0xbff4000000000000,
  0xbff4000000000000,
  0xbffbffffffffffff,
  0xbffc000000000000,
  0xbffc000000000001,
  0xc002000000000000,
  0xc025800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe7ffffffffffff,
  0xbfe7ffffffffffff,
  0xbfe7ffffffffffff,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbfd0000000000001,
  0xbfd0000000000000,
  0xbfcffffffffffffc,
  0x3fcffffffffffffc,
  0x3fd0000000000000,
  0x3fd0000000000004,
  0x3fe8000000000000,
  0x4022800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbff4000000000000,
  0xbff4000000000000,
  0xbff4000000000000,
  0xbffc000000000000,
  0xbffc000000000000,
  0xbffc000000000001,
  0xc002000000000000,
  0xc025800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbfe8000000000002,
  0xbfe8000000000001,
  0xbfd0000000000004,
  0xbfd0000000000003,
  0xbfd0000000000001,
  0x3fcffffffffffff6,
  0x3fcffffffffffffa,
  0x3fd0000000000001,
  0x3fe7fffffffffffe,
  0x4022800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe8000000000001,
  0xbfe8000000000001,
  0xbfe8000000000001,
  0xbfe8000000000002,
  0xbfe8000000000002,
  0xbff4000000000000,
  0xbff4000000000001,
  0xbff4000000000001,
  0xbffc000000000000,
  0xbffc000000000001,
  0xbffc000000000002,
  0xc002000000000000,
  0xc025800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe8000000000002,
  0xbfe8000000000002,
  0xbfe8000000000002,
  0xbff7ffffffffffff,
  0xbff7ffffffffffff,
  0xbfefffffffffffff,
  0xbfeffffffffffffe,
  0xbfeffffffffffffe,
  0xbfdfffffffffffff,
  0xbfdffffffffffffd,
  0xbfdffffffffffff9,
  0x3ca8000000000000,
  0x4021000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbff7ffffffffffff,
  0xbff7ffffffffffff,
  0xbff7ffffffffffff,
  0xbff7ffffffffffff,
  0xbff7ffffffffffff,
  0xbfffffffffffffff,
  0xbfffffffffffffff,
  0xc000000000000000,
  0xc003ffffffffffff,
  0xc004000000000000,
  0xc004000000000000,
  0xc008000000000000,
  0xc027000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbff7ffffffffffff,
  0xbff7ffffffffffff,
  0xbff7ffffffffffff,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbfefffffffffffff,
  0xbfe0000000000001,
  0xbfe0000000000000,
  0xbfdffffffffffffc,
  0x0000000000000000,
  0x4021000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xc000000000000000,
  0xc000000000000000,
  0xc000000000000000,
  0xc004000000000000,
  0xc004000000000000,
  0xc004000000000000,
  0xc008000000000000,
  0xc027000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000002,
  0xbff8000000000001,
  0xbff0000000000002,
  0xbff0000000000002,
  0xbff0000000000001,
  0xbfe0000000000004,
  0xbfe0000000000003,
  0xbfe0000000000001,
  0xbcb8000000000000,
  0x4021000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbff8000000000001,
  0xbff8000000000001,
  0xbff8000000000001,
  0xbff8000000000002,
  0xbff8000000000002,
  0xc000000000000001,
  0xc000000000000001,
  0xc000000000000001,
  0xc004000000000000,
  0xc004000000000001,
  0xc004000000000001,
  0xc008000000000001,
  0xc027000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbff8000000000002,
  0xbff8000000000002,
  0xbff8000000000002,
  0xc002000000000000,
  0xc002000000000000,
  0xbffc000000000000,
  0xbffc000000000000,
  0xbffc000000000000,
  0xbff4000000000000,
  0xbff4000000000000,
  0xbff3ffffffffffff,
  0xbfe8000000000000,
  0x401f000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc002000000000000,
  0xc002000000000000,
  0xc002000000000000,
  0xc002000000000000,
  0xc002000000000000,
  0xc006000000000000,
  0xc006000000000000,
  0xc006000000000000,
  0xc00a000000000000,
  0xc00a000000000000,
  0xc00a000000000000,
  0xc00e000000000000,
  0xc028800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc002000000000000,
  0xc002000000000000,
  0xc002000000000000,
  0xc02e000000000000,
  0xc02e000000000000,
  0xc02d000000000000,
  0xc02d000000000000,
  0xc02d000000000000,
  0xc02c000000000000,
  0xc02c000000000000,
  0xc02c000000000000,
  0xc02b000000000000,
  0xc014000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc02e000000000000,
  0xc02e000000000000,
  0xc02e000000000000,
  0xc02e000000000000,
  0xc02e000000000000,
  0xc02f000000000000,
  0xc02f000000000000,
  0xc02f000000000000,
  0xc030000000000000,
  0xc030000000000000,
  0xc030000000000000,
  0xc030800000000000,
  0xc039000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc02e000000000000,
  0xc02e000000000000,
  0xc02e000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xffdfffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x8001b4e81b4e81b4,
  0x000e4b17e4b17e4c,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x800091a2b3c4d5e6,
  0x000e4b17e4b17e4c,
  0x8001b4e81b4e81b2,
  0x8001b4e81b4e81b4,
  0x8011b4e81b4e81b4,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x8002d82d82d82d80,
  0x8011b4e81b4e81b2,
  0x8001b4e81b4e81b4,
  0x8017fffffffffffe,
  0x8007fffffffffffe,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8016dcba98765432,
  0x8008000000000000,
  0x8017fffffffffffe,
  0x8017fffffffffffe,
  0x8023ffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x801923456789abcc,
  0x8023ffffffffffff,
  0x8018000000000000,
  0x8000000000000002,
  0x000ffffffffffffe,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcc,
  0x000ffffffffffffe,
  0x8000000000000000,
  0x8000000000000002,
  0x8010000000000002,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abce,
  0x8010000000000000,
  0x8000000000000002,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0044000000000000,
  0x0046000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x00442468acf1357a,
  0x0046000000000000,
  0x0044000000000000,
  0x0044000000000000,
  0x0042000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0043db97530eca86,
  0x0042000000000000,
  0x0044000000000000,
  0x4013ffffffffffff,
  0x4013ffffffffffff,
  0x4015ffffffffffff,
  0x4015ffffffffffff,
  0x4016000000000000,
  0x4017ffffffffffff,
  0x4017ffffffffffff,
  0x4018000000000000,
  0x4019ffffffffffff,
  0x402e000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x4013ffffffffffff,
  0x4013ffffffffffff,
  0x4013ffffffffffff,
  0x4013ffffffffffff,
  0x4013ffffffffffff,
  0x4011ffffffffffff,
  0x4011ffffffffffff,
  0x4011ffffffffffff,
  0x400fffffffffffff,
  0x400fffffffffffff,
  0x400ffffffffffffe,
  0x400bffffffffffff,
  0xc014000000000001,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x4013ffffffffffff,
  0x4013ffffffffffff,
  0x4013ffffffffffff,
  0x4014000000000000,
  0x4014000000000000,
  0x4016000000000000,
  0x4016000000000000,
  0x4016000000000000,
  0x4018000000000000,
  0x4018000000000000,
  0x4018000000000000,
  0x401a000000000000,
  0x402e000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x4014000000000000,
  0x4014000000000000,
  0x4014000000000000,
  0x4014000000000000,
  0x4014000000000000,
  0x4012000000000000,
  0x4012000000000000,
  0x4012000000000000,
  0x4010000000000000,
  0x4010000000000000,
  0x4010000000000000,
  0x400c000000000000,
  0xc014000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x4014000000000000,
  0x4014000000000000,
  0x4014000000000000,
  0x4014000000000001,
  0x4014000000000001,
  0x4016000000000001,
  0x4016000000000001,
  0x4016000000000001,
  0x4018000000000001,
  0x4018000000000001,
  0x4018000000000002,
  0x401a000000000001,
  0x402e000000000001,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x4014000000000001,
  0x4014000000000001,
  0x4014000000000001,
  0x4014000000000001,
  0x4014000000000001,
  0x4012000000000001,
  0x4012000000000001,
  0x4012000000000001,
  0x4010000000000001,
  0x4010000000000001,
  0x4010000000000001,
  0x400c000000000002,
  0xc013ffffffffffff,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x4014000000000001,
  0x4014000000000001,
  0x4014000000000001,
  0x4023ffffffffffff,
  0x4023ffffffffffff,
  0x4024ffffffffffff,
  0x4024ffffffffffff,
  0x4024ffffffffffff,
  0x4025ffffffffffff,
  0x4025ffffffffffff,
  0x4026000000000000,
  0x4026ffffffffffff,
  0x4034000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x4023ffffffffffff,
  0x4023ffffffffffff,
  0x4023ffffffffffff,
  0x4023ffffffffffff,
  0x4023ffffffffffff,
  0x4022ffffffffffff,
  0x4022ffffffffffff,
  0x4022ffffffffffff,
  0x4021ffffffffffff,
  0x4021ffffffffffff,
  0x4021ffffffffffff,
  0x4020ffffffffffff,
  0xbcd4000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x4023ffffffffffff,
  0x4023ffffffffffff,
  0x4023ffffffffffff,
  0x4024000000000000,
  0x4024000000000000,
  0x4025000000000000,
  0x4025000000000000,
  0x4025000000000000,
  0x4026000000000000,
  0x4026000000000000,
  0x4026000000000000,
  0x4027000000000000,
  0x4034000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4023000000000000,
  0x4023000000000000,
  0x4023000000000000,
  0x4022000000000000,
  0x4022000000000000,
  0x4022000000000000,
  0x4021000000000000,
  0x0000000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4024000000000001,
  0x4024000000000001,
  0x4025000000000001,
  0x4025000000000001,
  0x4025000000000001,
  0x4026000000000001,
  0x4026000000000001,
  0x4026000000000001,
  0x4027000000000001,
  0x4034000000000001,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x4024000000000001,
  0x4024000000000001,
  0x4024000000000001,
  0x4024000000000001,
  0x4024000000000001,
  0x4023000000000001,
  0x4023000000000001,
  0x4023000000000001,
  0x4022000000000001,
  0x4022000000000001,
  0x4022000000000001,
  0x4021000000000001,
  0x3ce4000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x4024000000000001,
  0x4024000000000001,
  0x4024000000000001,
  0x402e000000000000,
  0x402e000000000000,
  0x402f000000000000,
  0x402f000000000000,
  0x402f000000000000,
  0x4030000000000000,
  0x4030000000000000,
  0x4030000000000000,
  0x4030800000000000,
  0x4039000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x402e000000000000,
  0x402e000000000000,
  0x402e000000000000,
  0x402e000000000000,
  0x402e000000000000,
  0x402d000000000000,
  0x402d000000000000,
  0x402d000000000000,
  0x402c000000000000,
  0x402c000000000000,
  0x402c000000000000,
  0x402b000000000000,
  0x4014000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x402e000000000000,
  0x402e000000000000,
  0x402e000000000000,
  0x4059000000000000,
  0x4059000000000000,
  0x4059200000000000,
  0x4059200000000000,
  0x4059200000000000,
  0x4059400000000000,
  0x4059400000000000,
  0x4059400000000000,
  0x4059600000000000,
  0x405b800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x4059000000000000,
  0x4059000000000000,
  0x4059000000000000,
  0x4059000000000000,
  0x4059000000000000,
  0x4058e00000000000,
  0x4058e00000000000,
  0x4058e00000000000,
  0x4058c00000000000,
  0x4058c00000000000,
  0x4058c00000000000,
  0x4058a00000000000,
  0x4056800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x4059000000000000,
  0x4059000000000000,
  0x4059000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x000b60b60b60b602,
  0x001b60b60b60b602,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000c83fb72ea61cf,
  0x001b60b60b60b601,
  0x000b60b60b60b603,
  0x000b60b60b60b602,
  0x80049f49f49f49fe,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x000a3d70a3d70a35,
  0x80049f49f49f49fd,
  0x000b60b60b60b601,
  0x0043ffffffffffff,
  0x0045ffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x00442468acf13578,
  0x0045ffffffffffff,
  0x0043ffffffffffff,
  0x0043ffffffffffff,
  0x0041ffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0043db97530eca85,
  0x0041ffffffffffff,
  0x0043ffffffffffff,
  0x000000000000000a,
  0x001000000000000a,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abd7,
  0x0010000000000009,
  0x000000000000000b,
  0x000000000000000a,
  0x800ffffffffffff6,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abc3,
  0x800ffffffffffff5,
  0x0000000000000009,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8044000000000000,
  0x8042000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8043db97530eca86,
  0x8042000000000000,
  0x8044000000000000,
  0x8044000000000000,
  0x8046000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x80442468acf1357a,
  0x8046000000000000,
  0x8044000000000000,
  0xc013ffffffffffff,
  0xc013ffffffffffff,
  0xc011ffffffffffff,
  0xc011ffffffffffff,
  0xc011ffffffffffff,
  0xc00fffffffffffff,
  0xc00fffffffffffff,
  0xc00ffffffffffffe,
  0xc00bffffffffffff,
  0x4014000000000001,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc013ffffffffffff,
  0xc013ffffffffffff,
  0xc013ffffffffffff,
  0xc013ffffffffffff,
  0xc013ffffffffffff,
  0xc015ffffffffffff,
  0xc015ffffffffffff,
  0xc016000000000000,
  0xc017ffffffffffff,
  0xc017ffffffffffff,
  0xc018000000000000,
  0xc019ffffffffffff,
  0xc02e000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc013ffffffffffff,
  0xc013ffffffffffff,
  0xc013ffffffffffff,
  0xc014000000000000,
  0xc014000000000000,
  0xc012000000000000,
  0xc012000000000000,
  0xc012000000000000,
  0xc010000000000000,
  0xc010000000000000,
  0xc010000000000000,
  0xc00c000000000000,
  0x4014000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc014000000000000,
  0xc014000000000000,
  0xc014000000000000,
  0xc014000000000000,
  0xc014000000000000,
  0xc016000000000000,
  0xc016000000000000,
  0xc016000000000000,
  0xc018000000000000,
  0xc018000000000000,
  0xc018000000000000,
  0xc01a000000000000,
  0xc02e000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc014000000000000,
  0xc014000000000000,
  0xc014000000000000,
  0xc014000000000001,
  0xc014000000000001,
  0xc012000000000001,
  0xc012000000000001,
  0xc012000000000001,
  0xc010000000000001,
  0xc010000000000001,
  0xc010000000000001,
  0xc00c000000000002,
  0x4013ffffffffffff,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc014000000000001,
  0xc014000000000001,
  0xc014000000000001,
  0xc014000000000001,
  0xc014000000000001,
  0xc016000000000001,
  0xc016000000000001,
  0xc016000000000001,
  0xc018000000000001,
  0xc018000000000001,
  0xc018000000000002,
  0xc01a000000000001,
  0xc02e000000000001,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc014000000000001,
  0xc014000000000001,
  0xc014000000000001,
  0xc023ffffffffffff,
  0xc023ffffffffffff,
  0xc022ffffffffffff,
  0xc022ffffffffffff,
  0xc022ffffffffffff,
  0xc021ffffffffffff,
  0xc021ffffffffffff,
  0xc021ffffffffffff,
  0xc020ffffffffffff,
  0x3cd4000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc023ffffffffffff,
  0xc023ffffffffffff,
  0xc023ffffffffffff,
  0xc023ffffffffffff,
  0xc023ffffffffffff,
  0xc024ffffffffffff,
  0xc024ffffffffffff,
  0xc024ffffffffffff,
  0xc025ffffffffffff,
  0xc025ffffffffffff,
  0xc026000000000000,
  0xc026ffffffffffff,
  0xc034000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc023ffffffffffff,
  0xc023ffffffffffff,
  0xc023ffffffffffff,
  0xc024000000000000,
  0xc024000000000000,
  0xc023000000000000,
  0xc023000000000000,
  0xc023000000000000,
  0xc022000000000000,
  0xc022000000000000,
  0xc022000000000000,
  0xc021000000000000,
  0x0000000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc025000000000000,
  0xc025000000000000,
  0xc025000000000000,
  0xc026000000000000,
  0xc026000000000000,
  0xc026000000000000,
  0xc027000000000000,
  0xc034000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc024000000000001,
  0xc024000000000001,
  0xc023000000000001,
  0xc023000000000001,
  0xc023000000000001,
  0xc022000000000001,
  0xc022000000000001,
  0xc022000000000001,
  0xc021000000000001,
  0xbce4000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc024000000000001,
  0xc024000000000001,
  0xc024000000000001,
  0xc024000000000001,
  0xc024000000000001,
  0xc025000000000001,
  0xc025000000000001,
  0xc025000000000001,
  0xc026000000000001,
  0xc026000000000001,
  0xc026000000000001,
  0xc027000000000001,
  0xc034000000000001,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc024000000000001,
  0xc024000000000001,
  0xc024000000000001,
  0xc02e000000000000,
  0xc02e000000000000,
  0xc02d000000000000,
  0xc02d000000000000,
  0xc02d000000000000,
  0xc02c000000000000,
  0xc02c000000000000,
  0xc02c000000000000,
  0xc02b000000000000,
  0xc014000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc02e000000000000,
  0xc02e000000000000,
  0xc02e000000000000,
  0xc02e000000000000,
  0xc02e000000000000,
  0xc02f000000000000,
  0xc02f000000000000,
  0xc02f000000000000,
  0xc030000000000000,
  0xc030000000000000,
  0xc030000000000000,
  0xc030800000000000,
  0xc039000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc02e000000000000,
  0xc02e000000000000,
  0xc02e000000000000,
  0xc059000000000000,
  0xc059000000000000,
  0xc058e00000000000,
  0xc058e00000000000,
  0xc058e00000000000,
  0xc058c00000000000,
  0xc058c00000000000,
  0xc058c00000000000,
  0xc058a00000000000,
  0xc056800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc059000000000000,
  0xc059000000000000,
  0xc059000000000000,
  0xc059000000000000,
  0xc059000000000000,
  0xc059200000000000,
  0xc059200000000000,
  0xc059200000000000,
  0xc059400000000000,
  0xc059400000000000,
  0xc059400000000000,
  0xc059600000000000,
  0xc05b800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc059000000000000,
  0xc059000000000000,
  0xc059000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x800b60b60b60b602,
  0x00049f49f49f49fe,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x800a3d70a3d70a35,
  0x00049f49f49f49fd,
  0x800b60b60b60b601,
  0x800b60b60b60b602,
  0x801b60b60b60b602,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800c83fb72ea61cf,
  0x801b60b60b60b601,
  0x800b60b60b60b603,
  0x8043ffffffffffff,
  0x8041ffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8043db97530eca85,
  0x8041ffffffffffff,
  0x8043ffffffffffff,
  0x8043ffffffffffff,
  0x8045ffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x80442468acf13578,
  0x8045ffffffffffff,
  0x8043ffffffffffff,
  0x800000000000000a,
  0x000ffffffffffff6,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abc3,
  0x000ffffffffffff5,
  0x8000000000000009,
  0x800000000000000a,
  0x801000000000000a,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abd7,
  0x8010000000000009,
  0x800000000000000b,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x400fffffffffffff,
  0x400fffffffffffff,
  0x4011ffffffffffff,
  0x4012000000000000,
  0x4012000000000000,
  0x4013ffffffffffff,
  0x4014000000000000,
  0x4014000000000000,
  0x4016000000000000,
  0x402c000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x400fffffffffffff,
  0x400fffffffffffff,
  0x400fffffffffffff,
  0x400fffffffffffff,
  0x400fffffffffffff,
  0x400bffffffffffff,
  0x400bffffffffffff,
  0x400bffffffffffff,
  0x4007ffffffffffff,
  0x4007ffffffffffff,
  0x4007fffffffffffe,
  0x4003ffffffffffff,
  0xc018000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x400fffffffffffff,
  0x400fffffffffffff,
  0x400fffffffffffff,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0xffe0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0xffdfffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0xffdffffffffffffd,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0xfc9fffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x0000000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7cafffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7fdfffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x3fd23456789abccf,
  0x3fd23456789abccf,
  0x3fe91a2b3c4d5e67,
  0x3fe91a2b3c4d5e68,
  0x3fe91a2b3c4d5e69,
  0x3ff48d159e26af33,
  0x3ff48d159e26af34,
  0x3ff48d159e26af35,
  0x3ffc8d159e26af34,
  0x402491a2b3c4d5e6,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fd23456789abccf,
  0x3fd23456789abccf,
  0x3fd23456789abccf,
  0x3fd23456789abccf,
  0x3fd23456789abccf,
  0xbfcb97530eca865f,
  0xbfcb97530eca8661,
  0xbfcb97530eca8665,
  0xbfe6e5d4c3b2a197,
  0xbfe6e5d4c3b2a198,
  0xbfe6e5d4c3b2a19a,
  0xbff372ea61d950cc,
  0xc0236e5d4c3b2a1a,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fd23456789abccf,
  0x3fd23456789abccf,
  0x3fd23456789abccf,
  0x400ffffffffffffd,
  0x400ffffffffffffd,
  0x4011fffffffffffe,
  0x4011ffffffffffff,
  0x4011ffffffffffff,
  0x4013fffffffffffe,
  0x4013ffffffffffff,
  0x4013ffffffffffff,
  0x4015ffffffffffff,
  0x402bffffffffffff,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x400ffffffffffffd,
  0x400ffffffffffffd,
  0x400ffffffffffffd,
  0x400ffffffffffffd,
  0x400ffffffffffffd,
  0x400bfffffffffffd,
  0x400bfffffffffffd,
  0x400bfffffffffffd,
  0x4007fffffffffffd,
  0x4007fffffffffffd,
  0x4007fffffffffffd,
  0x4003fffffffffffd,
  0xc018000000000001,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x400ffffffffffffd,
  0x400ffffffffffffd,
  0x400ffffffffffffd,
  0x3ccfffffffffffff,
  0x3ccfffffffffffff,
  0x3fe0000000000007,
  0x3fe0000000000008,
  0x3fe0000000000009,
  0x3ff0000000000003,
  0x3ff0000000000004,
  0x3ff0000000000005,
  0x3ff8000000000004,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3ccfffffffffffff,
  0x3ccfffffffffffff,
  0x3ccfffffffffffff,
  0x3ccfffffffffffff,
  0x3ccfffffffffffff,
  0xbfdfffffffffffef,
  0xbfdffffffffffff0,
  0xbfdffffffffffff2,
  0xbfeffffffffffff7,
  0xbfeffffffffffff8,
  0xbfeffffffffffffa,
  0xbff7fffffffffffc,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3ccfffffffffffff,
  0x3ccfffffffffffff,
  0x3ccfffffffffffff,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0xc00fffffffffffff,
  0xc00fffffffffffff,
  0xc00bffffffffffff,
  0xc00bffffffffffff,
  0xc00bffffffffffff,
  0xc007ffffffffffff,
  0xc007ffffffffffff,
  0xc007fffffffffffe,
  0xc003ffffffffffff,
  0x4018000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc00fffffffffffff,
  0xc00fffffffffffff,
  0xc00fffffffffffff,
  0xc00fffffffffffff,
  0xc00fffffffffffff,
  0xc011ffffffffffff,
  0xc012000000000000,
  0xc012000000000000,
  0xc013ffffffffffff,
  0xc014000000000000,
  0xc014000000000000,
  0xc016000000000000,
  0xc02c000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc00fffffffffffff,
  0xc00fffffffffffff,
  0xc00fffffffffffff,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0x7fe0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0x7fdfffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0x7fdffffffffffffd,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0x7c9fffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0x0000000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfcafffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xffdfffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xbfd23456789abccf,
  0xbfd23456789abccf,
  0x3fcb97530eca865f,
  0x3fcb97530eca8661,
  0x3fcb97530eca8665,
  0x3fe6e5d4c3b2a197,
  0x3fe6e5d4c3b2a198,
  0x3fe6e5d4c3b2a19a,
  0x3ff372ea61d950cc,
  0x40236e5d4c3b2a1a,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfd23456789abccf,
  0xbfd23456789abccf,
  0xbfd23456789abccf,
  0xbfd23456789abccf,
  0xbfd23456789abccf,
  0xbfe91a2b3c4d5e67,
  0xbfe91a2b3c4d5e68,
  0xbfe91a2b3c4d5e69,
  0xbff48d159e26af33,
  0xbff48d159e26af34,
  0xbff48d159e26af35,
  0xbffc8d159e26af34,
  0xc02491a2b3c4d5e6,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfd23456789abccf,
  0xbfd23456789abccf,
  0xbfd23456789abccf,
  0xc00ffffffffffffd,
  0xc00ffffffffffffd,
  0xc00bfffffffffffd,
  0xc00bfffffffffffd,
  0xc00bfffffffffffd,
  0xc007fffffffffffd,
  0xc007fffffffffffd,
  0xc007fffffffffffd,
  0xc003fffffffffffd,
  0x4018000000000001,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc00ffffffffffffd,
  0xc00ffffffffffffd,
  0xc00ffffffffffffd,
  0xc00ffffffffffffd,
  0xc00ffffffffffffd,
  0xc011fffffffffffe,
  0xc011ffffffffffff,
  0xc011ffffffffffff,
  0xc013fffffffffffe,
  0xc013ffffffffffff,
  0xc013ffffffffffff,
  0xc015ffffffffffff,
  0xc02bffffffffffff,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc00ffffffffffffd,
  0xc00ffffffffffffd,
  0xc00ffffffffffffd,
  0xbccfffffffffffff,
  0xbccfffffffffffff,
  0x3fdfffffffffffef,
  0x3fdffffffffffff0,
  0x3fdffffffffffff2,
  0x3feffffffffffff7,
  0x3feffffffffffff8,
  0x3feffffffffffffa,
  0x3ff7fffffffffffc,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbccfffffffffffff,
  0xbccfffffffffffff,
  0xbccfffffffffffff,
  0xbccfffffffffffff,
  0xbccfffffffffffff,
  0xbfe0000000000007,
  0xbfe0000000000008,
  0xbfe0000000000009,
  0xbff0000000000003,
  0xbff0000000000004,
  0xbff0000000000005,
  0xbff8000000000004,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbccfffffffffffff,
  0xbccfffffffffffff,
  0xbccfffffffffffff,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x000091a2b3c4d5e6,
  0x001091a2b3c4d5e6,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0001b4e81b4e81b3,
  0x001091a2b3c4d5e5,
  0x000091a2b3c4d5e7,
  0x000091a2b3c4d5e6,
  0x800f6e5d4c3b2a1a,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800091a2b3c4d5e7,
  0x800f6e5d4c3b2a19,
  0x000091a2b3c4d5e5,
  0x000091a2b3c4d5e6,
  0x001091a2b3c4d5e6,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0001b4e81b4e81b4,
  0x001091a2b3c4d5e6,
  0x000091a2b3c4d5e8,
  0x000091a2b3c4d5e6,
  0x800f6e5d4c3b2a1a,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800091a2b3c4d5e6,
  0x800f6e5d4c3b2a18,
  0x000091a2b3c4d5e6,
  0x000091a2b3c4d5e7,
  0x001091a2b3c4d5e7,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0001b4e81b4e81b4,
  0x001091a2b3c4d5e6,
  0x000091a2b3c4d5e8,
  0x000091a2b3c4d5e7,
  0x800f6e5d4c3b2a19,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800091a2b3c4d5e6,
  0x800f6e5d4c3b2a18,
  0x000091a2b3c4d5e6,
  0x000123456789abcd,
  0x001123456789abcd,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0002468acf13579a,
  0x001123456789abcc,
  0x000123456789abce,
  0x000123456789abcd,
  0x800edcba98765433,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x8000000000000000,
  0x800edcba98765432,
  0x000123456789abcc,
  0x000123456789abcd,
  0x001123456789abcd,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0002468acf13579a,
  0x001123456789abcc,
  0x000123456789abce,
  0x000123456789abcd,
  0x800edcba98765433,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0000000000000000,
  0x800edcba98765432,
  0x000123456789abcc,
  0x000123456789abcd,
  0x001123456789abcd,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0002468acf13579a,
  0x001123456789abcc,
  0x000123456789abce,
  0x000123456789abcd,
  0x800edcba98765433,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0000000000000000,
  0x800edcba98765432,
  0x000123456789abcc,
  0x0001b4e81b4e81b4,
  0x0011b4e81b4e81b4,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0002d82d82d82d80,
  0x0011b4e81b4e81b2,
  0x0001b4e81b4e81b4,
  0x0001b4e81b4e81b4,
  0x800e4b17e4b17e4c,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x000091a2b3c4d5e6,
  0x800e4b17e4b17e4c,
  0x0001b4e81b4e81b2,
  0x000b60b60b60b602,
  0x001b60b60b60b602,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000c83fb72ea61cf,
  0x001b60b60b60b601,
  0x000b60b60b60b603,
  0x000b60b60b60b602,
  0x80049f49f49f49fe,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x000a3d70a3d70a35,
  0x80049f49f49f49fd,
  0x000b60b60b60b601,
  0x3fd23456789abccf,
  0x3fd23456789abccf,
  0x3fe91a2b3c4d5e67,
  0x3fe91a2b3c4d5e68,
  0x3fe91a2b3c4d5e69,
  0x3ff48d159e26af33,
  0x3ff48d159e26af34,
  0x3ff48d159e26af35,
  0x3ffc8d159e26af34,
  0x402491a2b3c4d5e6,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fd23456789abccf,
  0x3fd23456789abccf,
  0x3fd23456789abccf,
  0x3fd23456789abccf,
  0x3fd23456789abccf,
  0xbfcb97530eca865f,
  0xbfcb97530eca8661,
  0xbfcb97530eca8665,
  0xbfe6e5d4c3b2a197,
  0xbfe6e5d4c3b2a198,
  0xbfe6e5d4c3b2a19a,
  0xbff372ea61d950cc,
  0xc0236e5d4c3b2a1a,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fd23456789abccf,
  0x3fd23456789abccf,
  0x3fd23456789abccf,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x800091a2b3c4d5e6,
  0x000f6e5d4c3b2a1a,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000091a2b3c4d5e7,
  0x000f6e5d4c3b2a19,
  0x800091a2b3c4d5e5,
  0x800091a2b3c4d5e6,
  0x801091a2b3c4d5e6,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x8001b4e81b4e81b3,
  0x801091a2b3c4d5e5,
  0x800091a2b3c4d5e7,
  0x800091a2b3c4d5e6,
  0x000f6e5d4c3b2a1a,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000091a2b3c4d5e6,
  0x000f6e5d4c3b2a18,
  0x800091a2b3c4d5e6,
  0x800091a2b3c4d5e6,
  0x801091a2b3c4d5e6,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x8001b4e81b4e81b4,
  0x801091a2b3c4d5e6,
  0x800091a2b3c4d5e8,
  0x800091a2b3c4d5e7,
  0x000f6e5d4c3b2a19,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000091a2b3c4d5e6,
  0x000f6e5d4c3b2a18,
  0x800091a2b3c4d5e6,
  0x800091a2b3c4d5e7,
  0x801091a2b3c4d5e7,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x8001b4e81b4e81b4,
  0x801091a2b3c4d5e6,
  0x800091a2b3c4d5e8,
  0x800123456789abcd,
  0x000edcba98765433,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0000000000000000,
  0x000edcba98765432,
  0x800123456789abcc,
  0x800123456789abcd,
  0x801123456789abcd,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x8002468acf13579a,
  0x801123456789abcc,
  0x800123456789abce,
  0x800123456789abcd,
  0x000edcba98765433,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0000000000000000,
  0x000edcba98765432,
  0x800123456789abcc,
  0x800123456789abcd,
  0x801123456789abcd,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x8002468acf13579a,
  0x801123456789abcc,
  0x800123456789abce,
  0x800123456789abcd,
  0x000edcba98765433,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8000000000000000,
  0x000edcba98765432,
  0x800123456789abcc,
  0x800123456789abcd,
  0x801123456789abcd,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x8002468acf13579a,
  0x801123456789abcc,
  0x800123456789abce,
  0x8001b4e81b4e81b4,
  0x000e4b17e4b17e4c,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x800091a2b3c4d5e6,
  0x000e4b17e4b17e4c,
  0x8001b4e81b4e81b2,
  0x8001b4e81b4e81b4,
  0x8011b4e81b4e81b4,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x8002d82d82d82d80,
  0x8011b4e81b4e81b2,
  0x8001b4e81b4e81b4,
  0x800b60b60b60b602,
  0x00049f49f49f49fe,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x800a3d70a3d70a35,
  0x00049f49f49f49fd,
  0x800b60b60b60b601,
  0x800b60b60b60b602,
  0x801b60b60b60b602,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800c83fb72ea61cf,
  0x801b60b60b60b601,
  0x800b60b60b60b603,
  0xbfd23456789abccf,
  0xbfd23456789abccf,
  0x3fcb97530eca865f,
  0x3fcb97530eca8661,
  0x3fcb97530eca8665,
  0x3fe6e5d4c3b2a197,
  0x3fe6e5d4c3b2a198,
  0x3fe6e5d4c3b2a19a,
  0x3ff372ea61d950cc,
  0x40236e5d4c3b2a1a,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfd23456789abccf,
  0xbfd23456789abccf,
  0xbfd23456789abccf,
  0xbfd23456789abccf,
  0xbfd23456789abccf,
  0xbfe91a2b3c4d5e67,
  0xbfe91a2b3c4d5e68,
  0xbfe91a2b3c4d5e69,
  0xbff48d159e26af33,
  0xbff48d159e26af34,
  0xbff48d159e26af35,
  0xbffc8d159e26af34,
  0xc02491a2b3c4d5e6,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfd23456789abccf,
  0xbfd23456789abccf,
  0xbfd23456789abccf,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0007ffffffffffff,
  0x0017ffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000923456789abcc,
  0x0017fffffffffffe,
  0x0008000000000000,
  0x0007ffffffffffff,
  0x8008000000000001,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0006dcba98765432,
  0x8008000000000000,
  0x0007fffffffffffe,
  0x0008000000000000,
  0x0018000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000923456789abcc,
  0x0017fffffffffffe,
  0x0008000000000000,
  0x0008000000000000,
  0x8008000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0006dcba98765432,
  0x8008000000000000,
  0x0007fffffffffffe,
  0x0008000000000000,
  0x0018000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000923456789abcd,
  0x0017ffffffffffff,
  0x0008000000000001,
  0x0008000000000000,
  0x8008000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0006dcba98765433,
  0x8007ffffffffffff,
  0x0007ffffffffffff,
  0x000fffffffffffff,
  0x001fffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x001123456789abcc,
  0x001ffffffffffffe,
  0x0010000000000000,
  0x000fffffffffffff,
  0x8000000000000001,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x000edcba98765432,
  0x8000000000000000,
  0x000ffffffffffffe,
  0x000fffffffffffff,
  0x001fffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x001123456789abcc,
  0x001ffffffffffffe,
  0x0010000000000000,
  0x000fffffffffffff,
  0x8000000000000001,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x000edcba98765432,
  0x0000000000000000,
  0x000ffffffffffffe,
  0x0010000000000000,
  0x0020000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x001123456789abcd,
  0x001fffffffffffff,
  0x0010000000000001,
  0x0010000000000000,
  0x8000000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x000edcba98765433,
  0x0000000000000001,
  0x000fffffffffffff,
  0x0017fffffffffffe,
  0x0023ffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x001923456789abcc,
  0x0023ffffffffffff,
  0x0018000000000000,
  0x0017fffffffffffe,
  0x0007fffffffffffe,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0016dcba98765432,
  0x0008000000000000,
  0x0017fffffffffffe,
  0x0043ffffffffffff,
  0x0045ffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x00442468acf13578,
  0x0045ffffffffffff,
  0x0043ffffffffffff,
  0x0043ffffffffffff,
  0x0041ffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0043db97530eca85,
  0x0041ffffffffffff,
  0x0043ffffffffffff,
  0x400ffffffffffffd,
  0x400ffffffffffffd,
  0x4011fffffffffffe,
  0x4011ffffffffffff,
  0x4011ffffffffffff,
  0x4013fffffffffffe,
  0x4013ffffffffffff,
  0x4013ffffffffffff,
  0x4015ffffffffffff,
  0x402bffffffffffff,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x400ffffffffffffd,
  0x400ffffffffffffd,
  0x400ffffffffffffd,
  0x400ffffffffffffd,
  0x400ffffffffffffd,
  0x400bfffffffffffd,
  0x400bfffffffffffd,
  0x400bfffffffffffd,
  0x4007fffffffffffd,
  0x4007fffffffffffd,
  0x4007fffffffffffd,
  0x4003fffffffffffd,
  0xc018000000000001,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x400ffffffffffffd,
  0x400ffffffffffffd,
  0x400ffffffffffffd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8007ffffffffffff,
  0x0008000000000001,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8006dcba98765432,
  0x0008000000000000,
  0x8007fffffffffffe,
  0x8007ffffffffffff,
  0x8017ffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800923456789abcc,
  0x8017fffffffffffe,
  0x8008000000000000,
  0x8008000000000000,
  0x0008000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8006dcba98765432,
  0x0008000000000000,
  0x8007fffffffffffe,
  0x8008000000000000,
  0x8018000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800923456789abcc,
  0x8017fffffffffffe,
  0x8008000000000000,
  0x8008000000000000,
  0x0008000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8006dcba98765433,
  0x0007ffffffffffff,
  0x8007ffffffffffff,
  0x8008000000000000,
  0x8018000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800923456789abcd,
  0x8017ffffffffffff,
  0x8008000000000001,
  0x800fffffffffffff,
  0x0000000000000001,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x800edcba98765432,
  0x0000000000000000,
  0x800ffffffffffffe,
  0x800fffffffffffff,
  0x801fffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x801123456789abcc,
  0x801ffffffffffffe,
  0x8010000000000000,
  0x800fffffffffffff,
  0x0000000000000001,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x800edcba98765432,
  0x0000000000000000,
  0x800ffffffffffffe,
  0x800fffffffffffff,
  0x801fffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x801123456789abcc,
  0x801ffffffffffffe,
  0x8010000000000000,
  0x8010000000000000,
  0x0000000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x800edcba98765433,
  0x8000000000000001,
  0x800fffffffffffff,
  0x8010000000000000,
  0x8020000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x801123456789abcd,
  0x801fffffffffffff,
  0x8010000000000001,
  0x8017fffffffffffe,
  0x8007fffffffffffe,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8016dcba98765432,
  0x8008000000000000,
  0x8017fffffffffffe,
  0x8017fffffffffffe,
  0x8023ffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x801923456789abcc,
  0x8023ffffffffffff,
  0x8018000000000000,
  0x8043ffffffffffff,
  0x8041ffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8043db97530eca85,
  0x8041ffffffffffff,
  0x8043ffffffffffff,
  0x8043ffffffffffff,
  0x8045ffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x80442468acf13578,
  0x8045ffffffffffff,
  0x8043ffffffffffff,
  0xc00ffffffffffffd,
  0xc00ffffffffffffd,
  0xc00bfffffffffffd,
  0xc00bfffffffffffd,
  0xc00bfffffffffffd,
  0xc007fffffffffffd,
  0xc007fffffffffffd,
  0xc007fffffffffffd,
  0xc003fffffffffffd,
  0x4018000000000001,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc00ffffffffffffd,
  0xc00ffffffffffffd,
  0xc00ffffffffffffd,
  0xc00ffffffffffffd,
  0xc00ffffffffffffd,
  0xc011fffffffffffe,
  0xc011ffffffffffff,
  0xc011ffffffffffff,
  0xc013fffffffffffe,
  0xc013ffffffffffff,
  0xc013ffffffffffff,
  0xc015ffffffffffff,
  0xc02bffffffffffff,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc00ffffffffffffd,
  0xc00ffffffffffffd,
  0xc00ffffffffffffd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abce,
  0x0010000000000000,
  0x0000000000000002,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcc,
  0x800ffffffffffffe,
  0x8000000000000000,
  0x0000000000000001,
  0x0010000000000001,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abce,
  0x0010000000000000,
  0x0000000000000002,
  0x0000000000000001,
  0x800fffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcc,
  0x800ffffffffffffe,
  0x8000000000000000,
  0x0000000000000001,
  0x0010000000000001,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abce,
  0x0010000000000000,
  0x0000000000000002,
  0x0000000000000001,
  0x800fffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcc,
  0x800ffffffffffffe,
  0x8000000000000000,
  0x0000000000000001,
  0x0010000000000001,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abce,
  0x0010000000000000,
  0x0000000000000002,
  0x0000000000000001,
  0x800fffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcc,
  0x800ffffffffffffe,
  0x0000000000000000,
  0x0000000000000001,
  0x0010000000000001,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abce,
  0x0010000000000000,
  0x0000000000000002,
  0x0000000000000001,
  0x800fffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcc,
  0x800ffffffffffffe,
  0x0000000000000000,
  0x0000000000000002,
  0x0010000000000002,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abce,
  0x0010000000000000,
  0x0000000000000002,
  0x0000000000000002,
  0x800ffffffffffffe,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcc,
  0x800ffffffffffffe,
  0x0000000000000000,
  0x000000000000000a,
  0x001000000000000a,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abd7,
  0x0010000000000009,
  0x000000000000000b,
  0x000000000000000a,
  0x800ffffffffffff6,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abc3,
  0x800ffffffffffff5,
  0x0000000000000009,
  0x3ccfffffffffffff,
  0x3ccfffffffffffff,
  0x3fe0000000000007,
  0x3fe0000000000008,
  0x3fe0000000000009,
  0x3ff0000000000003,
  0x3ff0000000000004,
  0x3ff0000000000005,
  0x3ff8000000000004,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3ccfffffffffffff,
  0x3ccfffffffffffff,
  0x3ccfffffffffffff,
  0x3ccfffffffffffff,
  0x3ccfffffffffffff,
  0xbfdfffffffffffef,
  0xbfdffffffffffff0,
  0xbfdffffffffffff2,
  0xbfeffffffffffff7,
  0xbfeffffffffffff8,
  0xbfeffffffffffffa,
  0xbff7fffffffffffc,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3ccfffffffffffff,
  0x3ccfffffffffffff,
  0x3ccfffffffffffff,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcc,
  0x000ffffffffffffe,
  0x0000000000000000,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abce,
  0x8010000000000000,
  0x8000000000000002,
  0x8000000000000001,
  0x000fffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcc,
  0x000ffffffffffffe,
  0x0000000000000000,
  0x8000000000000001,
  0x8010000000000001,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abce,
  0x8010000000000000,
  0x8000000000000002,
  0x8000000000000001,
  0x000fffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcc,
  0x000ffffffffffffe,
  0x0000000000000000,
  0x8000000000000001,
  0x8010000000000001,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abce,
  0x8010000000000000,
  0x8000000000000002,
  0x8000000000000001,
  0x000fffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcc,
  0x000ffffffffffffe,
  0x0000000000000000,
  0x8000000000000001,
  0x8010000000000001,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abce,
  0x8010000000000000,
  0x8000000000000002,
  0x8000000000000001,
  0x000fffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcc,
  0x000ffffffffffffe,
  0x8000000000000000,
  0x8000000000000001,
  0x8010000000000001,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abce,
  0x8010000000000000,
  0x8000000000000002,
  0x8000000000000002,
  0x000ffffffffffffe,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcc,
  0x000ffffffffffffe,
  0x8000000000000000,
  0x8000000000000002,
  0x8010000000000002,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abce,
  0x8010000000000000,
  0x8000000000000002,
  0x800000000000000a,
  0x000ffffffffffff6,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abc3,
  0x000ffffffffffff5,
  0x8000000000000009,
  0x800000000000000a,
  0x801000000000000a,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abd7,
  0x8010000000000009,
  0x800000000000000b,
  0xbccfffffffffffff,
  0xbccfffffffffffff,
  0x3fdfffffffffffef,
  0x3fdffffffffffff0,
  0x3fdffffffffffff2,
  0x3feffffffffffff7,
  0x3feffffffffffff8,
  0x3feffffffffffffa,
  0x3ff7fffffffffffc,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbccfffffffffffff,
  0xbccfffffffffffff,
  0xbccfffffffffffff,
  0xbccfffffffffffff,
  0xbccfffffffffffff,
  0xbfe0000000000007,
  0xbfe0000000000008,
  0xbfe0000000000009,
  0xbff0000000000003,
  0xbff0000000000004,
  0xbff0000000000005,
  0xbff8000000000004,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbccfffffffffffff,
  0xbccfffffffffffff,
  0xbccfffffffffffff,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
};
const unsigned kExpectedCount_fmsub_d = 54872;

const uint32_t kExpected_fmsub_s[] = {
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80400000,
  0x00400000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x802dcbaa,
  0x003fffff,
  0x803fffff,
  0x80400000,
  0x80c00000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80523456,
  0x80bfffff,
  0x80400001,
  0x80400000,
  0x00400000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x802dcbaa,
  0x003fffff,
  0x803fffff,
  0x80400000,
  0x80c00000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80523456,
  0x80bfffff,
  0x80400001,
  0x80400000,
  0x00400000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x802dcbaa,
  0x003ffffe,
  0x80400000,
  0x80400000,
  0x80c00000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80523456,
  0x80c00000,
  0x80400002,
  0x80800000,
  0x00000000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x806dcbaa,
  0x80000000,
  0x807ffffe,
  0x80800000,
  0x81000000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80923456,
  0x80fffffe,
  0x80800000,
  0x80800000,
  0x00000000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x806dcbaa,
  0x80000001,
  0x807fffff,
  0x80800000,
  0x81000000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80923456,
  0x80ffffff,
  0x80800001,
  0x80800001,
  0x80000001,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x806dcbab,
  0x80000002,
  0x80800000,
  0x80800001,
  0x81000000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80923457,
  0x81000000,
  0x80800002,
  0x80c00000,
  0x80400000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x80adcbaa,
  0x80400001,
  0x80bfffff,
  0x80c00000,
  0x81200000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80d23456,
  0x81200000,
  0x80c00001,
  0x82200000,
  0x82100000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x821db975,
  0x82100000,
  0x82200000,
  0x82200000,
  0x82300000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x8222468b,
  0x82300000,
  0x82200000,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00400000,
  0x00c00000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00523456,
  0x00bfffff,
  0x00400001,
  0x00400000,
  0x80400000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x002dcbaa,
  0x803fffff,
  0x003fffff,
  0x00400000,
  0x00c00000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00523456,
  0x00bfffff,
  0x00400001,
  0x00400000,
  0x80400000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x002dcbaa,
  0x803fffff,
  0x003fffff,
  0x00400000,
  0x00c00000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00523456,
  0x00c00000,
  0x00400002,
  0x00400000,
  0x80400000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x002dcbaa,
  0x803ffffe,
  0x00400000,
  0x00800000,
  0x01000000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00923456,
  0x00fffffe,
  0x00800000,
  0x00800000,
  0x80000000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x006dcbaa,
  0x00000000,
  0x007ffffe,
  0x00800000,
  0x01000000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00923456,
  0x00ffffff,
  0x00800001,
  0x00800000,
  0x00000000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x006dcbaa,
  0x00000001,
  0x007fffff,
  0x00800001,
  0x01000000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00923457,
  0x01000000,
  0x00800002,
  0x00800001,
  0x00000001,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x006dcbab,
  0x00000002,
  0x00800000,
  0x00c00000,
  0x01200000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00d23456,
  0x01200000,
  0x00c00001,
  0x00c00000,
  0x00400000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x00adcbaa,
  0x00400001,
  0x00bfffff,
  0x02200000,
  0x02300000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x0222468b,
  0x02300000,
  0x02200000,
  0x02200000,
  0x02100000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x021db975,
  0x02100000,
  0x02200000,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80400000,
  0x00400000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x802dcbaa,
  0x003fffff,
  0x803fffff,
  0x80400000,
  0x80c00000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80523456,
  0x80bfffff,
  0x80400001,
  0xbe7ffffe,
  0xbe7ffffe,
  0x3e800000,
  0x3e800001,
  0x3e800003,
  0x3f3fffff,
  0x3f400000,
  0x3f400002,
  0x3fa00000,
  0x411c0000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbe7ffffe,
  0xbe7ffffe,
  0xbe7ffffe,
  0xbe7ffffe,
  0xbe7ffffe,
  0xbf3fffff,
  0xbf400000,
  0xbf400001,
  0xbf9fffff,
  0xbfa00000,
  0xbfa00001,
  0xbfe00000,
  0xc1240000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbe7ffffe,
  0xbe7ffffe,
  0xbe7ffffe,
  0xbe7fffff,
  0xbe7fffff,
  0x3e7fffff,
  0x3e800000,
  0x3e800002,
  0x3f3fffff,
  0x3f400000,
  0x3f400002,
  0x3fa00000,
  0x411c0000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbe7fffff,
  0xbe7fffff,
  0xbe7fffff,
  0xbe7fffff,
  0xbe7fffff,
  0xbf3fffff,
  0xbf400000,
  0xbf400001,
  0xbf9fffff,
  0xbfa00000,
  0xbfa00001,
  0xbfe00000,
  0xc1240000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbe7fffff,
  0xbe7fffff,
  0xbe7fffff,
  0xbe800000,
  0xbe800000,
  0x3e7ffffd,
  0x3e7fffff,
  0x3e800002,
  0x3f3fffff,
  0x3f400000,
  0x3f400002,
  0x3fa00000,
  0x411c0000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbe800000,
  0xbe800000,
  0xbe800000,
  0xbe800000,
  0xbe800000,
  0xbf400000,
  0xbf400000,
  0xbf400001,
  0xbfa00000,
  0xbfa00000,
  0xbfa00001,
  0xbfe00000,
  0xc1240000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbe800000,
  0xbe800000,
  0xbe800000,
  0xbefffffe,
  0xbefffffe,
  0x32ffffff,
  0x33800000,
  0x34000000,
  0x3f000000,
  0x3f000001,
  0x3f000003,
  0x3f800000,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbefffffe,
  0xbefffffe,
  0xbefffffe,
  0xbefffffe,
  0xbefffffe,
  0xbf7fffff,
  0xbf7fffff,
  0xbf800000,
  0xbfbfffff,
  0xbfc00000,
  0xbfc00001,
  0xc0000000,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbefffffe,
  0xbefffffe,
  0xbefffffe,
  0xbeffffff,
  0xbeffffff,
  0x00000000,
  0x33000000,
  0x33c00000,
  0x3effffff,
  0x3f000000,
  0x3f000002,
  0x3f800000,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbf7fffff,
  0xbf800000,
  0xbf800000,
  0xbfbfffff,
  0xbfc00000,
  0xbfc00001,
  0xc0000000,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbf000000,
  0xbf000000,
  0xb37fffff,
  0xb2fffffe,
  0x33000001,
  0x3efffffd,
  0x3effffff,
  0x3f000002,
  0x3f800000,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf800000,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xbfc00000,
  0xbfc00001,
  0xc0000000,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf3fffff,
  0xbf3fffff,
  0xbe7fffff,
  0xbe7ffffd,
  0xbe7ffff9,
  0x3e7fffff,
  0x3e800002,
  0x3e800006,
  0x3f400001,
  0x41140000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf3fffff,
  0xbf3fffff,
  0xbf3fffff,
  0xbf3fffff,
  0xbf3fffff,
  0xbf9fffff,
  0xbfa00000,
  0xbfa00000,
  0xbfdfffff,
  0xbfe00000,
  0xbfe00001,
  0xc0100000,
  0xc12c0000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf3fffff,
  0xbf3fffff,
  0xbf3fffff,
  0xc09fffff,
  0xc09fffff,
  0xc08fffff,
  0xc08fffff,
  0xc08fffff,
  0xc07fffff,
  0xc07fffff,
  0xc07ffffe,
  0xc05fffff,
  0x40a00001,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xc09fffff,
  0xc09fffff,
  0xc09fffff,
  0xc09fffff,
  0xc09fffff,
  0xc0afffff,
  0xc0afffff,
  0xc0b00000,
  0xc0bfffff,
  0xc0bfffff,
  0xc0c00000,
  0xc0cfffff,
  0xc1700000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xc09fffff,
  0xc09fffff,
  0xc09fffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x80091a2b,
  0x0076e5d5,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00091a2b,
  0x0076e5d4,
  0x80091a2a,
  0x80091a2b,
  0x80891a2b,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x801b4e81,
  0x80891a2a,
  0x80091a2c,
  0x803fffff,
  0x00400001,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x802dcba9,
  0x00400000,
  0x803ffffe,
  0x803fffff,
  0x80bfffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80523455,
  0x80bffffe,
  0x80400000,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00400000,
  0x00c00000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00523456,
  0x00bfffff,
  0x00400001,
  0x00400000,
  0x80400000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x002dcbaa,
  0x803fffff,
  0x003fffff,
  0x3e7ffffe,
  0x3e7ffffe,
  0x3f3fffff,
  0x3f400000,
  0x3f400001,
  0x3f9fffff,
  0x3fa00000,
  0x3fa00001,
  0x3fe00000,
  0x41240000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3e7ffffe,
  0x3e7ffffe,
  0x3e7ffffe,
  0x3e7ffffe,
  0x3e7ffffe,
  0xbe800000,
  0xbe800001,
  0xbe800003,
  0xbf3fffff,
  0xbf400000,
  0xbf400002,
  0xbfa00000,
  0xc11c0000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3e7ffffe,
  0x3e7ffffe,
  0x3e7ffffe,
  0x3e7fffff,
  0x3e7fffff,
  0x3f3fffff,
  0x3f400000,
  0x3f400001,
  0x3f9fffff,
  0x3fa00000,
  0x3fa00001,
  0x3fe00000,
  0x41240000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3e7fffff,
  0x3e7fffff,
  0x3e7fffff,
  0x3e7fffff,
  0x3e7fffff,
  0xbe7fffff,
  0xbe800000,
  0xbe800002,
  0xbf3fffff,
  0xbf400000,
  0xbf400002,
  0xbfa00000,
  0xc11c0000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3e7fffff,
  0x3e7fffff,
  0x3e7fffff,
  0x3e800000,
  0x3e800000,
  0x3f400000,
  0x3f400000,
  0x3f400001,
  0x3fa00000,
  0x3fa00000,
  0x3fa00001,
  0x3fe00000,
  0x41240000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3e800000,
  0x3e800000,
  0x3e800000,
  0x3e800000,
  0x3e800000,
  0xbe7ffffd,
  0xbe7fffff,
  0xbe800002,
  0xbf3fffff,
  0xbf400000,
  0xbf400002,
  0xbfa00000,
  0xc11c0000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3e800000,
  0x3e800000,
  0x3e800000,
  0x3efffffe,
  0x3efffffe,
  0x3f7fffff,
  0x3f7fffff,
  0x3f800000,
  0x3fbfffff,
  0x3fc00000,
  0x3fc00001,
  0x40000000,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3efffffe,
  0x3efffffe,
  0x3efffffe,
  0x3efffffe,
  0x3efffffe,
  0xb2ffffff,
  0xb3800000,
  0xb4000000,
  0xbf000000,
  0xbf000001,
  0xbf000003,
  0xbf800000,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3efffffe,
  0x3efffffe,
  0x3efffffe,
  0x3effffff,
  0x3effffff,
  0x3f7fffff,
  0x3f800000,
  0x3f800000,
  0x3fbfffff,
  0x3fc00000,
  0x3fc00001,
  0x40000000,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x00000000,
  0xb3000000,
  0xb3c00000,
  0xbeffffff,
  0xbf000000,
  0xbf000002,
  0xbf800000,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3f000000,
  0x3f000000,
  0x3f800000,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x3fc00000,
  0x3fc00001,
  0x40000000,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x337fffff,
  0x32fffffe,
  0xb3000001,
  0xbefffffd,
  0xbeffffff,
  0xbf000002,
  0xbf800000,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f3fffff,
  0x3f3fffff,
  0x3f9fffff,
  0x3fa00000,
  0x3fa00000,
  0x3fdfffff,
  0x3fe00000,
  0x3fe00001,
  0x40100000,
  0x412c0000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f3fffff,
  0x3f3fffff,
  0x3f3fffff,
  0x3f3fffff,
  0x3f3fffff,
  0x3e7fffff,
  0x3e7ffffd,
  0x3e7ffff9,
  0xbe7fffff,
  0xbe800002,
  0xbe800006,
  0xbf400001,
  0xc1140000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f3fffff,
  0x3f3fffff,
  0x3f3fffff,
  0x409fffff,
  0x409fffff,
  0x40afffff,
  0x40afffff,
  0x40b00000,
  0x40bfffff,
  0x40bfffff,
  0x40c00000,
  0x40cfffff,
  0x41700000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x409fffff,
  0x409fffff,
  0x409fffff,
  0x409fffff,
  0x409fffff,
  0x408fffff,
  0x408fffff,
  0x408fffff,
  0x407fffff,
  0x407fffff,
  0x407ffffe,
  0x405fffff,
  0xc0a00001,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x409fffff,
  0x409fffff,
  0x409fffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x00091a2b,
  0x00891a2b,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x001b4e81,
  0x00891a2a,
  0x00091a2c,
  0x00091a2b,
  0x8076e5d5,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80091a2b,
  0x8076e5d4,
  0x00091a2a,
  0x003fffff,
  0x00bfffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00523455,
  0x00bffffe,
  0x00400000,
  0x003fffff,
  0x80400001,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x002dcba9,
  0x80400000,
  0x003ffffe,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80400000,
  0x00400000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x802dcbaa,
  0x003fffff,
  0x803fffff,
  0x80400000,
  0x80c00000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80523456,
  0x80bfffff,
  0x80400001,
  0xbe7fffff,
  0xbe7fffff,
  0x3e7fffff,
  0x3e800000,
  0x3e800002,
  0x3f3fffff,
  0x3f400000,
  0x3f400002,
  0x3fa00000,
  0x411c0000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbe7fffff,
  0xbe7fffff,
  0xbe7fffff,
  0xbe7fffff,
  0xbe7fffff,
  0xbf3fffff,
  0xbf400000,
  0xbf400001,
  0xbf9fffff,
  0xbfa00000,
  0xbfa00001,
  0xbfe00000,
  0xc1240000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbe7fffff,
  0xbe7fffff,
  0xbe7fffff,
  0xbe800000,
  0xbe800000,
  0x3e7ffffe,
  0x3e800000,
  0x3e800002,
  0x3f3fffff,
  0x3f400000,
  0x3f400002,
  0x3fa00000,
  0x411c0000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbe800000,
  0xbe800000,
  0xbe800000,
  0xbe800000,
  0xbe800000,
  0xbf400000,
  0xbf400000,
  0xbf400001,
  0xbfa00000,
  0xbfa00000,
  0xbfa00001,
  0xbfe00000,
  0xc1240000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbe800000,
  0xbe800000,
  0xbe800000,
  0xbe800001,
  0xbe800001,
  0x3e7ffffc,
  0x3e7ffffe,
  0x3e800001,
  0x3f3ffffe,
  0x3f400000,
  0x3f400002,
  0x3fa00000,
  0x411c0000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbe800001,
  0xbe800001,
  0xbe800001,
  0xbe800001,
  0xbe800001,
  0xbf400000,
  0xbf400000,
  0xbf400002,
  0xbfa00000,
  0xbfa00000,
  0xbfa00001,
  0xbfe00000,
  0xc1240000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbe800001,
  0xbe800001,
  0xbe800001,
  0xbeffffff,
  0xbeffffff,
  0x00000000,
  0x33000000,
  0x33c00000,
  0x3effffff,
  0x3f000000,
  0x3f000002,
  0x3f800000,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbf7fffff,
  0xbf800000,
  0xbf800000,
  0xbfbfffff,
  0xbfc00000,
  0xbfc00001,
  0xc0000000,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbf000000,
  0xbf000000,
  0xb3000000,
  0x00000000,
  0x33800000,
  0x3efffffe,
  0x3f000000,
  0x3f000002,
  0x3f800000,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbfc00000,
  0xbfc00000,
  0xbfc00001,
  0xc0000000,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000001,
  0xbf000001,
  0xb3c00000,
  0xb3800000,
  0x00000000,
  0x3efffffc,
  0x3efffffe,
  0x3f000001,
  0x3f7fffff,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf800000,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xbfc00000,
  0xbfc00002,
  0xc0000000,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf400000,
  0xbf400000,
  0xbe800001,
  0xbe800000,
  0xbe7ffffc,
  0x3e7ffffc,
  0x3e800000,
  0x3e800004,
  0x3f400000,
  0x41140000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf400000,
  0xbf400000,
  0xbf400000,
  0xbf400000,
  0xbf400000,
  0xbfa00000,
  0xbfa00000,
  0xbfa00000,
  0xbfe00000,
  0xbfe00000,
  0xbfe00001,
  0xc0100000,
  0xc12c0000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf400000,
  0xbf400000,
  0xbf400000,
  0xc0a00000,
  0xc0a00000,
  0xc0900000,
  0xc0900000,
  0xc0900000,
  0xc0800000,
  0xc0800000,
  0xc0800000,
  0xc0600000,
  0x40a00000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xc0a00000,
  0xc0a00000,
  0xc0a00000,
  0xc0a00000,
  0xc0a00000,
  0xc0b00000,
  0xc0b00000,
  0xc0b00000,
  0xc0c00000,
  0xc0c00000,
  0xc0c00000,
  0xc0d00000,
  0xc1700000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xc0a00000,
  0xc0a00000,
  0xc0a00000,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x80091a2b,
  0x0076e5d5,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00091a2b,
  0x0076e5d4,
  0x80091a2a,
  0x80091a2b,
  0x80891a2b,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x801b4e81,
  0x80891a2a,
  0x80091a2c,
  0x80400000,
  0x00400000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x802dcbaa,
  0x00400000,
  0x803ffffe,
  0x80400000,
  0x80c00000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80523456,
  0x80bffffe,
  0x80400000,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007ffffe,
  0x00000000,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x80800000,
  0x80000002,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00400000,
  0x00c00000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00523456,
  0x00bfffff,
  0x00400001,
  0x00400000,
  0x80400000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x002dcbaa,
  0x803fffff,
  0x003fffff,
  0x3e7fffff,
  0x3e7fffff,
  0x3f3fffff,
  0x3f400000,
  0x3f400001,
  0x3f9fffff,
  0x3fa00000,
  0x3fa00001,
  0x3fe00000,
  0x41240000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3e7fffff,
  0x3e7fffff,
  0x3e7fffff,
  0x3e7fffff,
  0x3e7fffff,
  0xbe7fffff,
  0xbe800000,
  0xbe800002,
  0xbf3fffff,
  0xbf400000,
  0xbf400002,
  0xbfa00000,
  0xc11c0000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3e7fffff,
  0x3e7fffff,
  0x3e7fffff,
  0x3e800000,
  0x3e800000,
  0x3f400000,
  0x3f400000,
  0x3f400001,
  0x3fa00000,
  0x3fa00000,
  0x3fa00001,
  0x3fe00000,
  0x41240000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3e800000,
  0x3e800000,
  0x3e800000,
  0x3e800000,
  0x3e800000,
  0xbe7ffffe,
  0xbe800000,
  0xbe800002,
  0xbf3fffff,
  0xbf400000,
  0xbf400002,
  0xbfa00000,
  0xc11c0000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3e800000,
  0x3e800000,
  0x3e800000,
  0x3e800001,
  0x3e800001,
  0x3f400000,
  0x3f400000,
  0x3f400002,
  0x3fa00000,
  0x3fa00000,
  0x3fa00001,
  0x3fe00000,
  0x41240000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3e800001,
  0x3e800001,
  0x3e800001,
  0x3e800001,
  0x3e800001,
  0xbe7ffffc,
  0xbe7ffffe,
  0xbe800001,
  0xbf3ffffe,
  0xbf400000,
  0xbf400002,
  0xbfa00000,
  0xc11c0000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3e800001,
  0x3e800001,
  0x3e800001,
  0x3effffff,
  0x3effffff,
  0x3f7fffff,
  0x3f800000,
  0x3f800000,
  0x3fbfffff,
  0x3fc00000,
  0x3fc00001,
  0x40000000,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x00000000,
  0xb3000000,
  0xb3c00000,
  0xbeffffff,
  0xbf000000,
  0xbf000002,
  0xbf800000,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3f000000,
  0x3f000000,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3fc00000,
  0x3fc00000,
  0x3fc00001,
  0x40000000,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x33000000,
  0x00000000,
  0xb3800000,
  0xbefffffe,
  0xbf000000,
  0xbf000002,
  0xbf800000,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000001,
  0x3f000001,
  0x3f800000,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x3fc00000,
  0x3fc00002,
  0x40000000,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x33c00000,
  0x33800000,
  0x00000000,
  0xbefffffc,
  0xbefffffe,
  0xbf000001,
  0xbf7fffff,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f400000,
  0x3f400000,
  0x3fa00000,
  0x3fa00000,
  0x3fa00000,
  0x3fe00000,
  0x3fe00000,
  0x3fe00001,
  0x40100000,
  0x412c0000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f400000,
  0x3f400000,
  0x3f400000,
  0x3f400000,
  0x3f400000,
  0x3e800001,
  0x3e800000,
  0x3e7ffffc,
  0xbe7ffffc,
  0xbe800000,
  0xbe800004,
  0xbf400000,
  0xc1140000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f400000,
  0x3f400000,
  0x3f400000,
  0x40a00000,
  0x40a00000,
  0x40b00000,
  0x40b00000,
  0x40b00000,
  0x40c00000,
  0x40c00000,
  0x40c00000,
  0x40d00000,
  0x41700000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x40a00000,
  0x40a00000,
  0x40a00000,
  0x40a00000,
  0x40a00000,
  0x40900000,
  0x40900000,
  0x40900000,
  0x40800000,
  0x40800000,
  0x40800000,
  0x40600000,
  0xc0a00000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x40a00000,
  0x40a00000,
  0x40a00000,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x00091a2b,
  0x00891a2b,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x001b4e81,
  0x00891a2a,
  0x00091a2c,
  0x00091a2b,
  0x8076e5d5,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80091a2b,
  0x8076e5d4,
  0x00091a2a,
  0x00400000,
  0x00c00000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00523456,
  0x00bffffe,
  0x00400000,
  0x00400000,
  0x80400000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x002dcbaa,
  0x80400000,
  0x003ffffe,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x00800000,
  0x00000002,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807ffffe,
  0x80000000,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80400000,
  0x00400000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x802dcbaa,
  0x003ffffe,
  0x80400000,
  0x80400000,
  0x80c00000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80523456,
  0x80c00000,
  0x80400002,
  0xbe800000,
  0xbe800000,
  0x3e7ffffd,
  0x3e7fffff,
  0x3e800002,
  0x3f3fffff,
  0x3f400000,
  0x3f400002,
  0x3fa00000,
  0x411c0000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbe800000,
  0xbe800000,
  0xbe800000,
  0xbe800000,
  0xbe800000,
  0xbf400000,
  0xbf400000,
  0xbf400001,
  0xbfa00000,
  0xbfa00000,
  0xbfa00001,
  0xbfe00000,
  0xc1240000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbe800000,
  0xbe800000,
  0xbe800000,
  0xbe800001,
  0xbe800001,
  0x3e7ffffc,
  0x3e7ffffe,
  0x3e800001,
  0x3f3ffffe,
  0x3f400000,
  0x3f400002,
  0x3fa00000,
  0x411c0000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbe800001,
  0xbe800001,
  0xbe800001,
  0xbe800001,
  0xbe800001,
  0xbf400000,
  0xbf400000,
  0xbf400002,
  0xbfa00000,
  0xbfa00000,
  0xbfa00001,
  0xbfe00000,
  0xc1240000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbe800001,
  0xbe800001,
  0xbe800001,
  0xbe800002,
  0xbe800002,
  0x3e7ffffa,
  0x3e7ffffc,
  0x3e800000,
  0x3f3ffffe,
  0x3f3fffff,
  0x3f400001,
  0x3f9fffff,
  0x411c0000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbe800002,
  0xbe800002,
  0xbe800002,
  0xbe800002,
  0xbe800002,
  0xbf400001,
  0xbf400001,
  0xbf400002,
  0xbfa00000,
  0xbfa00001,
  0xbfa00002,
  0xbfe00001,
  0xc1240000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbe800002,
  0xbe800002,
  0xbe800002,
  0xbf000000,
  0xbf000000,
  0xb37fffff,
  0xb2fffffe,
  0x33000001,
  0x3efffffd,
  0x3effffff,
  0x3f000002,
  0x3f800000,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf800000,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xbfc00000,
  0xbfc00001,
  0xc0000000,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000001,
  0xbf000001,
  0xb3c00000,
  0xb3800000,
  0x00000000,
  0x3efffffc,
  0x3efffffe,
  0x3f000001,
  0x3f7fffff,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf800000,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xbfc00000,
  0xbfc00002,
  0xc0000000,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf000002,
  0xbf000002,
  0xb4200000,
  0xb4000000,
  0xb3800001,
  0x3efffffa,
  0x3efffffc,
  0x3f000000,
  0x3f7ffffe,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf000002,
  0xbf000002,
  0xbf000002,
  0xbf000002,
  0xbf000002,
  0xbf800001,
  0xbf800001,
  0xbf800002,
  0xbfc00001,
  0xbfc00001,
  0xbfc00002,
  0xc0000001,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf000002,
  0xbf000002,
  0xbf000002,
  0xbf400002,
  0xbf400001,
  0xbe800004,
  0xbe800003,
  0xbe800001,
  0x3e7ffff6,
  0x3e7ffffa,
  0x3e800001,
  0x3f3ffffe,
  0x41140000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf400001,
  0xbf400001,
  0xbf400001,
  0xbf400002,
  0xbf400002,
  0xbfa00000,
  0xbfa00001,
  0xbfa00001,
  0xbfe00000,
  0xbfe00001,
  0xbfe00002,
  0xc0100000,
  0xc12c0000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf400002,
  0xbf400002,
  0xbf400002,
  0xc0a00001,
  0xc0a00001,
  0xc0900001,
  0xc0900001,
  0xc0900001,
  0xc0800001,
  0xc0800001,
  0xc0800001,
  0xc0600002,
  0x409fffff,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xc0a00001,
  0xc0a00001,
  0xc0a00001,
  0xc0a00001,
  0xc0a00001,
  0xc0b00001,
  0xc0b00001,
  0xc0b00001,
  0xc0c00001,
  0xc0c00001,
  0xc0c00002,
  0xc0d00001,
  0xc1700001,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xc0a00001,
  0xc0a00001,
  0xc0a00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x80091a2b,
  0x0076e5d5,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00091a2b,
  0x0076e5d4,
  0x80091a2a,
  0x80091a2b,
  0x80891a2b,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x801b4e81,
  0x80891a2a,
  0x80091a2c,
  0x80400000,
  0x00400000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x802dcbaa,
  0x003fffff,
  0x803fffff,
  0x80400000,
  0x80c00000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80523456,
  0x80bfffff,
  0x80400001,
  0x80000001,
  0x007fffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123455,
  0x007ffffe,
  0x00000000,
  0x80000001,
  0x80800001,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123457,
  0x80800000,
  0x80000002,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00400000,
  0x00c00000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00523456,
  0x00c00000,
  0x00400002,
  0x00400000,
  0x80400000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x002dcbaa,
  0x803ffffe,
  0x00400000,
  0x3e800000,
  0x3e800000,
  0x3f400000,
  0x3f400000,
  0x3f400001,
  0x3fa00000,
  0x3fa00000,
  0x3fa00001,
  0x3fe00000,
  0x41240000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3e800000,
  0x3e800000,
  0x3e800000,
  0x3e800000,
  0x3e800000,
  0xbe7ffffd,
  0xbe7fffff,
  0xbe800002,
  0xbf3fffff,
  0xbf400000,
  0xbf400002,
  0xbfa00000,
  0xc11c0000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3e800000,
  0x3e800000,
  0x3e800000,
  0x3e800001,
  0x3e800001,
  0x3f400000,
  0x3f400000,
  0x3f400002,
  0x3fa00000,
  0x3fa00000,
  0x3fa00001,
  0x3fe00000,
  0x41240000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3e800001,
  0x3e800001,
  0x3e800001,
  0x3e800001,
  0x3e800001,
  0xbe7ffffc,
  0xbe7ffffe,
  0xbe800001,
  0xbf3ffffe,
  0xbf400000,
  0xbf400002,
  0xbfa00000,
  0xc11c0000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3e800001,
  0x3e800001,
  0x3e800001,
  0x3e800002,
  0x3e800002,
  0x3f400001,
  0x3f400001,
  0x3f400002,
  0x3fa00000,
  0x3fa00001,
  0x3fa00002,
  0x3fe00001,
  0x41240000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3e800002,
  0x3e800002,
  0x3e800002,
  0x3e800002,
  0x3e800002,
  0xbe7ffffa,
  0xbe7ffffc,
  0xbe800000,
  0xbf3ffffe,
  0xbf3fffff,
  0xbf400001,
  0xbf9fffff,
  0xc11c0000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3e800002,
  0x3e800002,
  0x3e800002,
  0x3f000000,
  0x3f000000,
  0x3f800000,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x3fc00000,
  0x3fc00001,
  0x40000000,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x337fffff,
  0x32fffffe,
  0xb3000001,
  0xbefffffd,
  0xbeffffff,
  0xbf000002,
  0xbf800000,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000001,
  0x3f000001,
  0x3f800000,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x3fc00000,
  0x3fc00002,
  0x40000000,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x33c00000,
  0x33800000,
  0x00000000,
  0xbefffffc,
  0xbefffffe,
  0xbf000001,
  0xbf7fffff,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f000002,
  0x3f000002,
  0x3f800001,
  0x3f800001,
  0x3f800002,
  0x3fc00001,
  0x3fc00001,
  0x3fc00002,
  0x40000001,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f000002,
  0x3f000002,
  0x3f000002,
  0x3f000002,
  0x3f000002,
  0x34200000,
  0x34000000,
  0x33800001,
  0xbefffffa,
  0xbefffffc,
  0xbf000000,
  0xbf7ffffe,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f000002,
  0x3f000002,
  0x3f000002,
  0x3f400002,
  0x3f400002,
  0x3fa00000,
  0x3fa00001,
  0x3fa00001,
  0x3fe00000,
  0x3fe00001,
  0x3fe00002,
  0x40100000,
  0x412c0000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f400002,
  0x3f400002,
  0x3f400002,
  0x3f400002,
  0x3f400001,
  0x3e800004,
  0x3e800003,
  0x3e800001,
  0xbe7ffff6,
  0xbe7ffffa,
  0xbe800001,
  0xbf3ffffe,
  0xc1140000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f400001,
  0x3f400001,
  0x3f400001,
  0x40a00001,
  0x40a00001,
  0x40b00001,
  0x40b00001,
  0x40b00001,
  0x40c00001,
  0x40c00001,
  0x40c00002,
  0x40d00001,
  0x41700001,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x40a00001,
  0x40a00001,
  0x40a00001,
  0x40a00001,
  0x40a00001,
  0x40900001,
  0x40900001,
  0x40900001,
  0x40800001,
  0x40800001,
  0x40800001,
  0x40600002,
  0xc09fffff,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x40a00001,
  0x40a00001,
  0x40a00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x00091a2b,
  0x00891a2b,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x001b4e81,
  0x00891a2a,
  0x00091a2c,
  0x00091a2b,
  0x8076e5d5,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80091a2b,
  0x8076e5d4,
  0x00091a2a,
  0x00400000,
  0x00c00000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00523456,
  0x00bfffff,
  0x00400001,
  0x00400000,
  0x80400000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x002dcbaa,
  0x803fffff,
  0x003fffff,
  0x00000001,
  0x00800001,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123457,
  0x00800000,
  0x00000002,
  0x00000001,
  0x807fffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123455,
  0x807ffffe,
  0x80000000,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80800000,
  0x00000000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x806dcbaa,
  0x80000000,
  0x807ffffe,
  0x80800000,
  0x81000000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80923456,
  0x80fffffe,
  0x80800000,
  0xbefffffe,
  0xbefffffe,
  0x32ffffff,
  0x33800000,
  0x34000000,
  0x3f000000,
  0x3f000001,
  0x3f000003,
  0x3f800000,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbefffffe,
  0xbefffffe,
  0xbefffffe,
  0xbefffffe,
  0xbefffffe,
  0xbf7fffff,
  0xbf7fffff,
  0xbf800000,
  0xbfbfffff,
  0xbfc00000,
  0xbfc00001,
  0xc0000000,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbefffffe,
  0xbefffffe,
  0xbefffffe,
  0xbeffffff,
  0xbeffffff,
  0x00000000,
  0x33000000,
  0x33c00000,
  0x3effffff,
  0x3f000000,
  0x3f000002,
  0x3f800000,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbf7fffff,
  0xbf800000,
  0xbf800000,
  0xbfbfffff,
  0xbfc00000,
  0xbfc00001,
  0xc0000000,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbf000000,
  0xbf000000,
  0xb37fffff,
  0xb2fffffe,
  0x33000001,
  0x3efffffd,
  0x3effffff,
  0x3f000002,
  0x3f800000,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf800000,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xbfc00000,
  0xbfc00001,
  0xc0000000,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf7ffffe,
  0xbf7ffffe,
  0xbefffffd,
  0xbefffffc,
  0xbefffffa,
  0x337fffff,
  0x34000000,
  0x34800000,
  0x3f000002,
  0x41100000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf7ffffe,
  0xbf7ffffe,
  0xbf7ffffe,
  0xbf7ffffe,
  0xbf7ffffe,
  0xbfbfffff,
  0xbfbfffff,
  0xbfc00000,
  0xbfffffff,
  0xbfffffff,
  0xc0000000,
  0xc0200000,
  0xc1300000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf7ffffe,
  0xbf7ffffe,
  0xbf7ffffe,
  0xbf7fffff,
  0xbf7fffff,
  0xbeffffff,
  0xbefffffe,
  0xbefffffc,
  0x00000000,
  0x33800000,
  0x34400000,
  0x3f000001,
  0x41100000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf7fffff,
  0xbf7fffff,
  0xbf7fffff,
  0xbf7fffff,
  0xbf7fffff,
  0xbfbfffff,
  0xbfc00000,
  0xbfc00000,
  0xbfffffff,
  0xc0000000,
  0xc0000000,
  0xc0200000,
  0xc1300000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf7fffff,
  0xbf7fffff,
  0xbf7fffff,
  0xbf800000,
  0xbf800000,
  0xbf000001,
  0xbf000001,
  0xbf000000,
  0xb3ffffff,
  0xb37ffffe,
  0x33800001,
  0x3efffffe,
  0x41100000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbfc00000,
  0xbfc00000,
  0xbfc00001,
  0xc0000000,
  0xc0000000,
  0xc0000001,
  0xc0200000,
  0xc1300000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbfbfffff,
  0xbfbfffff,
  0xbf7fffff,
  0xbf7ffffe,
  0xbf7ffffe,
  0xbeffffff,
  0xbefffffd,
  0xbefffff9,
  0x33c00000,
  0x41080000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbfbfffff,
  0xbfbfffff,
  0xbfbfffff,
  0xbfbfffff,
  0xbfbfffff,
  0xbfffffff,
  0xbfffffff,
  0xc0000000,
  0xc01fffff,
  0xc0200000,
  0xc0200000,
  0xc0400000,
  0xc1380000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbfbfffff,
  0xbfbfffff,
  0xbfbfffff,
  0xc11fffff,
  0xc11fffff,
  0xc117ffff,
  0xc117ffff,
  0xc117ffff,
  0xc10fffff,
  0xc10fffff,
  0xc10fffff,
  0xc107ffff,
  0x35200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xc11fffff,
  0xc11fffff,
  0xc11fffff,
  0xc11fffff,
  0xc11fffff,
  0xc127ffff,
  0xc127ffff,
  0xc127ffff,
  0xc12fffff,
  0xc12fffff,
  0xc1300000,
  0xc137ffff,
  0xc1a00000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xc11fffff,
  0xc11fffff,
  0xc11fffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x80123456,
  0x006dcbaa,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00000000,
  0x006dcba9,
  0x80123455,
  0x80123456,
  0x80923456,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x802468ac,
  0x80923455,
  0x80123457,
  0x807fffff,
  0x00000001,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x806dcba9,
  0x00000000,
  0x807ffffe,
  0x807fffff,
  0x80ffffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80923455,
  0x80fffffe,
  0x80800000,
  0x80000001,
  0x007fffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123455,
  0x007ffffe,
  0x00000000,
  0x80000001,
  0x80800001,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123457,
  0x80800000,
  0x80000002,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00800000,
  0x01000000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00923456,
  0x00fffffe,
  0x00800000,
  0x00800000,
  0x80000000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x006dcbaa,
  0x00000000,
  0x007ffffe,
  0x3efffffe,
  0x3efffffe,
  0x3f7fffff,
  0x3f7fffff,
  0x3f800000,
  0x3fbfffff,
  0x3fc00000,
  0x3fc00001,
  0x40000000,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3efffffe,
  0x3efffffe,
  0x3efffffe,
  0x3efffffe,
  0x3efffffe,
  0xb2ffffff,
  0xb3800000,
  0xb4000000,
  0xbf000000,
  0xbf000001,
  0xbf000003,
  0xbf800000,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3efffffe,
  0x3efffffe,
  0x3efffffe,
  0x3effffff,
  0x3effffff,
  0x3f7fffff,
  0x3f800000,
  0x3f800000,
  0x3fbfffff,
  0x3fc00000,
  0x3fc00001,
  0x40000000,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x00000000,
  0xb3000000,
  0xb3c00000,
  0xbeffffff,
  0xbf000000,
  0xbf000002,
  0xbf800000,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3f000000,
  0x3f000000,
  0x3f800000,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x3fc00000,
  0x3fc00001,
  0x40000000,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x337fffff,
  0x32fffffe,
  0xb3000001,
  0xbefffffd,
  0xbeffffff,
  0xbf000002,
  0xbf800000,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f7ffffe,
  0x3f7ffffe,
  0x3fbfffff,
  0x3fbfffff,
  0x3fc00000,
  0x3fffffff,
  0x3fffffff,
  0x40000000,
  0x40200000,
  0x41300000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f7ffffe,
  0x3f7ffffe,
  0x3f7ffffe,
  0x3f7ffffe,
  0x3f7ffffe,
  0x3efffffd,
  0x3efffffc,
  0x3efffffa,
  0xb37fffff,
  0xb4000000,
  0xb4800000,
  0xbf000002,
  0xc1100000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f7ffffe,
  0x3f7ffffe,
  0x3f7ffffe,
  0x3f7fffff,
  0x3f7fffff,
  0x3fbfffff,
  0x3fc00000,
  0x3fc00000,
  0x3fffffff,
  0x40000000,
  0x40000000,
  0x40200000,
  0x41300000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f7fffff,
  0x3f7fffff,
  0x3f7fffff,
  0x3f7fffff,
  0x3f7fffff,
  0x3effffff,
  0x3efffffe,
  0x3efffffc,
  0x00000000,
  0xb3800000,
  0xb4400000,
  0xbf000001,
  0xc1100000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f7fffff,
  0x3f7fffff,
  0x3f7fffff,
  0x3f800000,
  0x3f800000,
  0x3fc00000,
  0x3fc00000,
  0x3fc00001,
  0x40000000,
  0x40000000,
  0x40000001,
  0x40200000,
  0x41300000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3f000001,
  0x3f000001,
  0x3f000000,
  0x33ffffff,
  0x337ffffe,
  0xb3800001,
  0xbefffffe,
  0xc1100000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3fbfffff,
  0x3fbfffff,
  0x3fffffff,
  0x3fffffff,
  0x40000000,
  0x401fffff,
  0x40200000,
  0x40200000,
  0x40400000,
  0x41380000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3fbfffff,
  0x3fbfffff,
  0x3fbfffff,
  0x3fbfffff,
  0x3fbfffff,
  0x3f7fffff,
  0x3f7ffffe,
  0x3f7ffffe,
  0x3effffff,
  0x3efffffd,
  0x3efffff9,
  0xb3c00000,
  0xc1080000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3fbfffff,
  0x3fbfffff,
  0x3fbfffff,
  0x411fffff,
  0x411fffff,
  0x4127ffff,
  0x4127ffff,
  0x4127ffff,
  0x412fffff,
  0x412fffff,
  0x41300000,
  0x4137ffff,
  0x41a00000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x411fffff,
  0x411fffff,
  0x411fffff,
  0x411fffff,
  0x411fffff,
  0x4117ffff,
  0x4117ffff,
  0x4117ffff,
  0x410fffff,
  0x410fffff,
  0x410fffff,
  0x4107ffff,
  0xb5200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x411fffff,
  0x411fffff,
  0x411fffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x00123456,
  0x00923456,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x002468ac,
  0x00923455,
  0x00123457,
  0x00123456,
  0x806dcbaa,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80000000,
  0x806dcba9,
  0x00123455,
  0x007fffff,
  0x00ffffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00923455,
  0x00fffffe,
  0x00800000,
  0x007fffff,
  0x80000001,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x006dcba9,
  0x80000000,
  0x007ffffe,
  0x00000001,
  0x00800001,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123457,
  0x00800000,
  0x00000002,
  0x00000001,
  0x807fffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123455,
  0x807ffffe,
  0x80000000,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80800000,
  0x00000000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x806dcbaa,
  0x80000001,
  0x807fffff,
  0x80800000,
  0x81000000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80923456,
  0x80ffffff,
  0x80800001,
  0xbeffffff,
  0xbeffffff,
  0x00000000,
  0x33000000,
  0x33c00000,
  0x3effffff,
  0x3f000000,
  0x3f000002,
  0x3f800000,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbf7fffff,
  0xbf800000,
  0xbf800000,
  0xbfbfffff,
  0xbfc00000,
  0xbfc00001,
  0xc0000000,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbf000000,
  0xbf000000,
  0xb3000000,
  0x00000000,
  0x33800000,
  0x3efffffe,
  0x3f000000,
  0x3f000002,
  0x3f800000,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbfc00000,
  0xbfc00000,
  0xbfc00001,
  0xc0000000,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000001,
  0xbf000001,
  0xb3c00000,
  0xb3800000,
  0x00000000,
  0x3efffffc,
  0x3efffffe,
  0x3f000001,
  0x3f7fffff,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf800000,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xbfc00000,
  0xbfc00002,
  0xc0000000,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf7fffff,
  0xbf7fffff,
  0xbeffffff,
  0xbefffffe,
  0xbefffffc,
  0x00000000,
  0x33800000,
  0x34400000,
  0x3f000001,
  0x41100000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf7fffff,
  0xbf7fffff,
  0xbf7fffff,
  0xbf7fffff,
  0xbf7fffff,
  0xbfbfffff,
  0xbfc00000,
  0xbfc00000,
  0xbfffffff,
  0xc0000000,
  0xc0000000,
  0xc0200000,
  0xc1300000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf7fffff,
  0xbf7fffff,
  0xbf7fffff,
  0xbf800000,
  0xbf800000,
  0xbf000000,
  0xbf000000,
  0xbefffffe,
  0xb3800000,
  0x00000000,
  0x34000000,
  0x3f000000,
  0x41100000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbfc00000,
  0xbfc00000,
  0xbfc00000,
  0xc0000000,
  0xc0000000,
  0xc0000000,
  0xc0200000,
  0xc1300000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbf800001,
  0xbf800001,
  0xbf000002,
  0xbf000002,
  0xbf000001,
  0xb4400000,
  0xb4000000,
  0x00000000,
  0x3efffffc,
  0x41100000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf800001,
  0xbf800001,
  0xbf800001,
  0xbf800001,
  0xbf800001,
  0xbfc00001,
  0xbfc00001,
  0xbfc00002,
  0xc0000000,
  0xc0000000,
  0xc0000001,
  0xc0200000,
  0xc1300000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf800001,
  0xbf800001,
  0xbf800001,
  0xbfc00000,
  0xbfc00000,
  0xbf800000,
  0xbf800000,
  0xbf7fffff,
  0xbf000001,
  0xbf000000,
  0xbefffffc,
  0x00000000,
  0x41080000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbfc00000,
  0xbfc00000,
  0xbfc00000,
  0xbfc00000,
  0xbfc00000,
  0xc0000000,
  0xc0000000,
  0xc0000000,
  0xc0200000,
  0xc0200000,
  0xc0200000,
  0xc0400000,
  0xc1380000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbfc00000,
  0xbfc00000,
  0xbfc00000,
  0xc1200000,
  0xc1200000,
  0xc1180000,
  0xc1180000,
  0xc1180000,
  0xc1100000,
  0xc1100000,
  0xc1100000,
  0xc1080000,
  0x00000000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xc1200000,
  0xc1200000,
  0xc1200000,
  0xc1200000,
  0xc1200000,
  0xc1280000,
  0xc1280000,
  0xc1280000,
  0xc1300000,
  0xc1300000,
  0xc1300000,
  0xc1380000,
  0xc1a00000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xc1200000,
  0xc1200000,
  0xc1200000,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x80123456,
  0x006dcbaa,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00000000,
  0x006dcba9,
  0x80123455,
  0x80123456,
  0x80923456,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x802468ac,
  0x80923455,
  0x80123457,
  0x807fffff,
  0x00000001,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x806dcba9,
  0x00000000,
  0x807ffffe,
  0x807fffff,
  0x80ffffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80923455,
  0x80fffffe,
  0x80800000,
  0x80000001,
  0x007fffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123455,
  0x007ffffe,
  0x00000000,
  0x80000001,
  0x80800001,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123457,
  0x80800000,
  0x80000002,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00800000,
  0x01000000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00923456,
  0x00ffffff,
  0x00800001,
  0x00800000,
  0x00000000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x006dcbaa,
  0x00000001,
  0x007fffff,
  0x3effffff,
  0x3effffff,
  0x3f7fffff,
  0x3f800000,
  0x3f800000,
  0x3fbfffff,
  0x3fc00000,
  0x3fc00001,
  0x40000000,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x00000000,
  0xb3000000,
  0xb3c00000,
  0xbeffffff,
  0xbf000000,
  0xbf000002,
  0xbf800000,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3f000000,
  0x3f000000,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3fc00000,
  0x3fc00000,
  0x3fc00001,
  0x40000000,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x33000000,
  0x00000000,
  0xb3800000,
  0xbefffffe,
  0xbf000000,
  0xbf000002,
  0xbf800000,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000001,
  0x3f000001,
  0x3f800000,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x3fc00000,
  0x3fc00002,
  0x40000000,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x33c00000,
  0x33800000,
  0x00000000,
  0xbefffffc,
  0xbefffffe,
  0xbf000001,
  0xbf7fffff,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f7fffff,
  0x3f7fffff,
  0x3fbfffff,
  0x3fc00000,
  0x3fc00000,
  0x3fffffff,
  0x40000000,
  0x40000000,
  0x40200000,
  0x41300000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f7fffff,
  0x3f7fffff,
  0x3f7fffff,
  0x3f7fffff,
  0x3f7fffff,
  0x3effffff,
  0x3efffffe,
  0x3efffffc,
  0x00000000,
  0xb3800000,
  0xb4400000,
  0xbf000001,
  0xc1100000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f7fffff,
  0x3f7fffff,
  0x3f7fffff,
  0x3f800000,
  0x3f800000,
  0x3fc00000,
  0x3fc00000,
  0x3fc00000,
  0x40000000,
  0x40000000,
  0x40000000,
  0x40200000,
  0x41300000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3f000000,
  0x3f000000,
  0x3efffffe,
  0x33800000,
  0x00000000,
  0xb4000000,
  0xbf000000,
  0xc1100000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3f800001,
  0x3f800001,
  0x3fc00001,
  0x3fc00001,
  0x3fc00002,
  0x40000000,
  0x40000000,
  0x40000001,
  0x40200000,
  0x41300000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f800001,
  0x3f800001,
  0x3f800001,
  0x3f800001,
  0x3f800001,
  0x3f000002,
  0x3f000002,
  0x3f000001,
  0x34400000,
  0x34000000,
  0x00000000,
  0xbefffffc,
  0xc1100000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f800001,
  0x3f800001,
  0x3f800001,
  0x3fc00000,
  0x3fc00000,
  0x40000000,
  0x40000000,
  0x40000000,
  0x40200000,
  0x40200000,
  0x40200000,
  0x40400000,
  0x41380000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3fc00000,
  0x3fc00000,
  0x3fc00000,
  0x3fc00000,
  0x3fc00000,
  0x3f800000,
  0x3f800000,
  0x3f7fffff,
  0x3f000001,
  0x3f000000,
  0x3efffffc,
  0x00000000,
  0xc1080000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3fc00000,
  0x3fc00000,
  0x3fc00000,
  0x41200000,
  0x41200000,
  0x41280000,
  0x41280000,
  0x41280000,
  0x41300000,
  0x41300000,
  0x41300000,
  0x41380000,
  0x41a00000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x41200000,
  0x41200000,
  0x41200000,
  0x41200000,
  0x41200000,
  0x41180000,
  0x41180000,
  0x41180000,
  0x41100000,
  0x41100000,
  0x41100000,
  0x41080000,
  0x00000000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x41200000,
  0x41200000,
  0x41200000,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x00123456,
  0x00923456,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x002468ac,
  0x00923455,
  0x00123457,
  0x00123456,
  0x806dcbaa,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x00000000,
  0x806dcba9,
  0x00123455,
  0x007fffff,
  0x00ffffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00923455,
  0x00fffffe,
  0x00800000,
  0x007fffff,
  0x80000001,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x006dcba9,
  0x00000000,
  0x007ffffe,
  0x00000001,
  0x00800001,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123457,
  0x00800000,
  0x00000002,
  0x00000001,
  0x807fffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123455,
  0x807ffffe,
  0x00000000,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80800001,
  0x80000001,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x806dcbab,
  0x80000002,
  0x80800000,
  0x80800001,
  0x81000000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80923457,
  0x81000000,
  0x80800002,
  0xbf000000,
  0xbf000000,
  0xb37fffff,
  0xb2fffffe,
  0x33000001,
  0x3efffffd,
  0x3effffff,
  0x3f000002,
  0x3f800000,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf800000,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xbfc00000,
  0xbfc00001,
  0xc0000000,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000001,
  0xbf000001,
  0xb3c00000,
  0xb3800000,
  0x00000000,
  0x3efffffc,
  0x3efffffe,
  0x3f000001,
  0x3f7fffff,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf800000,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xbfc00000,
  0xbfc00002,
  0xc0000000,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf000002,
  0xbf000002,
  0xb4200000,
  0xb4000000,
  0xb3800001,
  0x3efffffa,
  0x3efffffc,
  0x3f000000,
  0x3f7ffffe,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf000002,
  0xbf000002,
  0xbf000002,
  0xbf000002,
  0xbf000002,
  0xbf800001,
  0xbf800001,
  0xbf800002,
  0xbfc00001,
  0xbfc00001,
  0xbfc00002,
  0xc0000001,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf000002,
  0xbf000002,
  0xbf000002,
  0xbf800000,
  0xbf800000,
  0xbf000001,
  0xbf000001,
  0xbf000000,
  0xb3ffffff,
  0xb37ffffe,
  0x33800001,
  0x3efffffe,
  0x41100000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbfc00000,
  0xbfc00000,
  0xbfc00001,
  0xc0000000,
  0xc0000000,
  0xc0000001,
  0xc0200000,
  0xc1300000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbf800001,
  0xbf800001,
  0xbf000002,
  0xbf000002,
  0xbf000001,
  0xb4400000,
  0xb4000000,
  0x00000000,
  0x3efffffc,
  0x41100000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf800001,
  0xbf800001,
  0xbf800001,
  0xbf800001,
  0xbf800001,
  0xbfc00001,
  0xbfc00001,
  0xbfc00002,
  0xc0000000,
  0xc0000000,
  0xc0000001,
  0xc0200000,
  0xc1300000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf800001,
  0xbf800001,
  0xbf800001,
  0xbf800002,
  0xbf800002,
  0xbf000005,
  0xbf000004,
  0xbf000003,
  0xb4a00000,
  0xb4800000,
  0xb4000001,
  0x3efffff8,
  0x41100000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf800002,
  0xbf800002,
  0xbf800002,
  0xbf800002,
  0xbf800002,
  0xbfc00002,
  0xbfc00002,
  0xbfc00003,
  0xc0000001,
  0xc0000001,
  0xc0000002,
  0xc0200001,
  0xc1300000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf800002,
  0xbf800002,
  0xbf800002,
  0xbfc00002,
  0xbfc00001,
  0xbf800002,
  0xbf800002,
  0xbf800001,
  0xbf000004,
  0xbf000003,
  0xbf000001,
  0xb4400000,
  0x41080000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbfc00001,
  0xbfc00001,
  0xbfc00001,
  0xbfc00002,
  0xbfc00002,
  0xc0000001,
  0xc0000001,
  0xc0000001,
  0xc0200000,
  0xc0200001,
  0xc0200001,
  0xc0400001,
  0xc1380000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbfc00002,
  0xbfc00002,
  0xbfc00002,
  0xc1200001,
  0xc1200001,
  0xc1180001,
  0xc1180001,
  0xc1180001,
  0xc1100001,
  0xc1100001,
  0xc1100001,
  0xc1080001,
  0xb5a00000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xc1200001,
  0xc1200001,
  0xc1200001,
  0xc1200001,
  0xc1200001,
  0xc1280001,
  0xc1280001,
  0xc1280001,
  0xc1300001,
  0xc1300001,
  0xc1300001,
  0xc1380001,
  0xc1a00001,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xc1200001,
  0xc1200001,
  0xc1200001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x80123456,
  0x006dcbaa,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x80000000,
  0x006dcba9,
  0x80123455,
  0x80123456,
  0x80923456,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x802468ac,
  0x80923455,
  0x80123457,
  0x80800000,
  0x00000000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x806dcbaa,
  0x80000001,
  0x807fffff,
  0x80800000,
  0x81000000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80923456,
  0x80ffffff,
  0x80800001,
  0x80000001,
  0x007fffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123455,
  0x007ffffe,
  0x80000000,
  0x80000001,
  0x80800001,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123457,
  0x80800000,
  0x80000002,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00800001,
  0x01000000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00923457,
  0x01000000,
  0x00800002,
  0x00800001,
  0x00000001,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x006dcbab,
  0x00000002,
  0x00800000,
  0x3f000000,
  0x3f000000,
  0x3f800000,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x3fc00000,
  0x3fc00001,
  0x40000000,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x337fffff,
  0x32fffffe,
  0xb3000001,
  0xbefffffd,
  0xbeffffff,
  0xbf000002,
  0xbf800000,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000001,
  0x3f000001,
  0x3f800000,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x3fc00000,
  0x3fc00002,
  0x40000000,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x33c00000,
  0x33800000,
  0x00000000,
  0xbefffffc,
  0xbefffffe,
  0xbf000001,
  0xbf7fffff,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f000002,
  0x3f000002,
  0x3f800001,
  0x3f800001,
  0x3f800002,
  0x3fc00001,
  0x3fc00001,
  0x3fc00002,
  0x40000001,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f000002,
  0x3f000002,
  0x3f000002,
  0x3f000002,
  0x3f000002,
  0x34200000,
  0x34000000,
  0x33800001,
  0xbefffffa,
  0xbefffffc,
  0xbf000000,
  0xbf7ffffe,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f000002,
  0x3f000002,
  0x3f000002,
  0x3f800000,
  0x3f800000,
  0x3fc00000,
  0x3fc00000,
  0x3fc00001,
  0x40000000,
  0x40000000,
  0x40000001,
  0x40200000,
  0x41300000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3f000001,
  0x3f000001,
  0x3f000000,
  0x33ffffff,
  0x337ffffe,
  0xb3800001,
  0xbefffffe,
  0xc1100000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3f800001,
  0x3f800001,
  0x3fc00001,
  0x3fc00001,
  0x3fc00002,
  0x40000000,
  0x40000000,
  0x40000001,
  0x40200000,
  0x41300000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f800001,
  0x3f800001,
  0x3f800001,
  0x3f800001,
  0x3f800001,
  0x3f000002,
  0x3f000002,
  0x3f000001,
  0x34400000,
  0x34000000,
  0x00000000,
  0xbefffffc,
  0xc1100000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f800001,
  0x3f800001,
  0x3f800001,
  0x3f800002,
  0x3f800002,
  0x3fc00002,
  0x3fc00002,
  0x3fc00003,
  0x40000001,
  0x40000001,
  0x40000002,
  0x40200001,
  0x41300000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f800002,
  0x3f800002,
  0x3f800002,
  0x3f800002,
  0x3f800002,
  0x3f000005,
  0x3f000004,
  0x3f000003,
  0x34a00000,
  0x34800000,
  0x34000001,
  0xbefffff8,
  0xc1100000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f800002,
  0x3f800002,
  0x3f800002,
  0x3fc00002,
  0x3fc00002,
  0x40000001,
  0x40000001,
  0x40000001,
  0x40200000,
  0x40200001,
  0x40200001,
  0x40400001,
  0x41380000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3fc00002,
  0x3fc00002,
  0x3fc00002,
  0x3fc00002,
  0x3fc00001,
  0x3f800002,
  0x3f800002,
  0x3f800001,
  0x3f000004,
  0x3f000003,
  0x3f000001,
  0x34400000,
  0xc1080000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3fc00001,
  0x3fc00001,
  0x3fc00001,
  0x41200001,
  0x41200001,
  0x41280001,
  0x41280001,
  0x41280001,
  0x41300001,
  0x41300001,
  0x41300001,
  0x41380001,
  0x41a00001,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x41200001,
  0x41200001,
  0x41200001,
  0x41200001,
  0x41200001,
  0x41180001,
  0x41180001,
  0x41180001,
  0x41100001,
  0x41100001,
  0x41100001,
  0x41080001,
  0x35a00000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x41200001,
  0x41200001,
  0x41200001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x00123456,
  0x00923456,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x002468ac,
  0x00923455,
  0x00123457,
  0x00123456,
  0x806dcbaa,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x00000000,
  0x806dcba9,
  0x00123455,
  0x00800000,
  0x01000000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00923456,
  0x00ffffff,
  0x00800001,
  0x00800000,
  0x80000000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x006dcbaa,
  0x00000001,
  0x007fffff,
  0x00000001,
  0x00800001,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123457,
  0x00800000,
  0x00000002,
  0x00000001,
  0x807fffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123455,
  0x807ffffe,
  0x00000000,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80c00000,
  0x80400000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x80adcbaa,
  0x80400001,
  0x80bfffff,
  0x80c00000,
  0x81200000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80d23456,
  0x81200000,
  0x80c00001,
  0xbf3fffff,
  0xbf3fffff,
  0xbe7fffff,
  0xbe7ffffd,
  0xbe7ffff9,
  0x3e7fffff,
  0x3e800002,
  0x3e800006,
  0x3f400001,
  0x41140000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf3fffff,
  0xbf3fffff,
  0xbf3fffff,
  0xbf3fffff,
  0xbf3fffff,
  0xbf9fffff,
  0xbfa00000,
  0xbfa00000,
  0xbfdfffff,
  0xbfe00000,
  0xbfe00001,
  0xc0100000,
  0xc12c0000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf3fffff,
  0xbf3fffff,
  0xbf3fffff,
  0xbf400000,
  0xbf400000,
  0xbe800001,
  0xbe800000,
  0xbe7ffffc,
  0x3e7ffffc,
  0x3e800000,
  0x3e800004,
  0x3f400000,
  0x41140000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf400000,
  0xbf400000,
  0xbf400000,
  0xbf400000,
  0xbf400000,
  0xbfa00000,
  0xbfa00000,
  0xbfa00000,
  0xbfe00000,
  0xbfe00000,
  0xbfe00001,
  0xc0100000,
  0xc12c0000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf400000,
  0xbf400000,
  0xbf400000,
  0xbf400002,
  0xbf400001,
  0xbe800004,
  0xbe800003,
  0xbe800001,
  0x3e7ffff6,
  0x3e7ffffa,
  0x3e800001,
  0x3f3ffffe,
  0x41140000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf400001,
  0xbf400001,
  0xbf400001,
  0xbf400002,
  0xbf400002,
  0xbfa00000,
  0xbfa00001,
  0xbfa00001,
  0xbfe00000,
  0xbfe00001,
  0xbfe00002,
  0xc0100000,
  0xc12c0000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf400002,
  0xbf400002,
  0xbf400002,
  0xbfbfffff,
  0xbfbfffff,
  0xbf7fffff,
  0xbf7ffffe,
  0xbf7ffffe,
  0xbeffffff,
  0xbefffffd,
  0xbefffff9,
  0x33c00000,
  0x41080000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbfbfffff,
  0xbfbfffff,
  0xbfbfffff,
  0xbfbfffff,
  0xbfbfffff,
  0xbfffffff,
  0xbfffffff,
  0xc0000000,
  0xc01fffff,
  0xc0200000,
  0xc0200000,
  0xc0400000,
  0xc1380000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbfbfffff,
  0xbfbfffff,
  0xbfbfffff,
  0xbfc00000,
  0xbfc00000,
  0xbf800000,
  0xbf800000,
  0xbf7fffff,
  0xbf000001,
  0xbf000000,
  0xbefffffc,
  0x00000000,
  0x41080000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbfc00000,
  0xbfc00000,
  0xbfc00000,
  0xbfc00000,
  0xbfc00000,
  0xc0000000,
  0xc0000000,
  0xc0000000,
  0xc0200000,
  0xc0200000,
  0xc0200000,
  0xc0400000,
  0xc1380000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbfc00000,
  0xbfc00000,
  0xbfc00000,
  0xbfc00002,
  0xbfc00001,
  0xbf800002,
  0xbf800002,
  0xbf800001,
  0xbf000004,
  0xbf000003,
  0xbf000001,
  0xb4400000,
  0x41080000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbfc00001,
  0xbfc00001,
  0xbfc00001,
  0xbfc00002,
  0xbfc00002,
  0xc0000001,
  0xc0000001,
  0xc0000001,
  0xc0200000,
  0xc0200001,
  0xc0200001,
  0xc0400001,
  0xc1380000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbfc00002,
  0xbfc00002,
  0xbfc00002,
  0xc0100000,
  0xc0100000,
  0xbfe00000,
  0xbfe00000,
  0xbfe00000,
  0xbfa00000,
  0xbfa00000,
  0xbf9fffff,
  0xbf400000,
  0x40f80000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xc0100000,
  0xc0100000,
  0xc0100000,
  0xc0100000,
  0xc0100000,
  0xc0300000,
  0xc0300000,
  0xc0300000,
  0xc0500000,
  0xc0500000,
  0xc0500000,
  0xc0700000,
  0xc1440000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xc0100000,
  0xc0100000,
  0xc0100000,
  0xc1700000,
  0xc1700000,
  0xc1680000,
  0xc1680000,
  0xc1680000,
  0xc1600000,
  0xc1600000,
  0xc1600000,
  0xc1580000,
  0xc0a00000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xc1700000,
  0xc1700000,
  0xc1700000,
  0xc1700000,
  0xc1700000,
  0xc1780000,
  0xc1780000,
  0xc1780000,
  0xc1800000,
  0xc1800000,
  0xc1800000,
  0xc1840000,
  0xc1c80000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xc1700000,
  0xc1700000,
  0xc1700000,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x801b4e81,
  0x0064b17f,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x80091a2b,
  0x0064b17e,
  0x801b4e80,
  0x801b4e81,
  0x809b4e81,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x802d82d7,
  0x809b4e80,
  0x801b4e82,
  0x80bffffe,
  0x803ffffe,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x80adcba8,
  0x80400000,
  0x80bffffe,
  0x80bffffe,
  0x811fffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80d23454,
  0x811fffff,
  0x80c00000,
  0x80000002,
  0x007ffffe,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123454,
  0x007ffffe,
  0x80000000,
  0x80000002,
  0x80800002,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123458,
  0x80800000,
  0x80000002,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00c00000,
  0x01200000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00d23456,
  0x01200000,
  0x00c00001,
  0x00c00000,
  0x00400000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x00adcbaa,
  0x00400001,
  0x00bfffff,
  0x3f3fffff,
  0x3f3fffff,
  0x3f9fffff,
  0x3fa00000,
  0x3fa00000,
  0x3fdfffff,
  0x3fe00000,
  0x3fe00001,
  0x40100000,
  0x412c0000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f3fffff,
  0x3f3fffff,
  0x3f3fffff,
  0x3f3fffff,
  0x3f3fffff,
  0x3e7fffff,
  0x3e7ffffd,
  0x3e7ffff9,
  0xbe7fffff,
  0xbe800002,
  0xbe800006,
  0xbf400001,
  0xc1140000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f3fffff,
  0x3f3fffff,
  0x3f3fffff,
  0x3f400000,
  0x3f400000,
  0x3fa00000,
  0x3fa00000,
  0x3fa00000,
  0x3fe00000,
  0x3fe00000,
  0x3fe00001,
  0x40100000,
  0x412c0000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f400000,
  0x3f400000,
  0x3f400000,
  0x3f400000,
  0x3f400000,
  0x3e800001,
  0x3e800000,
  0x3e7ffffc,
  0xbe7ffffc,
  0xbe800000,
  0xbe800004,
  0xbf400000,
  0xc1140000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f400000,
  0x3f400000,
  0x3f400000,
  0x3f400002,
  0x3f400002,
  0x3fa00000,
  0x3fa00001,
  0x3fa00001,
  0x3fe00000,
  0x3fe00001,
  0x3fe00002,
  0x40100000,
  0x412c0000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f400002,
  0x3f400002,
  0x3f400002,
  0x3f400002,
  0x3f400001,
  0x3e800004,
  0x3e800003,
  0x3e800001,
  0xbe7ffff6,
  0xbe7ffffa,
  0xbe800001,
  0xbf3ffffe,
  0xc1140000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f400001,
  0x3f400001,
  0x3f400001,
  0x3fbfffff,
  0x3fbfffff,
  0x3fffffff,
  0x3fffffff,
  0x40000000,
  0x401fffff,
  0x40200000,
  0x40200000,
  0x40400000,
  0x41380000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3fbfffff,
  0x3fbfffff,
  0x3fbfffff,
  0x3fbfffff,
  0x3fbfffff,
  0x3f7fffff,
  0x3f7ffffe,
  0x3f7ffffe,
  0x3effffff,
  0x3efffffd,
  0x3efffff9,
  0xb3c00000,
  0xc1080000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3fbfffff,
  0x3fbfffff,
  0x3fbfffff,
  0x3fc00000,
  0x3fc00000,
  0x40000000,
  0x40000000,
  0x40000000,
  0x40200000,
  0x40200000,
  0x40200000,
  0x40400000,
  0x41380000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3fc00000,
  0x3fc00000,
  0x3fc00000,
  0x3fc00000,
  0x3fc00000,
  0x3f800000,
  0x3f800000,
  0x3f7fffff,
  0x3f000001,
  0x3f000000,
  0x3efffffc,
  0x00000000,
  0xc1080000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3fc00000,
  0x3fc00000,
  0x3fc00000,
  0x3fc00002,
  0x3fc00002,
  0x40000001,
  0x40000001,
  0x40000001,
  0x40200000,
  0x40200001,
  0x40200001,
  0x40400001,
  0x41380000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3fc00002,
  0x3fc00002,
  0x3fc00002,
  0x3fc00002,
  0x3fc00001,
  0x3f800002,
  0x3f800002,
  0x3f800001,
  0x3f000004,
  0x3f000003,
  0x3f000001,
  0x34400000,
  0xc1080000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3fc00001,
  0x3fc00001,
  0x3fc00001,
  0x40100000,
  0x40100000,
  0x40300000,
  0x40300000,
  0x40300000,
  0x40500000,
  0x40500000,
  0x40500000,
  0x40700000,
  0x41440000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x40100000,
  0x40100000,
  0x40100000,
  0x40100000,
  0x40100000,
  0x3fe00000,
  0x3fe00000,
  0x3fe00000,
  0x3fa00000,
  0x3fa00000,
  0x3f9fffff,
  0x3f400000,
  0xc0f80000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x40100000,
  0x40100000,
  0x40100000,
  0x41700000,
  0x41700000,
  0x41780000,
  0x41780000,
  0x41780000,
  0x41800000,
  0x41800000,
  0x41800000,
  0x41840000,
  0x41c80000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x41700000,
  0x41700000,
  0x41700000,
  0x41700000,
  0x41700000,
  0x41680000,
  0x41680000,
  0x41680000,
  0x41600000,
  0x41600000,
  0x41600000,
  0x41580000,
  0x40a00000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x41700000,
  0x41700000,
  0x41700000,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x001b4e81,
  0x009b4e81,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x002d82d7,
  0x009b4e80,
  0x001b4e82,
  0x001b4e81,
  0x8064b17f,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x00091a2b,
  0x8064b17e,
  0x001b4e80,
  0x00bffffe,
  0x011fffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00d23454,
  0x011fffff,
  0x00c00000,
  0x00bffffe,
  0x003ffffe,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x00adcba8,
  0x00400000,
  0x00bffffe,
  0x00000002,
  0x00800002,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123458,
  0x00800000,
  0x00000002,
  0x00000002,
  0x807ffffe,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123454,
  0x807ffffe,
  0x00000000,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x82200000,
  0x82100000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x821db975,
  0x82100000,
  0x82200000,
  0x82200000,
  0x82300000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x8222468b,
  0x82300000,
  0x82200000,
  0xc09fffff,
  0xc09fffff,
  0xc08fffff,
  0xc08fffff,
  0xc08fffff,
  0xc07fffff,
  0xc07fffff,
  0xc07ffffe,
  0xc05fffff,
  0x40a00001,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xc09fffff,
  0xc09fffff,
  0xc09fffff,
  0xc09fffff,
  0xc09fffff,
  0xc0afffff,
  0xc0afffff,
  0xc0b00000,
  0xc0bfffff,
  0xc0bfffff,
  0xc0c00000,
  0xc0cfffff,
  0xc1700000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xc09fffff,
  0xc09fffff,
  0xc09fffff,
  0xc0a00000,
  0xc0a00000,
  0xc0900000,
  0xc0900000,
  0xc0900000,
  0xc0800000,
  0xc0800000,
  0xc0800000,
  0xc0600000,
  0x40a00000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xc0a00000,
  0xc0a00000,
  0xc0a00000,
  0xc0a00000,
  0xc0a00000,
  0xc0b00000,
  0xc0b00000,
  0xc0b00000,
  0xc0c00000,
  0xc0c00000,
  0xc0c00000,
  0xc0d00000,
  0xc1700000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xc0a00000,
  0xc0a00000,
  0xc0a00000,
  0xc0a00001,
  0xc0a00001,
  0xc0900001,
  0xc0900001,
  0xc0900001,
  0xc0800001,
  0xc0800001,
  0xc0800001,
  0xc0600002,
  0x409fffff,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xc0a00001,
  0xc0a00001,
  0xc0a00001,
  0xc0a00001,
  0xc0a00001,
  0xc0b00001,
  0xc0b00001,
  0xc0b00001,
  0xc0c00001,
  0xc0c00001,
  0xc0c00002,
  0xc0d00001,
  0xc1700001,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xc0a00001,
  0xc0a00001,
  0xc0a00001,
  0xc11fffff,
  0xc11fffff,
  0xc117ffff,
  0xc117ffff,
  0xc117ffff,
  0xc10fffff,
  0xc10fffff,
  0xc10fffff,
  0xc107ffff,
  0x35200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xc11fffff,
  0xc11fffff,
  0xc11fffff,
  0xc11fffff,
  0xc11fffff,
  0xc127ffff,
  0xc127ffff,
  0xc127ffff,
  0xc12fffff,
  0xc12fffff,
  0xc1300000,
  0xc137ffff,
  0xc1a00000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xc11fffff,
  0xc11fffff,
  0xc11fffff,
  0xc1200000,
  0xc1200000,
  0xc1180000,
  0xc1180000,
  0xc1180000,
  0xc1100000,
  0xc1100000,
  0xc1100000,
  0xc1080000,
  0x00000000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xc1200000,
  0xc1200000,
  0xc1200000,
  0xc1200000,
  0xc1200000,
  0xc1280000,
  0xc1280000,
  0xc1280000,
  0xc1300000,
  0xc1300000,
  0xc1300000,
  0xc1380000,
  0xc1a00000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xc1200000,
  0xc1200000,
  0xc1200000,
  0xc1200001,
  0xc1200001,
  0xc1180001,
  0xc1180001,
  0xc1180001,
  0xc1100001,
  0xc1100001,
  0xc1100001,
  0xc1080001,
  0xb5a00000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xc1200001,
  0xc1200001,
  0xc1200001,
  0xc1200001,
  0xc1200001,
  0xc1280001,
  0xc1280001,
  0xc1280001,
  0xc1300001,
  0xc1300001,
  0xc1300001,
  0xc1380001,
  0xc1a00001,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xc1200001,
  0xc1200001,
  0xc1200001,
  0xc1700000,
  0xc1700000,
  0xc1680000,
  0xc1680000,
  0xc1680000,
  0xc1600000,
  0xc1600000,
  0xc1600000,
  0xc1580000,
  0xc0a00000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xc1700000,
  0xc1700000,
  0xc1700000,
  0xc1700000,
  0xc1700000,
  0xc1780000,
  0xc1780000,
  0xc1780000,
  0xc1800000,
  0xc1800000,
  0xc1800000,
  0xc1840000,
  0xc1c80000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xc1700000,
  0xc1700000,
  0xc1700000,
  0xc2c80000,
  0xc2c80000,
  0xc2c70000,
  0xc2c70000,
  0xc2c70000,
  0xc2c60000,
  0xc2c60000,
  0xc2c60000,
  0xc2c50000,
  0xc2b40000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xc2c80000,
  0xc2c80000,
  0xc2c80000,
  0xc2c80000,
  0xc2c80000,
  0xc2c90000,
  0xc2c90000,
  0xc2c90000,
  0xc2ca0000,
  0xc2ca0000,
  0xc2ca0000,
  0xc2cb0000,
  0xc2dc0000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xc2c80000,
  0xc2c80000,
  0xc2c80000,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x80b60b5c,
  0x80360b5c,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x80a3d706,
  0x80360b5d,
  0x80b60b5b,
  0x80b60b5c,
  0x811b05ae,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80c83fb2,
  0x811b05ae,
  0x80b60b5d,
  0x821fffff,
  0x820fffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x821db974,
  0x820fffff,
  0x821fffff,
  0x821fffff,
  0x822fffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x8222468a,
  0x822fffff,
  0x821fffff,
  0x8000000a,
  0x007ffff6,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x0012344c,
  0x007ffff5,
  0x80000009,
  0x8000000a,
  0x8080000a,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123460,
  0x80800009,
  0x8000000b,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x02200000,
  0x02300000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x0222468b,
  0x02300000,
  0x02200000,
  0x02200000,
  0x02100000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x021db975,
  0x02100000,
  0x02200000,
  0x409fffff,
  0x409fffff,
  0x40afffff,
  0x40afffff,
  0x40b00000,
  0x40bfffff,
  0x40bfffff,
  0x40c00000,
  0x40cfffff,
  0x41700000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x409fffff,
  0x409fffff,
  0x409fffff,
  0x409fffff,
  0x409fffff,
  0x408fffff,
  0x408fffff,
  0x408fffff,
  0x407fffff,
  0x407fffff,
  0x407ffffe,
  0x405fffff,
  0xc0a00001,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x409fffff,
  0x409fffff,
  0x409fffff,
  0x40a00000,
  0x40a00000,
  0x40b00000,
  0x40b00000,
  0x40b00000,
  0x40c00000,
  0x40c00000,
  0x40c00000,
  0x40d00000,
  0x41700000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x40a00000,
  0x40a00000,
  0x40a00000,
  0x40a00000,
  0x40a00000,
  0x40900000,
  0x40900000,
  0x40900000,
  0x40800000,
  0x40800000,
  0x40800000,
  0x40600000,
  0xc0a00000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x40a00000,
  0x40a00000,
  0x40a00000,
  0x40a00001,
  0x40a00001,
  0x40b00001,
  0x40b00001,
  0x40b00001,
  0x40c00001,
  0x40c00001,
  0x40c00002,
  0x40d00001,
  0x41700001,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x40a00001,
  0x40a00001,
  0x40a00001,
  0x40a00001,
  0x40a00001,
  0x40900001,
  0x40900001,
  0x40900001,
  0x40800001,
  0x40800001,
  0x40800001,
  0x40600002,
  0xc09fffff,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x40a00001,
  0x40a00001,
  0x40a00001,
  0x411fffff,
  0x411fffff,
  0x4127ffff,
  0x4127ffff,
  0x4127ffff,
  0x412fffff,
  0x412fffff,
  0x41300000,
  0x4137ffff,
  0x41a00000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x411fffff,
  0x411fffff,
  0x411fffff,
  0x411fffff,
  0x411fffff,
  0x4117ffff,
  0x4117ffff,
  0x4117ffff,
  0x410fffff,
  0x410fffff,
  0x410fffff,
  0x4107ffff,
  0xb5200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x411fffff,
  0x411fffff,
  0x411fffff,
  0x41200000,
  0x41200000,
  0x41280000,
  0x41280000,
  0x41280000,
  0x41300000,
  0x41300000,
  0x41300000,
  0x41380000,
  0x41a00000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x41200000,
  0x41200000,
  0x41200000,
  0x41200000,
  0x41200000,
  0x41180000,
  0x41180000,
  0x41180000,
  0x41100000,
  0x41100000,
  0x41100000,
  0x41080000,
  0x00000000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x41200000,
  0x41200000,
  0x41200000,
  0x41200001,
  0x41200001,
  0x41280001,
  0x41280001,
  0x41280001,
  0x41300001,
  0x41300001,
  0x41300001,
  0x41380001,
  0x41a00001,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x41200001,
  0x41200001,
  0x41200001,
  0x41200001,
  0x41200001,
  0x41180001,
  0x41180001,
  0x41180001,
  0x41100001,
  0x41100001,
  0x41100001,
  0x41080001,
  0x35a00000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x41200001,
  0x41200001,
  0x41200001,
  0x41700000,
  0x41700000,
  0x41780000,
  0x41780000,
  0x41780000,
  0x41800000,
  0x41800000,
  0x41800000,
  0x41840000,
  0x41c80000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x41700000,
  0x41700000,
  0x41700000,
  0x41700000,
  0x41700000,
  0x41680000,
  0x41680000,
  0x41680000,
  0x41600000,
  0x41600000,
  0x41600000,
  0x41580000,
  0x40a00000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x41700000,
  0x41700000,
  0x41700000,
  0x42c80000,
  0x42c80000,
  0x42c90000,
  0x42c90000,
  0x42c90000,
  0x42ca0000,
  0x42ca0000,
  0x42ca0000,
  0x42cb0000,
  0x42dc0000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x42c80000,
  0x42c80000,
  0x42c80000,
  0x42c80000,
  0x42c80000,
  0x42c70000,
  0x42c70000,
  0x42c70000,
  0x42c60000,
  0x42c60000,
  0x42c60000,
  0x42c50000,
  0x42b40000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x42c80000,
  0x42c80000,
  0x42c80000,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x00b60b5c,
  0x011b05ae,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00c83fb2,
  0x011b05ae,
  0x00b60b5d,
  0x00b60b5c,
  0x00360b5c,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x00a3d706,
  0x00360b5d,
  0x00b60b5b,
  0x021fffff,
  0x022fffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x0222468a,
  0x022fffff,
  0x021fffff,
  0x021fffff,
  0x020fffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x021db974,
  0x020fffff,
  0x021fffff,
  0x0000000a,
  0x0080000a,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123460,
  0x00800009,
  0x0000000b,
  0x0000000a,
  0x807ffff6,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x8012344c,
  0x807ffff5,
  0x00000009,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80091a2b,
  0x0076e5d5,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00091a2b,
  0x0076e5d4,
  0x80091a2a,
  0x80091a2b,
  0x80891a2b,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x801b4e81,
  0x80891a2a,
  0x80091a2c,
  0x80091a2b,
  0x0076e5d5,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00091a2b,
  0x0076e5d4,
  0x80091a2a,
  0x80091a2b,
  0x80891a2b,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x801b4e81,
  0x80891a2a,
  0x80091a2c,
  0x80091a2b,
  0x0076e5d5,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00091a2b,
  0x0076e5d4,
  0x80091a2a,
  0x80091a2b,
  0x80891a2b,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x801b4e81,
  0x80891a2a,
  0x80091a2c,
  0x80123456,
  0x006dcbaa,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00000000,
  0x006dcba9,
  0x80123455,
  0x80123456,
  0x80923456,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x802468ac,
  0x80923455,
  0x80123457,
  0x80123456,
  0x006dcbaa,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00000000,
  0x006dcba9,
  0x80123455,
  0x80123456,
  0x80923456,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x802468ac,
  0x80923455,
  0x80123457,
  0x80123456,
  0x006dcbaa,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x80000000,
  0x006dcba9,
  0x80123455,
  0x80123456,
  0x80923456,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x802468ac,
  0x80923455,
  0x80123457,
  0x801b4e81,
  0x0064b17f,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x80091a2b,
  0x0064b17e,
  0x801b4e80,
  0x801b4e81,
  0x809b4e81,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x802d82d7,
  0x809b4e80,
  0x801b4e82,
  0x80b60b5c,
  0x80360b5c,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x80a3d706,
  0x80360b5d,
  0x80b60b5b,
  0x80b60b5c,
  0x811b05ae,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80c83fb2,
  0x811b05ae,
  0x80b60b5d,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00091a2b,
  0x00891a2b,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x001b4e81,
  0x00891a2a,
  0x00091a2c,
  0x00091a2b,
  0x8076e5d5,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80091a2b,
  0x8076e5d4,
  0x00091a2a,
  0x00091a2b,
  0x00891a2b,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x001b4e81,
  0x00891a2a,
  0x00091a2c,
  0x00091a2b,
  0x8076e5d5,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80091a2b,
  0x8076e5d4,
  0x00091a2a,
  0x00091a2b,
  0x00891a2b,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x001b4e81,
  0x00891a2a,
  0x00091a2c,
  0x00091a2b,
  0x8076e5d5,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80091a2b,
  0x8076e5d4,
  0x00091a2a,
  0x00123456,
  0x00923456,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x002468ac,
  0x00923455,
  0x00123457,
  0x00123456,
  0x806dcbaa,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80000000,
  0x806dcba9,
  0x00123455,
  0x00123456,
  0x00923456,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x002468ac,
  0x00923455,
  0x00123457,
  0x00123456,
  0x806dcbaa,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x00000000,
  0x806dcba9,
  0x00123455,
  0x00123456,
  0x00923456,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x002468ac,
  0x00923455,
  0x00123457,
  0x00123456,
  0x806dcbaa,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x00000000,
  0x806dcba9,
  0x00123455,
  0x001b4e81,
  0x009b4e81,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x002d82d7,
  0x009b4e80,
  0x001b4e82,
  0x001b4e81,
  0x8064b17f,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x00091a2b,
  0x8064b17e,
  0x001b4e80,
  0x00b60b5c,
  0x011b05ae,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00c83fb2,
  0x011b05ae,
  0x00b60b5d,
  0x00b60b5c,
  0x00360b5c,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x00a3d706,
  0x00360b5d,
  0x00b60b5b,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x803fffff,
  0x00400001,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x802dcba9,
  0x00400000,
  0x803ffffe,
  0x803fffff,
  0x80bfffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80523455,
  0x80bffffe,
  0x80400000,
  0x80400000,
  0x00400000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x802dcbaa,
  0x00400000,
  0x803ffffe,
  0x80400000,
  0x80c00000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80523456,
  0x80bffffe,
  0x80400000,
  0x80400000,
  0x00400000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x802dcbaa,
  0x003fffff,
  0x803fffff,
  0x80400000,
  0x80c00000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80523456,
  0x80bfffff,
  0x80400001,
  0x807fffff,
  0x00000001,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x806dcba9,
  0x00000000,
  0x807ffffe,
  0x807fffff,
  0x80ffffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80923455,
  0x80fffffe,
  0x80800000,
  0x807fffff,
  0x00000001,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x806dcba9,
  0x00000000,
  0x807ffffe,
  0x807fffff,
  0x80ffffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80923455,
  0x80fffffe,
  0x80800000,
  0x80800000,
  0x00000000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x806dcbaa,
  0x80000001,
  0x807fffff,
  0x80800000,
  0x81000000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80923456,
  0x80ffffff,
  0x80800001,
  0x80bffffe,
  0x803ffffe,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x80adcba8,
  0x80400000,
  0x80bffffe,
  0x80bffffe,
  0x811fffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80d23454,
  0x811fffff,
  0x80c00000,
  0x821fffff,
  0x820fffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x821db974,
  0x820fffff,
  0x821fffff,
  0x821fffff,
  0x822fffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x8222468a,
  0x822fffff,
  0x821fffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x003fffff,
  0x00bfffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00523455,
  0x00bffffe,
  0x00400000,
  0x003fffff,
  0x80400001,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x002dcba9,
  0x80400000,
  0x003ffffe,
  0x00400000,
  0x00c00000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00523456,
  0x00bffffe,
  0x00400000,
  0x00400000,
  0x80400000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x002dcbaa,
  0x80400000,
  0x003ffffe,
  0x00400000,
  0x00c00000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00523456,
  0x00bfffff,
  0x00400001,
  0x00400000,
  0x80400000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x002dcbaa,
  0x803fffff,
  0x003fffff,
  0x007fffff,
  0x00ffffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00923455,
  0x00fffffe,
  0x00800000,
  0x007fffff,
  0x80000001,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x006dcba9,
  0x80000000,
  0x007ffffe,
  0x007fffff,
  0x00ffffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00923455,
  0x00fffffe,
  0x00800000,
  0x007fffff,
  0x80000001,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x006dcba9,
  0x00000000,
  0x007ffffe,
  0x00800000,
  0x01000000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00923456,
  0x00ffffff,
  0x00800001,
  0x00800000,
  0x80000000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x006dcbaa,
  0x00000001,
  0x007fffff,
  0x00bffffe,
  0x011fffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00d23454,
  0x011fffff,
  0x00c00000,
  0x00bffffe,
  0x003ffffe,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x00adcba8,
  0x00400000,
  0x00bffffe,
  0x021fffff,
  0x022fffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x0222468a,
  0x022fffff,
  0x021fffff,
  0x021fffff,
  0x020fffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x021db974,
  0x020fffff,
  0x021fffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007ffffe,
  0x00000000,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x80800000,
  0x80000002,
  0x80000001,
  0x007fffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123455,
  0x007ffffe,
  0x00000000,
  0x80000001,
  0x80800001,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123457,
  0x80800000,
  0x80000002,
  0x80000001,
  0x007fffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123455,
  0x007ffffe,
  0x00000000,
  0x80000001,
  0x80800001,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123457,
  0x80800000,
  0x80000002,
  0x80000001,
  0x007fffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123455,
  0x007ffffe,
  0x00000000,
  0x80000001,
  0x80800001,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123457,
  0x80800000,
  0x80000002,
  0x80000001,
  0x007fffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123455,
  0x007ffffe,
  0x80000000,
  0x80000001,
  0x80800001,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123457,
  0x80800000,
  0x80000002,
  0x80000002,
  0x007ffffe,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123454,
  0x007ffffe,
  0x80000000,
  0x80000002,
  0x80800002,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123458,
  0x80800000,
  0x80000002,
  0x8000000a,
  0x007ffff6,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x0012344c,
  0x007ffff5,
  0x80000009,
  0x8000000a,
  0x8080000a,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123460,
  0x80800009,
  0x8000000b,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x00800000,
  0x00000002,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807ffffe,
  0x80000000,
  0x00000001,
  0x00800001,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123457,
  0x00800000,
  0x00000002,
  0x00000001,
  0x807fffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123455,
  0x807ffffe,
  0x80000000,
  0x00000001,
  0x00800001,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123457,
  0x00800000,
  0x00000002,
  0x00000001,
  0x807fffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123455,
  0x807ffffe,
  0x80000000,
  0x00000001,
  0x00800001,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123457,
  0x00800000,
  0x00000002,
  0x00000001,
  0x807fffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123455,
  0x807ffffe,
  0x00000000,
  0x00000001,
  0x00800001,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123457,
  0x00800000,
  0x00000002,
  0x00000001,
  0x807fffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123455,
  0x807ffffe,
  0x00000000,
  0x00000002,
  0x00800002,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123458,
  0x00800000,
  0x00000002,
  0x00000002,
  0x807ffffe,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123454,
  0x807ffffe,
  0x00000000,
  0x0000000a,
  0x0080000a,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123460,
  0x00800009,
  0x0000000b,
  0x0000000a,
  0x807ffff6,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x8012344c,
  0x807ffff5,
  0x00000009,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00400000,
  0x00c00000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00523456,
  0x00bfffff,
  0x00400001,
  0x00400000,
  0x80400000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x002dcbaa,
  0x803fffff,
  0x003fffff,
  0x00400000,
  0x00c00000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00523456,
  0x00bfffff,
  0x00400001,
  0x00400000,
  0x80400000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x002dcbaa,
  0x803fffff,
  0x003fffff,
  0x00400000,
  0x00c00000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00523456,
  0x00c00000,
  0x00400002,
  0x00400000,
  0x80400000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x002dcbaa,
  0x803ffffe,
  0x00400000,
  0x00800000,
  0x01000000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00923456,
  0x00fffffe,
  0x00800000,
  0x00800000,
  0x80000000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x006dcbaa,
  0x00000000,
  0x007ffffe,
  0x00800000,
  0x01000000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00923456,
  0x00ffffff,
  0x00800001,
  0x00800000,
  0x00000000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x006dcbaa,
  0x00000001,
  0x007fffff,
  0x00800001,
  0x01000000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00923457,
  0x01000000,
  0x00800002,
  0x00800001,
  0x00000001,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x006dcbab,
  0x00000002,
  0x00800000,
  0x00c00000,
  0x01200000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00d23456,
  0x01200000,
  0x00c00001,
  0x00c00000,
  0x00400000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x00adcbaa,
  0x00400001,
  0x00bfffff,
  0x02200000,
  0x02300000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x0222468b,
  0x02300000,
  0x02200000,
  0x02200000,
  0x02100000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x021db975,
  0x02100000,
  0x02200000,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80400000,
  0x00400000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x802dcbaa,
  0x003fffff,
  0x803fffff,
  0x80400000,
  0x80c00000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80523456,
  0x80bfffff,
  0x80400001,
  0x80400000,
  0x00400000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x802dcbaa,
  0x003fffff,
  0x803fffff,
  0x80400000,
  0x80c00000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80523456,
  0x80bfffff,
  0x80400001,
  0x80400000,
  0x00400000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x802dcbaa,
  0x003ffffe,
  0x80400000,
  0x80400000,
  0x80c00000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80523456,
  0x80c00000,
  0x80400002,
  0x80800000,
  0x00000000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x806dcbaa,
  0x80000000,
  0x807ffffe,
  0x80800000,
  0x81000000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80923456,
  0x80fffffe,
  0x80800000,
  0x80800000,
  0x00000000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x806dcbaa,
  0x80000001,
  0x807fffff,
  0x80800000,
  0x81000000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80923456,
  0x80ffffff,
  0x80800001,
  0x80800001,
  0x80000001,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x806dcbab,
  0x80000002,
  0x80800000,
  0x80800001,
  0x81000000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80923457,
  0x81000000,
  0x80800002,
  0x80c00000,
  0x80400000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x80adcbaa,
  0x80400001,
  0x80bfffff,
  0x80c00000,
  0x81200000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80d23456,
  0x81200000,
  0x80c00001,
  0x82200000,
  0x82100000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x821db975,
  0x82100000,
  0x82200000,
  0x82200000,
  0x82300000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x8222468b,
  0x82300000,
  0x82200000,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00400000,
  0x00c00000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00523456,
  0x00bfffff,
  0x00400001,
  0x00400000,
  0x80400000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x002dcbaa,
  0x803fffff,
  0x003fffff,
  0x3e7ffffe,
  0x3e7ffffe,
  0x3f3fffff,
  0x3f400000,
  0x3f400001,
  0x3f9fffff,
  0x3fa00000,
  0x3fa00001,
  0x3fe00000,
  0x41240000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3e7ffffe,
  0x3e7ffffe,
  0x3e7ffffe,
  0x3e7ffffe,
  0x3e7ffffe,
  0xbe800000,
  0xbe800001,
  0xbe800003,
  0xbf3fffff,
  0xbf400000,
  0xbf400002,
  0xbfa00000,
  0xc11c0000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3e7ffffe,
  0x3e7ffffe,
  0x3e7ffffe,
  0x3e7fffff,
  0x3e7fffff,
  0x3f3fffff,
  0x3f400000,
  0x3f400001,
  0x3f9fffff,
  0x3fa00000,
  0x3fa00001,
  0x3fe00000,
  0x41240000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3e7fffff,
  0x3e7fffff,
  0x3e7fffff,
  0x3e7fffff,
  0x3e7fffff,
  0xbe7fffff,
  0xbe800000,
  0xbe800002,
  0xbf3fffff,
  0xbf400000,
  0xbf400002,
  0xbfa00000,
  0xc11c0000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3e7fffff,
  0x3e7fffff,
  0x3e7fffff,
  0x3e800000,
  0x3e800000,
  0x3f400000,
  0x3f400000,
  0x3f400001,
  0x3fa00000,
  0x3fa00000,
  0x3fa00001,
  0x3fe00000,
  0x41240000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3e800000,
  0x3e800000,
  0x3e800000,
  0x3e800000,
  0x3e800000,
  0xbe7ffffd,
  0xbe7fffff,
  0xbe800002,
  0xbf3fffff,
  0xbf400000,
  0xbf400002,
  0xbfa00000,
  0xc11c0000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3e800000,
  0x3e800000,
  0x3e800000,
  0x3efffffe,
  0x3efffffe,
  0x3f7fffff,
  0x3f7fffff,
  0x3f800000,
  0x3fbfffff,
  0x3fc00000,
  0x3fc00001,
  0x40000000,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3efffffe,
  0x3efffffe,
  0x3efffffe,
  0x3efffffe,
  0x3efffffe,
  0xb2ffffff,
  0xb3800000,
  0xb4000000,
  0xbf000000,
  0xbf000001,
  0xbf000003,
  0xbf800000,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3efffffe,
  0x3efffffe,
  0x3efffffe,
  0x3effffff,
  0x3effffff,
  0x3f7fffff,
  0x3f800000,
  0x3f800000,
  0x3fbfffff,
  0x3fc00000,
  0x3fc00001,
  0x40000000,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x00000000,
  0xb3000000,
  0xb3c00000,
  0xbeffffff,
  0xbf000000,
  0xbf000002,
  0xbf800000,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3f000000,
  0x3f000000,
  0x3f800000,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x3fc00000,
  0x3fc00001,
  0x40000000,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x337fffff,
  0x32fffffe,
  0xb3000001,
  0xbefffffd,
  0xbeffffff,
  0xbf000002,
  0xbf800000,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f3fffff,
  0x3f3fffff,
  0x3f9fffff,
  0x3fa00000,
  0x3fa00000,
  0x3fdfffff,
  0x3fe00000,
  0x3fe00001,
  0x40100000,
  0x412c0000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f3fffff,
  0x3f3fffff,
  0x3f3fffff,
  0x3f3fffff,
  0x3f3fffff,
  0x3e7fffff,
  0x3e7ffffd,
  0x3e7ffff9,
  0xbe7fffff,
  0xbe800002,
  0xbe800006,
  0xbf400001,
  0xc1140000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f3fffff,
  0x3f3fffff,
  0x3f3fffff,
  0x409fffff,
  0x409fffff,
  0x40afffff,
  0x40afffff,
  0x40b00000,
  0x40bfffff,
  0x40bfffff,
  0x40c00000,
  0x40cfffff,
  0x41700000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x409fffff,
  0x409fffff,
  0x409fffff,
  0x409fffff,
  0x409fffff,
  0x408fffff,
  0x408fffff,
  0x408fffff,
  0x407fffff,
  0x407fffff,
  0x407ffffe,
  0x405fffff,
  0xc0a00001,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x409fffff,
  0x409fffff,
  0x409fffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x00091a2b,
  0x00891a2b,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x001b4e81,
  0x00891a2a,
  0x00091a2c,
  0x00091a2b,
  0x8076e5d5,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80091a2b,
  0x8076e5d4,
  0x00091a2a,
  0x003fffff,
  0x00bfffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00523455,
  0x00bffffe,
  0x00400000,
  0x003fffff,
  0x80400001,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x002dcba9,
  0x80400000,
  0x003ffffe,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80400000,
  0x00400000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x802dcbaa,
  0x003fffff,
  0x803fffff,
  0x80400000,
  0x80c00000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80523456,
  0x80bfffff,
  0x80400001,
  0xbe7ffffe,
  0xbe7ffffe,
  0x3e800000,
  0x3e800001,
  0x3e800003,
  0x3f3fffff,
  0x3f400000,
  0x3f400002,
  0x3fa00000,
  0x411c0000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbe7ffffe,
  0xbe7ffffe,
  0xbe7ffffe,
  0xbe7ffffe,
  0xbe7ffffe,
  0xbf3fffff,
  0xbf400000,
  0xbf400001,
  0xbf9fffff,
  0xbfa00000,
  0xbfa00001,
  0xbfe00000,
  0xc1240000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbe7ffffe,
  0xbe7ffffe,
  0xbe7ffffe,
  0xbe7fffff,
  0xbe7fffff,
  0x3e7fffff,
  0x3e800000,
  0x3e800002,
  0x3f3fffff,
  0x3f400000,
  0x3f400002,
  0x3fa00000,
  0x411c0000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbe7fffff,
  0xbe7fffff,
  0xbe7fffff,
  0xbe7fffff,
  0xbe7fffff,
  0xbf3fffff,
  0xbf400000,
  0xbf400001,
  0xbf9fffff,
  0xbfa00000,
  0xbfa00001,
  0xbfe00000,
  0xc1240000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbe7fffff,
  0xbe7fffff,
  0xbe7fffff,
  0xbe800000,
  0xbe800000,
  0x3e7ffffd,
  0x3e7fffff,
  0x3e800002,
  0x3f3fffff,
  0x3f400000,
  0x3f400002,
  0x3fa00000,
  0x411c0000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbe800000,
  0xbe800000,
  0xbe800000,
  0xbe800000,
  0xbe800000,
  0xbf400000,
  0xbf400000,
  0xbf400001,
  0xbfa00000,
  0xbfa00000,
  0xbfa00001,
  0xbfe00000,
  0xc1240000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbe800000,
  0xbe800000,
  0xbe800000,
  0xbefffffe,
  0xbefffffe,
  0x32ffffff,
  0x33800000,
  0x34000000,
  0x3f000000,
  0x3f000001,
  0x3f000003,
  0x3f800000,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbefffffe,
  0xbefffffe,
  0xbefffffe,
  0xbefffffe,
  0xbefffffe,
  0xbf7fffff,
  0xbf7fffff,
  0xbf800000,
  0xbfbfffff,
  0xbfc00000,
  0xbfc00001,
  0xc0000000,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbefffffe,
  0xbefffffe,
  0xbefffffe,
  0xbeffffff,
  0xbeffffff,
  0x00000000,
  0x33000000,
  0x33c00000,
  0x3effffff,
  0x3f000000,
  0x3f000002,
  0x3f800000,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbf7fffff,
  0xbf800000,
  0xbf800000,
  0xbfbfffff,
  0xbfc00000,
  0xbfc00001,
  0xc0000000,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbf000000,
  0xbf000000,
  0xb37fffff,
  0xb2fffffe,
  0x33000001,
  0x3efffffd,
  0x3effffff,
  0x3f000002,
  0x3f800000,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf800000,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xbfc00000,
  0xbfc00001,
  0xc0000000,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf3fffff,
  0xbf3fffff,
  0xbe7fffff,
  0xbe7ffffd,
  0xbe7ffff9,
  0x3e7fffff,
  0x3e800002,
  0x3e800006,
  0x3f400001,
  0x41140000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf3fffff,
  0xbf3fffff,
  0xbf3fffff,
  0xbf3fffff,
  0xbf3fffff,
  0xbf9fffff,
  0xbfa00000,
  0xbfa00000,
  0xbfdfffff,
  0xbfe00000,
  0xbfe00001,
  0xc0100000,
  0xc12c0000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf3fffff,
  0xbf3fffff,
  0xbf3fffff,
  0xc09fffff,
  0xc09fffff,
  0xc08fffff,
  0xc08fffff,
  0xc08fffff,
  0xc07fffff,
  0xc07fffff,
  0xc07ffffe,
  0xc05fffff,
  0x40a00001,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xc09fffff,
  0xc09fffff,
  0xc09fffff,
  0xc09fffff,
  0xc09fffff,
  0xc0afffff,
  0xc0afffff,
  0xc0b00000,
  0xc0bfffff,
  0xc0bfffff,
  0xc0c00000,
  0xc0cfffff,
  0xc1700000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xc09fffff,
  0xc09fffff,
  0xc09fffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x80091a2b,
  0x0076e5d5,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00091a2b,
  0x0076e5d4,
  0x80091a2a,
  0x80091a2b,
  0x80891a2b,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x801b4e81,
  0x80891a2a,
  0x80091a2c,
  0x803fffff,
  0x00400001,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x802dcba9,
  0x00400000,
  0x803ffffe,
  0x803fffff,
  0x80bfffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80523455,
  0x80bffffe,
  0x80400000,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00400000,
  0x00c00000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00523456,
  0x00bfffff,
  0x00400001,
  0x00400000,
  0x80400000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x002dcbaa,
  0x803fffff,
  0x003fffff,
  0x3e7fffff,
  0x3e7fffff,
  0x3f3fffff,
  0x3f400000,
  0x3f400001,
  0x3f9fffff,
  0x3fa00000,
  0x3fa00001,
  0x3fe00000,
  0x41240000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3e7fffff,
  0x3e7fffff,
  0x3e7fffff,
  0x3e7fffff,
  0x3e7fffff,
  0xbe7fffff,
  0xbe800000,
  0xbe800002,
  0xbf3fffff,
  0xbf400000,
  0xbf400002,
  0xbfa00000,
  0xc11c0000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3e7fffff,
  0x3e7fffff,
  0x3e7fffff,
  0x3e800000,
  0x3e800000,
  0x3f400000,
  0x3f400000,
  0x3f400001,
  0x3fa00000,
  0x3fa00000,
  0x3fa00001,
  0x3fe00000,
  0x41240000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3e800000,
  0x3e800000,
  0x3e800000,
  0x3e800000,
  0x3e800000,
  0xbe7ffffe,
  0xbe800000,
  0xbe800002,
  0xbf3fffff,
  0xbf400000,
  0xbf400002,
  0xbfa00000,
  0xc11c0000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3e800000,
  0x3e800000,
  0x3e800000,
  0x3e800001,
  0x3e800001,
  0x3f400000,
  0x3f400000,
  0x3f400002,
  0x3fa00000,
  0x3fa00000,
  0x3fa00001,
  0x3fe00000,
  0x41240000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3e800001,
  0x3e800001,
  0x3e800001,
  0x3e800001,
  0x3e800001,
  0xbe7ffffc,
  0xbe7ffffe,
  0xbe800001,
  0xbf3ffffe,
  0xbf400000,
  0xbf400002,
  0xbfa00000,
  0xc11c0000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3e800001,
  0x3e800001,
  0x3e800001,
  0x3effffff,
  0x3effffff,
  0x3f7fffff,
  0x3f800000,
  0x3f800000,
  0x3fbfffff,
  0x3fc00000,
  0x3fc00001,
  0x40000000,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x00000000,
  0xb3000000,
  0xb3c00000,
  0xbeffffff,
  0xbf000000,
  0xbf000002,
  0xbf800000,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3f000000,
  0x3f000000,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3fc00000,
  0x3fc00000,
  0x3fc00001,
  0x40000000,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x33000000,
  0x00000000,
  0xb3800000,
  0xbefffffe,
  0xbf000000,
  0xbf000002,
  0xbf800000,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000001,
  0x3f000001,
  0x3f800000,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x3fc00000,
  0x3fc00002,
  0x40000000,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x33c00000,
  0x33800000,
  0x00000000,
  0xbefffffc,
  0xbefffffe,
  0xbf000001,
  0xbf7fffff,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f400000,
  0x3f400000,
  0x3fa00000,
  0x3fa00000,
  0x3fa00000,
  0x3fe00000,
  0x3fe00000,
  0x3fe00001,
  0x40100000,
  0x412c0000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f400000,
  0x3f400000,
  0x3f400000,
  0x3f400000,
  0x3f400000,
  0x3e800001,
  0x3e800000,
  0x3e7ffffc,
  0xbe7ffffc,
  0xbe800000,
  0xbe800004,
  0xbf400000,
  0xc1140000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f400000,
  0x3f400000,
  0x3f400000,
  0x40a00000,
  0x40a00000,
  0x40b00000,
  0x40b00000,
  0x40b00000,
  0x40c00000,
  0x40c00000,
  0x40c00000,
  0x40d00000,
  0x41700000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x40a00000,
  0x40a00000,
  0x40a00000,
  0x40a00000,
  0x40a00000,
  0x40900000,
  0x40900000,
  0x40900000,
  0x40800000,
  0x40800000,
  0x40800000,
  0x40600000,
  0xc0a00000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x40a00000,
  0x40a00000,
  0x40a00000,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x00091a2b,
  0x00891a2b,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x001b4e81,
  0x00891a2a,
  0x00091a2c,
  0x00091a2b,
  0x8076e5d5,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80091a2b,
  0x8076e5d4,
  0x00091a2a,
  0x00400000,
  0x00c00000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00523456,
  0x00bffffe,
  0x00400000,
  0x00400000,
  0x80400000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x002dcbaa,
  0x80400000,
  0x003ffffe,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x00800000,
  0x00000002,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807ffffe,
  0x80000000,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80400000,
  0x00400000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x802dcbaa,
  0x003fffff,
  0x803fffff,
  0x80400000,
  0x80c00000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80523456,
  0x80bfffff,
  0x80400001,
  0xbe7fffff,
  0xbe7fffff,
  0x3e7fffff,
  0x3e800000,
  0x3e800002,
  0x3f3fffff,
  0x3f400000,
  0x3f400002,
  0x3fa00000,
  0x411c0000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbe7fffff,
  0xbe7fffff,
  0xbe7fffff,
  0xbe7fffff,
  0xbe7fffff,
  0xbf3fffff,
  0xbf400000,
  0xbf400001,
  0xbf9fffff,
  0xbfa00000,
  0xbfa00001,
  0xbfe00000,
  0xc1240000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbe7fffff,
  0xbe7fffff,
  0xbe7fffff,
  0xbe800000,
  0xbe800000,
  0x3e7ffffe,
  0x3e800000,
  0x3e800002,
  0x3f3fffff,
  0x3f400000,
  0x3f400002,
  0x3fa00000,
  0x411c0000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbe800000,
  0xbe800000,
  0xbe800000,
  0xbe800000,
  0xbe800000,
  0xbf400000,
  0xbf400000,
  0xbf400001,
  0xbfa00000,
  0xbfa00000,
  0xbfa00001,
  0xbfe00000,
  0xc1240000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbe800000,
  0xbe800000,
  0xbe800000,
  0xbe800001,
  0xbe800001,
  0x3e7ffffc,
  0x3e7ffffe,
  0x3e800001,
  0x3f3ffffe,
  0x3f400000,
  0x3f400002,
  0x3fa00000,
  0x411c0000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbe800001,
  0xbe800001,
  0xbe800001,
  0xbe800001,
  0xbe800001,
  0xbf400000,
  0xbf400000,
  0xbf400002,
  0xbfa00000,
  0xbfa00000,
  0xbfa00001,
  0xbfe00000,
  0xc1240000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbe800001,
  0xbe800001,
  0xbe800001,
  0xbeffffff,
  0xbeffffff,
  0x00000000,
  0x33000000,
  0x33c00000,
  0x3effffff,
  0x3f000000,
  0x3f000002,
  0x3f800000,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbf7fffff,
  0xbf800000,
  0xbf800000,
  0xbfbfffff,
  0xbfc00000,
  0xbfc00001,
  0xc0000000,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbf000000,
  0xbf000000,
  0xb3000000,
  0x00000000,
  0x33800000,
  0x3efffffe,
  0x3f000000,
  0x3f000002,
  0x3f800000,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbfc00000,
  0xbfc00000,
  0xbfc00001,
  0xc0000000,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000001,
  0xbf000001,
  0xb3c00000,
  0xb3800000,
  0x00000000,
  0x3efffffc,
  0x3efffffe,
  0x3f000001,
  0x3f7fffff,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf800000,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xbfc00000,
  0xbfc00002,
  0xc0000000,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf400000,
  0xbf400000,
  0xbe800001,
  0xbe800000,
  0xbe7ffffc,
  0x3e7ffffc,
  0x3e800000,
  0x3e800004,
  0x3f400000,
  0x41140000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf400000,
  0xbf400000,
  0xbf400000,
  0xbf400000,
  0xbf400000,
  0xbfa00000,
  0xbfa00000,
  0xbfa00000,
  0xbfe00000,
  0xbfe00000,
  0xbfe00001,
  0xc0100000,
  0xc12c0000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf400000,
  0xbf400000,
  0xbf400000,
  0xc0a00000,
  0xc0a00000,
  0xc0900000,
  0xc0900000,
  0xc0900000,
  0xc0800000,
  0xc0800000,
  0xc0800000,
  0xc0600000,
  0x40a00000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xc0a00000,
  0xc0a00000,
  0xc0a00000,
  0xc0a00000,
  0xc0a00000,
  0xc0b00000,
  0xc0b00000,
  0xc0b00000,
  0xc0c00000,
  0xc0c00000,
  0xc0c00000,
  0xc0d00000,
  0xc1700000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xc0a00000,
  0xc0a00000,
  0xc0a00000,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x80091a2b,
  0x0076e5d5,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00091a2b,
  0x0076e5d4,
  0x80091a2a,
  0x80091a2b,
  0x80891a2b,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x801b4e81,
  0x80891a2a,
  0x80091a2c,
  0x80400000,
  0x00400000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x802dcbaa,
  0x00400000,
  0x803ffffe,
  0x80400000,
  0x80c00000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80523456,
  0x80bffffe,
  0x80400000,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007ffffe,
  0x00000000,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x80800000,
  0x80000002,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00400000,
  0x00c00000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00523456,
  0x00c00000,
  0x00400002,
  0x00400000,
  0x80400000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x002dcbaa,
  0x803ffffe,
  0x00400000,
  0x3e800000,
  0x3e800000,
  0x3f400000,
  0x3f400000,
  0x3f400001,
  0x3fa00000,
  0x3fa00000,
  0x3fa00001,
  0x3fe00000,
  0x41240000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3e800000,
  0x3e800000,
  0x3e800000,
  0x3e800000,
  0x3e800000,
  0xbe7ffffd,
  0xbe7fffff,
  0xbe800002,
  0xbf3fffff,
  0xbf400000,
  0xbf400002,
  0xbfa00000,
  0xc11c0000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3e800000,
  0x3e800000,
  0x3e800000,
  0x3e800001,
  0x3e800001,
  0x3f400000,
  0x3f400000,
  0x3f400002,
  0x3fa00000,
  0x3fa00000,
  0x3fa00001,
  0x3fe00000,
  0x41240000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3e800001,
  0x3e800001,
  0x3e800001,
  0x3e800001,
  0x3e800001,
  0xbe7ffffc,
  0xbe7ffffe,
  0xbe800001,
  0xbf3ffffe,
  0xbf400000,
  0xbf400002,
  0xbfa00000,
  0xc11c0000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3e800001,
  0x3e800001,
  0x3e800001,
  0x3e800002,
  0x3e800002,
  0x3f400001,
  0x3f400001,
  0x3f400002,
  0x3fa00000,
  0x3fa00001,
  0x3fa00002,
  0x3fe00001,
  0x41240000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3e800002,
  0x3e800002,
  0x3e800002,
  0x3e800002,
  0x3e800002,
  0xbe7ffffa,
  0xbe7ffffc,
  0xbe800000,
  0xbf3ffffe,
  0xbf3fffff,
  0xbf400001,
  0xbf9fffff,
  0xc11c0000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3e800002,
  0x3e800002,
  0x3e800002,
  0x3f000000,
  0x3f000000,
  0x3f800000,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x3fc00000,
  0x3fc00001,
  0x40000000,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x337fffff,
  0x32fffffe,
  0xb3000001,
  0xbefffffd,
  0xbeffffff,
  0xbf000002,
  0xbf800000,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000001,
  0x3f000001,
  0x3f800000,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x3fc00000,
  0x3fc00002,
  0x40000000,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x33c00000,
  0x33800000,
  0x00000000,
  0xbefffffc,
  0xbefffffe,
  0xbf000001,
  0xbf7fffff,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f000002,
  0x3f000002,
  0x3f800001,
  0x3f800001,
  0x3f800002,
  0x3fc00001,
  0x3fc00001,
  0x3fc00002,
  0x40000001,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f000002,
  0x3f000002,
  0x3f000002,
  0x3f000002,
  0x3f000002,
  0x34200000,
  0x34000000,
  0x33800001,
  0xbefffffa,
  0xbefffffc,
  0xbf000000,
  0xbf7ffffe,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f000002,
  0x3f000002,
  0x3f000002,
  0x3f400002,
  0x3f400002,
  0x3fa00000,
  0x3fa00001,
  0x3fa00001,
  0x3fe00000,
  0x3fe00001,
  0x3fe00002,
  0x40100000,
  0x412c0000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f400002,
  0x3f400002,
  0x3f400002,
  0x3f400002,
  0x3f400001,
  0x3e800004,
  0x3e800003,
  0x3e800001,
  0xbe7ffff6,
  0xbe7ffffa,
  0xbe800001,
  0xbf3ffffe,
  0xc1140000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f400001,
  0x3f400001,
  0x3f400001,
  0x40a00001,
  0x40a00001,
  0x40b00001,
  0x40b00001,
  0x40b00001,
  0x40c00001,
  0x40c00001,
  0x40c00002,
  0x40d00001,
  0x41700001,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x40a00001,
  0x40a00001,
  0x40a00001,
  0x40a00001,
  0x40a00001,
  0x40900001,
  0x40900001,
  0x40900001,
  0x40800001,
  0x40800001,
  0x40800001,
  0x40600002,
  0xc09fffff,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x40a00001,
  0x40a00001,
  0x40a00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x00091a2b,
  0x00891a2b,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x001b4e81,
  0x00891a2a,
  0x00091a2c,
  0x00091a2b,
  0x8076e5d5,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80091a2b,
  0x8076e5d4,
  0x00091a2a,
  0x00400000,
  0x00c00000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00523456,
  0x00bfffff,
  0x00400001,
  0x00400000,
  0x80400000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x002dcbaa,
  0x803fffff,
  0x003fffff,
  0x00000001,
  0x00800001,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123457,
  0x00800000,
  0x00000002,
  0x00000001,
  0x807fffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123455,
  0x807ffffe,
  0x80000000,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80400000,
  0x00400000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x802dcbaa,
  0x003ffffe,
  0x80400000,
  0x80400000,
  0x80c00000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80523456,
  0x80c00000,
  0x80400002,
  0xbe800000,
  0xbe800000,
  0x3e7ffffd,
  0x3e7fffff,
  0x3e800002,
  0x3f3fffff,
  0x3f400000,
  0x3f400002,
  0x3fa00000,
  0x411c0000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbe800000,
  0xbe800000,
  0xbe800000,
  0xbe800000,
  0xbe800000,
  0xbf400000,
  0xbf400000,
  0xbf400001,
  0xbfa00000,
  0xbfa00000,
  0xbfa00001,
  0xbfe00000,
  0xc1240000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbe800000,
  0xbe800000,
  0xbe800000,
  0xbe800001,
  0xbe800001,
  0x3e7ffffc,
  0x3e7ffffe,
  0x3e800001,
  0x3f3ffffe,
  0x3f400000,
  0x3f400002,
  0x3fa00000,
  0x411c0000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbe800001,
  0xbe800001,
  0xbe800001,
  0xbe800001,
  0xbe800001,
  0xbf400000,
  0xbf400000,
  0xbf400002,
  0xbfa00000,
  0xbfa00000,
  0xbfa00001,
  0xbfe00000,
  0xc1240000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbe800001,
  0xbe800001,
  0xbe800001,
  0xbe800002,
  0xbe800002,
  0x3e7ffffa,
  0x3e7ffffc,
  0x3e800000,
  0x3f3ffffe,
  0x3f3fffff,
  0x3f400001,
  0x3f9fffff,
  0x411c0000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbe800002,
  0xbe800002,
  0xbe800002,
  0xbe800002,
  0xbe800002,
  0xbf400001,
  0xbf400001,
  0xbf400002,
  0xbfa00000,
  0xbfa00001,
  0xbfa00002,
  0xbfe00001,
  0xc1240000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbe800002,
  0xbe800002,
  0xbe800002,
  0xbf000000,
  0xbf000000,
  0xb37fffff,
  0xb2fffffe,
  0x33000001,
  0x3efffffd,
  0x3effffff,
  0x3f000002,
  0x3f800000,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf800000,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xbfc00000,
  0xbfc00001,
  0xc0000000,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000001,
  0xbf000001,
  0xb3c00000,
  0xb3800000,
  0x00000000,
  0x3efffffc,
  0x3efffffe,
  0x3f000001,
  0x3f7fffff,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf800000,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xbfc00000,
  0xbfc00002,
  0xc0000000,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf000002,
  0xbf000002,
  0xb4200000,
  0xb4000000,
  0xb3800001,
  0x3efffffa,
  0x3efffffc,
  0x3f000000,
  0x3f7ffffe,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf000002,
  0xbf000002,
  0xbf000002,
  0xbf000002,
  0xbf000002,
  0xbf800001,
  0xbf800001,
  0xbf800002,
  0xbfc00001,
  0xbfc00001,
  0xbfc00002,
  0xc0000001,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf000002,
  0xbf000002,
  0xbf000002,
  0xbf400002,
  0xbf400001,
  0xbe800004,
  0xbe800003,
  0xbe800001,
  0x3e7ffff6,
  0x3e7ffffa,
  0x3e800001,
  0x3f3ffffe,
  0x41140000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf400001,
  0xbf400001,
  0xbf400001,
  0xbf400002,
  0xbf400002,
  0xbfa00000,
  0xbfa00001,
  0xbfa00001,
  0xbfe00000,
  0xbfe00001,
  0xbfe00002,
  0xc0100000,
  0xc12c0000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf400002,
  0xbf400002,
  0xbf400002,
  0xc0a00001,
  0xc0a00001,
  0xc0900001,
  0xc0900001,
  0xc0900001,
  0xc0800001,
  0xc0800001,
  0xc0800001,
  0xc0600002,
  0x409fffff,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xc0a00001,
  0xc0a00001,
  0xc0a00001,
  0xc0a00001,
  0xc0a00001,
  0xc0b00001,
  0xc0b00001,
  0xc0b00001,
  0xc0c00001,
  0xc0c00001,
  0xc0c00002,
  0xc0d00001,
  0xc1700001,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xc0a00001,
  0xc0a00001,
  0xc0a00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x80091a2b,
  0x0076e5d5,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00091a2b,
  0x0076e5d4,
  0x80091a2a,
  0x80091a2b,
  0x80891a2b,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x801b4e81,
  0x80891a2a,
  0x80091a2c,
  0x80400000,
  0x00400000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x802dcbaa,
  0x003fffff,
  0x803fffff,
  0x80400000,
  0x80c00000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80523456,
  0x80bfffff,
  0x80400001,
  0x80000001,
  0x007fffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123455,
  0x007ffffe,
  0x00000000,
  0x80000001,
  0x80800001,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123457,
  0x80800000,
  0x80000002,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00800000,
  0x01000000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00923456,
  0x00fffffe,
  0x00800000,
  0x00800000,
  0x80000000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x006dcbaa,
  0x00000000,
  0x007ffffe,
  0x3efffffe,
  0x3efffffe,
  0x3f7fffff,
  0x3f7fffff,
  0x3f800000,
  0x3fbfffff,
  0x3fc00000,
  0x3fc00001,
  0x40000000,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3efffffe,
  0x3efffffe,
  0x3efffffe,
  0x3efffffe,
  0x3efffffe,
  0xb2ffffff,
  0xb3800000,
  0xb4000000,
  0xbf000000,
  0xbf000001,
  0xbf000003,
  0xbf800000,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3efffffe,
  0x3efffffe,
  0x3efffffe,
  0x3effffff,
  0x3effffff,
  0x3f7fffff,
  0x3f800000,
  0x3f800000,
  0x3fbfffff,
  0x3fc00000,
  0x3fc00001,
  0x40000000,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x00000000,
  0xb3000000,
  0xb3c00000,
  0xbeffffff,
  0xbf000000,
  0xbf000002,
  0xbf800000,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3f000000,
  0x3f000000,
  0x3f800000,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x3fc00000,
  0x3fc00001,
  0x40000000,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x337fffff,
  0x32fffffe,
  0xb3000001,
  0xbefffffd,
  0xbeffffff,
  0xbf000002,
  0xbf800000,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f7ffffe,
  0x3f7ffffe,
  0x3fbfffff,
  0x3fbfffff,
  0x3fc00000,
  0x3fffffff,
  0x3fffffff,
  0x40000000,
  0x40200000,
  0x41300000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f7ffffe,
  0x3f7ffffe,
  0x3f7ffffe,
  0x3f7ffffe,
  0x3f7ffffe,
  0x3efffffd,
  0x3efffffc,
  0x3efffffa,
  0xb37fffff,
  0xb4000000,
  0xb4800000,
  0xbf000002,
  0xc1100000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f7ffffe,
  0x3f7ffffe,
  0x3f7ffffe,
  0x3f7fffff,
  0x3f7fffff,
  0x3fbfffff,
  0x3fc00000,
  0x3fc00000,
  0x3fffffff,
  0x40000000,
  0x40000000,
  0x40200000,
  0x41300000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f7fffff,
  0x3f7fffff,
  0x3f7fffff,
  0x3f7fffff,
  0x3f7fffff,
  0x3effffff,
  0x3efffffe,
  0x3efffffc,
  0x00000000,
  0xb3800000,
  0xb4400000,
  0xbf000001,
  0xc1100000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f7fffff,
  0x3f7fffff,
  0x3f7fffff,
  0x3f800000,
  0x3f800000,
  0x3fc00000,
  0x3fc00000,
  0x3fc00001,
  0x40000000,
  0x40000000,
  0x40000001,
  0x40200000,
  0x41300000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3f000001,
  0x3f000001,
  0x3f000000,
  0x33ffffff,
  0x337ffffe,
  0xb3800001,
  0xbefffffe,
  0xc1100000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3fbfffff,
  0x3fbfffff,
  0x3fffffff,
  0x3fffffff,
  0x40000000,
  0x401fffff,
  0x40200000,
  0x40200000,
  0x40400000,
  0x41380000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3fbfffff,
  0x3fbfffff,
  0x3fbfffff,
  0x3fbfffff,
  0x3fbfffff,
  0x3f7fffff,
  0x3f7ffffe,
  0x3f7ffffe,
  0x3effffff,
  0x3efffffd,
  0x3efffff9,
  0xb3c00000,
  0xc1080000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3fbfffff,
  0x3fbfffff,
  0x3fbfffff,
  0x411fffff,
  0x411fffff,
  0x4127ffff,
  0x4127ffff,
  0x4127ffff,
  0x412fffff,
  0x412fffff,
  0x41300000,
  0x4137ffff,
  0x41a00000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x411fffff,
  0x411fffff,
  0x411fffff,
  0x411fffff,
  0x411fffff,
  0x4117ffff,
  0x4117ffff,
  0x4117ffff,
  0x410fffff,
  0x410fffff,
  0x410fffff,
  0x4107ffff,
  0xb5200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x411fffff,
  0x411fffff,
  0x411fffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x00123456,
  0x00923456,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x002468ac,
  0x00923455,
  0x00123457,
  0x00123456,
  0x806dcbaa,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80000000,
  0x806dcba9,
  0x00123455,
  0x007fffff,
  0x00ffffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00923455,
  0x00fffffe,
  0x00800000,
  0x007fffff,
  0x80000001,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x006dcba9,
  0x80000000,
  0x007ffffe,
  0x00000001,
  0x00800001,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123457,
  0x00800000,
  0x00000002,
  0x00000001,
  0x807fffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123455,
  0x807ffffe,
  0x80000000,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80800000,
  0x00000000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x806dcbaa,
  0x80000000,
  0x807ffffe,
  0x80800000,
  0x81000000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80923456,
  0x80fffffe,
  0x80800000,
  0xbefffffe,
  0xbefffffe,
  0x32ffffff,
  0x33800000,
  0x34000000,
  0x3f000000,
  0x3f000001,
  0x3f000003,
  0x3f800000,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbefffffe,
  0xbefffffe,
  0xbefffffe,
  0xbefffffe,
  0xbefffffe,
  0xbf7fffff,
  0xbf7fffff,
  0xbf800000,
  0xbfbfffff,
  0xbfc00000,
  0xbfc00001,
  0xc0000000,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbefffffe,
  0xbefffffe,
  0xbefffffe,
  0xbeffffff,
  0xbeffffff,
  0x00000000,
  0x33000000,
  0x33c00000,
  0x3effffff,
  0x3f000000,
  0x3f000002,
  0x3f800000,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbf7fffff,
  0xbf800000,
  0xbf800000,
  0xbfbfffff,
  0xbfc00000,
  0xbfc00001,
  0xc0000000,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbf000000,
  0xbf000000,
  0xb37fffff,
  0xb2fffffe,
  0x33000001,
  0x3efffffd,
  0x3effffff,
  0x3f000002,
  0x3f800000,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf800000,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xbfc00000,
  0xbfc00001,
  0xc0000000,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf7ffffe,
  0xbf7ffffe,
  0xbefffffd,
  0xbefffffc,
  0xbefffffa,
  0x337fffff,
  0x34000000,
  0x34800000,
  0x3f000002,
  0x41100000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf7ffffe,
  0xbf7ffffe,
  0xbf7ffffe,
  0xbf7ffffe,
  0xbf7ffffe,
  0xbfbfffff,
  0xbfbfffff,
  0xbfc00000,
  0xbfffffff,
  0xbfffffff,
  0xc0000000,
  0xc0200000,
  0xc1300000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf7ffffe,
  0xbf7ffffe,
  0xbf7ffffe,
  0xbf7fffff,
  0xbf7fffff,
  0xbeffffff,
  0xbefffffe,
  0xbefffffc,
  0x00000000,
  0x33800000,
  0x34400000,
  0x3f000001,
  0x41100000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf7fffff,
  0xbf7fffff,
  0xbf7fffff,
  0xbf7fffff,
  0xbf7fffff,
  0xbfbfffff,
  0xbfc00000,
  0xbfc00000,
  0xbfffffff,
  0xc0000000,
  0xc0000000,
  0xc0200000,
  0xc1300000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf7fffff,
  0xbf7fffff,
  0xbf7fffff,
  0xbf800000,
  0xbf800000,
  0xbf000001,
  0xbf000001,
  0xbf000000,
  0xb3ffffff,
  0xb37ffffe,
  0x33800001,
  0x3efffffe,
  0x41100000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbfc00000,
  0xbfc00000,
  0xbfc00001,
  0xc0000000,
  0xc0000000,
  0xc0000001,
  0xc0200000,
  0xc1300000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbfbfffff,
  0xbfbfffff,
  0xbf7fffff,
  0xbf7ffffe,
  0xbf7ffffe,
  0xbeffffff,
  0xbefffffd,
  0xbefffff9,
  0x33c00000,
  0x41080000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbfbfffff,
  0xbfbfffff,
  0xbfbfffff,
  0xbfbfffff,
  0xbfbfffff,
  0xbfffffff,
  0xbfffffff,
  0xc0000000,
  0xc01fffff,
  0xc0200000,
  0xc0200000,
  0xc0400000,
  0xc1380000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbfbfffff,
  0xbfbfffff,
  0xbfbfffff,
  0xc11fffff,
  0xc11fffff,
  0xc117ffff,
  0xc117ffff,
  0xc117ffff,
  0xc10fffff,
  0xc10fffff,
  0xc10fffff,
  0xc107ffff,
  0x35200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xc11fffff,
  0xc11fffff,
  0xc11fffff,
  0xc11fffff,
  0xc11fffff,
  0xc127ffff,
  0xc127ffff,
  0xc127ffff,
  0xc12fffff,
  0xc12fffff,
  0xc1300000,
  0xc137ffff,
  0xc1a00000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xc11fffff,
  0xc11fffff,
  0xc11fffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x80123456,
  0x006dcbaa,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00000000,
  0x006dcba9,
  0x80123455,
  0x80123456,
  0x80923456,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x802468ac,
  0x80923455,
  0x80123457,
  0x807fffff,
  0x00000001,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x806dcba9,
  0x00000000,
  0x807ffffe,
  0x807fffff,
  0x80ffffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80923455,
  0x80fffffe,
  0x80800000,
  0x80000001,
  0x007fffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123455,
  0x007ffffe,
  0x00000000,
  0x80000001,
  0x80800001,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123457,
  0x80800000,
  0x80000002,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00800000,
  0x01000000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00923456,
  0x00ffffff,
  0x00800001,
  0x00800000,
  0x00000000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x006dcbaa,
  0x00000001,
  0x007fffff,
  0x3effffff,
  0x3effffff,
  0x3f7fffff,
  0x3f800000,
  0x3f800000,
  0x3fbfffff,
  0x3fc00000,
  0x3fc00001,
  0x40000000,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x00000000,
  0xb3000000,
  0xb3c00000,
  0xbeffffff,
  0xbf000000,
  0xbf000002,
  0xbf800000,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3f000000,
  0x3f000000,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3fc00000,
  0x3fc00000,
  0x3fc00001,
  0x40000000,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x33000000,
  0x00000000,
  0xb3800000,
  0xbefffffe,
  0xbf000000,
  0xbf000002,
  0xbf800000,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000001,
  0x3f000001,
  0x3f800000,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x3fc00000,
  0x3fc00002,
  0x40000000,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x33c00000,
  0x33800000,
  0x00000000,
  0xbefffffc,
  0xbefffffe,
  0xbf000001,
  0xbf7fffff,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f7fffff,
  0x3f7fffff,
  0x3fbfffff,
  0x3fc00000,
  0x3fc00000,
  0x3fffffff,
  0x40000000,
  0x40000000,
  0x40200000,
  0x41300000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f7fffff,
  0x3f7fffff,
  0x3f7fffff,
  0x3f7fffff,
  0x3f7fffff,
  0x3effffff,
  0x3efffffe,
  0x3efffffc,
  0x00000000,
  0xb3800000,
  0xb4400000,
  0xbf000001,
  0xc1100000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f7fffff,
  0x3f7fffff,
  0x3f7fffff,
  0x3f800000,
  0x3f800000,
  0x3fc00000,
  0x3fc00000,
  0x3fc00000,
  0x40000000,
  0x40000000,
  0x40000000,
  0x40200000,
  0x41300000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3f000000,
  0x3f000000,
  0x3efffffe,
  0x33800000,
  0x00000000,
  0xb4000000,
  0xbf000000,
  0xc1100000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3f800001,
  0x3f800001,
  0x3fc00001,
  0x3fc00001,
  0x3fc00002,
  0x40000000,
  0x40000000,
  0x40000001,
  0x40200000,
  0x41300000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f800001,
  0x3f800001,
  0x3f800001,
  0x3f800001,
  0x3f800001,
  0x3f000002,
  0x3f000002,
  0x3f000001,
  0x34400000,
  0x34000000,
  0x00000000,
  0xbefffffc,
  0xc1100000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f800001,
  0x3f800001,
  0x3f800001,
  0x3fc00000,
  0x3fc00000,
  0x40000000,
  0x40000000,
  0x40000000,
  0x40200000,
  0x40200000,
  0x40200000,
  0x40400000,
  0x41380000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3fc00000,
  0x3fc00000,
  0x3fc00000,
  0x3fc00000,
  0x3fc00000,
  0x3f800000,
  0x3f800000,
  0x3f7fffff,
  0x3f000001,
  0x3f000000,
  0x3efffffc,
  0x00000000,
  0xc1080000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3fc00000,
  0x3fc00000,
  0x3fc00000,
  0x41200000,
  0x41200000,
  0x41280000,
  0x41280000,
  0x41280000,
  0x41300000,
  0x41300000,
  0x41300000,
  0x41380000,
  0x41a00000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x41200000,
  0x41200000,
  0x41200000,
  0x41200000,
  0x41200000,
  0x41180000,
  0x41180000,
  0x41180000,
  0x41100000,
  0x41100000,
  0x41100000,
  0x41080000,
  0x00000000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x41200000,
  0x41200000,
  0x41200000,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x00123456,
  0x00923456,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x002468ac,
  0x00923455,
  0x00123457,
  0x00123456,
  0x806dcbaa,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x00000000,
  0x806dcba9,
  0x00123455,
  0x007fffff,
  0x00ffffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00923455,
  0x00fffffe,
  0x00800000,
  0x007fffff,
  0x80000001,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x006dcba9,
  0x00000000,
  0x007ffffe,
  0x00000001,
  0x00800001,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123457,
  0x00800000,
  0x00000002,
  0x00000001,
  0x807fffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123455,
  0x807ffffe,
  0x00000000,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80800000,
  0x00000000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x806dcbaa,
  0x80000001,
  0x807fffff,
  0x80800000,
  0x81000000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80923456,
  0x80ffffff,
  0x80800001,
  0xbeffffff,
  0xbeffffff,
  0x00000000,
  0x33000000,
  0x33c00000,
  0x3effffff,
  0x3f000000,
  0x3f000002,
  0x3f800000,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbf7fffff,
  0xbf800000,
  0xbf800000,
  0xbfbfffff,
  0xbfc00000,
  0xbfc00001,
  0xc0000000,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbf000000,
  0xbf000000,
  0xb3000000,
  0x00000000,
  0x33800000,
  0x3efffffe,
  0x3f000000,
  0x3f000002,
  0x3f800000,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbfc00000,
  0xbfc00000,
  0xbfc00001,
  0xc0000000,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000001,
  0xbf000001,
  0xb3c00000,
  0xb3800000,
  0x00000000,
  0x3efffffc,
  0x3efffffe,
  0x3f000001,
  0x3f7fffff,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf800000,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xbfc00000,
  0xbfc00002,
  0xc0000000,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf7fffff,
  0xbf7fffff,
  0xbeffffff,
  0xbefffffe,
  0xbefffffc,
  0x00000000,
  0x33800000,
  0x34400000,
  0x3f000001,
  0x41100000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf7fffff,
  0xbf7fffff,
  0xbf7fffff,
  0xbf7fffff,
  0xbf7fffff,
  0xbfbfffff,
  0xbfc00000,
  0xbfc00000,
  0xbfffffff,
  0xc0000000,
  0xc0000000,
  0xc0200000,
  0xc1300000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf7fffff,
  0xbf7fffff,
  0xbf7fffff,
  0xbf800000,
  0xbf800000,
  0xbf000000,
  0xbf000000,
  0xbefffffe,
  0xb3800000,
  0x00000000,
  0x34000000,
  0x3f000000,
  0x41100000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbfc00000,
  0xbfc00000,
  0xbfc00000,
  0xc0000000,
  0xc0000000,
  0xc0000000,
  0xc0200000,
  0xc1300000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbf800001,
  0xbf800001,
  0xbf000002,
  0xbf000002,
  0xbf000001,
  0xb4400000,
  0xb4000000,
  0x00000000,
  0x3efffffc,
  0x41100000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf800001,
  0xbf800001,
  0xbf800001,
  0xbf800001,
  0xbf800001,
  0xbfc00001,
  0xbfc00001,
  0xbfc00002,
  0xc0000000,
  0xc0000000,
  0xc0000001,
  0xc0200000,
  0xc1300000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf800001,
  0xbf800001,
  0xbf800001,
  0xbfc00000,
  0xbfc00000,
  0xbf800000,
  0xbf800000,
  0xbf7fffff,
  0xbf000001,
  0xbf000000,
  0xbefffffc,
  0x00000000,
  0x41080000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbfc00000,
  0xbfc00000,
  0xbfc00000,
  0xbfc00000,
  0xbfc00000,
  0xc0000000,
  0xc0000000,
  0xc0000000,
  0xc0200000,
  0xc0200000,
  0xc0200000,
  0xc0400000,
  0xc1380000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbfc00000,
  0xbfc00000,
  0xbfc00000,
  0xc1200000,
  0xc1200000,
  0xc1180000,
  0xc1180000,
  0xc1180000,
  0xc1100000,
  0xc1100000,
  0xc1100000,
  0xc1080000,
  0x00000000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xc1200000,
  0xc1200000,
  0xc1200000,
  0xc1200000,
  0xc1200000,
  0xc1280000,
  0xc1280000,
  0xc1280000,
  0xc1300000,
  0xc1300000,
  0xc1300000,
  0xc1380000,
  0xc1a00000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xc1200000,
  0xc1200000,
  0xc1200000,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x80123456,
  0x006dcbaa,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00000000,
  0x006dcba9,
  0x80123455,
  0x80123456,
  0x80923456,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x802468ac,
  0x80923455,
  0x80123457,
  0x807fffff,
  0x00000001,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x806dcba9,
  0x00000000,
  0x807ffffe,
  0x807fffff,
  0x80ffffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80923455,
  0x80fffffe,
  0x80800000,
  0x80000001,
  0x007fffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123455,
  0x007ffffe,
  0x00000000,
  0x80000001,
  0x80800001,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123457,
  0x80800000,
  0x80000002,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00800001,
  0x01000000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00923457,
  0x01000000,
  0x00800002,
  0x00800001,
  0x00000001,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x006dcbab,
  0x00000002,
  0x00800000,
  0x3f000000,
  0x3f000000,
  0x3f800000,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x3fc00000,
  0x3fc00001,
  0x40000000,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x337fffff,
  0x32fffffe,
  0xb3000001,
  0xbefffffd,
  0xbeffffff,
  0xbf000002,
  0xbf800000,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000001,
  0x3f000001,
  0x3f800000,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x3fc00000,
  0x3fc00002,
  0x40000000,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x33c00000,
  0x33800000,
  0x00000000,
  0xbefffffc,
  0xbefffffe,
  0xbf000001,
  0xbf7fffff,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f000002,
  0x3f000002,
  0x3f800001,
  0x3f800001,
  0x3f800002,
  0x3fc00001,
  0x3fc00001,
  0x3fc00002,
  0x40000001,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f000002,
  0x3f000002,
  0x3f000002,
  0x3f000002,
  0x3f000002,
  0x34200000,
  0x34000000,
  0x33800001,
  0xbefffffa,
  0xbefffffc,
  0xbf000000,
  0xbf7ffffe,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f000002,
  0x3f000002,
  0x3f000002,
  0x3f800000,
  0x3f800000,
  0x3fc00000,
  0x3fc00000,
  0x3fc00001,
  0x40000000,
  0x40000000,
  0x40000001,
  0x40200000,
  0x41300000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3f000001,
  0x3f000001,
  0x3f000000,
  0x33ffffff,
  0x337ffffe,
  0xb3800001,
  0xbefffffe,
  0xc1100000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3f800001,
  0x3f800001,
  0x3fc00001,
  0x3fc00001,
  0x3fc00002,
  0x40000000,
  0x40000000,
  0x40000001,
  0x40200000,
  0x41300000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f800001,
  0x3f800001,
  0x3f800001,
  0x3f800001,
  0x3f800001,
  0x3f000002,
  0x3f000002,
  0x3f000001,
  0x34400000,
  0x34000000,
  0x00000000,
  0xbefffffc,
  0xc1100000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f800001,
  0x3f800001,
  0x3f800001,
  0x3f800002,
  0x3f800002,
  0x3fc00002,
  0x3fc00002,
  0x3fc00003,
  0x40000001,
  0x40000001,
  0x40000002,
  0x40200001,
  0x41300000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f800002,
  0x3f800002,
  0x3f800002,
  0x3f800002,
  0x3f800002,
  0x3f000005,
  0x3f000004,
  0x3f000003,
  0x34a00000,
  0x34800000,
  0x34000001,
  0xbefffff8,
  0xc1100000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f800002,
  0x3f800002,
  0x3f800002,
  0x3fc00002,
  0x3fc00002,
  0x40000001,
  0x40000001,
  0x40000001,
  0x40200000,
  0x40200001,
  0x40200001,
  0x40400001,
  0x41380000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3fc00002,
  0x3fc00002,
  0x3fc00002,
  0x3fc00002,
  0x3fc00001,
  0x3f800002,
  0x3f800002,
  0x3f800001,
  0x3f000004,
  0x3f000003,
  0x3f000001,
  0x34400000,
  0xc1080000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3fc00001,
  0x3fc00001,
  0x3fc00001,
  0x41200001,
  0x41200001,
  0x41280001,
  0x41280001,
  0x41280001,
  0x41300001,
  0x41300001,
  0x41300001,
  0x41380001,
  0x41a00001,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x41200001,
  0x41200001,
  0x41200001,
  0x41200001,
  0x41200001,
  0x41180001,
  0x41180001,
  0x41180001,
  0x41100001,
  0x41100001,
  0x41100001,
  0x41080001,
  0x35a00000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x41200001,
  0x41200001,
  0x41200001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x00123456,
  0x00923456,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x002468ac,
  0x00923455,
  0x00123457,
  0x00123456,
  0x806dcbaa,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x00000000,
  0x806dcba9,
  0x00123455,
  0x00800000,
  0x01000000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00923456,
  0x00ffffff,
  0x00800001,
  0x00800000,
  0x80000000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x006dcbaa,
  0x00000001,
  0x007fffff,
  0x00000001,
  0x00800001,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123457,
  0x00800000,
  0x00000002,
  0x00000001,
  0x807fffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123455,
  0x807ffffe,
  0x00000000,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80800001,
  0x80000001,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x806dcbab,
  0x80000002,
  0x80800000,
  0x80800001,
  0x81000000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80923457,
  0x81000000,
  0x80800002,
  0xbf000000,
  0xbf000000,
  0xb37fffff,
  0xb2fffffe,
  0x33000001,
  0x3efffffd,
  0x3effffff,
  0x3f000002,
  0x3f800000,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf800000,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xbfc00000,
  0xbfc00001,
  0xc0000000,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000001,
  0xbf000001,
  0xb3c00000,
  0xb3800000,
  0x00000000,
  0x3efffffc,
  0x3efffffe,
  0x3f000001,
  0x3f7fffff,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf800000,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xbfc00000,
  0xbfc00002,
  0xc0000000,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf000002,
  0xbf000002,
  0xb4200000,
  0xb4000000,
  0xb3800001,
  0x3efffffa,
  0x3efffffc,
  0x3f000000,
  0x3f7ffffe,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf000002,
  0xbf000002,
  0xbf000002,
  0xbf000002,
  0xbf000002,
  0xbf800001,
  0xbf800001,
  0xbf800002,
  0xbfc00001,
  0xbfc00001,
  0xbfc00002,
  0xc0000001,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf000002,
  0xbf000002,
  0xbf000002,
  0xbf800000,
  0xbf800000,
  0xbf000001,
  0xbf000001,
  0xbf000000,
  0xb3ffffff,
  0xb37ffffe,
  0x33800001,
  0x3efffffe,
  0x41100000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbfc00000,
  0xbfc00000,
  0xbfc00001,
  0xc0000000,
  0xc0000000,
  0xc0000001,
  0xc0200000,
  0xc1300000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbf800001,
  0xbf800001,
  0xbf000002,
  0xbf000002,
  0xbf000001,
  0xb4400000,
  0xb4000000,
  0x00000000,
  0x3efffffc,
  0x41100000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf800001,
  0xbf800001,
  0xbf800001,
  0xbf800001,
  0xbf800001,
  0xbfc00001,
  0xbfc00001,
  0xbfc00002,
  0xc0000000,
  0xc0000000,
  0xc0000001,
  0xc0200000,
  0xc1300000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf800001,
  0xbf800001,
  0xbf800001,
  0xbf800002,
  0xbf800002,
  0xbf000005,
  0xbf000004,
  0xbf000003,
  0xb4a00000,
  0xb4800000,
  0xb4000001,
  0x3efffff8,
  0x41100000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf800002,
  0xbf800002,
  0xbf800002,
  0xbf800002,
  0xbf800002,
  0xbfc00002,
  0xbfc00002,
  0xbfc00003,
  0xc0000001,
  0xc0000001,
  0xc0000002,
  0xc0200001,
  0xc1300000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf800002,
  0xbf800002,
  0xbf800002,
  0xbfc00002,
  0xbfc00001,
  0xbf800002,
  0xbf800002,
  0xbf800001,
  0xbf000004,
  0xbf000003,
  0xbf000001,
  0xb4400000,
  0x41080000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbfc00001,
  0xbfc00001,
  0xbfc00001,
  0xbfc00002,
  0xbfc00002,
  0xc0000001,
  0xc0000001,
  0xc0000001,
  0xc0200000,
  0xc0200001,
  0xc0200001,
  0xc0400001,
  0xc1380000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbfc00002,
  0xbfc00002,
  0xbfc00002,
  0xc1200001,
  0xc1200001,
  0xc1180001,
  0xc1180001,
  0xc1180001,
  0xc1100001,
  0xc1100001,
  0xc1100001,
  0xc1080001,
  0xb5a00000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xc1200001,
  0xc1200001,
  0xc1200001,
  0xc1200001,
  0xc1200001,
  0xc1280001,
  0xc1280001,
  0xc1280001,
  0xc1300001,
  0xc1300001,
  0xc1300001,
  0xc1380001,
  0xc1a00001,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xc1200001,
  0xc1200001,
  0xc1200001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x80123456,
  0x006dcbaa,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x80000000,
  0x006dcba9,
  0x80123455,
  0x80123456,
  0x80923456,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x802468ac,
  0x80923455,
  0x80123457,
  0x80800000,
  0x00000000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x806dcbaa,
  0x80000001,
  0x807fffff,
  0x80800000,
  0x81000000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80923456,
  0x80ffffff,
  0x80800001,
  0x80000001,
  0x007fffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123455,
  0x007ffffe,
  0x80000000,
  0x80000001,
  0x80800001,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123457,
  0x80800000,
  0x80000002,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00c00000,
  0x01200000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00d23456,
  0x01200000,
  0x00c00001,
  0x00c00000,
  0x00400000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x00adcbaa,
  0x00400001,
  0x00bfffff,
  0x3f3fffff,
  0x3f3fffff,
  0x3f9fffff,
  0x3fa00000,
  0x3fa00000,
  0x3fdfffff,
  0x3fe00000,
  0x3fe00001,
  0x40100000,
  0x412c0000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f3fffff,
  0x3f3fffff,
  0x3f3fffff,
  0x3f3fffff,
  0x3f3fffff,
  0x3e7fffff,
  0x3e7ffffd,
  0x3e7ffff9,
  0xbe7fffff,
  0xbe800002,
  0xbe800006,
  0xbf400001,
  0xc1140000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f3fffff,
  0x3f3fffff,
  0x3f3fffff,
  0x3f400000,
  0x3f400000,
  0x3fa00000,
  0x3fa00000,
  0x3fa00000,
  0x3fe00000,
  0x3fe00000,
  0x3fe00001,
  0x40100000,
  0x412c0000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f400000,
  0x3f400000,
  0x3f400000,
  0x3f400000,
  0x3f400000,
  0x3e800001,
  0x3e800000,
  0x3e7ffffc,
  0xbe7ffffc,
  0xbe800000,
  0xbe800004,
  0xbf400000,
  0xc1140000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f400000,
  0x3f400000,
  0x3f400000,
  0x3f400002,
  0x3f400002,
  0x3fa00000,
  0x3fa00001,
  0x3fa00001,
  0x3fe00000,
  0x3fe00001,
  0x3fe00002,
  0x40100000,
  0x412c0000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f400002,
  0x3f400002,
  0x3f400002,
  0x3f400002,
  0x3f400001,
  0x3e800004,
  0x3e800003,
  0x3e800001,
  0xbe7ffff6,
  0xbe7ffffa,
  0xbe800001,
  0xbf3ffffe,
  0xc1140000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f400001,
  0x3f400001,
  0x3f400001,
  0x3fbfffff,
  0x3fbfffff,
  0x3fffffff,
  0x3fffffff,
  0x40000000,
  0x401fffff,
  0x40200000,
  0x40200000,
  0x40400000,
  0x41380000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3fbfffff,
  0x3fbfffff,
  0x3fbfffff,
  0x3fbfffff,
  0x3fbfffff,
  0x3f7fffff,
  0x3f7ffffe,
  0x3f7ffffe,
  0x3effffff,
  0x3efffffd,
  0x3efffff9,
  0xb3c00000,
  0xc1080000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3fbfffff,
  0x3fbfffff,
  0x3fbfffff,
  0x3fc00000,
  0x3fc00000,
  0x40000000,
  0x40000000,
  0x40000000,
  0x40200000,
  0x40200000,
  0x40200000,
  0x40400000,
  0x41380000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3fc00000,
  0x3fc00000,
  0x3fc00000,
  0x3fc00000,
  0x3fc00000,
  0x3f800000,
  0x3f800000,
  0x3f7fffff,
  0x3f000001,
  0x3f000000,
  0x3efffffc,
  0x00000000,
  0xc1080000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3fc00000,
  0x3fc00000,
  0x3fc00000,
  0x3fc00002,
  0x3fc00002,
  0x40000001,
  0x40000001,
  0x40000001,
  0x40200000,
  0x40200001,
  0x40200001,
  0x40400001,
  0x41380000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3fc00002,
  0x3fc00002,
  0x3fc00002,
  0x3fc00002,
  0x3fc00001,
  0x3f800002,
  0x3f800002,
  0x3f800001,
  0x3f000004,
  0x3f000003,
  0x3f000001,
  0x34400000,
  0xc1080000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3fc00001,
  0x3fc00001,
  0x3fc00001,
  0x40100000,
  0x40100000,
  0x40300000,
  0x40300000,
  0x40300000,
  0x40500000,
  0x40500000,
  0x40500000,
  0x40700000,
  0x41440000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x40100000,
  0x40100000,
  0x40100000,
  0x40100000,
  0x40100000,
  0x3fe00000,
  0x3fe00000,
  0x3fe00000,
  0x3fa00000,
  0x3fa00000,
  0x3f9fffff,
  0x3f400000,
  0xc0f80000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x40100000,
  0x40100000,
  0x40100000,
  0x41700000,
  0x41700000,
  0x41780000,
  0x41780000,
  0x41780000,
  0x41800000,
  0x41800000,
  0x41800000,
  0x41840000,
  0x41c80000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x41700000,
  0x41700000,
  0x41700000,
  0x41700000,
  0x41700000,
  0x41680000,
  0x41680000,
  0x41680000,
  0x41600000,
  0x41600000,
  0x41600000,
  0x41580000,
  0x40a00000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x41700000,
  0x41700000,
  0x41700000,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x001b4e81,
  0x009b4e81,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x002d82d7,
  0x009b4e80,
  0x001b4e82,
  0x001b4e81,
  0x8064b17f,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x00091a2b,
  0x8064b17e,
  0x001b4e80,
  0x00bffffe,
  0x011fffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00d23454,
  0x011fffff,
  0x00c00000,
  0x00bffffe,
  0x003ffffe,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x00adcba8,
  0x00400000,
  0x00bffffe,
  0x00000002,
  0x00800002,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123458,
  0x00800000,
  0x00000002,
  0x00000002,
  0x807ffffe,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123454,
  0x807ffffe,
  0x00000000,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80c00000,
  0x80400000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x80adcbaa,
  0x80400001,
  0x80bfffff,
  0x80c00000,
  0x81200000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80d23456,
  0x81200000,
  0x80c00001,
  0xbf3fffff,
  0xbf3fffff,
  0xbe7fffff,
  0xbe7ffffd,
  0xbe7ffff9,
  0x3e7fffff,
  0x3e800002,
  0x3e800006,
  0x3f400001,
  0x41140000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf3fffff,
  0xbf3fffff,
  0xbf3fffff,
  0xbf3fffff,
  0xbf3fffff,
  0xbf9fffff,
  0xbfa00000,
  0xbfa00000,
  0xbfdfffff,
  0xbfe00000,
  0xbfe00001,
  0xc0100000,
  0xc12c0000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf3fffff,
  0xbf3fffff,
  0xbf3fffff,
  0xbf400000,
  0xbf400000,
  0xbe800001,
  0xbe800000,
  0xbe7ffffc,
  0x3e7ffffc,
  0x3e800000,
  0x3e800004,
  0x3f400000,
  0x41140000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf400000,
  0xbf400000,
  0xbf400000,
  0xbf400000,
  0xbf400000,
  0xbfa00000,
  0xbfa00000,
  0xbfa00000,
  0xbfe00000,
  0xbfe00000,
  0xbfe00001,
  0xc0100000,
  0xc12c0000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf400000,
  0xbf400000,
  0xbf400000,
  0xbf400002,
  0xbf400001,
  0xbe800004,
  0xbe800003,
  0xbe800001,
  0x3e7ffff6,
  0x3e7ffffa,
  0x3e800001,
  0x3f3ffffe,
  0x41140000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf400001,
  0xbf400001,
  0xbf400001,
  0xbf400002,
  0xbf400002,
  0xbfa00000,
  0xbfa00001,
  0xbfa00001,
  0xbfe00000,
  0xbfe00001,
  0xbfe00002,
  0xc0100000,
  0xc12c0000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf400002,
  0xbf400002,
  0xbf400002,
  0xbfbfffff,
  0xbfbfffff,
  0xbf7fffff,
  0xbf7ffffe,
  0xbf7ffffe,
  0xbeffffff,
  0xbefffffd,
  0xbefffff9,
  0x33c00000,
  0x41080000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbfbfffff,
  0xbfbfffff,
  0xbfbfffff,
  0xbfbfffff,
  0xbfbfffff,
  0xbfffffff,
  0xbfffffff,
  0xc0000000,
  0xc01fffff,
  0xc0200000,
  0xc0200000,
  0xc0400000,
  0xc1380000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbfbfffff,
  0xbfbfffff,
  0xbfbfffff,
  0xbfc00000,
  0xbfc00000,
  0xbf800000,
  0xbf800000,
  0xbf7fffff,
  0xbf000001,
  0xbf000000,
  0xbefffffc,
  0x00000000,
  0x41080000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbfc00000,
  0xbfc00000,
  0xbfc00000,
  0xbfc00000,
  0xbfc00000,
  0xc0000000,
  0xc0000000,
  0xc0000000,
  0xc0200000,
  0xc0200000,
  0xc0200000,
  0xc0400000,
  0xc1380000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbfc00000,
  0xbfc00000,
  0xbfc00000,
  0xbfc00002,
  0xbfc00001,
  0xbf800002,
  0xbf800002,
  0xbf800001,
  0xbf000004,
  0xbf000003,
  0xbf000001,
  0xb4400000,
  0x41080000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbfc00001,
  0xbfc00001,
  0xbfc00001,
  0xbfc00002,
  0xbfc00002,
  0xc0000001,
  0xc0000001,
  0xc0000001,
  0xc0200000,
  0xc0200001,
  0xc0200001,
  0xc0400001,
  0xc1380000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbfc00002,
  0xbfc00002,
  0xbfc00002,
  0xc0100000,
  0xc0100000,
  0xbfe00000,
  0xbfe00000,
  0xbfe00000,
  0xbfa00000,
  0xbfa00000,
  0xbf9fffff,
  0xbf400000,
  0x40f80000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xc0100000,
  0xc0100000,
  0xc0100000,
  0xc0100000,
  0xc0100000,
  0xc0300000,
  0xc0300000,
  0xc0300000,
  0xc0500000,
  0xc0500000,
  0xc0500000,
  0xc0700000,
  0xc1440000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xc0100000,
  0xc0100000,
  0xc0100000,
  0xc1700000,
  0xc1700000,
  0xc1680000,
  0xc1680000,
  0xc1680000,
  0xc1600000,
  0xc1600000,
  0xc1600000,
  0xc1580000,
  0xc0a00000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xc1700000,
  0xc1700000,
  0xc1700000,
  0xc1700000,
  0xc1700000,
  0xc1780000,
  0xc1780000,
  0xc1780000,
  0xc1800000,
  0xc1800000,
  0xc1800000,
  0xc1840000,
  0xc1c80000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xc1700000,
  0xc1700000,
  0xc1700000,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x801b4e81,
  0x0064b17f,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x80091a2b,
  0x0064b17e,
  0x801b4e80,
  0x801b4e81,
  0x809b4e81,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x802d82d7,
  0x809b4e80,
  0x801b4e82,
  0x80bffffe,
  0x803ffffe,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x80adcba8,
  0x80400000,
  0x80bffffe,
  0x80bffffe,
  0x811fffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80d23454,
  0x811fffff,
  0x80c00000,
  0x80000002,
  0x007ffffe,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123454,
  0x007ffffe,
  0x80000000,
  0x80000002,
  0x80800002,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123458,
  0x80800000,
  0x80000002,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x02200000,
  0x02300000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x0222468b,
  0x02300000,
  0x02200000,
  0x02200000,
  0x02100000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x021db975,
  0x02100000,
  0x02200000,
  0x409fffff,
  0x409fffff,
  0x40afffff,
  0x40afffff,
  0x40b00000,
  0x40bfffff,
  0x40bfffff,
  0x40c00000,
  0x40cfffff,
  0x41700000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x409fffff,
  0x409fffff,
  0x409fffff,
  0x409fffff,
  0x409fffff,
  0x408fffff,
  0x408fffff,
  0x408fffff,
  0x407fffff,
  0x407fffff,
  0x407ffffe,
  0x405fffff,
  0xc0a00001,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x409fffff,
  0x409fffff,
  0x409fffff,
  0x40a00000,
  0x40a00000,
  0x40b00000,
  0x40b00000,
  0x40b00000,
  0x40c00000,
  0x40c00000,
  0x40c00000,
  0x40d00000,
  0x41700000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x40a00000,
  0x40a00000,
  0x40a00000,
  0x40a00000,
  0x40a00000,
  0x40900000,
  0x40900000,
  0x40900000,
  0x40800000,
  0x40800000,
  0x40800000,
  0x40600000,
  0xc0a00000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x40a00000,
  0x40a00000,
  0x40a00000,
  0x40a00001,
  0x40a00001,
  0x40b00001,
  0x40b00001,
  0x40b00001,
  0x40c00001,
  0x40c00001,
  0x40c00002,
  0x40d00001,
  0x41700001,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x40a00001,
  0x40a00001,
  0x40a00001,
  0x40a00001,
  0x40a00001,
  0x40900001,
  0x40900001,
  0x40900001,
  0x40800001,
  0x40800001,
  0x40800001,
  0x40600002,
  0xc09fffff,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x40a00001,
  0x40a00001,
  0x40a00001,
  0x411fffff,
  0x411fffff,
  0x4127ffff,
  0x4127ffff,
  0x4127ffff,
  0x412fffff,
  0x412fffff,
  0x41300000,
  0x4137ffff,
  0x41a00000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x411fffff,
  0x411fffff,
  0x411fffff,
  0x411fffff,
  0x411fffff,
  0x4117ffff,
  0x4117ffff,
  0x4117ffff,
  0x410fffff,
  0x410fffff,
  0x410fffff,
  0x4107ffff,
  0xb5200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x411fffff,
  0x411fffff,
  0x411fffff,
  0x41200000,
  0x41200000,
  0x41280000,
  0x41280000,
  0x41280000,
  0x41300000,
  0x41300000,
  0x41300000,
  0x41380000,
  0x41a00000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x41200000,
  0x41200000,
  0x41200000,
  0x41200000,
  0x41200000,
  0x41180000,
  0x41180000,
  0x41180000,
  0x41100000,
  0x41100000,
  0x41100000,
  0x41080000,
  0x00000000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x41200000,
  0x41200000,
  0x41200000,
  0x41200001,
  0x41200001,
  0x41280001,
  0x41280001,
  0x41280001,
  0x41300001,
  0x41300001,
  0x41300001,
  0x41380001,
  0x41a00001,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x41200001,
  0x41200001,
  0x41200001,
  0x41200001,
  0x41200001,
  0x41180001,
  0x41180001,
  0x41180001,
  0x41100001,
  0x41100001,
  0x41100001,
  0x41080001,
  0x35a00000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x41200001,
  0x41200001,
  0x41200001,
  0x41700000,
  0x41700000,
  0x41780000,
  0x41780000,
  0x41780000,
  0x41800000,
  0x41800000,
  0x41800000,
  0x41840000,
  0x41c80000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x41700000,
  0x41700000,
  0x41700000,
  0x41700000,
  0x41700000,
  0x41680000,
  0x41680000,
  0x41680000,
  0x41600000,
  0x41600000,
  0x41600000,
  0x41580000,
  0x40a00000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x41700000,
  0x41700000,
  0x41700000,
  0x42c80000,
  0x42c80000,
  0x42c90000,
  0x42c90000,
  0x42c90000,
  0x42ca0000,
  0x42ca0000,
  0x42ca0000,
  0x42cb0000,
  0x42dc0000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x42c80000,
  0x42c80000,
  0x42c80000,
  0x42c80000,
  0x42c80000,
  0x42c70000,
  0x42c70000,
  0x42c70000,
  0x42c60000,
  0x42c60000,
  0x42c60000,
  0x42c50000,
  0x42b40000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x42c80000,
  0x42c80000,
  0x42c80000,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x00b60b5c,
  0x011b05ae,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00c83fb2,
  0x011b05ae,
  0x00b60b5d,
  0x00b60b5c,
  0x00360b5c,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x00a3d706,
  0x00360b5d,
  0x00b60b5b,
  0x021fffff,
  0x022fffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x0222468a,
  0x022fffff,
  0x021fffff,
  0x021fffff,
  0x020fffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x021db974,
  0x020fffff,
  0x021fffff,
  0x0000000a,
  0x0080000a,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123460,
  0x00800009,
  0x0000000b,
  0x0000000a,
  0x807ffff6,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x8012344c,
  0x807ffff5,
  0x00000009,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x82200000,
  0x82100000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x821db975,
  0x82100000,
  0x82200000,
  0x82200000,
  0x82300000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x8222468b,
  0x82300000,
  0x82200000,
  0xc09fffff,
  0xc09fffff,
  0xc08fffff,
  0xc08fffff,
  0xc08fffff,
  0xc07fffff,
  0xc07fffff,
  0xc07ffffe,
  0xc05fffff,
  0x40a00001,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xc09fffff,
  0xc09fffff,
  0xc09fffff,
  0xc09fffff,
  0xc09fffff,
  0xc0afffff,
  0xc0afffff,
  0xc0b00000,
  0xc0bfffff,
  0xc0bfffff,
  0xc0c00000,
  0xc0cfffff,
  0xc1700000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xc09fffff,
  0xc09fffff,
  0xc09fffff,
  0xc0a00000,
  0xc0a00000,
  0xc0900000,
  0xc0900000,
  0xc0900000,
  0xc0800000,
  0xc0800000,
  0xc0800000,
  0xc0600000,
  0x40a00000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xc0a00000,
  0xc0a00000,
  0xc0a00000,
  0xc0a00000,
  0xc0a00000,
  0xc0b00000,
  0xc0b00000,
  0xc0b00000,
  0xc0c00000,
  0xc0c00000,
  0xc0c00000,
  0xc0d00000,
  0xc1700000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xc0a00000,
  0xc0a00000,
  0xc0a00000,
  0xc0a00001,
  0xc0a00001,
  0xc0900001,
  0xc0900001,
  0xc0900001,
  0xc0800001,
  0xc0800001,
  0xc0800001,
  0xc0600002,
  0x409fffff,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xc0a00001,
  0xc0a00001,
  0xc0a00001,
  0xc0a00001,
  0xc0a00001,
  0xc0b00001,
  0xc0b00001,
  0xc0b00001,
  0xc0c00001,
  0xc0c00001,
  0xc0c00002,
  0xc0d00001,
  0xc1700001,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xc0a00001,
  0xc0a00001,
  0xc0a00001,
  0xc11fffff,
  0xc11fffff,
  0xc117ffff,
  0xc117ffff,
  0xc117ffff,
  0xc10fffff,
  0xc10fffff,
  0xc10fffff,
  0xc107ffff,
  0x35200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xc11fffff,
  0xc11fffff,
  0xc11fffff,
  0xc11fffff,
  0xc11fffff,
  0xc127ffff,
  0xc127ffff,
  0xc127ffff,
  0xc12fffff,
  0xc12fffff,
  0xc1300000,
  0xc137ffff,
  0xc1a00000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xc11fffff,
  0xc11fffff,
  0xc11fffff,
  0xc1200000,
  0xc1200000,
  0xc1180000,
  0xc1180000,
  0xc1180000,
  0xc1100000,
  0xc1100000,
  0xc1100000,
  0xc1080000,
  0x00000000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xc1200000,
  0xc1200000,
  0xc1200000,
  0xc1200000,
  0xc1200000,
  0xc1280000,
  0xc1280000,
  0xc1280000,
  0xc1300000,
  0xc1300000,
  0xc1300000,
  0xc1380000,
  0xc1a00000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xc1200000,
  0xc1200000,
  0xc1200000,
  0xc1200001,
  0xc1200001,
  0xc1180001,
  0xc1180001,
  0xc1180001,
  0xc1100001,
  0xc1100001,
  0xc1100001,
  0xc1080001,
  0xb5a00000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xc1200001,
  0xc1200001,
  0xc1200001,
  0xc1200001,
  0xc1200001,
  0xc1280001,
  0xc1280001,
  0xc1280001,
  0xc1300001,
  0xc1300001,
  0xc1300001,
  0xc1380001,
  0xc1a00001,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xc1200001,
  0xc1200001,
  0xc1200001,
  0xc1700000,
  0xc1700000,
  0xc1680000,
  0xc1680000,
  0xc1680000,
  0xc1600000,
  0xc1600000,
  0xc1600000,
  0xc1580000,
  0xc0a00000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xc1700000,
  0xc1700000,
  0xc1700000,
  0xc1700000,
  0xc1700000,
  0xc1780000,
  0xc1780000,
  0xc1780000,
  0xc1800000,
  0xc1800000,
  0xc1800000,
  0xc1840000,
  0xc1c80000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xc1700000,
  0xc1700000,
  0xc1700000,
  0xc2c80000,
  0xc2c80000,
  0xc2c70000,
  0xc2c70000,
  0xc2c70000,
  0xc2c60000,
  0xc2c60000,
  0xc2c60000,
  0xc2c50000,
  0xc2b40000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xc2c80000,
  0xc2c80000,
  0xc2c80000,
  0xc2c80000,
  0xc2c80000,
  0xc2c90000,
  0xc2c90000,
  0xc2c90000,
  0xc2ca0000,
  0xc2ca0000,
  0xc2ca0000,
  0xc2cb0000,
  0xc2dc0000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xc2c80000,
  0xc2c80000,
  0xc2c80000,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x80b60b5c,
  0x80360b5c,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x80a3d706,
  0x80360b5d,
  0x80b60b5b,
  0x80b60b5c,
  0x811b05ae,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80c83fb2,
  0x811b05ae,
  0x80b60b5d,
  0x821fffff,
  0x820fffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x821db974,
  0x820fffff,
  0x821fffff,
  0x821fffff,
  0x822fffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x8222468a,
  0x822fffff,
  0x821fffff,
  0x8000000a,
  0x007ffff6,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x0012344c,
  0x007ffff5,
  0x80000009,
  0x8000000a,
  0x8080000a,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123460,
  0x80800009,
  0x8000000b,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00091a2b,
  0x00891a2b,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x001b4e81,
  0x00891a2a,
  0x00091a2c,
  0x00091a2b,
  0x8076e5d5,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80091a2b,
  0x8076e5d4,
  0x00091a2a,
  0x00091a2b,
  0x00891a2b,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x001b4e81,
  0x00891a2a,
  0x00091a2c,
  0x00091a2b,
  0x8076e5d5,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80091a2b,
  0x8076e5d4,
  0x00091a2a,
  0x00091a2b,
  0x00891a2b,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x001b4e81,
  0x00891a2a,
  0x00091a2c,
  0x00091a2b,
  0x8076e5d5,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80091a2b,
  0x8076e5d4,
  0x00091a2a,
  0x00123456,
  0x00923456,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x002468ac,
  0x00923455,
  0x00123457,
  0x00123456,
  0x806dcbaa,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80000000,
  0x806dcba9,
  0x00123455,
  0x00123456,
  0x00923456,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x002468ac,
  0x00923455,
  0x00123457,
  0x00123456,
  0x806dcbaa,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x00000000,
  0x806dcba9,
  0x00123455,
  0x00123456,
  0x00923456,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x002468ac,
  0x00923455,
  0x00123457,
  0x00123456,
  0x806dcbaa,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x00000000,
  0x806dcba9,
  0x00123455,
  0x001b4e81,
  0x009b4e81,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x002d82d7,
  0x009b4e80,
  0x001b4e82,
  0x001b4e81,
  0x8064b17f,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x00091a2b,
  0x8064b17e,
  0x001b4e80,
  0x00b60b5c,
  0x011b05ae,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00c83fb2,
  0x011b05ae,
  0x00b60b5d,
  0x00b60b5c,
  0x00360b5c,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x00a3d706,
  0x00360b5d,
  0x00b60b5b,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80091a2b,
  0x0076e5d5,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00091a2b,
  0x0076e5d4,
  0x80091a2a,
  0x80091a2b,
  0x80891a2b,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x801b4e81,
  0x80891a2a,
  0x80091a2c,
  0x80091a2b,
  0x0076e5d5,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00091a2b,
  0x0076e5d4,
  0x80091a2a,
  0x80091a2b,
  0x80891a2b,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x801b4e81,
  0x80891a2a,
  0x80091a2c,
  0x80091a2b,
  0x0076e5d5,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00091a2b,
  0x0076e5d4,
  0x80091a2a,
  0x80091a2b,
  0x80891a2b,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x801b4e81,
  0x80891a2a,
  0x80091a2c,
  0x80123456,
  0x006dcbaa,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00000000,
  0x006dcba9,
  0x80123455,
  0x80123456,
  0x80923456,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x802468ac,
  0x80923455,
  0x80123457,
  0x80123456,
  0x006dcbaa,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00000000,
  0x006dcba9,
  0x80123455,
  0x80123456,
  0x80923456,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x802468ac,
  0x80923455,
  0x80123457,
  0x80123456,
  0x006dcbaa,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x80000000,
  0x006dcba9,
  0x80123455,
  0x80123456,
  0x80923456,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x802468ac,
  0x80923455,
  0x80123457,
  0x801b4e81,
  0x0064b17f,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x80091a2b,
  0x0064b17e,
  0x801b4e80,
  0x801b4e81,
  0x809b4e81,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x802d82d7,
  0x809b4e80,
  0x801b4e82,
  0x80b60b5c,
  0x80360b5c,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x80a3d706,
  0x80360b5d,
  0x80b60b5b,
  0x80b60b5c,
  0x811b05ae,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80c83fb2,
  0x811b05ae,
  0x80b60b5d,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x003fffff,
  0x00bfffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00523455,
  0x00bffffe,
  0x00400000,
  0x003fffff,
  0x80400001,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x002dcba9,
  0x80400000,
  0x003ffffe,
  0x00400000,
  0x00c00000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00523456,
  0x00bffffe,
  0x00400000,
  0x00400000,
  0x80400000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x002dcbaa,
  0x80400000,
  0x003ffffe,
  0x00400000,
  0x00c00000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00523456,
  0x00bfffff,
  0x00400001,
  0x00400000,
  0x80400000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x002dcbaa,
  0x803fffff,
  0x003fffff,
  0x007fffff,
  0x00ffffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00923455,
  0x00fffffe,
  0x00800000,
  0x007fffff,
  0x80000001,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x006dcba9,
  0x80000000,
  0x007ffffe,
  0x007fffff,
  0x00ffffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00923455,
  0x00fffffe,
  0x00800000,
  0x007fffff,
  0x80000001,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x006dcba9,
  0x00000000,
  0x007ffffe,
  0x00800000,
  0x01000000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00923456,
  0x00ffffff,
  0x00800001,
  0x00800000,
  0x80000000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x006dcbaa,
  0x00000001,
  0x007fffff,
  0x00bffffe,
  0x011fffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00d23454,
  0x011fffff,
  0x00c00000,
  0x00bffffe,
  0x003ffffe,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x00adcba8,
  0x00400000,
  0x00bffffe,
  0x021fffff,
  0x022fffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x0222468a,
  0x022fffff,
  0x021fffff,
  0x021fffff,
  0x020fffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x021db974,
  0x020fffff,
  0x021fffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x803fffff,
  0x00400001,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x802dcba9,
  0x00400000,
  0x803ffffe,
  0x803fffff,
  0x80bfffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80523455,
  0x80bffffe,
  0x80400000,
  0x80400000,
  0x00400000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x802dcbaa,
  0x00400000,
  0x803ffffe,
  0x80400000,
  0x80c00000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80523456,
  0x80bffffe,
  0x80400000,
  0x80400000,
  0x00400000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x802dcbaa,
  0x003fffff,
  0x803fffff,
  0x80400000,
  0x80c00000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80523456,
  0x80bfffff,
  0x80400001,
  0x807fffff,
  0x00000001,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x806dcba9,
  0x00000000,
  0x807ffffe,
  0x807fffff,
  0x80ffffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80923455,
  0x80fffffe,
  0x80800000,
  0x807fffff,
  0x00000001,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x806dcba9,
  0x00000000,
  0x807ffffe,
  0x807fffff,
  0x80ffffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80923455,
  0x80fffffe,
  0x80800000,
  0x80800000,
  0x00000000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x806dcbaa,
  0x80000001,
  0x807fffff,
  0x80800000,
  0x81000000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80923456,
  0x80ffffff,
  0x80800001,
  0x80bffffe,
  0x803ffffe,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x80adcba8,
  0x80400000,
  0x80bffffe,
  0x80bffffe,
  0x811fffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80d23454,
  0x811fffff,
  0x80c00000,
  0x821fffff,
  0x820fffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x821db974,
  0x820fffff,
  0x821fffff,
  0x821fffff,
  0x822fffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x8222468a,
  0x822fffff,
  0x821fffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x00800000,
  0x00000002,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807ffffe,
  0x80000000,
  0x00000001,
  0x00800001,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123457,
  0x00800000,
  0x00000002,
  0x00000001,
  0x807fffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123455,
  0x807ffffe,
  0x80000000,
  0x00000001,
  0x00800001,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123457,
  0x00800000,
  0x00000002,
  0x00000001,
  0x807fffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123455,
  0x807ffffe,
  0x80000000,
  0x00000001,
  0x00800001,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123457,
  0x00800000,
  0x00000002,
  0x00000001,
  0x807fffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123455,
  0x807ffffe,
  0x00000000,
  0x00000001,
  0x00800001,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123457,
  0x00800000,
  0x00000002,
  0x00000001,
  0x807fffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123455,
  0x807ffffe,
  0x00000000,
  0x00000002,
  0x00800002,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123458,
  0x00800000,
  0x00000002,
  0x00000002,
  0x807ffffe,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123454,
  0x807ffffe,
  0x00000000,
  0x0000000a,
  0x0080000a,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123460,
  0x00800009,
  0x0000000b,
  0x0000000a,
  0x807ffff6,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x8012344c,
  0x807ffff5,
  0x00000009,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007ffffe,
  0x00000000,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x80800000,
  0x80000002,
  0x80000001,
  0x007fffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123455,
  0x007ffffe,
  0x00000000,
  0x80000001,
  0x80800001,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123457,
  0x80800000,
  0x80000002,
  0x80000001,
  0x007fffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123455,
  0x007ffffe,
  0x00000000,
  0x80000001,
  0x80800001,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123457,
  0x80800000,
  0x80000002,
  0x80000001,
  0x007fffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123455,
  0x007ffffe,
  0x00000000,
  0x80000001,
  0x80800001,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123457,
  0x80800000,
  0x80000002,
  0x80000001,
  0x007fffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123455,
  0x007ffffe,
  0x80000000,
  0x80000001,
  0x80800001,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123457,
  0x80800000,
  0x80000002,
  0x80000002,
  0x007ffffe,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123454,
  0x007ffffe,
  0x80000000,
  0x80000002,
  0x80800002,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123458,
  0x80800000,
  0x80000002,
  0x8000000a,
  0x007ffff6,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x0012344c,
  0x007ffff5,
  0x80000009,
  0x8000000a,
  0x8080000a,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123460,
  0x80800009,
  0x8000000b,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
};
const unsigned kExpectedCount_fmsub_s = 54872;

const uint64_t kExpected_fmul_d[] = {
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0008000000000000,
  0x0008000000000000,
  0x0008000000000000,
  0x0010000000000000,
  0x0010000000000000,
  0x0010000000000001,
  0x0018000000000000,
  0x0044000000000000,
  0x400fffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8008000000000000,
  0x8008000000000000,
  0x8008000000000000,
  0x8010000000000000,
  0x8010000000000000,
  0x8010000000000001,
  0x8018000000000000,
  0x8044000000000000,
  0xc00fffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x0000000000000000,
  0x0008000000000000,
  0x3fcffffffffffffe,
  0x3fcfffffffffffff,
  0x3fd0000000000000,
  0x3fdffffffffffffe,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe7ffffffffffff,
  0x4013ffffffffffff,
  0x7fdffffffffffffe,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000091a2b3c4d5e6,
  0x0007ffffffffffff,
  0x0000000000000000,
  0x8000000000000000,
  0x8008000000000000,
  0xbfcffffffffffffe,
  0xbfcfffffffffffff,
  0xbfd0000000000000,
  0xbfdffffffffffffe,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe7ffffffffffff,
  0xc013ffffffffffff,
  0xffdffffffffffffe,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800091a2b3c4d5e6,
  0x8007ffffffffffff,
  0x8000000000000000,
  0x0000000000000000,
  0x0008000000000000,
  0x3fcfffffffffffff,
  0x3fd0000000000000,
  0x3fd0000000000001,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fe8000000000000,
  0x4014000000000000,
  0x7fdfffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000091a2b3c4d5e6,
  0x0008000000000000,
  0x0000000000000000,
  0x8000000000000000,
  0x8008000000000000,
  0xbfcfffffffffffff,
  0xbfd0000000000000,
  0xbfd0000000000001,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfe8000000000000,
  0xc014000000000000,
  0xffdfffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800091a2b3c4d5e6,
  0x8008000000000000,
  0x8000000000000000,
  0x0000000000000000,
  0x0008000000000000,
  0x3fd0000000000000,
  0x3fd0000000000001,
  0x3fd0000000000002,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000002,
  0x3fe8000000000002,
  0x4014000000000001,
  0x7fe0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000091a2b3c4d5e7,
  0x0008000000000000,
  0x0000000000000001,
  0x8000000000000000,
  0x8008000000000000,
  0xbfd0000000000000,
  0xbfd0000000000001,
  0xbfd0000000000002,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000002,
  0xbfe8000000000002,
  0xc014000000000001,
  0xffe0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800091a2b3c4d5e7,
  0x8008000000000000,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdffffffffffffe,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3feffffffffffffe,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff7ffffffffffff,
  0x4023ffffffffffff,
  0x7feffffffffffffe,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdffffffffffffe,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfeffffffffffffe,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff7ffffffffffff,
  0xc023ffffffffffff,
  0xffeffffffffffffe,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000001,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000002,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff0000000000002,
  0x3ff8000000000002,
  0x4024000000000001,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x0010000000000000,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000001,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000002,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff0000000000002,
  0xbff8000000000002,
  0xc024000000000001,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x8010000000000000,
  0x8000000000000001,
  0x0000000000000000,
  0x0018000000000000,
  0x3fe7ffffffffffff,
  0x3fe8000000000000,
  0x3fe8000000000002,
  0x3ff7ffffffffffff,
  0x3ff8000000000000,
  0x3ff8000000000002,
  0x4002000000000000,
  0x402e000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0001b4e81b4e81b4,
  0x0017fffffffffffe,
  0x0000000000000002,
  0x8000000000000000,
  0x8018000000000000,
  0xbfe7ffffffffffff,
  0xbfe8000000000000,
  0xbfe8000000000002,
  0xbff7ffffffffffff,
  0xbff8000000000000,
  0xbff8000000000002,
  0xc002000000000000,
  0xc02e000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x8001b4e81b4e81b4,
  0x8017fffffffffffe,
  0x8000000000000002,
  0x0000000000000000,
  0x0044000000000000,
  0x4013ffffffffffff,
  0x4014000000000000,
  0x4014000000000001,
  0x4023ffffffffffff,
  0x4024000000000000,
  0x4024000000000001,
  0x402e000000000000,
  0x4059000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000b60b60b60b602,
  0x0043ffffffffffff,
  0x000000000000000a,
  0x8000000000000000,
  0x8044000000000000,
  0xc013ffffffffffff,
  0xc014000000000000,
  0xc014000000000001,
  0xc023ffffffffffff,
  0xc024000000000000,
  0xc024000000000001,
  0xc02e000000000000,
  0xc059000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800b60b60b60b602,
  0x8043ffffffffffff,
  0x800000000000000a,
  0x0000000000000000,
  0x400fffffffffffff,
  0x7fdffffffffffffe,
  0x7fdfffffffffffff,
  0x7fe0000000000000,
  0x7feffffffffffffe,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fd23456789abccf,
  0x400ffffffffffffd,
  0x3ccfffffffffffff,
  0x8000000000000000,
  0xc00fffffffffffff,
  0xffdffffffffffffe,
  0xffdfffffffffffff,
  0xffe0000000000000,
  0xffeffffffffffffe,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfd23456789abccf,
  0xc00ffffffffffffd,
  0xbccfffffffffffff,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x000091a2b3c4d5e6,
  0x000091a2b3c4d5e6,
  0x000091a2b3c4d5e7,
  0x000123456789abcd,
  0x000123456789abcd,
  0x000123456789abcd,
  0x0001b4e81b4e81b4,
  0x000b60b60b60b602,
  0x3fd23456789abccf,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x800091a2b3c4d5e6,
  0x800091a2b3c4d5e6,
  0x800091a2b3c4d5e7,
  0x800123456789abcd,
  0x800123456789abcd,
  0x800123456789abcd,
  0x8001b4e81b4e81b4,
  0x800b60b60b60b602,
  0xbfd23456789abccf,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0007ffffffffffff,
  0x0008000000000000,
  0x0008000000000000,
  0x000fffffffffffff,
  0x000fffffffffffff,
  0x0010000000000000,
  0x0017fffffffffffe,
  0x0043ffffffffffff,
  0x400ffffffffffffd,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8007ffffffffffff,
  0x8008000000000000,
  0x8008000000000000,
  0x800fffffffffffff,
  0x800fffffffffffff,
  0x8010000000000000,
  0x8017fffffffffffe,
  0x8043ffffffffffff,
  0xc00ffffffffffffd,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000001,
  0x0000000000000001,
  0x0000000000000001,
  0x0000000000000001,
  0x0000000000000002,
  0x000000000000000a,
  0x3ccfffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000001,
  0x8000000000000001,
  0x8000000000000001,
  0x8000000000000001,
  0x8000000000000002,
  0x800000000000000a,
  0xbccfffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8008000000000000,
  0x8008000000000000,
  0x8008000000000000,
  0x8010000000000000,
  0x8010000000000000,
  0x8010000000000001,
  0x8018000000000000,
  0x8044000000000000,
  0xc00fffffffffffff,
  0xfff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff0000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0008000000000000,
  0x0008000000000000,
  0x0008000000000000,
  0x0010000000000000,
  0x0010000000000000,
  0x0010000000000001,
  0x0018000000000000,
  0x0044000000000000,
  0x400fffffffffffff,
  0x7ff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff0000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x8000000000000000,
  0x8008000000000000,
  0xbfcffffffffffffe,
  0xbfcfffffffffffff,
  0xbfd0000000000000,
  0xbfdffffffffffffe,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe7ffffffffffff,
  0xc013ffffffffffff,
  0xffdffffffffffffe,
  0xfff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff0000000000000,
  0x800091a2b3c4d5e6,
  0x8007ffffffffffff,
  0x8000000000000000,
  0x0000000000000000,
  0x0008000000000000,
  0x3fcffffffffffffe,
  0x3fcfffffffffffff,
  0x3fd0000000000000,
  0x3fdffffffffffffe,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe7ffffffffffff,
  0x4013ffffffffffff,
  0x7fdffffffffffffe,
  0x7ff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff0000000000000,
  0x000091a2b3c4d5e6,
  0x0007ffffffffffff,
  0x0000000000000000,
  0x8000000000000000,
  0x8008000000000000,
  0xbfcfffffffffffff,
  0xbfd0000000000000,
  0xbfd0000000000001,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfe8000000000000,
  0xc014000000000000,
  0xffdfffffffffffff,
  0xfff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff0000000000000,
  0x800091a2b3c4d5e6,
  0x8008000000000000,
  0x8000000000000000,
  0x0000000000000000,
  0x0008000000000000,
  0x3fcfffffffffffff,
  0x3fd0000000000000,
  0x3fd0000000000001,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fe8000000000000,
  0x4014000000000000,
  0x7fdfffffffffffff,
  0x7ff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff0000000000000,
  0x000091a2b3c4d5e6,
  0x0008000000000000,
  0x0000000000000000,
  0x8000000000000000,
  0x8008000000000000,
  0xbfd0000000000000,
  0xbfd0000000000001,
  0xbfd0000000000002,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000002,
  0xbfe8000000000002,
  0xc014000000000001,
  0xffe0000000000000,
  0xfff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff0000000000000,
  0x800091a2b3c4d5e7,
  0x8008000000000000,
  0x8000000000000001,
  0x0000000000000000,
  0x0008000000000000,
  0x3fd0000000000000,
  0x3fd0000000000001,
  0x3fd0000000000002,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000002,
  0x3fe8000000000002,
  0x4014000000000001,
  0x7fe0000000000000,
  0x7ff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff0000000000000,
  0x000091a2b3c4d5e7,
  0x0008000000000000,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdffffffffffffe,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfeffffffffffffe,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff7ffffffffffff,
  0xc023ffffffffffff,
  0xffeffffffffffffe,
  0xfff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdffffffffffffe,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3feffffffffffffe,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff7ffffffffffff,
  0x4023ffffffffffff,
  0x7feffffffffffffe,
  0x7ff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000001,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000002,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff0000000000002,
  0xbff8000000000002,
  0xc024000000000001,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x8010000000000000,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000001,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000002,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff0000000000002,
  0x3ff8000000000002,
  0x4024000000000001,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x0010000000000000,
  0x0000000000000001,
  0x8000000000000000,
  0x8018000000000000,
  0xbfe7ffffffffffff,
  0xbfe8000000000000,
  0xbfe8000000000002,
  0xbff7ffffffffffff,
  0xbff8000000000000,
  0xbff8000000000002,
  0xc002000000000000,
  0xc02e000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff0000000000000,
  0x8001b4e81b4e81b4,
  0x8017fffffffffffe,
  0x8000000000000002,
  0x0000000000000000,
  0x0018000000000000,
  0x3fe7ffffffffffff,
  0x3fe8000000000000,
  0x3fe8000000000002,
  0x3ff7ffffffffffff,
  0x3ff8000000000000,
  0x3ff8000000000002,
  0x4002000000000000,
  0x402e000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff0000000000000,
  0x0001b4e81b4e81b4,
  0x0017fffffffffffe,
  0x0000000000000002,
  0x8000000000000000,
  0x8044000000000000,
  0xc013ffffffffffff,
  0xc014000000000000,
  0xc014000000000001,
  0xc023ffffffffffff,
  0xc024000000000000,
  0xc024000000000001,
  0xc02e000000000000,
  0xc059000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff0000000000000,
  0x800b60b60b60b602,
  0x8043ffffffffffff,
  0x800000000000000a,
  0x0000000000000000,
  0x0044000000000000,
  0x4013ffffffffffff,
  0x4014000000000000,
  0x4014000000000001,
  0x4023ffffffffffff,
  0x4024000000000000,
  0x4024000000000001,
  0x402e000000000000,
  0x4059000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff0000000000000,
  0x000b60b60b60b602,
  0x0043ffffffffffff,
  0x000000000000000a,
  0x8000000000000000,
  0xc00fffffffffffff,
  0xffdffffffffffffe,
  0xffdfffffffffffff,
  0xffe0000000000000,
  0xffeffffffffffffe,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff0000000000000,
  0xbfd23456789abccf,
  0xc00ffffffffffffd,
  0xbccfffffffffffff,
  0x0000000000000000,
  0x400fffffffffffff,
  0x7fdffffffffffffe,
  0x7fdfffffffffffff,
  0x7fe0000000000000,
  0x7feffffffffffffe,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff0000000000000,
  0x3fd23456789abccf,
  0x400ffffffffffffd,
  0x3ccfffffffffffff,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x800091a2b3c4d5e6,
  0x800091a2b3c4d5e6,
  0x800091a2b3c4d5e7,
  0x800123456789abcd,
  0x800123456789abcd,
  0x800123456789abcd,
  0x8001b4e81b4e81b4,
  0x800b60b60b60b602,
  0xbfd23456789abccf,
  0xfff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff0000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x000091a2b3c4d5e6,
  0x000091a2b3c4d5e6,
  0x000091a2b3c4d5e7,
  0x000123456789abcd,
  0x000123456789abcd,
  0x000123456789abcd,
  0x0001b4e81b4e81b4,
  0x000b60b60b60b602,
  0x3fd23456789abccf,
  0x7ff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff0000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8007ffffffffffff,
  0x8008000000000000,
  0x8008000000000000,
  0x800fffffffffffff,
  0x800fffffffffffff,
  0x8010000000000000,
  0x8017fffffffffffe,
  0x8043ffffffffffff,
  0xc00ffffffffffffd,
  0xfff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff0000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0007ffffffffffff,
  0x0008000000000000,
  0x0008000000000000,
  0x000fffffffffffff,
  0x000fffffffffffff,
  0x0010000000000000,
  0x0017fffffffffffe,
  0x0043ffffffffffff,
  0x400ffffffffffffd,
  0x7ff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff0000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000001,
  0x8000000000000001,
  0x8000000000000001,
  0x8000000000000001,
  0x8000000000000002,
  0x800000000000000a,
  0xbccfffffffffffff,
  0xfff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff0000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000001,
  0x0000000000000001,
  0x0000000000000001,
  0x0000000000000001,
  0x0000000000000002,
  0x000000000000000a,
  0x3ccfffffffffffff,
  0x7ff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff0000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
};
const unsigned kExpectedCount_fmul_d = 1444;

const uint32_t kExpected_fmul_s[] = {
  0x00000000,
  0x00000000,
  0x00000000,
  0x00000000,
  0x00000000,
  0x00000000,
  0x00000000,
  0x00000000,
  0x00000000,
  0x00000000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00000000,
  0x00000000,
  0x00000000,
  0x80000000,
  0x80000000,
  0x80000000,
  0x80000000,
  0x80000000,
  0x80000000,
  0x80000000,
  0x80000000,
  0x80000000,
  0x80000000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80000000,
  0x80000000,
  0x80000000,
  0x00000000,
  0x00000000,
  0x00400000,
  0x00400000,
  0x00400000,
  0x00800000,
  0x00800000,
  0x00800001,
  0x00c00000,
  0x02200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00000000,
  0x00000000,
  0x00000000,
  0x80000000,
  0x80000000,
  0x80400000,
  0x80400000,
  0x80400000,
  0x80800000,
  0x80800000,
  0x80800001,
  0x80c00000,
  0x82200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80000000,
  0x80000000,
  0x80000000,
  0x00000000,
  0x00400000,
  0x3e7ffffe,
  0x3e7fffff,
  0x3e800000,
  0x3efffffe,
  0x3effffff,
  0x3f000000,
  0x3f3fffff,
  0x409fffff,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00091a2b,
  0x003fffff,
  0x00000000,
  0x80000000,
  0x80400000,
  0xbe7ffffe,
  0xbe7fffff,
  0xbe800000,
  0xbefffffe,
  0xbeffffff,
  0xbf000000,
  0xbf3fffff,
  0xc09fffff,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80091a2b,
  0x803fffff,
  0x80000000,
  0x00000000,
  0x00400000,
  0x3e7fffff,
  0x3e800000,
  0x3e800001,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f400000,
  0x40a00000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00091a2b,
  0x00400000,
  0x00000000,
  0x80000000,
  0x80400000,
  0xbe7fffff,
  0xbe800000,
  0xbe800001,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf400000,
  0xc0a00000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80091a2b,
  0x80400000,
  0x80000000,
  0x00000000,
  0x00400000,
  0x3e800000,
  0x3e800001,
  0x3e800002,
  0x3f000000,
  0x3f000001,
  0x3f000002,
  0x3f400002,
  0x40a00001,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00091a2b,
  0x00400000,
  0x00000001,
  0x80000000,
  0x80400000,
  0xbe800000,
  0xbe800001,
  0xbe800002,
  0xbf000000,
  0xbf000001,
  0xbf000002,
  0xbf400002,
  0xc0a00001,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80091a2b,
  0x80400000,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3efffffe,
  0x3effffff,
  0x3f000000,
  0x3f7ffffe,
  0x3f7fffff,
  0x3f800000,
  0x3fbfffff,
  0x411fffff,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbefffffe,
  0xbeffffff,
  0xbf000000,
  0xbf7ffffe,
  0xbf7fffff,
  0xbf800000,
  0xbfbfffff,
  0xc11fffff,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800001,
  0x3f000000,
  0x3f000001,
  0x3f000002,
  0x3f800000,
  0x3f800001,
  0x3f800002,
  0x3fc00002,
  0x41200001,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x00800000,
  0x00000001,
  0x80000000,
  0x80800001,
  0xbf000000,
  0xbf000001,
  0xbf000002,
  0xbf800000,
  0xbf800001,
  0xbf800002,
  0xbfc00002,
  0xc1200001,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x80800000,
  0x80000001,
  0x00000000,
  0x00c00000,
  0x3f3fffff,
  0x3f400000,
  0x3f400002,
  0x3fbfffff,
  0x3fc00000,
  0x3fc00002,
  0x40100000,
  0x41700000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x001b4e81,
  0x00bffffe,
  0x00000002,
  0x80000000,
  0x80c00000,
  0xbf3fffff,
  0xbf400000,
  0xbf400002,
  0xbfbfffff,
  0xbfc00000,
  0xbfc00002,
  0xc0100000,
  0xc1700000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x801b4e81,
  0x80bffffe,
  0x80000002,
  0x00000000,
  0x02200000,
  0x409fffff,
  0x40a00000,
  0x40a00001,
  0x411fffff,
  0x41200000,
  0x41200001,
  0x41700000,
  0x42c80000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00b60b5c,
  0x021fffff,
  0x0000000a,
  0x80000000,
  0x82200000,
  0xc09fffff,
  0xc0a00000,
  0xc0a00001,
  0xc11fffff,
  0xc1200000,
  0xc1200001,
  0xc1700000,
  0xc2c80000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80b60b5c,
  0x821fffff,
  0x8000000a,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fc00000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fc00000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x00000000,
  0x00000000,
  0x00091a2b,
  0x00091a2b,
  0x00091a2b,
  0x00123456,
  0x00123456,
  0x00123456,
  0x001b4e81,
  0x00b60b5c,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00000000,
  0x00000000,
  0x00000000,
  0x80000000,
  0x80000000,
  0x80091a2b,
  0x80091a2b,
  0x80091a2b,
  0x80123456,
  0x80123456,
  0x80123456,
  0x801b4e81,
  0x80b60b5c,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80000000,
  0x80000000,
  0x80000000,
  0x00000000,
  0x00000000,
  0x003fffff,
  0x00400000,
  0x00400000,
  0x007fffff,
  0x007fffff,
  0x00800000,
  0x00bffffe,
  0x021fffff,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00000000,
  0x00000000,
  0x00000000,
  0x80000000,
  0x80000000,
  0x803fffff,
  0x80400000,
  0x80400000,
  0x807fffff,
  0x807fffff,
  0x80800000,
  0x80bffffe,
  0x821fffff,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80000000,
  0x80000000,
  0x80000000,
  0x00000000,
  0x00000000,
  0x00000000,
  0x00000000,
  0x00000001,
  0x00000001,
  0x00000001,
  0x00000001,
  0x00000002,
  0x0000000a,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00000000,
  0x00000000,
  0x00000000,
  0x80000000,
  0x80000000,
  0x80000000,
  0x80000000,
  0x80000001,
  0x80000001,
  0x80000001,
  0x80000001,
  0x80000002,
  0x8000000a,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80000000,
  0x80000000,
  0x80000000,
  0x80000000,
  0x80000000,
  0x80000000,
  0x80000000,
  0x80000000,
  0x80000000,
  0x80000000,
  0x80000000,
  0x80000000,
  0x80000000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x80000000,
  0x80000000,
  0x80000000,
  0x00000000,
  0x00000000,
  0x00000000,
  0x00000000,
  0x00000000,
  0x00000000,
  0x00000000,
  0x00000000,
  0x00000000,
  0x00000000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x00000000,
  0x00000000,
  0x00000000,
  0x80000000,
  0x80000000,
  0x80400000,
  0x80400000,
  0x80400000,
  0x80800000,
  0x80800000,
  0x80800001,
  0x80c00000,
  0x82200000,
  0x7fcfffff,
  0xff800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x80000000,
  0x80000000,
  0x80000000,
  0x00000000,
  0x00000000,
  0x00400000,
  0x00400000,
  0x00400000,
  0x00800000,
  0x00800000,
  0x00800001,
  0x00c00000,
  0x02200000,
  0xffcfffff,
  0x7f800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x00000000,
  0x00000000,
  0x00000000,
  0x80000000,
  0x80400000,
  0xbe7ffffe,
  0xbe7fffff,
  0xbe800000,
  0xbefffffe,
  0xbeffffff,
  0xbf000000,
  0xbf3fffff,
  0xc09fffff,
  0x7fcfffff,
  0xff800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x80091a2b,
  0x803fffff,
  0x80000000,
  0x00000000,
  0x00400000,
  0x3e7ffffe,
  0x3e7fffff,
  0x3e800000,
  0x3efffffe,
  0x3effffff,
  0x3f000000,
  0x3f3fffff,
  0x409fffff,
  0xffcfffff,
  0x7f800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x00091a2b,
  0x003fffff,
  0x00000000,
  0x80000000,
  0x80400000,
  0xbe7fffff,
  0xbe800000,
  0xbe800001,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf400000,
  0xc0a00000,
  0x7fcfffff,
  0xff800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x80091a2b,
  0x80400000,
  0x80000000,
  0x00000000,
  0x00400000,
  0x3e7fffff,
  0x3e800000,
  0x3e800001,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f400000,
  0x40a00000,
  0xffcfffff,
  0x7f800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x00091a2b,
  0x00400000,
  0x00000000,
  0x80000000,
  0x80400000,
  0xbe800000,
  0xbe800001,
  0xbe800002,
  0xbf000000,
  0xbf000001,
  0xbf000002,
  0xbf400002,
  0xc0a00001,
  0x7fcfffff,
  0xff800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x80091a2b,
  0x80400000,
  0x80000001,
  0x00000000,
  0x00400000,
  0x3e800000,
  0x3e800001,
  0x3e800002,
  0x3f000000,
  0x3f000001,
  0x3f000002,
  0x3f400002,
  0x40a00001,
  0xffcfffff,
  0x7f800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x00091a2b,
  0x00400000,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbefffffe,
  0xbeffffff,
  0xbf000000,
  0xbf7ffffe,
  0xbf7fffff,
  0xbf800000,
  0xbfbfffff,
  0xc11fffff,
  0x7fcfffff,
  0xff800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3efffffe,
  0x3effffff,
  0x3f000000,
  0x3f7ffffe,
  0x3f7fffff,
  0x3f800000,
  0x3fbfffff,
  0x411fffff,
  0xffcfffff,
  0x7f800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0x7fcfffff,
  0xff800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0xffcfffff,
  0x7f800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800001,
  0xbf000000,
  0xbf000001,
  0xbf000002,
  0xbf800000,
  0xbf800001,
  0xbf800002,
  0xbfc00002,
  0xc1200001,
  0x7fcfffff,
  0xff800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x80123456,
  0x80800000,
  0x80000001,
  0x00000000,
  0x00800001,
  0x3f000000,
  0x3f000001,
  0x3f000002,
  0x3f800000,
  0x3f800001,
  0x3f800002,
  0x3fc00002,
  0x41200001,
  0xffcfffff,
  0x7f800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x00123456,
  0x00800000,
  0x00000001,
  0x80000000,
  0x80c00000,
  0xbf3fffff,
  0xbf400000,
  0xbf400002,
  0xbfbfffff,
  0xbfc00000,
  0xbfc00002,
  0xc0100000,
  0xc1700000,
  0x7fcfffff,
  0xff800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x801b4e81,
  0x80bffffe,
  0x80000002,
  0x00000000,
  0x00c00000,
  0x3f3fffff,
  0x3f400000,
  0x3f400002,
  0x3fbfffff,
  0x3fc00000,
  0x3fc00002,
  0x40100000,
  0x41700000,
  0xffcfffff,
  0x7f800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x001b4e81,
  0x00bffffe,
  0x00000002,
  0x80000000,
  0x82200000,
  0xc09fffff,
  0xc0a00000,
  0xc0a00001,
  0xc11fffff,
  0xc1200000,
  0xc1200001,
  0xc1700000,
  0xc2c80000,
  0x7fcfffff,
  0xff800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x80b60b5c,
  0x821fffff,
  0x8000000a,
  0x00000000,
  0x02200000,
  0x409fffff,
  0x40a00000,
  0x40a00001,
  0x411fffff,
  0x41200000,
  0x41200001,
  0x41700000,
  0x42c80000,
  0xffcfffff,
  0x7f800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x00b60b5c,
  0x021fffff,
  0x0000000a,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fc00000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0xff800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fc00000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7f800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x80000000,
  0x80000000,
  0x80091a2b,
  0x80091a2b,
  0x80091a2b,
  0x80123456,
  0x80123456,
  0x80123456,
  0x801b4e81,
  0x80b60b5c,
  0x7fcfffff,
  0xff800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x80000000,
  0x80000000,
  0x80000000,
  0x00000000,
  0x00000000,
  0x00091a2b,
  0x00091a2b,
  0x00091a2b,
  0x00123456,
  0x00123456,
  0x00123456,
  0x001b4e81,
  0x00b60b5c,
  0xffcfffff,
  0x7f800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x00000000,
  0x00000000,
  0x00000000,
  0x80000000,
  0x80000000,
  0x803fffff,
  0x80400000,
  0x80400000,
  0x807fffff,
  0x807fffff,
  0x80800000,
  0x80bffffe,
  0x821fffff,
  0x7fcfffff,
  0xff800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x80000000,
  0x80000000,
  0x80000000,
  0x00000000,
  0x00000000,
  0x003fffff,
  0x00400000,
  0x00400000,
  0x007fffff,
  0x007fffff,
  0x00800000,
  0x00bffffe,
  0x021fffff,
  0xffcfffff,
  0x7f800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x00000000,
  0x00000000,
  0x00000000,
  0x80000000,
  0x80000000,
  0x80000000,
  0x80000000,
  0x80000001,
  0x80000001,
  0x80000001,
  0x80000001,
  0x80000002,
  0x8000000a,
  0x7fcfffff,
  0xff800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x80000000,
  0x80000000,
  0x80000000,
  0x00000000,
  0x00000000,
  0x00000000,
  0x00000000,
  0x00000001,
  0x00000001,
  0x00000001,
  0x00000001,
  0x00000002,
  0x0000000a,
  0xffcfffff,
  0x7f800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x00000000,
  0x00000000,
  0x00000000,
};
const unsigned kExpectedCount_fmul_s = 1444;

const uint64_t kExpected_fneg_d[] = {
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff123456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff123456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
};
const unsigned kExpectedCount_fneg_d = 38;

const uint32_t kExpected_fneg_s[] = {
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xff8fffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xff923456,
  0xff800001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7f8fffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7f923456,
  0x7f800001,
  0x00123456,
  0x007fffff,
  0x00000001,
};
const unsigned kExpectedCount_fneg_s = 38;

const uint64_t kExpected_fnmadd_d[] = {
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8008000000000000,
  0x8018000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800923456789abcd,
  0x8017ffffffffffff,
  0x8008000000000001,
  0x8008000000000000,
  0x0008000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8006dcba98765433,
  0x0007ffffffffffff,
  0x8007ffffffffffff,
  0x8008000000000000,
  0x8018000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800923456789abcd,
  0x8017ffffffffffff,
  0x8008000000000001,
  0x8008000000000000,
  0x0008000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8006dcba98765433,
  0x0007ffffffffffff,
  0x8007ffffffffffff,
  0x8008000000000000,
  0x8018000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800923456789abce,
  0x8018000000000000,
  0x8008000000000002,
  0x8008000000000000,
  0x0008000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8006dcba98765434,
  0x0007fffffffffffe,
  0x8008000000000000,
  0x8010000000000000,
  0x8020000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x801123456789abcc,
  0x801ffffffffffffe,
  0x8010000000000000,
  0x8010000000000000,
  0x0000000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x800edcba98765432,
  0x8000000000000000,
  0x800ffffffffffffe,
  0x8010000000000000,
  0x8020000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x801123456789abcd,
  0x801fffffffffffff,
  0x8010000000000001,
  0x8010000000000000,
  0x0000000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x800edcba98765433,
  0x8000000000000001,
  0x800fffffffffffff,
  0x8010000000000001,
  0x8020000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x801123456789abce,
  0x8020000000000000,
  0x8010000000000002,
  0x8010000000000001,
  0x8000000000000001,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x800edcba98765434,
  0x8000000000000002,
  0x8010000000000000,
  0x8018000000000000,
  0x8024000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x801923456789abcd,
  0x8024000000000000,
  0x8018000000000001,
  0x8018000000000000,
  0x8008000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8016dcba98765433,
  0x8008000000000001,
  0x8017ffffffffffff,
  0x8044000000000000,
  0x8046000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x80442468acf1357a,
  0x8046000000000000,
  0x8044000000000000,
  0x8044000000000000,
  0x8042000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8043db97530eca86,
  0x8042000000000000,
  0x8044000000000000,
  0xc00fffffffffffff,
  0xc00fffffffffffff,
  0xc011ffffffffffff,
  0xc012000000000000,
  0xc012000000000000,
  0xc013ffffffffffff,
  0xc014000000000000,
  0xc014000000000000,
  0xc016000000000000,
  0xc02c000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc00fffffffffffff,
  0xc00fffffffffffff,
  0xc00fffffffffffff,
  0xc00fffffffffffff,
  0xc00fffffffffffff,
  0xc00bffffffffffff,
  0xc00bffffffffffff,
  0xc00bffffffffffff,
  0xc007ffffffffffff,
  0xc007ffffffffffff,
  0xc007fffffffffffe,
  0xc003ffffffffffff,
  0x4018000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc00fffffffffffff,
  0xc00fffffffffffff,
  0xc00fffffffffffff,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0008000000000000,
  0x8008000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0006dcba98765433,
  0x8007ffffffffffff,
  0x0007ffffffffffff,
  0x0008000000000000,
  0x0018000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000923456789abcd,
  0x0017ffffffffffff,
  0x0008000000000001,
  0x0008000000000000,
  0x8008000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0006dcba98765433,
  0x8007ffffffffffff,
  0x0007ffffffffffff,
  0x0008000000000000,
  0x0018000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000923456789abcd,
  0x0017ffffffffffff,
  0x0008000000000001,
  0x0008000000000000,
  0x8008000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0006dcba98765434,
  0x8007fffffffffffe,
  0x0008000000000000,
  0x0008000000000000,
  0x0018000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000923456789abce,
  0x0018000000000000,
  0x0008000000000002,
  0x0010000000000000,
  0x8000000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x000edcba98765432,
  0x0000000000000000,
  0x000ffffffffffffe,
  0x0010000000000000,
  0x0020000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x001123456789abcc,
  0x001ffffffffffffe,
  0x0010000000000000,
  0x0010000000000000,
  0x0000000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x000edcba98765433,
  0x0000000000000001,
  0x000fffffffffffff,
  0x0010000000000000,
  0x0020000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x001123456789abcd,
  0x001fffffffffffff,
  0x0010000000000001,
  0x0010000000000001,
  0x0000000000000001,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x000edcba98765434,
  0x0000000000000002,
  0x0010000000000000,
  0x0010000000000001,
  0x0020000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x001123456789abce,
  0x0020000000000000,
  0x0010000000000002,
  0x0018000000000000,
  0x0008000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0016dcba98765433,
  0x0008000000000001,
  0x0017ffffffffffff,
  0x0018000000000000,
  0x0024000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x001923456789abcd,
  0x0024000000000000,
  0x0018000000000001,
  0x0044000000000000,
  0x0042000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0043db97530eca86,
  0x0042000000000000,
  0x0044000000000000,
  0x0044000000000000,
  0x0046000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x00442468acf1357a,
  0x0046000000000000,
  0x0044000000000000,
  0x400fffffffffffff,
  0x400fffffffffffff,
  0x400bffffffffffff,
  0x400bffffffffffff,
  0x400bffffffffffff,
  0x4007ffffffffffff,
  0x4007ffffffffffff,
  0x4007fffffffffffe,
  0x4003ffffffffffff,
  0xc018000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x400fffffffffffff,
  0x400fffffffffffff,
  0x400fffffffffffff,
  0x400fffffffffffff,
  0x400fffffffffffff,
  0x4011ffffffffffff,
  0x4012000000000000,
  0x4012000000000000,
  0x4013ffffffffffff,
  0x4014000000000000,
  0x4014000000000000,
  0x4016000000000000,
  0x402c000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x400fffffffffffff,
  0x400fffffffffffff,
  0x400fffffffffffff,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8008000000000000,
  0x8018000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800923456789abcd,
  0x8017ffffffffffff,
  0x8008000000000001,
  0x8008000000000000,
  0x0008000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8006dcba98765433,
  0x0007ffffffffffff,
  0x8007ffffffffffff,
  0xbfcffffffffffffe,
  0xbfcffffffffffffe,
  0xbfe7ffffffffffff,
  0xbfe8000000000000,
  0xbfe8000000000001,
  0xbff3ffffffffffff,
  0xbff4000000000000,
  0xbff4000000000001,
  0xbffc000000000000,
  0xc024800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfcffffffffffffe,
  0xbfcffffffffffffe,
  0xbfcffffffffffffe,
  0xbfcffffffffffffe,
  0xbfcffffffffffffe,
  0x3fd0000000000000,
  0x3fd0000000000001,
  0x3fd0000000000003,
  0x3fe7ffffffffffff,
  0x3fe8000000000000,
  0x3fe8000000000002,
  0x3ff4000000000000,
  0x4023800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfcffffffffffffe,
  0xbfcffffffffffffe,
  0xbfcffffffffffffe,
  0xbfcfffffffffffff,
  0xbfcfffffffffffff,
  0xbfe7ffffffffffff,
  0xbfe8000000000000,
  0xbfe8000000000001,
  0xbff3ffffffffffff,
  0xbff4000000000000,
  0xbff4000000000001,
  0xbffc000000000000,
  0xc024800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfcfffffffffffff,
  0xbfcfffffffffffff,
  0xbfcfffffffffffff,
  0xbfcfffffffffffff,
  0xbfcfffffffffffff,
  0x3fcfffffffffffff,
  0x3fd0000000000000,
  0x3fd0000000000002,
  0x3fe7ffffffffffff,
  0x3fe8000000000000,
  0x3fe8000000000002,
  0x3ff4000000000000,
  0x4023800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfcfffffffffffff,
  0xbfcfffffffffffff,
  0xbfcfffffffffffff,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbfe8000000000001,
  0xbff4000000000000,
  0xbff4000000000000,
  0xbff4000000000001,
  0xbffc000000000000,
  0xc024800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0x3fcffffffffffffd,
  0x3fcfffffffffffff,
  0x3fd0000000000002,
  0x3fe7ffffffffffff,
  0x3fe8000000000000,
  0x3fe8000000000002,
  0x3ff4000000000000,
  0x4023800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfdffffffffffffe,
  0xbfdffffffffffffe,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff7ffffffffffff,
  0xbff8000000000000,
  0xbff8000000000001,
  0xc000000000000000,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfdffffffffffffe,
  0xbfdffffffffffffe,
  0xbfdffffffffffffe,
  0xbfdffffffffffffe,
  0xbfdffffffffffffe,
  0x3c8fffffffffffff,
  0x3ca0000000000000,
  0x3cb0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000003,
  0x3ff0000000000000,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfdffffffffffffe,
  0xbfdffffffffffffe,
  0xbfdffffffffffffe,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff7ffffffffffff,
  0xbff8000000000000,
  0xbff8000000000001,
  0xc000000000000000,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0x0000000000000000,
  0x3c90000000000000,
  0x3ca8000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000002,
  0x3ff0000000000000,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000001,
  0xc000000000000000,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbc9fffffffffffff,
  0xbc8ffffffffffffe,
  0x3c90000000000001,
  0x3fdffffffffffffd,
  0x3fdfffffffffffff,
  0x3fe0000000000002,
  0x3ff0000000000000,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe7ffffffffffff,
  0xbfe7ffffffffffff,
  0xbff3ffffffffffff,
  0xbff4000000000000,
  0xbff4000000000000,
  0xbffbffffffffffff,
  0xbffc000000000000,
  0xbffc000000000001,
  0xc002000000000000,
  0xc025800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe7ffffffffffff,
  0xbfe7ffffffffffff,
  0xbfe7ffffffffffff,
  0xbfe7ffffffffffff,
  0xbfe7ffffffffffff,
  0xbfcfffffffffffff,
  0xbfcffffffffffffd,
  0xbfcffffffffffff9,
  0x3fcfffffffffffff,
  0x3fd0000000000002,
  0x3fd0000000000006,
  0x3fe8000000000001,
  0x4022800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe7ffffffffffff,
  0xbfe7ffffffffffff,
  0xbfe7ffffffffffff,
  0xc013ffffffffffff,
  0xc013ffffffffffff,
  0xc015ffffffffffff,
  0xc015ffffffffffff,
  0xc016000000000000,
  0xc017ffffffffffff,
  0xc017ffffffffffff,
  0xc018000000000000,
  0xc019ffffffffffff,
  0xc02e000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc013ffffffffffff,
  0xc013ffffffffffff,
  0xc013ffffffffffff,
  0xc013ffffffffffff,
  0xc013ffffffffffff,
  0xc011ffffffffffff,
  0xc011ffffffffffff,
  0xc011ffffffffffff,
  0xc00fffffffffffff,
  0xc00fffffffffffff,
  0xc00ffffffffffffe,
  0xc00bffffffffffff,
  0x4014000000000001,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc013ffffffffffff,
  0xc013ffffffffffff,
  0xc013ffffffffffff,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0x7fe0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x800091a2b3c4d5e6,
  0x801091a2b3c4d5e6,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x8001b4e81b4e81b3,
  0x801091a2b3c4d5e5,
  0x800091a2b3c4d5e7,
  0x800091a2b3c4d5e6,
  0x000f6e5d4c3b2a1a,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000091a2b3c4d5e7,
  0x000f6e5d4c3b2a19,
  0x800091a2b3c4d5e5,
  0x8007ffffffffffff,
  0x8017ffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800923456789abcc,
  0x8017fffffffffffe,
  0x8008000000000000,
  0x8007ffffffffffff,
  0x0008000000000001,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8006dcba98765432,
  0x0008000000000000,
  0x8007fffffffffffe,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0008000000000000,
  0x8008000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0006dcba98765433,
  0x8007ffffffffffff,
  0x0007ffffffffffff,
  0x0008000000000000,
  0x0018000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000923456789abcd,
  0x0017ffffffffffff,
  0x0008000000000001,
  0x3fcffffffffffffe,
  0x3fcffffffffffffe,
  0xbfd0000000000000,
  0xbfd0000000000001,
  0xbfd0000000000003,
  0xbfe7ffffffffffff,
  0xbfe8000000000000,
  0xbfe8000000000002,
  0xbff4000000000000,
  0xc023800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fcffffffffffffe,
  0x3fcffffffffffffe,
  0x3fcffffffffffffe,
  0x3fcffffffffffffe,
  0x3fcffffffffffffe,
  0x3fe7ffffffffffff,
  0x3fe8000000000000,
  0x3fe8000000000001,
  0x3ff3ffffffffffff,
  0x3ff4000000000000,
  0x3ff4000000000001,
  0x3ffc000000000000,
  0x4024800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fcffffffffffffe,
  0x3fcffffffffffffe,
  0x3fcffffffffffffe,
  0x3fcfffffffffffff,
  0x3fcfffffffffffff,
  0xbfcfffffffffffff,
  0xbfd0000000000000,
  0xbfd0000000000002,
  0xbfe7ffffffffffff,
  0xbfe8000000000000,
  0xbfe8000000000002,
  0xbff4000000000000,
  0xc023800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fcfffffffffffff,
  0x3fcfffffffffffff,
  0x3fcfffffffffffff,
  0x3fcfffffffffffff,
  0x3fcfffffffffffff,
  0x3fe7ffffffffffff,
  0x3fe8000000000000,
  0x3fe8000000000001,
  0x3ff3ffffffffffff,
  0x3ff4000000000000,
  0x3ff4000000000001,
  0x3ffc000000000000,
  0x4024800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fcfffffffffffff,
  0x3fcfffffffffffff,
  0x3fcfffffffffffff,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0xbfcffffffffffffd,
  0xbfcfffffffffffff,
  0xbfd0000000000002,
  0xbfe7ffffffffffff,
  0xbfe8000000000000,
  0xbfe8000000000002,
  0xbff4000000000000,
  0xc023800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3fe8000000000001,
  0x3ff4000000000000,
  0x3ff4000000000000,
  0x3ff4000000000001,
  0x3ffc000000000000,
  0x4024800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fdffffffffffffe,
  0x3fdffffffffffffe,
  0xbc8fffffffffffff,
  0xbca0000000000000,
  0xbcb0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000003,
  0xbff0000000000000,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fdffffffffffffe,
  0x3fdffffffffffffe,
  0x3fdffffffffffffe,
  0x3fdffffffffffffe,
  0x3fdffffffffffffe,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff7ffffffffffff,
  0x3ff8000000000000,
  0x3ff8000000000001,
  0x4000000000000000,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fdffffffffffffe,
  0x3fdffffffffffffe,
  0x3fdffffffffffffe,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x0000000000000000,
  0xbc90000000000000,
  0xbca8000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000002,
  0xbff0000000000000,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff7ffffffffffff,
  0x3ff8000000000000,
  0x3ff8000000000001,
  0x4000000000000000,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3c9fffffffffffff,
  0x3c8ffffffffffffe,
  0xbc90000000000001,
  0xbfdffffffffffffd,
  0xbfdfffffffffffff,
  0xbfe0000000000002,
  0xbff0000000000000,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000001,
  0x4000000000000000,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe7ffffffffffff,
  0x3fe7ffffffffffff,
  0x3fcfffffffffffff,
  0x3fcffffffffffffd,
  0x3fcffffffffffff9,
  0xbfcfffffffffffff,
  0xbfd0000000000002,
  0xbfd0000000000006,
  0xbfe8000000000001,
  0xc022800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe7ffffffffffff,
  0x3fe7ffffffffffff,
  0x3fe7ffffffffffff,
  0x3fe7ffffffffffff,
  0x3fe7ffffffffffff,
  0x3ff3ffffffffffff,
  0x3ff4000000000000,
  0x3ff4000000000000,
  0x3ffbffffffffffff,
  0x3ffc000000000000,
  0x3ffc000000000001,
  0x4002000000000000,
  0x4025800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe7ffffffffffff,
  0x3fe7ffffffffffff,
  0x3fe7ffffffffffff,
  0x4013ffffffffffff,
  0x4013ffffffffffff,
  0x4011ffffffffffff,
  0x4011ffffffffffff,
  0x4011ffffffffffff,
  0x400fffffffffffff,
  0x400fffffffffffff,
  0x400ffffffffffffe,
  0x400bffffffffffff,
  0xc014000000000001,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x4013ffffffffffff,
  0x4013ffffffffffff,
  0x4013ffffffffffff,
  0x4013ffffffffffff,
  0x4013ffffffffffff,
  0x4015ffffffffffff,
  0x4015ffffffffffff,
  0x4016000000000000,
  0x4017ffffffffffff,
  0x4017ffffffffffff,
  0x4018000000000000,
  0x4019ffffffffffff,
  0x402e000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x4013ffffffffffff,
  0x4013ffffffffffff,
  0x4013ffffffffffff,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0xffe0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x000091a2b3c4d5e6,
  0x800f6e5d4c3b2a1a,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800091a2b3c4d5e7,
  0x800f6e5d4c3b2a19,
  0x000091a2b3c4d5e5,
  0x000091a2b3c4d5e6,
  0x001091a2b3c4d5e6,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0001b4e81b4e81b3,
  0x001091a2b3c4d5e5,
  0x000091a2b3c4d5e7,
  0x0007ffffffffffff,
  0x8008000000000001,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0006dcba98765432,
  0x8008000000000000,
  0x0007fffffffffffe,
  0x0007ffffffffffff,
  0x0017ffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000923456789abcc,
  0x0017fffffffffffe,
  0x0008000000000000,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8008000000000000,
  0x8018000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800923456789abcd,
  0x8017ffffffffffff,
  0x8008000000000001,
  0x8008000000000000,
  0x0008000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8006dcba98765433,
  0x0007ffffffffffff,
  0x8007ffffffffffff,
  0xbfcfffffffffffff,
  0xbfcfffffffffffff,
  0xbfe7ffffffffffff,
  0xbfe8000000000000,
  0xbfe8000000000001,
  0xbff3ffffffffffff,
  0xbff4000000000000,
  0xbff4000000000001,
  0xbffc000000000000,
  0xc024800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfcfffffffffffff,
  0xbfcfffffffffffff,
  0xbfcfffffffffffff,
  0xbfcfffffffffffff,
  0xbfcfffffffffffff,
  0x3fcfffffffffffff,
  0x3fd0000000000000,
  0x3fd0000000000002,
  0x3fe7ffffffffffff,
  0x3fe8000000000000,
  0x3fe8000000000002,
  0x3ff4000000000000,
  0x4023800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfcfffffffffffff,
  0xbfcfffffffffffff,
  0xbfcfffffffffffff,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbfe8000000000001,
  0xbff4000000000000,
  0xbff4000000000000,
  0xbff4000000000001,
  0xbffc000000000000,
  0xc024800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0x3fcffffffffffffe,
  0x3fd0000000000000,
  0x3fd0000000000002,
  0x3fe7ffffffffffff,
  0x3fe8000000000000,
  0x3fe8000000000002,
  0x3ff4000000000000,
  0x4023800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000001,
  0xbfd0000000000001,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbfe8000000000002,
  0xbff4000000000000,
  0xbff4000000000000,
  0xbff4000000000001,
  0xbffc000000000000,
  0xc024800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfd0000000000001,
  0xbfd0000000000001,
  0xbfd0000000000001,
  0xbfd0000000000001,
  0xbfd0000000000001,
  0x3fcffffffffffffc,
  0x3fcffffffffffffe,
  0x3fd0000000000001,
  0x3fe7fffffffffffe,
  0x3fe8000000000000,
  0x3fe8000000000002,
  0x3ff4000000000000,
  0x4023800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfd0000000000001,
  0xbfd0000000000001,
  0xbfd0000000000001,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff7ffffffffffff,
  0xbff8000000000000,
  0xbff8000000000001,
  0xc000000000000000,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0x0000000000000000,
  0x3c90000000000000,
  0x3ca8000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000002,
  0x3ff0000000000000,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000001,
  0xc000000000000000,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbc90000000000000,
  0x0000000000000000,
  0x3ca0000000000000,
  0x3fdffffffffffffe,
  0x3fe0000000000000,
  0x3fe0000000000002,
  0x3ff0000000000000,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000002,
  0xc000000000000000,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbca8000000000000,
  0xbca0000000000000,
  0x0000000000000000,
  0x3fdffffffffffffc,
  0x3fdffffffffffffe,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbff4000000000000,
  0xbff4000000000000,
  0xbff4000000000000,
  0xbffc000000000000,
  0xbffc000000000000,
  0xbffc000000000001,
  0xc002000000000000,
  0xc025800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbfd0000000000001,
  0xbfd0000000000000,
  0xbfcffffffffffffc,
  0x3fcffffffffffffc,
  0x3fd0000000000000,
  0x3fd0000000000004,
  0x3fe8000000000000,
  0x4022800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xc014000000000000,
  0xc014000000000000,
  0xc016000000000000,
  0xc016000000000000,
  0xc016000000000000,
  0xc018000000000000,
  0xc018000000000000,
  0xc018000000000000,
  0xc01a000000000000,
  0xc02e000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc014000000000000,
  0xc014000000000000,
  0xc014000000000000,
  0xc014000000000000,
  0xc014000000000000,
  0xc012000000000000,
  0xc012000000000000,
  0xc012000000000000,
  0xc010000000000000,
  0xc010000000000000,
  0xc010000000000000,
  0xc00c000000000000,
  0x4014000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc014000000000000,
  0xc014000000000000,
  0xc014000000000000,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0x7fdfffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x800091a2b3c4d5e6,
  0x801091a2b3c4d5e6,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x8001b4e81b4e81b4,
  0x801091a2b3c4d5e6,
  0x800091a2b3c4d5e8,
  0x800091a2b3c4d5e6,
  0x000f6e5d4c3b2a1a,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000091a2b3c4d5e6,
  0x000f6e5d4c3b2a18,
  0x800091a2b3c4d5e6,
  0x8008000000000000,
  0x8018000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800923456789abcc,
  0x8017fffffffffffe,
  0x8008000000000000,
  0x8008000000000000,
  0x0008000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8006dcba98765432,
  0x0008000000000000,
  0x8007fffffffffffe,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abce,
  0x8010000000000000,
  0x8000000000000002,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcc,
  0x000ffffffffffffe,
  0x0000000000000000,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0008000000000000,
  0x8008000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0006dcba98765433,
  0x8007ffffffffffff,
  0x0007ffffffffffff,
  0x0008000000000000,
  0x0018000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000923456789abcd,
  0x0017ffffffffffff,
  0x0008000000000001,
  0x3fcfffffffffffff,
  0x3fcfffffffffffff,
  0xbfcfffffffffffff,
  0xbfd0000000000000,
  0xbfd0000000000002,
  0xbfe7ffffffffffff,
  0xbfe8000000000000,
  0xbfe8000000000002,
  0xbff4000000000000,
  0xc023800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fcfffffffffffff,
  0x3fcfffffffffffff,
  0x3fcfffffffffffff,
  0x3fcfffffffffffff,
  0x3fcfffffffffffff,
  0x3fe7ffffffffffff,
  0x3fe8000000000000,
  0x3fe8000000000001,
  0x3ff3ffffffffffff,
  0x3ff4000000000000,
  0x3ff4000000000001,
  0x3ffc000000000000,
  0x4024800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fcfffffffffffff,
  0x3fcfffffffffffff,
  0x3fcfffffffffffff,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0xbfcffffffffffffe,
  0xbfd0000000000000,
  0xbfd0000000000002,
  0xbfe7ffffffffffff,
  0xbfe8000000000000,
  0xbfe8000000000002,
  0xbff4000000000000,
  0xc023800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3fe8000000000001,
  0x3ff4000000000000,
  0x3ff4000000000000,
  0x3ff4000000000001,
  0x3ffc000000000000,
  0x4024800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000001,
  0x3fd0000000000001,
  0xbfcffffffffffffc,
  0xbfcffffffffffffe,
  0xbfd0000000000001,
  0xbfe7fffffffffffe,
  0xbfe8000000000000,
  0xbfe8000000000002,
  0xbff4000000000000,
  0xc023800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fd0000000000001,
  0x3fd0000000000001,
  0x3fd0000000000001,
  0x3fd0000000000001,
  0x3fd0000000000001,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3fe8000000000002,
  0x3ff4000000000000,
  0x3ff4000000000000,
  0x3ff4000000000001,
  0x3ffc000000000000,
  0x4024800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fd0000000000001,
  0x3fd0000000000001,
  0x3fd0000000000001,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x0000000000000000,
  0xbc90000000000000,
  0xbca8000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000002,
  0xbff0000000000000,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff7ffffffffffff,
  0x3ff8000000000000,
  0x3ff8000000000001,
  0x4000000000000000,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3c90000000000000,
  0x0000000000000000,
  0xbca0000000000000,
  0xbfdffffffffffffe,
  0xbfe0000000000000,
  0xbfe0000000000002,
  0xbff0000000000000,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000001,
  0x4000000000000000,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3ca8000000000000,
  0x3ca0000000000000,
  0x0000000000000000,
  0xbfdffffffffffffc,
  0xbfdffffffffffffe,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000002,
  0x4000000000000000,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3fd0000000000001,
  0x3fd0000000000000,
  0x3fcffffffffffffc,
  0xbfcffffffffffffc,
  0xbfd0000000000000,
  0xbfd0000000000004,
  0xbfe8000000000000,
  0xc022800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3ff4000000000000,
  0x3ff4000000000000,
  0x3ff4000000000000,
  0x3ffc000000000000,
  0x3ffc000000000000,
  0x3ffc000000000001,
  0x4002000000000000,
  0x4025800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x4014000000000000,
  0x4014000000000000,
  0x4012000000000000,
  0x4012000000000000,
  0x4012000000000000,
  0x4010000000000000,
  0x4010000000000000,
  0x4010000000000000,
  0x400c000000000000,
  0xc014000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x4014000000000000,
  0x4014000000000000,
  0x4014000000000000,
  0x4014000000000000,
  0x4014000000000000,
  0x4016000000000000,
  0x4016000000000000,
  0x4016000000000000,
  0x4018000000000000,
  0x4018000000000000,
  0x4018000000000000,
  0x401a000000000000,
  0x402e000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x4014000000000000,
  0x4014000000000000,
  0x4014000000000000,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0xffdfffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x000091a2b3c4d5e6,
  0x800f6e5d4c3b2a1a,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800091a2b3c4d5e6,
  0x800f6e5d4c3b2a18,
  0x000091a2b3c4d5e6,
  0x000091a2b3c4d5e6,
  0x001091a2b3c4d5e6,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0001b4e81b4e81b4,
  0x001091a2b3c4d5e6,
  0x000091a2b3c4d5e8,
  0x0008000000000000,
  0x8008000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0006dcba98765432,
  0x8008000000000000,
  0x0007fffffffffffe,
  0x0008000000000000,
  0x0018000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000923456789abcc,
  0x0017fffffffffffe,
  0x0008000000000000,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcc,
  0x800ffffffffffffe,
  0x8000000000000000,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abce,
  0x0010000000000000,
  0x0000000000000002,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8008000000000000,
  0x8018000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800923456789abce,
  0x8018000000000000,
  0x8008000000000002,
  0x8008000000000000,
  0x0008000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8006dcba98765434,
  0x0007fffffffffffe,
  0x8008000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbfe8000000000001,
  0xbff4000000000000,
  0xbff4000000000000,
  0xbff4000000000001,
  0xbffc000000000000,
  0xc024800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0x3fcffffffffffffd,
  0x3fcfffffffffffff,
  0x3fd0000000000002,
  0x3fe7ffffffffffff,
  0x3fe8000000000000,
  0x3fe8000000000002,
  0x3ff4000000000000,
  0x4023800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000001,
  0xbfd0000000000001,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbfe8000000000002,
  0xbff4000000000000,
  0xbff4000000000000,
  0xbff4000000000001,
  0xbffc000000000000,
  0xc024800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfd0000000000001,
  0xbfd0000000000001,
  0xbfd0000000000001,
  0xbfd0000000000001,
  0xbfd0000000000001,
  0x3fcffffffffffffc,
  0x3fcffffffffffffe,
  0x3fd0000000000001,
  0x3fe7fffffffffffe,
  0x3fe8000000000000,
  0x3fe8000000000002,
  0x3ff4000000000000,
  0x4023800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfd0000000000001,
  0xbfd0000000000001,
  0xbfd0000000000001,
  0xbfd0000000000002,
  0xbfd0000000000002,
  0xbfe8000000000001,
  0xbfe8000000000001,
  0xbfe8000000000002,
  0xbff4000000000000,
  0xbff4000000000001,
  0xbff4000000000002,
  0xbffc000000000001,
  0xc024800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfd0000000000002,
  0xbfd0000000000002,
  0xbfd0000000000002,
  0xbfd0000000000002,
  0xbfd0000000000002,
  0x3fcffffffffffffa,
  0x3fcffffffffffffc,
  0x3fd0000000000000,
  0x3fe7fffffffffffe,
  0x3fe7ffffffffffff,
  0x3fe8000000000001,
  0x3ff3ffffffffffff,
  0x4023800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfd0000000000002,
  0xbfd0000000000002,
  0xbfd0000000000002,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000001,
  0xc000000000000000,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbc9fffffffffffff,
  0xbc8ffffffffffffe,
  0x3c90000000000001,
  0x3fdffffffffffffd,
  0x3fdfffffffffffff,
  0x3fe0000000000002,
  0x3ff0000000000000,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000002,
  0xc000000000000000,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbca8000000000000,
  0xbca0000000000000,
  0x0000000000000000,
  0x3fdffffffffffffc,
  0x3fdffffffffffffe,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000002,
  0xbfe0000000000002,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000002,
  0xbff8000000000001,
  0xbff8000000000001,
  0xbff8000000000002,
  0xc000000000000001,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe0000000000002,
  0xbfe0000000000002,
  0xbfe0000000000002,
  0xbfe0000000000002,
  0xbfe0000000000002,
  0xbcb4000000000000,
  0xbcb0000000000000,
  0xbca0000000000001,
  0x3fdffffffffffffa,
  0x3fdffffffffffffc,
  0x3fe0000000000000,
  0x3feffffffffffffe,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe0000000000002,
  0xbfe0000000000002,
  0xbfe0000000000002,
  0xbfe8000000000002,
  0xbfe8000000000002,
  0xbff4000000000000,
  0xbff4000000000001,
  0xbff4000000000001,
  0xbffc000000000000,
  0xbffc000000000001,
  0xbffc000000000002,
  0xc002000000000000,
  0xc025800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe8000000000002,
  0xbfe8000000000002,
  0xbfe8000000000002,
  0xbfe8000000000002,
  0xbfe8000000000001,
  0xbfd0000000000004,
  0xbfd0000000000003,
  0xbfd0000000000001,
  0x3fcffffffffffff6,
  0x3fcffffffffffffa,
  0x3fd0000000000001,
  0x3fe7fffffffffffe,
  0x4022800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe8000000000001,
  0xbfe8000000000001,
  0xbfe8000000000001,
  0xc014000000000001,
  0xc014000000000001,
  0xc016000000000001,
  0xc016000000000001,
  0xc016000000000001,
  0xc018000000000001,
  0xc018000000000001,
  0xc018000000000002,
  0xc01a000000000001,
  0xc02e000000000001,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc014000000000001,
  0xc014000000000001,
  0xc014000000000001,
  0xc014000000000001,
  0xc014000000000001,
  0xc012000000000001,
  0xc012000000000001,
  0xc012000000000001,
  0xc010000000000001,
  0xc010000000000001,
  0xc010000000000001,
  0xc00c000000000002,
  0x4013ffffffffffff,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc014000000000001,
  0xc014000000000001,
  0xc014000000000001,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0x7fdffffffffffffd,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x800091a2b3c4d5e7,
  0x801091a2b3c4d5e7,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x8001b4e81b4e81b4,
  0x801091a2b3c4d5e6,
  0x800091a2b3c4d5e8,
  0x800091a2b3c4d5e7,
  0x000f6e5d4c3b2a19,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000091a2b3c4d5e6,
  0x000f6e5d4c3b2a18,
  0x800091a2b3c4d5e6,
  0x8008000000000000,
  0x8018000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800923456789abcd,
  0x8017ffffffffffff,
  0x8008000000000001,
  0x8008000000000000,
  0x0008000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8006dcba98765433,
  0x0007ffffffffffff,
  0x8007ffffffffffff,
  0x8000000000000001,
  0x8010000000000001,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abce,
  0x8010000000000000,
  0x8000000000000002,
  0x8000000000000001,
  0x000fffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcc,
  0x000ffffffffffffe,
  0x0000000000000000,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0008000000000000,
  0x8008000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0006dcba98765434,
  0x8007fffffffffffe,
  0x0008000000000000,
  0x0008000000000000,
  0x0018000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000923456789abce,
  0x0018000000000000,
  0x0008000000000002,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0xbfcffffffffffffd,
  0xbfcfffffffffffff,
  0xbfd0000000000002,
  0xbfe7ffffffffffff,
  0xbfe8000000000000,
  0xbfe8000000000002,
  0xbff4000000000000,
  0xc023800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3fe8000000000001,
  0x3ff4000000000000,
  0x3ff4000000000000,
  0x3ff4000000000001,
  0x3ffc000000000000,
  0x4024800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000001,
  0x3fd0000000000001,
  0xbfcffffffffffffc,
  0xbfcffffffffffffe,
  0xbfd0000000000001,
  0xbfe7fffffffffffe,
  0xbfe8000000000000,
  0xbfe8000000000002,
  0xbff4000000000000,
  0xc023800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fd0000000000001,
  0x3fd0000000000001,
  0x3fd0000000000001,
  0x3fd0000000000001,
  0x3fd0000000000001,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3fe8000000000002,
  0x3ff4000000000000,
  0x3ff4000000000000,
  0x3ff4000000000001,
  0x3ffc000000000000,
  0x4024800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fd0000000000001,
  0x3fd0000000000001,
  0x3fd0000000000001,
  0x3fd0000000000002,
  0x3fd0000000000002,
  0xbfcffffffffffffa,
  0xbfcffffffffffffc,
  0xbfd0000000000000,
  0xbfe7fffffffffffe,
  0xbfe7ffffffffffff,
  0xbfe8000000000001,
  0xbff3ffffffffffff,
  0xc023800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fd0000000000002,
  0x3fd0000000000002,
  0x3fd0000000000002,
  0x3fd0000000000002,
  0x3fd0000000000002,
  0x3fe8000000000001,
  0x3fe8000000000001,
  0x3fe8000000000002,
  0x3ff4000000000000,
  0x3ff4000000000001,
  0x3ff4000000000002,
  0x3ffc000000000001,
  0x4024800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fd0000000000002,
  0x3fd0000000000002,
  0x3fd0000000000002,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3c9fffffffffffff,
  0x3c8ffffffffffffe,
  0xbc90000000000001,
  0xbfdffffffffffffd,
  0xbfdfffffffffffff,
  0xbfe0000000000002,
  0xbff0000000000000,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000001,
  0x4000000000000000,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3ca8000000000000,
  0x3ca0000000000000,
  0x0000000000000000,
  0xbfdffffffffffffc,
  0xbfdffffffffffffe,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000002,
  0x4000000000000000,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000002,
  0x3fe0000000000002,
  0x3cb4000000000000,
  0x3cb0000000000000,
  0x3ca0000000000001,
  0xbfdffffffffffffa,
  0xbfdffffffffffffc,
  0xbfe0000000000000,
  0xbfeffffffffffffe,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe0000000000002,
  0x3fe0000000000002,
  0x3fe0000000000002,
  0x3fe0000000000002,
  0x3fe0000000000002,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000002,
  0x3ff8000000000001,
  0x3ff8000000000001,
  0x3ff8000000000002,
  0x4000000000000001,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe0000000000002,
  0x3fe0000000000002,
  0x3fe0000000000002,
  0x3fe8000000000002,
  0x3fe8000000000001,
  0x3fd0000000000004,
  0x3fd0000000000003,
  0x3fd0000000000001,
  0xbfcffffffffffff6,
  0xbfcffffffffffffa,
  0xbfd0000000000001,
  0xbfe7fffffffffffe,
  0xc022800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe8000000000001,
  0x3fe8000000000001,
  0x3fe8000000000001,
  0x3fe8000000000002,
  0x3fe8000000000002,
  0x3ff4000000000000,
  0x3ff4000000000001,
  0x3ff4000000000001,
  0x3ffc000000000000,
  0x3ffc000000000001,
  0x3ffc000000000002,
  0x4002000000000000,
  0x4025800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe8000000000002,
  0x3fe8000000000002,
  0x3fe8000000000002,
  0x4014000000000001,
  0x4014000000000001,
  0x4012000000000001,
  0x4012000000000001,
  0x4012000000000001,
  0x4010000000000001,
  0x4010000000000001,
  0x4010000000000001,
  0x400c000000000002,
  0xc013ffffffffffff,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x4014000000000001,
  0x4014000000000001,
  0x4014000000000001,
  0x4014000000000001,
  0x4014000000000001,
  0x4016000000000001,
  0x4016000000000001,
  0x4016000000000001,
  0x4018000000000001,
  0x4018000000000001,
  0x4018000000000002,
  0x401a000000000001,
  0x402e000000000001,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x4014000000000001,
  0x4014000000000001,
  0x4014000000000001,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0xffdffffffffffffd,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x000091a2b3c4d5e7,
  0x800f6e5d4c3b2a19,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800091a2b3c4d5e6,
  0x800f6e5d4c3b2a18,
  0x000091a2b3c4d5e6,
  0x000091a2b3c4d5e7,
  0x001091a2b3c4d5e7,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0001b4e81b4e81b4,
  0x001091a2b3c4d5e6,
  0x000091a2b3c4d5e8,
  0x0008000000000000,
  0x8008000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0006dcba98765433,
  0x8007ffffffffffff,
  0x0007ffffffffffff,
  0x0008000000000000,
  0x0018000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000923456789abcd,
  0x0017ffffffffffff,
  0x0008000000000001,
  0x0000000000000001,
  0x800fffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcc,
  0x800ffffffffffffe,
  0x8000000000000000,
  0x0000000000000001,
  0x0010000000000001,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abce,
  0x0010000000000000,
  0x0000000000000002,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8010000000000000,
  0x8020000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x801123456789abcc,
  0x801ffffffffffffe,
  0x8010000000000000,
  0x8010000000000000,
  0x0000000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x800edcba98765432,
  0x8000000000000000,
  0x800ffffffffffffe,
  0xbfdffffffffffffe,
  0xbfdffffffffffffe,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff7ffffffffffff,
  0xbff8000000000000,
  0xbff8000000000001,
  0xc000000000000000,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfdffffffffffffe,
  0xbfdffffffffffffe,
  0xbfdffffffffffffe,
  0xbfdffffffffffffe,
  0xbfdffffffffffffe,
  0x3c8fffffffffffff,
  0x3ca0000000000000,
  0x3cb0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000003,
  0x3ff0000000000000,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfdffffffffffffe,
  0xbfdffffffffffffe,
  0xbfdffffffffffffe,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff7ffffffffffff,
  0xbff8000000000000,
  0xbff8000000000001,
  0xc000000000000000,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0x0000000000000000,
  0x3c90000000000000,
  0x3ca8000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000002,
  0x3ff0000000000000,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000001,
  0xc000000000000000,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbc9fffffffffffff,
  0xbc8ffffffffffffe,
  0x3c90000000000001,
  0x3fdffffffffffffd,
  0x3fdfffffffffffff,
  0x3fe0000000000002,
  0x3ff0000000000000,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfeffffffffffffe,
  0xbfeffffffffffffe,
  0xbff7ffffffffffff,
  0xbff7ffffffffffff,
  0xbff8000000000000,
  0xbfffffffffffffff,
  0xbfffffffffffffff,
  0xc000000000000000,
  0xc004000000000000,
  0xc026000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfeffffffffffffe,
  0xbfeffffffffffffe,
  0xbfeffffffffffffe,
  0xbfeffffffffffffe,
  0xbfeffffffffffffe,
  0xbfdffffffffffffd,
  0xbfdffffffffffffc,
  0xbfdffffffffffffa,
  0x3c9fffffffffffff,
  0x3cb0000000000000,
  0x3cc0000000000000,
  0x3fe0000000000002,
  0x4022000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfeffffffffffffe,
  0xbfeffffffffffffe,
  0xbfeffffffffffffe,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbff7ffffffffffff,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbfffffffffffffff,
  0xc000000000000000,
  0xc000000000000000,
  0xc004000000000000,
  0xc026000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfdfffffffffffff,
  0xbfdffffffffffffe,
  0xbfdffffffffffffc,
  0x0000000000000000,
  0x3ca0000000000000,
  0x3cb8000000000000,
  0x3fe0000000000001,
  0x4022000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000001,
  0xc000000000000000,
  0xc000000000000000,
  0xc000000000000001,
  0xc004000000000000,
  0xc026000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000000,
  0xbcafffffffffffff,
  0xbc9ffffffffffffe,
  0x3ca0000000000001,
  0x3fdffffffffffffe,
  0x4022000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff7ffffffffffff,
  0xbff7ffffffffffff,
  0xbfffffffffffffff,
  0xbfffffffffffffff,
  0xc000000000000000,
  0xc003ffffffffffff,
  0xc004000000000000,
  0xc004000000000000,
  0xc008000000000000,
  0xc027000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbff7ffffffffffff,
  0xbff7ffffffffffff,
  0xbff7ffffffffffff,
  0xbff7ffffffffffff,
  0xbff7ffffffffffff,
  0xbfefffffffffffff,
  0xbfeffffffffffffe,
  0xbfeffffffffffffe,
  0xbfdfffffffffffff,
  0xbfdffffffffffffd,
  0xbfdffffffffffff9,
  0x3ca8000000000000,
  0x4021000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbff7ffffffffffff,
  0xbff7ffffffffffff,
  0xbff7ffffffffffff,
  0xc023ffffffffffff,
  0xc023ffffffffffff,
  0xc024ffffffffffff,
  0xc024ffffffffffff,
  0xc024ffffffffffff,
  0xc025ffffffffffff,
  0xc025ffffffffffff,
  0xc026000000000000,
  0xc026ffffffffffff,
  0xc034000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc023ffffffffffff,
  0xc023ffffffffffff,
  0xc023ffffffffffff,
  0xc023ffffffffffff,
  0xc023ffffffffffff,
  0xc022ffffffffffff,
  0xc022ffffffffffff,
  0xc022ffffffffffff,
  0xc021ffffffffffff,
  0xc021ffffffffffff,
  0xc021ffffffffffff,
  0xc020ffffffffffff,
  0x3cd4000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc023ffffffffffff,
  0xc023ffffffffffff,
  0xc023ffffffffffff,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0x7c9fffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x800123456789abcd,
  0x801123456789abcd,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x8002468acf13579a,
  0x801123456789abcc,
  0x800123456789abce,
  0x800123456789abcd,
  0x000edcba98765433,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0000000000000000,
  0x000edcba98765432,
  0x800123456789abcc,
  0x800fffffffffffff,
  0x801fffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x801123456789abcc,
  0x801ffffffffffffe,
  0x8010000000000000,
  0x800fffffffffffff,
  0x0000000000000001,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x800edcba98765432,
  0x0000000000000000,
  0x800ffffffffffffe,
  0x8000000000000001,
  0x8010000000000001,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abce,
  0x8010000000000000,
  0x8000000000000002,
  0x8000000000000001,
  0x000fffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcc,
  0x000ffffffffffffe,
  0x0000000000000000,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0010000000000000,
  0x8000000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x000edcba98765432,
  0x0000000000000000,
  0x000ffffffffffffe,
  0x0010000000000000,
  0x0020000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x001123456789abcc,
  0x001ffffffffffffe,
  0x0010000000000000,
  0x3fdffffffffffffe,
  0x3fdffffffffffffe,
  0xbc8fffffffffffff,
  0xbca0000000000000,
  0xbcb0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000003,
  0xbff0000000000000,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fdffffffffffffe,
  0x3fdffffffffffffe,
  0x3fdffffffffffffe,
  0x3fdffffffffffffe,
  0x3fdffffffffffffe,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff7ffffffffffff,
  0x3ff8000000000000,
  0x3ff8000000000001,
  0x4000000000000000,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fdffffffffffffe,
  0x3fdffffffffffffe,
  0x3fdffffffffffffe,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x0000000000000000,
  0xbc90000000000000,
  0xbca8000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000002,
  0xbff0000000000000,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff7ffffffffffff,
  0x3ff8000000000000,
  0x3ff8000000000001,
  0x4000000000000000,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3c9fffffffffffff,
  0x3c8ffffffffffffe,
  0xbc90000000000001,
  0xbfdffffffffffffd,
  0xbfdfffffffffffff,
  0xbfe0000000000002,
  0xbff0000000000000,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000001,
  0x4000000000000000,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3feffffffffffffe,
  0x3feffffffffffffe,
  0x3fdffffffffffffd,
  0x3fdffffffffffffc,
  0x3fdffffffffffffa,
  0xbc9fffffffffffff,
  0xbcb0000000000000,
  0xbcc0000000000000,
  0xbfe0000000000002,
  0xc022000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3feffffffffffffe,
  0x3feffffffffffffe,
  0x3feffffffffffffe,
  0x3feffffffffffffe,
  0x3feffffffffffffe,
  0x3ff7ffffffffffff,
  0x3ff7ffffffffffff,
  0x3ff8000000000000,
  0x3fffffffffffffff,
  0x3fffffffffffffff,
  0x4000000000000000,
  0x4004000000000000,
  0x4026000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3feffffffffffffe,
  0x3feffffffffffffe,
  0x3feffffffffffffe,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fdfffffffffffff,
  0x3fdffffffffffffe,
  0x3fdffffffffffffc,
  0x0000000000000000,
  0xbca0000000000000,
  0xbcb8000000000000,
  0xbfe0000000000001,
  0xc022000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3ff7ffffffffffff,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3fffffffffffffff,
  0x4000000000000000,
  0x4000000000000000,
  0x4004000000000000,
  0x4026000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000000,
  0x3cafffffffffffff,
  0x3c9ffffffffffffe,
  0xbca0000000000001,
  0xbfdffffffffffffe,
  0xc022000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000001,
  0x4000000000000000,
  0x4000000000000000,
  0x4000000000000001,
  0x4004000000000000,
  0x4026000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff7ffffffffffff,
  0x3ff7ffffffffffff,
  0x3fefffffffffffff,
  0x3feffffffffffffe,
  0x3feffffffffffffe,
  0x3fdfffffffffffff,
  0x3fdffffffffffffd,
  0x3fdffffffffffff9,
  0xbca8000000000000,
  0xc021000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3ff7ffffffffffff,
  0x3ff7ffffffffffff,
  0x3ff7ffffffffffff,
  0x3ff7ffffffffffff,
  0x3ff7ffffffffffff,
  0x3fffffffffffffff,
  0x3fffffffffffffff,
  0x4000000000000000,
  0x4003ffffffffffff,
  0x4004000000000000,
  0x4004000000000000,
  0x4008000000000000,
  0x4027000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3ff7ffffffffffff,
  0x3ff7ffffffffffff,
  0x3ff7ffffffffffff,
  0x4023ffffffffffff,
  0x4023ffffffffffff,
  0x4022ffffffffffff,
  0x4022ffffffffffff,
  0x4022ffffffffffff,
  0x4021ffffffffffff,
  0x4021ffffffffffff,
  0x4021ffffffffffff,
  0x4020ffffffffffff,
  0xbcd4000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x4023ffffffffffff,
  0x4023ffffffffffff,
  0x4023ffffffffffff,
  0x4023ffffffffffff,
  0x4023ffffffffffff,
  0x4024ffffffffffff,
  0x4024ffffffffffff,
  0x4024ffffffffffff,
  0x4025ffffffffffff,
  0x4025ffffffffffff,
  0x4026000000000000,
  0x4026ffffffffffff,
  0x4034000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x4023ffffffffffff,
  0x4023ffffffffffff,
  0x4023ffffffffffff,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0xfc9fffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x800edcba98765433,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x8000000000000000,
  0x800edcba98765432,
  0x000123456789abcc,
  0x000123456789abcd,
  0x001123456789abcd,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0002468acf13579a,
  0x001123456789abcc,
  0x000123456789abce,
  0x000fffffffffffff,
  0x8000000000000001,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x000edcba98765432,
  0x8000000000000000,
  0x000ffffffffffffe,
  0x000fffffffffffff,
  0x001fffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x001123456789abcc,
  0x001ffffffffffffe,
  0x0010000000000000,
  0x0000000000000001,
  0x800fffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcc,
  0x800ffffffffffffe,
  0x8000000000000000,
  0x0000000000000001,
  0x0010000000000001,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abce,
  0x0010000000000000,
  0x0000000000000002,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8010000000000000,
  0x8020000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x801123456789abcd,
  0x801fffffffffffff,
  0x8010000000000001,
  0x8010000000000000,
  0x0000000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x800edcba98765433,
  0x8000000000000001,
  0x800fffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff7ffffffffffff,
  0xbff8000000000000,
  0xbff8000000000001,
  0xc000000000000000,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0x0000000000000000,
  0x3c90000000000000,
  0x3ca8000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000002,
  0x3ff0000000000000,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000001,
  0xc000000000000000,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbc90000000000000,
  0x0000000000000000,
  0x3ca0000000000000,
  0x3fdffffffffffffe,
  0x3fe0000000000000,
  0x3fe0000000000002,
  0x3ff0000000000000,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000002,
  0xc000000000000000,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbca8000000000000,
  0xbca0000000000000,
  0x0000000000000000,
  0x3fdffffffffffffc,
  0x3fdffffffffffffe,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbff7ffffffffffff,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbfffffffffffffff,
  0xc000000000000000,
  0xc000000000000000,
  0xc004000000000000,
  0xc026000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfdfffffffffffff,
  0xbfdffffffffffffe,
  0xbfdffffffffffffc,
  0x0000000000000000,
  0x3ca0000000000000,
  0x3cb8000000000000,
  0x3fe0000000000001,
  0x4022000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xc000000000000000,
  0xc000000000000000,
  0xc000000000000000,
  0xc004000000000000,
  0xc026000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfdffffffffffffe,
  0xbca0000000000000,
  0x0000000000000000,
  0x3cb0000000000000,
  0x3fe0000000000000,
  0x4022000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff8000000000001,
  0xbff8000000000001,
  0xbff8000000000002,
  0xc000000000000000,
  0xc000000000000000,
  0xc000000000000001,
  0xc004000000000000,
  0xc026000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbfe0000000000002,
  0xbfe0000000000002,
  0xbfe0000000000001,
  0xbcb8000000000000,
  0xbcb0000000000000,
  0x0000000000000000,
  0x3fdffffffffffffc,
  0x4022000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff8000000000000,
  0xbff8000000000000,
  0xc000000000000000,
  0xc000000000000000,
  0xc000000000000000,
  0xc004000000000000,
  0xc004000000000000,
  0xc004000000000000,
  0xc008000000000000,
  0xc027000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbfefffffffffffff,
  0xbfe0000000000001,
  0xbfe0000000000000,
  0xbfdffffffffffffc,
  0x0000000000000000,
  0x4021000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc025000000000000,
  0xc025000000000000,
  0xc025000000000000,
  0xc026000000000000,
  0xc026000000000000,
  0xc026000000000000,
  0xc027000000000000,
  0xc034000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc023000000000000,
  0xc023000000000000,
  0xc023000000000000,
  0xc022000000000000,
  0xc022000000000000,
  0xc022000000000000,
  0xc021000000000000,
  0x0000000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0x0000000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x800123456789abcd,
  0x801123456789abcd,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x8002468acf13579a,
  0x801123456789abcc,
  0x800123456789abce,
  0x800123456789abcd,
  0x000edcba98765433,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0000000000000000,
  0x000edcba98765432,
  0x800123456789abcc,
  0x800fffffffffffff,
  0x801fffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x801123456789abcc,
  0x801ffffffffffffe,
  0x8010000000000000,
  0x800fffffffffffff,
  0x0000000000000001,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x800edcba98765432,
  0x0000000000000000,
  0x800ffffffffffffe,
  0x8000000000000001,
  0x8010000000000001,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abce,
  0x8010000000000000,
  0x8000000000000002,
  0x8000000000000001,
  0x000fffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcc,
  0x000ffffffffffffe,
  0x0000000000000000,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0010000000000000,
  0x0000000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x000edcba98765433,
  0x0000000000000001,
  0x000fffffffffffff,
  0x0010000000000000,
  0x0020000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x001123456789abcd,
  0x001fffffffffffff,
  0x0010000000000001,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x0000000000000000,
  0xbc90000000000000,
  0xbca8000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000002,
  0xbff0000000000000,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff7ffffffffffff,
  0x3ff8000000000000,
  0x3ff8000000000001,
  0x4000000000000000,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3c90000000000000,
  0x0000000000000000,
  0xbca0000000000000,
  0xbfdffffffffffffe,
  0xbfe0000000000000,
  0xbfe0000000000002,
  0xbff0000000000000,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000001,
  0x4000000000000000,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3ca8000000000000,
  0x3ca0000000000000,
  0x0000000000000000,
  0xbfdffffffffffffc,
  0xbfdffffffffffffe,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000002,
  0x4000000000000000,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fdfffffffffffff,
  0x3fdffffffffffffe,
  0x3fdffffffffffffc,
  0x0000000000000000,
  0xbca0000000000000,
  0xbcb8000000000000,
  0xbfe0000000000001,
  0xc022000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3ff7ffffffffffff,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3fffffffffffffff,
  0x4000000000000000,
  0x4000000000000000,
  0x4004000000000000,
  0x4026000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fdffffffffffffe,
  0x3ca0000000000000,
  0x0000000000000000,
  0xbcb0000000000000,
  0xbfe0000000000000,
  0xc022000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x4000000000000000,
  0x4000000000000000,
  0x4000000000000000,
  0x4004000000000000,
  0x4026000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3fe0000000000002,
  0x3fe0000000000002,
  0x3fe0000000000001,
  0x3cb8000000000000,
  0x3cb0000000000000,
  0x0000000000000000,
  0xbfdffffffffffffc,
  0xc022000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff8000000000001,
  0x3ff8000000000001,
  0x3ff8000000000002,
  0x4000000000000000,
  0x4000000000000000,
  0x4000000000000001,
  0x4004000000000000,
  0x4026000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3fefffffffffffff,
  0x3fe0000000000001,
  0x3fe0000000000000,
  0x3fdffffffffffffc,
  0x0000000000000000,
  0xc021000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x4000000000000000,
  0x4000000000000000,
  0x4000000000000000,
  0x4004000000000000,
  0x4004000000000000,
  0x4004000000000000,
  0x4008000000000000,
  0x4027000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4023000000000000,
  0x4023000000000000,
  0x4023000000000000,
  0x4022000000000000,
  0x4022000000000000,
  0x4022000000000000,
  0x4021000000000000,
  0x0000000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4025000000000000,
  0x4025000000000000,
  0x4025000000000000,
  0x4026000000000000,
  0x4026000000000000,
  0x4026000000000000,
  0x4027000000000000,
  0x4034000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x0000000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x800edcba98765433,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0000000000000000,
  0x800edcba98765432,
  0x000123456789abcc,
  0x000123456789abcd,
  0x001123456789abcd,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0002468acf13579a,
  0x001123456789abcc,
  0x000123456789abce,
  0x000fffffffffffff,
  0x8000000000000001,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x000edcba98765432,
  0x0000000000000000,
  0x000ffffffffffffe,
  0x000fffffffffffff,
  0x001fffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x001123456789abcc,
  0x001ffffffffffffe,
  0x0010000000000000,
  0x0000000000000001,
  0x800fffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcc,
  0x800ffffffffffffe,
  0x0000000000000000,
  0x0000000000000001,
  0x0010000000000001,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abce,
  0x0010000000000000,
  0x0000000000000002,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8010000000000001,
  0x8020000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x801123456789abce,
  0x8020000000000000,
  0x8010000000000002,
  0x8010000000000001,
  0x8000000000000001,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x800edcba98765434,
  0x8000000000000002,
  0x8010000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000001,
  0xc000000000000000,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbc9fffffffffffff,
  0xbc8ffffffffffffe,
  0x3c90000000000001,
  0x3fdffffffffffffd,
  0x3fdfffffffffffff,
  0x3fe0000000000002,
  0x3ff0000000000000,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000002,
  0xc000000000000000,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbca8000000000000,
  0xbca0000000000000,
  0x0000000000000000,
  0x3fdffffffffffffc,
  0x3fdffffffffffffe,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000002,
  0xbfe0000000000002,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000002,
  0xbff8000000000001,
  0xbff8000000000001,
  0xbff8000000000002,
  0xc000000000000001,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe0000000000002,
  0xbfe0000000000002,
  0xbfe0000000000002,
  0xbfe0000000000002,
  0xbfe0000000000002,
  0xbcb4000000000000,
  0xbcb0000000000000,
  0xbca0000000000001,
  0x3fdffffffffffffa,
  0x3fdffffffffffffc,
  0x3fe0000000000000,
  0x3feffffffffffffe,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe0000000000002,
  0xbfe0000000000002,
  0xbfe0000000000002,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000001,
  0xc000000000000000,
  0xc000000000000000,
  0xc000000000000001,
  0xc004000000000000,
  0xc026000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000000,
  0xbcafffffffffffff,
  0xbc9ffffffffffffe,
  0x3ca0000000000001,
  0x3fdffffffffffffe,
  0x4022000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff8000000000001,
  0xbff8000000000001,
  0xbff8000000000002,
  0xc000000000000000,
  0xc000000000000000,
  0xc000000000000001,
  0xc004000000000000,
  0xc026000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbfe0000000000002,
  0xbfe0000000000002,
  0xbfe0000000000001,
  0xbcb8000000000000,
  0xbcb0000000000000,
  0x0000000000000000,
  0x3fdffffffffffffc,
  0x4022000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000002,
  0xbff0000000000002,
  0xbff8000000000002,
  0xbff8000000000002,
  0xbff8000000000003,
  0xc000000000000001,
  0xc000000000000001,
  0xc000000000000002,
  0xc004000000000001,
  0xc026000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbff0000000000002,
  0xbff0000000000002,
  0xbff0000000000002,
  0xbff0000000000002,
  0xbff0000000000002,
  0xbfe0000000000005,
  0xbfe0000000000004,
  0xbfe0000000000003,
  0xbcc4000000000000,
  0xbcc0000000000000,
  0xbcb0000000000001,
  0x3fdffffffffffff8,
  0x4022000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbff0000000000002,
  0xbff0000000000002,
  0xbff0000000000002,
  0xbff8000000000002,
  0xbff8000000000002,
  0xc000000000000001,
  0xc000000000000001,
  0xc000000000000001,
  0xc004000000000000,
  0xc004000000000001,
  0xc004000000000001,
  0xc008000000000001,
  0xc027000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbff8000000000002,
  0xbff8000000000002,
  0xbff8000000000002,
  0xbff8000000000002,
  0xbff8000000000001,
  0xbff0000000000002,
  0xbff0000000000002,
  0xbff0000000000001,
  0xbfe0000000000004,
  0xbfe0000000000003,
  0xbfe0000000000001,
  0xbcb8000000000000,
  0x4021000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbff8000000000001,
  0xbff8000000000001,
  0xbff8000000000001,
  0xc024000000000001,
  0xc024000000000001,
  0xc025000000000001,
  0xc025000000000001,
  0xc025000000000001,
  0xc026000000000001,
  0xc026000000000001,
  0xc026000000000001,
  0xc027000000000001,
  0xc034000000000001,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc024000000000001,
  0xc024000000000001,
  0xc024000000000001,
  0xc024000000000001,
  0xc024000000000001,
  0xc023000000000001,
  0xc023000000000001,
  0xc023000000000001,
  0xc022000000000001,
  0xc022000000000001,
  0xc022000000000001,
  0xc021000000000001,
  0xbce4000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc024000000000001,
  0xc024000000000001,
  0xc024000000000001,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfcafffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x800123456789abcd,
  0x801123456789abcd,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x8002468acf13579a,
  0x801123456789abcc,
  0x800123456789abce,
  0x800123456789abcd,
  0x000edcba98765433,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8000000000000000,
  0x000edcba98765432,
  0x800123456789abcc,
  0x8010000000000000,
  0x8020000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x801123456789abcd,
  0x801fffffffffffff,
  0x8010000000000001,
  0x8010000000000000,
  0x0000000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x800edcba98765433,
  0x8000000000000001,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8010000000000001,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abce,
  0x8010000000000000,
  0x8000000000000002,
  0x8000000000000001,
  0x000fffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcc,
  0x000ffffffffffffe,
  0x8000000000000000,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0010000000000001,
  0x0000000000000001,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x000edcba98765434,
  0x0000000000000002,
  0x0010000000000000,
  0x0010000000000001,
  0x0020000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x001123456789abce,
  0x0020000000000000,
  0x0010000000000002,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3c9fffffffffffff,
  0x3c8ffffffffffffe,
  0xbc90000000000001,
  0xbfdffffffffffffd,
  0xbfdfffffffffffff,
  0xbfe0000000000002,
  0xbff0000000000000,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000001,
  0x4000000000000000,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3ca8000000000000,
  0x3ca0000000000000,
  0x0000000000000000,
  0xbfdffffffffffffc,
  0xbfdffffffffffffe,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000002,
  0x4000000000000000,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000002,
  0x3fe0000000000002,
  0x3cb4000000000000,
  0x3cb0000000000000,
  0x3ca0000000000001,
  0xbfdffffffffffffa,
  0xbfdffffffffffffc,
  0xbfe0000000000000,
  0xbfeffffffffffffe,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe0000000000002,
  0x3fe0000000000002,
  0x3fe0000000000002,
  0x3fe0000000000002,
  0x3fe0000000000002,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000002,
  0x3ff8000000000001,
  0x3ff8000000000001,
  0x3ff8000000000002,
  0x4000000000000001,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe0000000000002,
  0x3fe0000000000002,
  0x3fe0000000000002,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000000,
  0x3cafffffffffffff,
  0x3c9ffffffffffffe,
  0xbca0000000000001,
  0xbfdffffffffffffe,
  0xc022000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000001,
  0x4000000000000000,
  0x4000000000000000,
  0x4000000000000001,
  0x4004000000000000,
  0x4026000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3fe0000000000002,
  0x3fe0000000000002,
  0x3fe0000000000001,
  0x3cb8000000000000,
  0x3cb0000000000000,
  0x0000000000000000,
  0xbfdffffffffffffc,
  0xc022000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff8000000000001,
  0x3ff8000000000001,
  0x3ff8000000000002,
  0x4000000000000000,
  0x4000000000000000,
  0x4000000000000001,
  0x4004000000000000,
  0x4026000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000002,
  0x3ff0000000000002,
  0x3fe0000000000005,
  0x3fe0000000000004,
  0x3fe0000000000003,
  0x3cc4000000000000,
  0x3cc0000000000000,
  0x3cb0000000000001,
  0xbfdffffffffffff8,
  0xc022000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3ff0000000000002,
  0x3ff0000000000002,
  0x3ff0000000000002,
  0x3ff0000000000002,
  0x3ff0000000000002,
  0x3ff8000000000002,
  0x3ff8000000000002,
  0x3ff8000000000003,
  0x4000000000000001,
  0x4000000000000001,
  0x4000000000000002,
  0x4004000000000001,
  0x4026000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3ff0000000000002,
  0x3ff0000000000002,
  0x3ff0000000000002,
  0x3ff8000000000002,
  0x3ff8000000000001,
  0x3ff0000000000002,
  0x3ff0000000000002,
  0x3ff0000000000001,
  0x3fe0000000000004,
  0x3fe0000000000003,
  0x3fe0000000000001,
  0x3cb8000000000000,
  0xc021000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3ff8000000000001,
  0x3ff8000000000001,
  0x3ff8000000000001,
  0x3ff8000000000002,
  0x3ff8000000000002,
  0x4000000000000001,
  0x4000000000000001,
  0x4000000000000001,
  0x4004000000000000,
  0x4004000000000001,
  0x4004000000000001,
  0x4008000000000001,
  0x4027000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3ff8000000000002,
  0x3ff8000000000002,
  0x3ff8000000000002,
  0x4024000000000001,
  0x4024000000000001,
  0x4023000000000001,
  0x4023000000000001,
  0x4023000000000001,
  0x4022000000000001,
  0x4022000000000001,
  0x4022000000000001,
  0x4021000000000001,
  0x3ce4000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x4024000000000001,
  0x4024000000000001,
  0x4024000000000001,
  0x4024000000000001,
  0x4024000000000001,
  0x4025000000000001,
  0x4025000000000001,
  0x4025000000000001,
  0x4026000000000001,
  0x4026000000000001,
  0x4026000000000001,
  0x4027000000000001,
  0x4034000000000001,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x4024000000000001,
  0x4024000000000001,
  0x4024000000000001,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7cafffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x800edcba98765433,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0000000000000000,
  0x800edcba98765432,
  0x000123456789abcc,
  0x000123456789abcd,
  0x001123456789abcd,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0002468acf13579a,
  0x001123456789abcc,
  0x000123456789abce,
  0x0010000000000000,
  0x8000000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x000edcba98765433,
  0x0000000000000001,
  0x000fffffffffffff,
  0x0010000000000000,
  0x0020000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x001123456789abcd,
  0x001fffffffffffff,
  0x0010000000000001,
  0x0000000000000001,
  0x800fffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcc,
  0x800ffffffffffffe,
  0x0000000000000000,
  0x0000000000000001,
  0x0010000000000001,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abce,
  0x0010000000000000,
  0x0000000000000002,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8018000000000000,
  0x8024000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x801923456789abcd,
  0x8024000000000000,
  0x8018000000000001,
  0x8018000000000000,
  0x8008000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8016dcba98765433,
  0x8008000000000001,
  0x8017ffffffffffff,
  0xbfe7ffffffffffff,
  0xbfe7ffffffffffff,
  0xbff3ffffffffffff,
  0xbff4000000000000,
  0xbff4000000000000,
  0xbffbffffffffffff,
  0xbffc000000000000,
  0xbffc000000000001,
  0xc002000000000000,
  0xc025800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe7ffffffffffff,
  0xbfe7ffffffffffff,
  0xbfe7ffffffffffff,
  0xbfe7ffffffffffff,
  0xbfe7ffffffffffff,
  0xbfcfffffffffffff,
  0xbfcffffffffffffd,
  0xbfcffffffffffff9,
  0x3fcfffffffffffff,
  0x3fd0000000000002,
  0x3fd0000000000006,
  0x3fe8000000000001,
  0x4022800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe7ffffffffffff,
  0xbfe7ffffffffffff,
  0xbfe7ffffffffffff,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbff4000000000000,
  0xbff4000000000000,
  0xbff4000000000000,
  0xbffc000000000000,
  0xbffc000000000000,
  0xbffc000000000001,
  0xc002000000000000,
  0xc025800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbfd0000000000001,
  0xbfd0000000000000,
  0xbfcffffffffffffc,
  0x3fcffffffffffffc,
  0x3fd0000000000000,
  0x3fd0000000000004,
  0x3fe8000000000000,
  0x4022800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbfe8000000000002,
  0xbfe8000000000002,
  0xbff4000000000000,
  0xbff4000000000001,
  0xbff4000000000001,
  0xbffc000000000000,
  0xbffc000000000001,
  0xbffc000000000002,
  0xc002000000000000,
  0xc025800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe8000000000002,
  0xbfe8000000000002,
  0xbfe8000000000002,
  0xbfe8000000000002,
  0xbfe8000000000001,
  0xbfd0000000000004,
  0xbfd0000000000003,
  0xbfd0000000000001,
  0x3fcffffffffffff6,
  0x3fcffffffffffffa,
  0x3fd0000000000001,
  0x3fe7fffffffffffe,
  0x4022800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe8000000000001,
  0xbfe8000000000001,
  0xbfe8000000000001,
  0xbff7ffffffffffff,
  0xbff7ffffffffffff,
  0xbfffffffffffffff,
  0xbfffffffffffffff,
  0xc000000000000000,
  0xc003ffffffffffff,
  0xc004000000000000,
  0xc004000000000000,
  0xc008000000000000,
  0xc027000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbff7ffffffffffff,
  0xbff7ffffffffffff,
  0xbff7ffffffffffff,
  0xbff7ffffffffffff,
  0xbff7ffffffffffff,
  0xbfefffffffffffff,
  0xbfeffffffffffffe,
  0xbfeffffffffffffe,
  0xbfdfffffffffffff,
  0xbfdffffffffffffd,
  0xbfdffffffffffff9,
  0x3ca8000000000000,
  0x4021000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbff7ffffffffffff,
  0xbff7ffffffffffff,
  0xbff7ffffffffffff,
  0xbff8000000000000,
  0xbff8000000000000,
  0xc000000000000000,
  0xc000000000000000,
  0xc000000000000000,
  0xc004000000000000,
  0xc004000000000000,
  0xc004000000000000,
  0xc008000000000000,
  0xc027000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbfefffffffffffff,
  0xbfe0000000000001,
  0xbfe0000000000000,
  0xbfdffffffffffffc,
  0x0000000000000000,
  0x4021000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000002,
  0xbff8000000000002,
  0xc000000000000001,
  0xc000000000000001,
  0xc000000000000001,
  0xc004000000000000,
  0xc004000000000001,
  0xc004000000000001,
  0xc008000000000001,
  0xc027000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbff8000000000002,
  0xbff8000000000002,
  0xbff8000000000002,
  0xbff8000000000002,
  0xbff8000000000001,
  0xbff0000000000002,
  0xbff0000000000002,
  0xbff0000000000001,
  0xbfe0000000000004,
  0xbfe0000000000003,
  0xbfe0000000000001,
  0xbcb8000000000000,
  0x4021000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbff8000000000001,
  0xbff8000000000001,
  0xbff8000000000001,
  0xc002000000000000,
  0xc002000000000000,
  0xc006000000000000,
  0xc006000000000000,
  0xc006000000000000,
  0xc00a000000000000,
  0xc00a000000000000,
  0xc00a000000000000,
  0xc00e000000000000,
  0xc028800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc002000000000000,
  0xc002000000000000,
  0xc002000000000000,
  0xc002000000000000,
  0xc002000000000000,
  0xbffc000000000000,
  0xbffc000000000000,
  0xbffc000000000000,
  0xbff4000000000000,
  0xbff4000000000000,
  0xbff3ffffffffffff,
  0xbfe8000000000000,
  0x401f000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc002000000000000,
  0xc002000000000000,
  0xc002000000000000,
  0xc02e000000000000,
  0xc02e000000000000,
  0xc02f000000000000,
  0xc02f000000000000,
  0xc02f000000000000,
  0xc030000000000000,
  0xc030000000000000,
  0xc030000000000000,
  0xc030800000000000,
  0xc039000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc02e000000000000,
  0xc02e000000000000,
  0xc02e000000000000,
  0xc02e000000000000,
  0xc02e000000000000,
  0xc02d000000000000,
  0xc02d000000000000,
  0xc02d000000000000,
  0xc02c000000000000,
  0xc02c000000000000,
  0xc02c000000000000,
  0xc02b000000000000,
  0xc014000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc02e000000000000,
  0xc02e000000000000,
  0xc02e000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xffdfffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x8001b4e81b4e81b4,
  0x8011b4e81b4e81b4,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x8002d82d82d82d80,
  0x8011b4e81b4e81b2,
  0x8001b4e81b4e81b4,
  0x8001b4e81b4e81b4,
  0x000e4b17e4b17e4c,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x800091a2b3c4d5e6,
  0x000e4b17e4b17e4c,
  0x8001b4e81b4e81b2,
  0x8017fffffffffffe,
  0x8023ffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x801923456789abcc,
  0x8023ffffffffffff,
  0x8018000000000000,
  0x8017fffffffffffe,
  0x8007fffffffffffe,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8016dcba98765432,
  0x8008000000000000,
  0x8017fffffffffffe,
  0x8000000000000002,
  0x8010000000000002,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abce,
  0x8010000000000000,
  0x8000000000000002,
  0x8000000000000002,
  0x000ffffffffffffe,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcc,
  0x000ffffffffffffe,
  0x8000000000000000,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0018000000000000,
  0x0008000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0016dcba98765433,
  0x0008000000000001,
  0x0017ffffffffffff,
  0x0018000000000000,
  0x0024000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x001923456789abcd,
  0x0024000000000000,
  0x0018000000000001,
  0x3fe7ffffffffffff,
  0x3fe7ffffffffffff,
  0x3fcfffffffffffff,
  0x3fcffffffffffffd,
  0x3fcffffffffffff9,
  0xbfcfffffffffffff,
  0xbfd0000000000002,
  0xbfd0000000000006,
  0xbfe8000000000001,
  0xc022800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe7ffffffffffff,
  0x3fe7ffffffffffff,
  0x3fe7ffffffffffff,
  0x3fe7ffffffffffff,
  0x3fe7ffffffffffff,
  0x3ff3ffffffffffff,
  0x3ff4000000000000,
  0x3ff4000000000000,
  0x3ffbffffffffffff,
  0x3ffc000000000000,
  0x3ffc000000000001,
  0x4002000000000000,
  0x4025800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe7ffffffffffff,
  0x3fe7ffffffffffff,
  0x3fe7ffffffffffff,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3fd0000000000001,
  0x3fd0000000000000,
  0x3fcffffffffffffc,
  0xbfcffffffffffffc,
  0xbfd0000000000000,
  0xbfd0000000000004,
  0xbfe8000000000000,
  0xc022800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3ff4000000000000,
  0x3ff4000000000000,
  0x3ff4000000000000,
  0x3ffc000000000000,
  0x3ffc000000000000,
  0x3ffc000000000001,
  0x4002000000000000,
  0x4025800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3fe8000000000002,
  0x3fe8000000000001,
  0x3fd0000000000004,
  0x3fd0000000000003,
  0x3fd0000000000001,
  0xbfcffffffffffff6,
  0xbfcffffffffffffa,
  0xbfd0000000000001,
  0xbfe7fffffffffffe,
  0xc022800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe8000000000001,
  0x3fe8000000000001,
  0x3fe8000000000001,
  0x3fe8000000000002,
  0x3fe8000000000002,
  0x3ff4000000000000,
  0x3ff4000000000001,
  0x3ff4000000000001,
  0x3ffc000000000000,
  0x3ffc000000000001,
  0x3ffc000000000002,
  0x4002000000000000,
  0x4025800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe8000000000002,
  0x3fe8000000000002,
  0x3fe8000000000002,
  0x3ff7ffffffffffff,
  0x3ff7ffffffffffff,
  0x3fefffffffffffff,
  0x3feffffffffffffe,
  0x3feffffffffffffe,
  0x3fdfffffffffffff,
  0x3fdffffffffffffd,
  0x3fdffffffffffff9,
  0xbca8000000000000,
  0xc021000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3ff7ffffffffffff,
  0x3ff7ffffffffffff,
  0x3ff7ffffffffffff,
  0x3ff7ffffffffffff,
  0x3ff7ffffffffffff,
  0x3fffffffffffffff,
  0x3fffffffffffffff,
  0x4000000000000000,
  0x4003ffffffffffff,
  0x4004000000000000,
  0x4004000000000000,
  0x4008000000000000,
  0x4027000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3ff7ffffffffffff,
  0x3ff7ffffffffffff,
  0x3ff7ffffffffffff,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3fefffffffffffff,
  0x3fe0000000000001,
  0x3fe0000000000000,
  0x3fdffffffffffffc,
  0x0000000000000000,
  0xc021000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x4000000000000000,
  0x4000000000000000,
  0x4000000000000000,
  0x4004000000000000,
  0x4004000000000000,
  0x4004000000000000,
  0x4008000000000000,
  0x4027000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000002,
  0x3ff8000000000001,
  0x3ff0000000000002,
  0x3ff0000000000002,
  0x3ff0000000000001,
  0x3fe0000000000004,
  0x3fe0000000000003,
  0x3fe0000000000001,
  0x3cb8000000000000,
  0xc021000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3ff8000000000001,
  0x3ff8000000000001,
  0x3ff8000000000001,
  0x3ff8000000000002,
  0x3ff8000000000002,
  0x4000000000000001,
  0x4000000000000001,
  0x4000000000000001,
  0x4004000000000000,
  0x4004000000000001,
  0x4004000000000001,
  0x4008000000000001,
  0x4027000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3ff8000000000002,
  0x3ff8000000000002,
  0x3ff8000000000002,
  0x4002000000000000,
  0x4002000000000000,
  0x3ffc000000000000,
  0x3ffc000000000000,
  0x3ffc000000000000,
  0x3ff4000000000000,
  0x3ff4000000000000,
  0x3ff3ffffffffffff,
  0x3fe8000000000000,
  0xc01f000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x4002000000000000,
  0x4002000000000000,
  0x4002000000000000,
  0x4002000000000000,
  0x4002000000000000,
  0x4006000000000000,
  0x4006000000000000,
  0x4006000000000000,
  0x400a000000000000,
  0x400a000000000000,
  0x400a000000000000,
  0x400e000000000000,
  0x4028800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x4002000000000000,
  0x4002000000000000,
  0x4002000000000000,
  0x402e000000000000,
  0x402e000000000000,
  0x402d000000000000,
  0x402d000000000000,
  0x402d000000000000,
  0x402c000000000000,
  0x402c000000000000,
  0x402c000000000000,
  0x402b000000000000,
  0x4014000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x402e000000000000,
  0x402e000000000000,
  0x402e000000000000,
  0x402e000000000000,
  0x402e000000000000,
  0x402f000000000000,
  0x402f000000000000,
  0x402f000000000000,
  0x4030000000000000,
  0x4030000000000000,
  0x4030000000000000,
  0x4030800000000000,
  0x4039000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x402e000000000000,
  0x402e000000000000,
  0x402e000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7fdfffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x0001b4e81b4e81b4,
  0x800e4b17e4b17e4c,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x000091a2b3c4d5e6,
  0x800e4b17e4b17e4c,
  0x0001b4e81b4e81b2,
  0x0001b4e81b4e81b4,
  0x0011b4e81b4e81b4,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0002d82d82d82d80,
  0x0011b4e81b4e81b2,
  0x0001b4e81b4e81b4,
  0x0017fffffffffffe,
  0x0007fffffffffffe,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0016dcba98765432,
  0x0008000000000000,
  0x0017fffffffffffe,
  0x0017fffffffffffe,
  0x0023ffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x001923456789abcc,
  0x0023ffffffffffff,
  0x0018000000000000,
  0x0000000000000002,
  0x800ffffffffffffe,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcc,
  0x800ffffffffffffe,
  0x0000000000000000,
  0x0000000000000002,
  0x0010000000000002,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abce,
  0x0010000000000000,
  0x0000000000000002,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8044000000000000,
  0x8046000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x80442468acf1357a,
  0x8046000000000000,
  0x8044000000000000,
  0x8044000000000000,
  0x8042000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8043db97530eca86,
  0x8042000000000000,
  0x8044000000000000,
  0xc013ffffffffffff,
  0xc013ffffffffffff,
  0xc015ffffffffffff,
  0xc015ffffffffffff,
  0xc016000000000000,
  0xc017ffffffffffff,
  0xc017ffffffffffff,
  0xc018000000000000,
  0xc019ffffffffffff,
  0xc02e000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc013ffffffffffff,
  0xc013ffffffffffff,
  0xc013ffffffffffff,
  0xc013ffffffffffff,
  0xc013ffffffffffff,
  0xc011ffffffffffff,
  0xc011ffffffffffff,
  0xc011ffffffffffff,
  0xc00fffffffffffff,
  0xc00fffffffffffff,
  0xc00ffffffffffffe,
  0xc00bffffffffffff,
  0x4014000000000001,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc013ffffffffffff,
  0xc013ffffffffffff,
  0xc013ffffffffffff,
  0xc014000000000000,
  0xc014000000000000,
  0xc016000000000000,
  0xc016000000000000,
  0xc016000000000000,
  0xc018000000000000,
  0xc018000000000000,
  0xc018000000000000,
  0xc01a000000000000,
  0xc02e000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc014000000000000,
  0xc014000000000000,
  0xc014000000000000,
  0xc014000000000000,
  0xc014000000000000,
  0xc012000000000000,
  0xc012000000000000,
  0xc012000000000000,
  0xc010000000000000,
  0xc010000000000000,
  0xc010000000000000,
  0xc00c000000000000,
  0x4014000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc014000000000000,
  0xc014000000000000,
  0xc014000000000000,
  0xc014000000000001,
  0xc014000000000001,
  0xc016000000000001,
  0xc016000000000001,
  0xc016000000000001,
  0xc018000000000001,
  0xc018000000000001,
  0xc018000000000002,
  0xc01a000000000001,
  0xc02e000000000001,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc014000000000001,
  0xc014000000000001,
  0xc014000000000001,
  0xc014000000000001,
  0xc014000000000001,
  0xc012000000000001,
  0xc012000000000001,
  0xc012000000000001,
  0xc010000000000001,
  0xc010000000000001,
  0xc010000000000001,
  0xc00c000000000002,
  0x4013ffffffffffff,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc014000000000001,
  0xc014000000000001,
  0xc014000000000001,
  0xc023ffffffffffff,
  0xc023ffffffffffff,
  0xc024ffffffffffff,
  0xc024ffffffffffff,
  0xc024ffffffffffff,
  0xc025ffffffffffff,
  0xc025ffffffffffff,
  0xc026000000000000,
  0xc026ffffffffffff,
  0xc034000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc023ffffffffffff,
  0xc023ffffffffffff,
  0xc023ffffffffffff,
  0xc023ffffffffffff,
  0xc023ffffffffffff,
  0xc022ffffffffffff,
  0xc022ffffffffffff,
  0xc022ffffffffffff,
  0xc021ffffffffffff,
  0xc021ffffffffffff,
  0xc021ffffffffffff,
  0xc020ffffffffffff,
  0x3cd4000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc023ffffffffffff,
  0xc023ffffffffffff,
  0xc023ffffffffffff,
  0xc024000000000000,
  0xc024000000000000,
  0xc025000000000000,
  0xc025000000000000,
  0xc025000000000000,
  0xc026000000000000,
  0xc026000000000000,
  0xc026000000000000,
  0xc027000000000000,
  0xc034000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc023000000000000,
  0xc023000000000000,
  0xc023000000000000,
  0xc022000000000000,
  0xc022000000000000,
  0xc022000000000000,
  0xc021000000000000,
  0x0000000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc024000000000001,
  0xc024000000000001,
  0xc025000000000001,
  0xc025000000000001,
  0xc025000000000001,
  0xc026000000000001,
  0xc026000000000001,
  0xc026000000000001,
  0xc027000000000001,
  0xc034000000000001,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc024000000000001,
  0xc024000000000001,
  0xc024000000000001,
  0xc024000000000001,
  0xc024000000000001,
  0xc023000000000001,
  0xc023000000000001,
  0xc023000000000001,
  0xc022000000000001,
  0xc022000000000001,
  0xc022000000000001,
  0xc021000000000001,
  0xbce4000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc024000000000001,
  0xc024000000000001,
  0xc024000000000001,
  0xc02e000000000000,
  0xc02e000000000000,
  0xc02f000000000000,
  0xc02f000000000000,
  0xc02f000000000000,
  0xc030000000000000,
  0xc030000000000000,
  0xc030000000000000,
  0xc030800000000000,
  0xc039000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc02e000000000000,
  0xc02e000000000000,
  0xc02e000000000000,
  0xc02e000000000000,
  0xc02e000000000000,
  0xc02d000000000000,
  0xc02d000000000000,
  0xc02d000000000000,
  0xc02c000000000000,
  0xc02c000000000000,
  0xc02c000000000000,
  0xc02b000000000000,
  0xc014000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc02e000000000000,
  0xc02e000000000000,
  0xc02e000000000000,
  0xc059000000000000,
  0xc059000000000000,
  0xc059200000000000,
  0xc059200000000000,
  0xc059200000000000,
  0xc059400000000000,
  0xc059400000000000,
  0xc059400000000000,
  0xc059600000000000,
  0xc05b800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc059000000000000,
  0xc059000000000000,
  0xc059000000000000,
  0xc059000000000000,
  0xc059000000000000,
  0xc058e00000000000,
  0xc058e00000000000,
  0xc058e00000000000,
  0xc058c00000000000,
  0xc058c00000000000,
  0xc058c00000000000,
  0xc058a00000000000,
  0xc056800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc059000000000000,
  0xc059000000000000,
  0xc059000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x800b60b60b60b602,
  0x801b60b60b60b602,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800c83fb72ea61cf,
  0x801b60b60b60b601,
  0x800b60b60b60b603,
  0x800b60b60b60b602,
  0x00049f49f49f49fe,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x800a3d70a3d70a35,
  0x00049f49f49f49fd,
  0x800b60b60b60b601,
  0x8043ffffffffffff,
  0x8045ffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x80442468acf13578,
  0x8045ffffffffffff,
  0x8043ffffffffffff,
  0x8043ffffffffffff,
  0x8041ffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8043db97530eca85,
  0x8041ffffffffffff,
  0x8043ffffffffffff,
  0x800000000000000a,
  0x801000000000000a,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abd7,
  0x8010000000000009,
  0x800000000000000b,
  0x800000000000000a,
  0x000ffffffffffff6,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abc3,
  0x000ffffffffffff5,
  0x8000000000000009,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0044000000000000,
  0x0042000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0043db97530eca86,
  0x0042000000000000,
  0x0044000000000000,
  0x0044000000000000,
  0x0046000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x00442468acf1357a,
  0x0046000000000000,
  0x0044000000000000,
  0x4013ffffffffffff,
  0x4013ffffffffffff,
  0x4011ffffffffffff,
  0x4011ffffffffffff,
  0x4011ffffffffffff,
  0x400fffffffffffff,
  0x400fffffffffffff,
  0x400ffffffffffffe,
  0x400bffffffffffff,
  0xc014000000000001,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x4013ffffffffffff,
  0x4013ffffffffffff,
  0x4013ffffffffffff,
  0x4013ffffffffffff,
  0x4013ffffffffffff,
  0x4015ffffffffffff,
  0x4015ffffffffffff,
  0x4016000000000000,
  0x4017ffffffffffff,
  0x4017ffffffffffff,
  0x4018000000000000,
  0x4019ffffffffffff,
  0x402e000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x4013ffffffffffff,
  0x4013ffffffffffff,
  0x4013ffffffffffff,
  0x4014000000000000,
  0x4014000000000000,
  0x4012000000000000,
  0x4012000000000000,
  0x4012000000000000,
  0x4010000000000000,
  0x4010000000000000,
  0x4010000000000000,
  0x400c000000000000,
  0xc014000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x4014000000000000,
  0x4014000000000000,
  0x4014000000000000,
  0x4014000000000000,
  0x4014000000000000,
  0x4016000000000000,
  0x4016000000000000,
  0x4016000000000000,
  0x4018000000000000,
  0x4018000000000000,
  0x4018000000000000,
  0x401a000000000000,
  0x402e000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x4014000000000000,
  0x4014000000000000,
  0x4014000000000000,
  0x4014000000000001,
  0x4014000000000001,
  0x4012000000000001,
  0x4012000000000001,
  0x4012000000000001,
  0x4010000000000001,
  0x4010000000000001,
  0x4010000000000001,
  0x400c000000000002,
  0xc013ffffffffffff,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x4014000000000001,
  0x4014000000000001,
  0x4014000000000001,
  0x4014000000000001,
  0x4014000000000001,
  0x4016000000000001,
  0x4016000000000001,
  0x4016000000000001,
  0x4018000000000001,
  0x4018000000000001,
  0x4018000000000002,
  0x401a000000000001,
  0x402e000000000001,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x4014000000000001,
  0x4014000000000001,
  0x4014000000000001,
  0x4023ffffffffffff,
  0x4023ffffffffffff,
  0x4022ffffffffffff,
  0x4022ffffffffffff,
  0x4022ffffffffffff,
  0x4021ffffffffffff,
  0x4021ffffffffffff,
  0x4021ffffffffffff,
  0x4020ffffffffffff,
  0xbcd4000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x4023ffffffffffff,
  0x4023ffffffffffff,
  0x4023ffffffffffff,
  0x4023ffffffffffff,
  0x4023ffffffffffff,
  0x4024ffffffffffff,
  0x4024ffffffffffff,
  0x4024ffffffffffff,
  0x4025ffffffffffff,
  0x4025ffffffffffff,
  0x4026000000000000,
  0x4026ffffffffffff,
  0x4034000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x4023ffffffffffff,
  0x4023ffffffffffff,
  0x4023ffffffffffff,
  0x4024000000000000,
  0x4024000000000000,
  0x4023000000000000,
  0x4023000000000000,
  0x4023000000000000,
  0x4022000000000000,
  0x4022000000000000,
  0x4022000000000000,
  0x4021000000000000,
  0x0000000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4025000000000000,
  0x4025000000000000,
  0x4025000000000000,
  0x4026000000000000,
  0x4026000000000000,
  0x4026000000000000,
  0x4027000000000000,
  0x4034000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4024000000000001,
  0x4024000000000001,
  0x4023000000000001,
  0x4023000000000001,
  0x4023000000000001,
  0x4022000000000001,
  0x4022000000000001,
  0x4022000000000001,
  0x4021000000000001,
  0x3ce4000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x4024000000000001,
  0x4024000000000001,
  0x4024000000000001,
  0x4024000000000001,
  0x4024000000000001,
  0x4025000000000001,
  0x4025000000000001,
  0x4025000000000001,
  0x4026000000000001,
  0x4026000000000001,
  0x4026000000000001,
  0x4027000000000001,
  0x4034000000000001,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x4024000000000001,
  0x4024000000000001,
  0x4024000000000001,
  0x402e000000000000,
  0x402e000000000000,
  0x402d000000000000,
  0x402d000000000000,
  0x402d000000000000,
  0x402c000000000000,
  0x402c000000000000,
  0x402c000000000000,
  0x402b000000000000,
  0x4014000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x402e000000000000,
  0x402e000000000000,
  0x402e000000000000,
  0x402e000000000000,
  0x402e000000000000,
  0x402f000000000000,
  0x402f000000000000,
  0x402f000000000000,
  0x4030000000000000,
  0x4030000000000000,
  0x4030000000000000,
  0x4030800000000000,
  0x4039000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x402e000000000000,
  0x402e000000000000,
  0x402e000000000000,
  0x4059000000000000,
  0x4059000000000000,
  0x4058e00000000000,
  0x4058e00000000000,
  0x4058e00000000000,
  0x4058c00000000000,
  0x4058c00000000000,
  0x4058c00000000000,
  0x4058a00000000000,
  0x4056800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x4059000000000000,
  0x4059000000000000,
  0x4059000000000000,
  0x4059000000000000,
  0x4059000000000000,
  0x4059200000000000,
  0x4059200000000000,
  0x4059200000000000,
  0x4059400000000000,
  0x4059400000000000,
  0x4059400000000000,
  0x4059600000000000,
  0x405b800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x4059000000000000,
  0x4059000000000000,
  0x4059000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x000b60b60b60b602,
  0x80049f49f49f49fe,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x000a3d70a3d70a35,
  0x80049f49f49f49fd,
  0x000b60b60b60b601,
  0x000b60b60b60b602,
  0x001b60b60b60b602,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000c83fb72ea61cf,
  0x001b60b60b60b601,
  0x000b60b60b60b603,
  0x0043ffffffffffff,
  0x0041ffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0043db97530eca85,
  0x0041ffffffffffff,
  0x0043ffffffffffff,
  0x0043ffffffffffff,
  0x0045ffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x00442468acf13578,
  0x0045ffffffffffff,
  0x0043ffffffffffff,
  0x000000000000000a,
  0x800ffffffffffff6,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abc3,
  0x800ffffffffffff5,
  0x0000000000000009,
  0x000000000000000a,
  0x001000000000000a,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abd7,
  0x0010000000000009,
  0x000000000000000b,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0xc00fffffffffffff,
  0xc00fffffffffffff,
  0xc011ffffffffffff,
  0xc012000000000000,
  0xc012000000000000,
  0xc013ffffffffffff,
  0xc014000000000000,
  0xc014000000000000,
  0xc016000000000000,
  0xc02c000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc00fffffffffffff,
  0xc00fffffffffffff,
  0xc00fffffffffffff,
  0xc00fffffffffffff,
  0xc00fffffffffffff,
  0xc00bffffffffffff,
  0xc00bffffffffffff,
  0xc00bffffffffffff,
  0xc007ffffffffffff,
  0xc007ffffffffffff,
  0xc007fffffffffffe,
  0xc003ffffffffffff,
  0x4018000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc00fffffffffffff,
  0xc00fffffffffffff,
  0xc00fffffffffffff,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0x7fe0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0x7fdfffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0x7fdffffffffffffd,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0x7c9fffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0x0000000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfcafffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xffdfffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xbfd23456789abccf,
  0xbfd23456789abccf,
  0xbfe91a2b3c4d5e67,
  0xbfe91a2b3c4d5e68,
  0xbfe91a2b3c4d5e69,
  0xbff48d159e26af33,
  0xbff48d159e26af34,
  0xbff48d159e26af35,
  0xbffc8d159e26af34,
  0xc02491a2b3c4d5e6,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfd23456789abccf,
  0xbfd23456789abccf,
  0xbfd23456789abccf,
  0xbfd23456789abccf,
  0xbfd23456789abccf,
  0x3fcb97530eca865f,
  0x3fcb97530eca8661,
  0x3fcb97530eca8665,
  0x3fe6e5d4c3b2a197,
  0x3fe6e5d4c3b2a198,
  0x3fe6e5d4c3b2a19a,
  0x3ff372ea61d950cc,
  0x40236e5d4c3b2a1a,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfd23456789abccf,
  0xbfd23456789abccf,
  0xbfd23456789abccf,
  0xc00ffffffffffffd,
  0xc00ffffffffffffd,
  0xc011fffffffffffe,
  0xc011ffffffffffff,
  0xc011ffffffffffff,
  0xc013fffffffffffe,
  0xc013ffffffffffff,
  0xc013ffffffffffff,
  0xc015ffffffffffff,
  0xc02bffffffffffff,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc00ffffffffffffd,
  0xc00ffffffffffffd,
  0xc00ffffffffffffd,
  0xc00ffffffffffffd,
  0xc00ffffffffffffd,
  0xc00bfffffffffffd,
  0xc00bfffffffffffd,
  0xc00bfffffffffffd,
  0xc007fffffffffffd,
  0xc007fffffffffffd,
  0xc007fffffffffffd,
  0xc003fffffffffffd,
  0x4018000000000001,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc00ffffffffffffd,
  0xc00ffffffffffffd,
  0xc00ffffffffffffd,
  0xbccfffffffffffff,
  0xbccfffffffffffff,
  0xbfe0000000000007,
  0xbfe0000000000008,
  0xbfe0000000000009,
  0xbff0000000000003,
  0xbff0000000000004,
  0xbff0000000000005,
  0xbff8000000000004,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbccfffffffffffff,
  0xbccfffffffffffff,
  0xbccfffffffffffff,
  0xbccfffffffffffff,
  0xbccfffffffffffff,
  0x3fdfffffffffffef,
  0x3fdffffffffffff0,
  0x3fdffffffffffff2,
  0x3feffffffffffff7,
  0x3feffffffffffff8,
  0x3feffffffffffffa,
  0x3ff7fffffffffffc,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbccfffffffffffff,
  0xbccfffffffffffff,
  0xbccfffffffffffff,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x400fffffffffffff,
  0x400fffffffffffff,
  0x400bffffffffffff,
  0x400bffffffffffff,
  0x400bffffffffffff,
  0x4007ffffffffffff,
  0x4007ffffffffffff,
  0x4007fffffffffffe,
  0x4003ffffffffffff,
  0xc018000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x400fffffffffffff,
  0x400fffffffffffff,
  0x400fffffffffffff,
  0x400fffffffffffff,
  0x400fffffffffffff,
  0x4011ffffffffffff,
  0x4012000000000000,
  0x4012000000000000,
  0x4013ffffffffffff,
  0x4014000000000000,
  0x4014000000000000,
  0x4016000000000000,
  0x402c000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x400fffffffffffff,
  0x400fffffffffffff,
  0x400fffffffffffff,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0xffe0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0xffdfffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0xffdffffffffffffd,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0xfc9fffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x0000000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7cafffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7fdfffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x3fd23456789abccf,
  0x3fd23456789abccf,
  0xbfcb97530eca865f,
  0xbfcb97530eca8661,
  0xbfcb97530eca8665,
  0xbfe6e5d4c3b2a197,
  0xbfe6e5d4c3b2a198,
  0xbfe6e5d4c3b2a19a,
  0xbff372ea61d950cc,
  0xc0236e5d4c3b2a1a,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fd23456789abccf,
  0x3fd23456789abccf,
  0x3fd23456789abccf,
  0x3fd23456789abccf,
  0x3fd23456789abccf,
  0x3fe91a2b3c4d5e67,
  0x3fe91a2b3c4d5e68,
  0x3fe91a2b3c4d5e69,
  0x3ff48d159e26af33,
  0x3ff48d159e26af34,
  0x3ff48d159e26af35,
  0x3ffc8d159e26af34,
  0x402491a2b3c4d5e6,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fd23456789abccf,
  0x3fd23456789abccf,
  0x3fd23456789abccf,
  0x400ffffffffffffd,
  0x400ffffffffffffd,
  0x400bfffffffffffd,
  0x400bfffffffffffd,
  0x400bfffffffffffd,
  0x4007fffffffffffd,
  0x4007fffffffffffd,
  0x4007fffffffffffd,
  0x4003fffffffffffd,
  0xc018000000000001,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x400ffffffffffffd,
  0x400ffffffffffffd,
  0x400ffffffffffffd,
  0x400ffffffffffffd,
  0x400ffffffffffffd,
  0x4011fffffffffffe,
  0x4011ffffffffffff,
  0x4011ffffffffffff,
  0x4013fffffffffffe,
  0x4013ffffffffffff,
  0x4013ffffffffffff,
  0x4015ffffffffffff,
  0x402bffffffffffff,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x400ffffffffffffd,
  0x400ffffffffffffd,
  0x400ffffffffffffd,
  0x3ccfffffffffffff,
  0x3ccfffffffffffff,
  0xbfdfffffffffffef,
  0xbfdffffffffffff0,
  0xbfdffffffffffff2,
  0xbfeffffffffffff7,
  0xbfeffffffffffff8,
  0xbfeffffffffffffa,
  0xbff7fffffffffffc,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3ccfffffffffffff,
  0x3ccfffffffffffff,
  0x3ccfffffffffffff,
  0x3ccfffffffffffff,
  0x3ccfffffffffffff,
  0x3fe0000000000007,
  0x3fe0000000000008,
  0x3fe0000000000009,
  0x3ff0000000000003,
  0x3ff0000000000004,
  0x3ff0000000000005,
  0x3ff8000000000004,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3ccfffffffffffff,
  0x3ccfffffffffffff,
  0x3ccfffffffffffff,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x800091a2b3c4d5e6,
  0x801091a2b3c4d5e6,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x8001b4e81b4e81b3,
  0x801091a2b3c4d5e5,
  0x800091a2b3c4d5e7,
  0x800091a2b3c4d5e6,
  0x000f6e5d4c3b2a1a,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000091a2b3c4d5e7,
  0x000f6e5d4c3b2a19,
  0x800091a2b3c4d5e5,
  0x800091a2b3c4d5e6,
  0x801091a2b3c4d5e6,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x8001b4e81b4e81b4,
  0x801091a2b3c4d5e6,
  0x800091a2b3c4d5e8,
  0x800091a2b3c4d5e6,
  0x000f6e5d4c3b2a1a,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000091a2b3c4d5e6,
  0x000f6e5d4c3b2a18,
  0x800091a2b3c4d5e6,
  0x800091a2b3c4d5e7,
  0x801091a2b3c4d5e7,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x8001b4e81b4e81b4,
  0x801091a2b3c4d5e6,
  0x800091a2b3c4d5e8,
  0x800091a2b3c4d5e7,
  0x000f6e5d4c3b2a19,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000091a2b3c4d5e6,
  0x000f6e5d4c3b2a18,
  0x800091a2b3c4d5e6,
  0x800123456789abcd,
  0x801123456789abcd,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x8002468acf13579a,
  0x801123456789abcc,
  0x800123456789abce,
  0x800123456789abcd,
  0x000edcba98765433,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0000000000000000,
  0x000edcba98765432,
  0x800123456789abcc,
  0x800123456789abcd,
  0x801123456789abcd,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x8002468acf13579a,
  0x801123456789abcc,
  0x800123456789abce,
  0x800123456789abcd,
  0x000edcba98765433,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0000000000000000,
  0x000edcba98765432,
  0x800123456789abcc,
  0x800123456789abcd,
  0x801123456789abcd,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x8002468acf13579a,
  0x801123456789abcc,
  0x800123456789abce,
  0x800123456789abcd,
  0x000edcba98765433,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8000000000000000,
  0x000edcba98765432,
  0x800123456789abcc,
  0x8001b4e81b4e81b4,
  0x8011b4e81b4e81b4,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x8002d82d82d82d80,
  0x8011b4e81b4e81b2,
  0x8001b4e81b4e81b4,
  0x8001b4e81b4e81b4,
  0x000e4b17e4b17e4c,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x800091a2b3c4d5e6,
  0x000e4b17e4b17e4c,
  0x8001b4e81b4e81b2,
  0x800b60b60b60b602,
  0x801b60b60b60b602,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800c83fb72ea61cf,
  0x801b60b60b60b601,
  0x800b60b60b60b603,
  0x800b60b60b60b602,
  0x00049f49f49f49fe,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x800a3d70a3d70a35,
  0x00049f49f49f49fd,
  0x800b60b60b60b601,
  0xbfd23456789abccf,
  0xbfd23456789abccf,
  0xbfe91a2b3c4d5e67,
  0xbfe91a2b3c4d5e68,
  0xbfe91a2b3c4d5e69,
  0xbff48d159e26af33,
  0xbff48d159e26af34,
  0xbff48d159e26af35,
  0xbffc8d159e26af34,
  0xc02491a2b3c4d5e6,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfd23456789abccf,
  0xbfd23456789abccf,
  0xbfd23456789abccf,
  0xbfd23456789abccf,
  0xbfd23456789abccf,
  0x3fcb97530eca865f,
  0x3fcb97530eca8661,
  0x3fcb97530eca8665,
  0x3fe6e5d4c3b2a197,
  0x3fe6e5d4c3b2a198,
  0x3fe6e5d4c3b2a19a,
  0x3ff372ea61d950cc,
  0x40236e5d4c3b2a1a,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfd23456789abccf,
  0xbfd23456789abccf,
  0xbfd23456789abccf,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x000091a2b3c4d5e6,
  0x800f6e5d4c3b2a1a,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800091a2b3c4d5e7,
  0x800f6e5d4c3b2a19,
  0x000091a2b3c4d5e5,
  0x000091a2b3c4d5e6,
  0x001091a2b3c4d5e6,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0001b4e81b4e81b3,
  0x001091a2b3c4d5e5,
  0x000091a2b3c4d5e7,
  0x000091a2b3c4d5e6,
  0x800f6e5d4c3b2a1a,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800091a2b3c4d5e6,
  0x800f6e5d4c3b2a18,
  0x000091a2b3c4d5e6,
  0x000091a2b3c4d5e6,
  0x001091a2b3c4d5e6,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0001b4e81b4e81b4,
  0x001091a2b3c4d5e6,
  0x000091a2b3c4d5e8,
  0x000091a2b3c4d5e7,
  0x800f6e5d4c3b2a19,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800091a2b3c4d5e6,
  0x800f6e5d4c3b2a18,
  0x000091a2b3c4d5e6,
  0x000091a2b3c4d5e7,
  0x001091a2b3c4d5e7,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0001b4e81b4e81b4,
  0x001091a2b3c4d5e6,
  0x000091a2b3c4d5e8,
  0x000123456789abcd,
  0x800edcba98765433,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x8000000000000000,
  0x800edcba98765432,
  0x000123456789abcc,
  0x000123456789abcd,
  0x001123456789abcd,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0002468acf13579a,
  0x001123456789abcc,
  0x000123456789abce,
  0x000123456789abcd,
  0x800edcba98765433,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0000000000000000,
  0x800edcba98765432,
  0x000123456789abcc,
  0x000123456789abcd,
  0x001123456789abcd,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0002468acf13579a,
  0x001123456789abcc,
  0x000123456789abce,
  0x000123456789abcd,
  0x800edcba98765433,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0000000000000000,
  0x800edcba98765432,
  0x000123456789abcc,
  0x000123456789abcd,
  0x001123456789abcd,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0002468acf13579a,
  0x001123456789abcc,
  0x000123456789abce,
  0x0001b4e81b4e81b4,
  0x800e4b17e4b17e4c,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x000091a2b3c4d5e6,
  0x800e4b17e4b17e4c,
  0x0001b4e81b4e81b2,
  0x0001b4e81b4e81b4,
  0x0011b4e81b4e81b4,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0002d82d82d82d80,
  0x0011b4e81b4e81b2,
  0x0001b4e81b4e81b4,
  0x000b60b60b60b602,
  0x80049f49f49f49fe,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x000a3d70a3d70a35,
  0x80049f49f49f49fd,
  0x000b60b60b60b601,
  0x000b60b60b60b602,
  0x001b60b60b60b602,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000c83fb72ea61cf,
  0x001b60b60b60b601,
  0x000b60b60b60b603,
  0x3fd23456789abccf,
  0x3fd23456789abccf,
  0xbfcb97530eca865f,
  0xbfcb97530eca8661,
  0xbfcb97530eca8665,
  0xbfe6e5d4c3b2a197,
  0xbfe6e5d4c3b2a198,
  0xbfe6e5d4c3b2a19a,
  0xbff372ea61d950cc,
  0xc0236e5d4c3b2a1a,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fd23456789abccf,
  0x3fd23456789abccf,
  0x3fd23456789abccf,
  0x3fd23456789abccf,
  0x3fd23456789abccf,
  0x3fe91a2b3c4d5e67,
  0x3fe91a2b3c4d5e68,
  0x3fe91a2b3c4d5e69,
  0x3ff48d159e26af33,
  0x3ff48d159e26af34,
  0x3ff48d159e26af35,
  0x3ffc8d159e26af34,
  0x402491a2b3c4d5e6,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fd23456789abccf,
  0x3fd23456789abccf,
  0x3fd23456789abccf,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8007ffffffffffff,
  0x8017ffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800923456789abcc,
  0x8017fffffffffffe,
  0x8008000000000000,
  0x8007ffffffffffff,
  0x0008000000000001,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8006dcba98765432,
  0x0008000000000000,
  0x8007fffffffffffe,
  0x8008000000000000,
  0x8018000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800923456789abcc,
  0x8017fffffffffffe,
  0x8008000000000000,
  0x8008000000000000,
  0x0008000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8006dcba98765432,
  0x0008000000000000,
  0x8007fffffffffffe,
  0x8008000000000000,
  0x8018000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800923456789abcd,
  0x8017ffffffffffff,
  0x8008000000000001,
  0x8008000000000000,
  0x0008000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8006dcba98765433,
  0x0007ffffffffffff,
  0x8007ffffffffffff,
  0x800fffffffffffff,
  0x801fffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x801123456789abcc,
  0x801ffffffffffffe,
  0x8010000000000000,
  0x800fffffffffffff,
  0x0000000000000001,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x800edcba98765432,
  0x0000000000000000,
  0x800ffffffffffffe,
  0x800fffffffffffff,
  0x801fffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x801123456789abcc,
  0x801ffffffffffffe,
  0x8010000000000000,
  0x800fffffffffffff,
  0x0000000000000001,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x800edcba98765432,
  0x0000000000000000,
  0x800ffffffffffffe,
  0x8010000000000000,
  0x8020000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x801123456789abcd,
  0x801fffffffffffff,
  0x8010000000000001,
  0x8010000000000000,
  0x0000000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x800edcba98765433,
  0x8000000000000001,
  0x800fffffffffffff,
  0x8017fffffffffffe,
  0x8023ffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x801923456789abcc,
  0x8023ffffffffffff,
  0x8018000000000000,
  0x8017fffffffffffe,
  0x8007fffffffffffe,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8016dcba98765432,
  0x8008000000000000,
  0x8017fffffffffffe,
  0x8043ffffffffffff,
  0x8045ffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x80442468acf13578,
  0x8045ffffffffffff,
  0x8043ffffffffffff,
  0x8043ffffffffffff,
  0x8041ffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8043db97530eca85,
  0x8041ffffffffffff,
  0x8043ffffffffffff,
  0xc00ffffffffffffd,
  0xc00ffffffffffffd,
  0xc011fffffffffffe,
  0xc011ffffffffffff,
  0xc011ffffffffffff,
  0xc013fffffffffffe,
  0xc013ffffffffffff,
  0xc013ffffffffffff,
  0xc015ffffffffffff,
  0xc02bffffffffffff,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc00ffffffffffffd,
  0xc00ffffffffffffd,
  0xc00ffffffffffffd,
  0xc00ffffffffffffd,
  0xc00ffffffffffffd,
  0xc00bfffffffffffd,
  0xc00bfffffffffffd,
  0xc00bfffffffffffd,
  0xc007fffffffffffd,
  0xc007fffffffffffd,
  0xc007fffffffffffd,
  0xc003fffffffffffd,
  0x4018000000000001,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc00ffffffffffffd,
  0xc00ffffffffffffd,
  0xc00ffffffffffffd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0007ffffffffffff,
  0x8008000000000001,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0006dcba98765432,
  0x8008000000000000,
  0x0007fffffffffffe,
  0x0007ffffffffffff,
  0x0017ffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000923456789abcc,
  0x0017fffffffffffe,
  0x0008000000000000,
  0x0008000000000000,
  0x8008000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0006dcba98765432,
  0x8008000000000000,
  0x0007fffffffffffe,
  0x0008000000000000,
  0x0018000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000923456789abcc,
  0x0017fffffffffffe,
  0x0008000000000000,
  0x0008000000000000,
  0x8008000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0006dcba98765433,
  0x8007ffffffffffff,
  0x0007ffffffffffff,
  0x0008000000000000,
  0x0018000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000923456789abcd,
  0x0017ffffffffffff,
  0x0008000000000001,
  0x000fffffffffffff,
  0x8000000000000001,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x000edcba98765432,
  0x8000000000000000,
  0x000ffffffffffffe,
  0x000fffffffffffff,
  0x001fffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x001123456789abcc,
  0x001ffffffffffffe,
  0x0010000000000000,
  0x000fffffffffffff,
  0x8000000000000001,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x000edcba98765432,
  0x0000000000000000,
  0x000ffffffffffffe,
  0x000fffffffffffff,
  0x001fffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x001123456789abcc,
  0x001ffffffffffffe,
  0x0010000000000000,
  0x0010000000000000,
  0x8000000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x000edcba98765433,
  0x0000000000000001,
  0x000fffffffffffff,
  0x0010000000000000,
  0x0020000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x001123456789abcd,
  0x001fffffffffffff,
  0x0010000000000001,
  0x0017fffffffffffe,
  0x0007fffffffffffe,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0016dcba98765432,
  0x0008000000000000,
  0x0017fffffffffffe,
  0x0017fffffffffffe,
  0x0023ffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x001923456789abcc,
  0x0023ffffffffffff,
  0x0018000000000000,
  0x0043ffffffffffff,
  0x0041ffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0043db97530eca85,
  0x0041ffffffffffff,
  0x0043ffffffffffff,
  0x0043ffffffffffff,
  0x0045ffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x00442468acf13578,
  0x0045ffffffffffff,
  0x0043ffffffffffff,
  0x400ffffffffffffd,
  0x400ffffffffffffd,
  0x400bfffffffffffd,
  0x400bfffffffffffd,
  0x400bfffffffffffd,
  0x4007fffffffffffd,
  0x4007fffffffffffd,
  0x4007fffffffffffd,
  0x4003fffffffffffd,
  0xc018000000000001,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x400ffffffffffffd,
  0x400ffffffffffffd,
  0x400ffffffffffffd,
  0x400ffffffffffffd,
  0x400ffffffffffffd,
  0x4011fffffffffffe,
  0x4011ffffffffffff,
  0x4011ffffffffffff,
  0x4013fffffffffffe,
  0x4013ffffffffffff,
  0x4013ffffffffffff,
  0x4015ffffffffffff,
  0x402bffffffffffff,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x400ffffffffffffd,
  0x400ffffffffffffd,
  0x400ffffffffffffd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abce,
  0x8010000000000000,
  0x8000000000000002,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcc,
  0x000ffffffffffffe,
  0x0000000000000000,
  0x8000000000000001,
  0x8010000000000001,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abce,
  0x8010000000000000,
  0x8000000000000002,
  0x8000000000000001,
  0x000fffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcc,
  0x000ffffffffffffe,
  0x0000000000000000,
  0x8000000000000001,
  0x8010000000000001,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abce,
  0x8010000000000000,
  0x8000000000000002,
  0x8000000000000001,
  0x000fffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcc,
  0x000ffffffffffffe,
  0x0000000000000000,
  0x8000000000000001,
  0x8010000000000001,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abce,
  0x8010000000000000,
  0x8000000000000002,
  0x8000000000000001,
  0x000fffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcc,
  0x000ffffffffffffe,
  0x0000000000000000,
  0x8000000000000001,
  0x8010000000000001,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abce,
  0x8010000000000000,
  0x8000000000000002,
  0x8000000000000001,
  0x000fffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcc,
  0x000ffffffffffffe,
  0x8000000000000000,
  0x8000000000000002,
  0x8010000000000002,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abce,
  0x8010000000000000,
  0x8000000000000002,
  0x8000000000000002,
  0x000ffffffffffffe,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcc,
  0x000ffffffffffffe,
  0x8000000000000000,
  0x800000000000000a,
  0x801000000000000a,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abd7,
  0x8010000000000009,
  0x800000000000000b,
  0x800000000000000a,
  0x000ffffffffffff6,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abc3,
  0x000ffffffffffff5,
  0x8000000000000009,
  0xbccfffffffffffff,
  0xbccfffffffffffff,
  0xbfe0000000000007,
  0xbfe0000000000008,
  0xbfe0000000000009,
  0xbff0000000000003,
  0xbff0000000000004,
  0xbff0000000000005,
  0xbff8000000000004,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbccfffffffffffff,
  0xbccfffffffffffff,
  0xbccfffffffffffff,
  0xbccfffffffffffff,
  0xbccfffffffffffff,
  0x3fdfffffffffffef,
  0x3fdffffffffffff0,
  0x3fdffffffffffff2,
  0x3feffffffffffff7,
  0x3feffffffffffff8,
  0x3feffffffffffffa,
  0x3ff7fffffffffffc,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbccfffffffffffff,
  0xbccfffffffffffff,
  0xbccfffffffffffff,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcc,
  0x800ffffffffffffe,
  0x8000000000000000,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abce,
  0x0010000000000000,
  0x0000000000000002,
  0x0000000000000001,
  0x800fffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcc,
  0x800ffffffffffffe,
  0x8000000000000000,
  0x0000000000000001,
  0x0010000000000001,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abce,
  0x0010000000000000,
  0x0000000000000002,
  0x0000000000000001,
  0x800fffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcc,
  0x800ffffffffffffe,
  0x8000000000000000,
  0x0000000000000001,
  0x0010000000000001,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abce,
  0x0010000000000000,
  0x0000000000000002,
  0x0000000000000001,
  0x800fffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcc,
  0x800ffffffffffffe,
  0x0000000000000000,
  0x0000000000000001,
  0x0010000000000001,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abce,
  0x0010000000000000,
  0x0000000000000002,
  0x0000000000000001,
  0x800fffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcc,
  0x800ffffffffffffe,
  0x0000000000000000,
  0x0000000000000001,
  0x0010000000000001,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abce,
  0x0010000000000000,
  0x0000000000000002,
  0x0000000000000002,
  0x800ffffffffffffe,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcc,
  0x800ffffffffffffe,
  0x0000000000000000,
  0x0000000000000002,
  0x0010000000000002,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abce,
  0x0010000000000000,
  0x0000000000000002,
  0x000000000000000a,
  0x800ffffffffffff6,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abc3,
  0x800ffffffffffff5,
  0x0000000000000009,
  0x000000000000000a,
  0x001000000000000a,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abd7,
  0x0010000000000009,
  0x000000000000000b,
  0x3ccfffffffffffff,
  0x3ccfffffffffffff,
  0xbfdfffffffffffef,
  0xbfdffffffffffff0,
  0xbfdffffffffffff2,
  0xbfeffffffffffff7,
  0xbfeffffffffffff8,
  0xbfeffffffffffffa,
  0xbff7fffffffffffc,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3ccfffffffffffff,
  0x3ccfffffffffffff,
  0x3ccfffffffffffff,
  0x3ccfffffffffffff,
  0x3ccfffffffffffff,
  0x3fe0000000000007,
  0x3fe0000000000008,
  0x3fe0000000000009,
  0x3ff0000000000003,
  0x3ff0000000000004,
  0x3ff0000000000005,
  0x3ff8000000000004,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3ccfffffffffffff,
  0x3ccfffffffffffff,
  0x3ccfffffffffffff,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0008000000000000,
  0x8008000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0006dcba98765433,
  0x8007ffffffffffff,
  0x0007ffffffffffff,
  0x0008000000000000,
  0x0018000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000923456789abcd,
  0x0017ffffffffffff,
  0x0008000000000001,
  0x0008000000000000,
  0x8008000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0006dcba98765433,
  0x8007ffffffffffff,
  0x0007ffffffffffff,
  0x0008000000000000,
  0x0018000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000923456789abcd,
  0x0017ffffffffffff,
  0x0008000000000001,
  0x0008000000000000,
  0x8008000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0006dcba98765434,
  0x8007fffffffffffe,
  0x0008000000000000,
  0x0008000000000000,
  0x0018000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000923456789abce,
  0x0018000000000000,
  0x0008000000000002,
  0x0010000000000000,
  0x8000000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x000edcba98765432,
  0x0000000000000000,
  0x000ffffffffffffe,
  0x0010000000000000,
  0x0020000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x001123456789abcc,
  0x001ffffffffffffe,
  0x0010000000000000,
  0x0010000000000000,
  0x0000000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x000edcba98765433,
  0x0000000000000001,
  0x000fffffffffffff,
  0x0010000000000000,
  0x0020000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x001123456789abcd,
  0x001fffffffffffff,
  0x0010000000000001,
  0x0010000000000001,
  0x0000000000000001,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x000edcba98765434,
  0x0000000000000002,
  0x0010000000000000,
  0x0010000000000001,
  0x0020000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x001123456789abce,
  0x0020000000000000,
  0x0010000000000002,
  0x0018000000000000,
  0x0008000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0016dcba98765433,
  0x0008000000000001,
  0x0017ffffffffffff,
  0x0018000000000000,
  0x0024000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x001923456789abcd,
  0x0024000000000000,
  0x0018000000000001,
  0x0044000000000000,
  0x0042000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0043db97530eca86,
  0x0042000000000000,
  0x0044000000000000,
  0x0044000000000000,
  0x0046000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x00442468acf1357a,
  0x0046000000000000,
  0x0044000000000000,
  0x400fffffffffffff,
  0x400fffffffffffff,
  0x400bffffffffffff,
  0x400bffffffffffff,
  0x400bffffffffffff,
  0x4007ffffffffffff,
  0x4007ffffffffffff,
  0x4007fffffffffffe,
  0x4003ffffffffffff,
  0xc018000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x400fffffffffffff,
  0x400fffffffffffff,
  0x400fffffffffffff,
  0x400fffffffffffff,
  0x400fffffffffffff,
  0x4011ffffffffffff,
  0x4012000000000000,
  0x4012000000000000,
  0x4013ffffffffffff,
  0x4014000000000000,
  0x4014000000000000,
  0x4016000000000000,
  0x402c000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x400fffffffffffff,
  0x400fffffffffffff,
  0x400fffffffffffff,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8008000000000000,
  0x8018000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800923456789abcd,
  0x8017ffffffffffff,
  0x8008000000000001,
  0x8008000000000000,
  0x0008000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8006dcba98765433,
  0x0007ffffffffffff,
  0x8007ffffffffffff,
  0x8008000000000000,
  0x8018000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800923456789abcd,
  0x8017ffffffffffff,
  0x8008000000000001,
  0x8008000000000000,
  0x0008000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8006dcba98765433,
  0x0007ffffffffffff,
  0x8007ffffffffffff,
  0x8008000000000000,
  0x8018000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800923456789abce,
  0x8018000000000000,
  0x8008000000000002,
  0x8008000000000000,
  0x0008000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8006dcba98765434,
  0x0007fffffffffffe,
  0x8008000000000000,
  0x8010000000000000,
  0x8020000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x801123456789abcc,
  0x801ffffffffffffe,
  0x8010000000000000,
  0x8010000000000000,
  0x0000000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x800edcba98765432,
  0x8000000000000000,
  0x800ffffffffffffe,
  0x8010000000000000,
  0x8020000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x801123456789abcd,
  0x801fffffffffffff,
  0x8010000000000001,
  0x8010000000000000,
  0x0000000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x800edcba98765433,
  0x8000000000000001,
  0x800fffffffffffff,
  0x8010000000000001,
  0x8020000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x801123456789abce,
  0x8020000000000000,
  0x8010000000000002,
  0x8010000000000001,
  0x8000000000000001,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x800edcba98765434,
  0x8000000000000002,
  0x8010000000000000,
  0x8018000000000000,
  0x8024000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x801923456789abcd,
  0x8024000000000000,
  0x8018000000000001,
  0x8018000000000000,
  0x8008000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8016dcba98765433,
  0x8008000000000001,
  0x8017ffffffffffff,
  0x8044000000000000,
  0x8046000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x80442468acf1357a,
  0x8046000000000000,
  0x8044000000000000,
  0x8044000000000000,
  0x8042000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8043db97530eca86,
  0x8042000000000000,
  0x8044000000000000,
  0xc00fffffffffffff,
  0xc00fffffffffffff,
  0xc011ffffffffffff,
  0xc012000000000000,
  0xc012000000000000,
  0xc013ffffffffffff,
  0xc014000000000000,
  0xc014000000000000,
  0xc016000000000000,
  0xc02c000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc00fffffffffffff,
  0xc00fffffffffffff,
  0xc00fffffffffffff,
  0xc00fffffffffffff,
  0xc00fffffffffffff,
  0xc00bffffffffffff,
  0xc00bffffffffffff,
  0xc00bffffffffffff,
  0xc007ffffffffffff,
  0xc007ffffffffffff,
  0xc007fffffffffffe,
  0xc003ffffffffffff,
  0x4018000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc00fffffffffffff,
  0xc00fffffffffffff,
  0xc00fffffffffffff,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0008000000000000,
  0x8008000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0006dcba98765433,
  0x8007ffffffffffff,
  0x0007ffffffffffff,
  0x0008000000000000,
  0x0018000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000923456789abcd,
  0x0017ffffffffffff,
  0x0008000000000001,
  0x3fcffffffffffffe,
  0x3fcffffffffffffe,
  0xbfd0000000000000,
  0xbfd0000000000001,
  0xbfd0000000000003,
  0xbfe7ffffffffffff,
  0xbfe8000000000000,
  0xbfe8000000000002,
  0xbff4000000000000,
  0xc023800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fcffffffffffffe,
  0x3fcffffffffffffe,
  0x3fcffffffffffffe,
  0x3fcffffffffffffe,
  0x3fcffffffffffffe,
  0x3fe7ffffffffffff,
  0x3fe8000000000000,
  0x3fe8000000000001,
  0x3ff3ffffffffffff,
  0x3ff4000000000000,
  0x3ff4000000000001,
  0x3ffc000000000000,
  0x4024800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fcffffffffffffe,
  0x3fcffffffffffffe,
  0x3fcffffffffffffe,
  0x3fcfffffffffffff,
  0x3fcfffffffffffff,
  0xbfcfffffffffffff,
  0xbfd0000000000000,
  0xbfd0000000000002,
  0xbfe7ffffffffffff,
  0xbfe8000000000000,
  0xbfe8000000000002,
  0xbff4000000000000,
  0xc023800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fcfffffffffffff,
  0x3fcfffffffffffff,
  0x3fcfffffffffffff,
  0x3fcfffffffffffff,
  0x3fcfffffffffffff,
  0x3fe7ffffffffffff,
  0x3fe8000000000000,
  0x3fe8000000000001,
  0x3ff3ffffffffffff,
  0x3ff4000000000000,
  0x3ff4000000000001,
  0x3ffc000000000000,
  0x4024800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fcfffffffffffff,
  0x3fcfffffffffffff,
  0x3fcfffffffffffff,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0xbfcffffffffffffd,
  0xbfcfffffffffffff,
  0xbfd0000000000002,
  0xbfe7ffffffffffff,
  0xbfe8000000000000,
  0xbfe8000000000002,
  0xbff4000000000000,
  0xc023800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3fe8000000000001,
  0x3ff4000000000000,
  0x3ff4000000000000,
  0x3ff4000000000001,
  0x3ffc000000000000,
  0x4024800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fdffffffffffffe,
  0x3fdffffffffffffe,
  0xbc8fffffffffffff,
  0xbca0000000000000,
  0xbcb0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000003,
  0xbff0000000000000,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fdffffffffffffe,
  0x3fdffffffffffffe,
  0x3fdffffffffffffe,
  0x3fdffffffffffffe,
  0x3fdffffffffffffe,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff7ffffffffffff,
  0x3ff8000000000000,
  0x3ff8000000000001,
  0x4000000000000000,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fdffffffffffffe,
  0x3fdffffffffffffe,
  0x3fdffffffffffffe,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x0000000000000000,
  0xbc90000000000000,
  0xbca8000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000002,
  0xbff0000000000000,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff7ffffffffffff,
  0x3ff8000000000000,
  0x3ff8000000000001,
  0x4000000000000000,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3c9fffffffffffff,
  0x3c8ffffffffffffe,
  0xbc90000000000001,
  0xbfdffffffffffffd,
  0xbfdfffffffffffff,
  0xbfe0000000000002,
  0xbff0000000000000,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000001,
  0x4000000000000000,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe7ffffffffffff,
  0x3fe7ffffffffffff,
  0x3fcfffffffffffff,
  0x3fcffffffffffffd,
  0x3fcffffffffffff9,
  0xbfcfffffffffffff,
  0xbfd0000000000002,
  0xbfd0000000000006,
  0xbfe8000000000001,
  0xc022800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe7ffffffffffff,
  0x3fe7ffffffffffff,
  0x3fe7ffffffffffff,
  0x3fe7ffffffffffff,
  0x3fe7ffffffffffff,
  0x3ff3ffffffffffff,
  0x3ff4000000000000,
  0x3ff4000000000000,
  0x3ffbffffffffffff,
  0x3ffc000000000000,
  0x3ffc000000000001,
  0x4002000000000000,
  0x4025800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe7ffffffffffff,
  0x3fe7ffffffffffff,
  0x3fe7ffffffffffff,
  0x4013ffffffffffff,
  0x4013ffffffffffff,
  0x4011ffffffffffff,
  0x4011ffffffffffff,
  0x4011ffffffffffff,
  0x400fffffffffffff,
  0x400fffffffffffff,
  0x400ffffffffffffe,
  0x400bffffffffffff,
  0xc014000000000001,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x4013ffffffffffff,
  0x4013ffffffffffff,
  0x4013ffffffffffff,
  0x4013ffffffffffff,
  0x4013ffffffffffff,
  0x4015ffffffffffff,
  0x4015ffffffffffff,
  0x4016000000000000,
  0x4017ffffffffffff,
  0x4017ffffffffffff,
  0x4018000000000000,
  0x4019ffffffffffff,
  0x402e000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x4013ffffffffffff,
  0x4013ffffffffffff,
  0x4013ffffffffffff,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0xffe0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x000091a2b3c4d5e6,
  0x800f6e5d4c3b2a1a,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800091a2b3c4d5e7,
  0x800f6e5d4c3b2a19,
  0x000091a2b3c4d5e5,
  0x000091a2b3c4d5e6,
  0x001091a2b3c4d5e6,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0001b4e81b4e81b3,
  0x001091a2b3c4d5e5,
  0x000091a2b3c4d5e7,
  0x0007ffffffffffff,
  0x8008000000000001,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0006dcba98765432,
  0x8008000000000000,
  0x0007fffffffffffe,
  0x0007ffffffffffff,
  0x0017ffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000923456789abcc,
  0x0017fffffffffffe,
  0x0008000000000000,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8008000000000000,
  0x8018000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800923456789abcd,
  0x8017ffffffffffff,
  0x8008000000000001,
  0x8008000000000000,
  0x0008000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8006dcba98765433,
  0x0007ffffffffffff,
  0x8007ffffffffffff,
  0xbfcffffffffffffe,
  0xbfcffffffffffffe,
  0xbfe7ffffffffffff,
  0xbfe8000000000000,
  0xbfe8000000000001,
  0xbff3ffffffffffff,
  0xbff4000000000000,
  0xbff4000000000001,
  0xbffc000000000000,
  0xc024800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfcffffffffffffe,
  0xbfcffffffffffffe,
  0xbfcffffffffffffe,
  0xbfcffffffffffffe,
  0xbfcffffffffffffe,
  0x3fd0000000000000,
  0x3fd0000000000001,
  0x3fd0000000000003,
  0x3fe7ffffffffffff,
  0x3fe8000000000000,
  0x3fe8000000000002,
  0x3ff4000000000000,
  0x4023800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfcffffffffffffe,
  0xbfcffffffffffffe,
  0xbfcffffffffffffe,
  0xbfcfffffffffffff,
  0xbfcfffffffffffff,
  0xbfe7ffffffffffff,
  0xbfe8000000000000,
  0xbfe8000000000001,
  0xbff3ffffffffffff,
  0xbff4000000000000,
  0xbff4000000000001,
  0xbffc000000000000,
  0xc024800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfcfffffffffffff,
  0xbfcfffffffffffff,
  0xbfcfffffffffffff,
  0xbfcfffffffffffff,
  0xbfcfffffffffffff,
  0x3fcfffffffffffff,
  0x3fd0000000000000,
  0x3fd0000000000002,
  0x3fe7ffffffffffff,
  0x3fe8000000000000,
  0x3fe8000000000002,
  0x3ff4000000000000,
  0x4023800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfcfffffffffffff,
  0xbfcfffffffffffff,
  0xbfcfffffffffffff,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbfe8000000000001,
  0xbff4000000000000,
  0xbff4000000000000,
  0xbff4000000000001,
  0xbffc000000000000,
  0xc024800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0x3fcffffffffffffd,
  0x3fcfffffffffffff,
  0x3fd0000000000002,
  0x3fe7ffffffffffff,
  0x3fe8000000000000,
  0x3fe8000000000002,
  0x3ff4000000000000,
  0x4023800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfdffffffffffffe,
  0xbfdffffffffffffe,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff7ffffffffffff,
  0xbff8000000000000,
  0xbff8000000000001,
  0xc000000000000000,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfdffffffffffffe,
  0xbfdffffffffffffe,
  0xbfdffffffffffffe,
  0xbfdffffffffffffe,
  0xbfdffffffffffffe,
  0x3c8fffffffffffff,
  0x3ca0000000000000,
  0x3cb0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000003,
  0x3ff0000000000000,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfdffffffffffffe,
  0xbfdffffffffffffe,
  0xbfdffffffffffffe,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff7ffffffffffff,
  0xbff8000000000000,
  0xbff8000000000001,
  0xc000000000000000,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0x0000000000000000,
  0x3c90000000000000,
  0x3ca8000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000002,
  0x3ff0000000000000,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000001,
  0xc000000000000000,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbc9fffffffffffff,
  0xbc8ffffffffffffe,
  0x3c90000000000001,
  0x3fdffffffffffffd,
  0x3fdfffffffffffff,
  0x3fe0000000000002,
  0x3ff0000000000000,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe7ffffffffffff,
  0xbfe7ffffffffffff,
  0xbff3ffffffffffff,
  0xbff4000000000000,
  0xbff4000000000000,
  0xbffbffffffffffff,
  0xbffc000000000000,
  0xbffc000000000001,
  0xc002000000000000,
  0xc025800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe7ffffffffffff,
  0xbfe7ffffffffffff,
  0xbfe7ffffffffffff,
  0xbfe7ffffffffffff,
  0xbfe7ffffffffffff,
  0xbfcfffffffffffff,
  0xbfcffffffffffffd,
  0xbfcffffffffffff9,
  0x3fcfffffffffffff,
  0x3fd0000000000002,
  0x3fd0000000000006,
  0x3fe8000000000001,
  0x4022800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe7ffffffffffff,
  0xbfe7ffffffffffff,
  0xbfe7ffffffffffff,
  0xc013ffffffffffff,
  0xc013ffffffffffff,
  0xc015ffffffffffff,
  0xc015ffffffffffff,
  0xc016000000000000,
  0xc017ffffffffffff,
  0xc017ffffffffffff,
  0xc018000000000000,
  0xc019ffffffffffff,
  0xc02e000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc013ffffffffffff,
  0xc013ffffffffffff,
  0xc013ffffffffffff,
  0xc013ffffffffffff,
  0xc013ffffffffffff,
  0xc011ffffffffffff,
  0xc011ffffffffffff,
  0xc011ffffffffffff,
  0xc00fffffffffffff,
  0xc00fffffffffffff,
  0xc00ffffffffffffe,
  0xc00bffffffffffff,
  0x4014000000000001,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc013ffffffffffff,
  0xc013ffffffffffff,
  0xc013ffffffffffff,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0x7fe0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x800091a2b3c4d5e6,
  0x801091a2b3c4d5e6,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x8001b4e81b4e81b3,
  0x801091a2b3c4d5e5,
  0x800091a2b3c4d5e7,
  0x800091a2b3c4d5e6,
  0x000f6e5d4c3b2a1a,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000091a2b3c4d5e7,
  0x000f6e5d4c3b2a19,
  0x800091a2b3c4d5e5,
  0x8007ffffffffffff,
  0x8017ffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800923456789abcc,
  0x8017fffffffffffe,
  0x8008000000000000,
  0x8007ffffffffffff,
  0x0008000000000001,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8006dcba98765432,
  0x0008000000000000,
  0x8007fffffffffffe,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0008000000000000,
  0x8008000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0006dcba98765433,
  0x8007ffffffffffff,
  0x0007ffffffffffff,
  0x0008000000000000,
  0x0018000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000923456789abcd,
  0x0017ffffffffffff,
  0x0008000000000001,
  0x3fcfffffffffffff,
  0x3fcfffffffffffff,
  0xbfcfffffffffffff,
  0xbfd0000000000000,
  0xbfd0000000000002,
  0xbfe7ffffffffffff,
  0xbfe8000000000000,
  0xbfe8000000000002,
  0xbff4000000000000,
  0xc023800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fcfffffffffffff,
  0x3fcfffffffffffff,
  0x3fcfffffffffffff,
  0x3fcfffffffffffff,
  0x3fcfffffffffffff,
  0x3fe7ffffffffffff,
  0x3fe8000000000000,
  0x3fe8000000000001,
  0x3ff3ffffffffffff,
  0x3ff4000000000000,
  0x3ff4000000000001,
  0x3ffc000000000000,
  0x4024800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fcfffffffffffff,
  0x3fcfffffffffffff,
  0x3fcfffffffffffff,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0xbfcffffffffffffe,
  0xbfd0000000000000,
  0xbfd0000000000002,
  0xbfe7ffffffffffff,
  0xbfe8000000000000,
  0xbfe8000000000002,
  0xbff4000000000000,
  0xc023800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3fe8000000000001,
  0x3ff4000000000000,
  0x3ff4000000000000,
  0x3ff4000000000001,
  0x3ffc000000000000,
  0x4024800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000001,
  0x3fd0000000000001,
  0xbfcffffffffffffc,
  0xbfcffffffffffffe,
  0xbfd0000000000001,
  0xbfe7fffffffffffe,
  0xbfe8000000000000,
  0xbfe8000000000002,
  0xbff4000000000000,
  0xc023800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fd0000000000001,
  0x3fd0000000000001,
  0x3fd0000000000001,
  0x3fd0000000000001,
  0x3fd0000000000001,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3fe8000000000002,
  0x3ff4000000000000,
  0x3ff4000000000000,
  0x3ff4000000000001,
  0x3ffc000000000000,
  0x4024800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fd0000000000001,
  0x3fd0000000000001,
  0x3fd0000000000001,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x0000000000000000,
  0xbc90000000000000,
  0xbca8000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000002,
  0xbff0000000000000,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff7ffffffffffff,
  0x3ff8000000000000,
  0x3ff8000000000001,
  0x4000000000000000,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3c90000000000000,
  0x0000000000000000,
  0xbca0000000000000,
  0xbfdffffffffffffe,
  0xbfe0000000000000,
  0xbfe0000000000002,
  0xbff0000000000000,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000001,
  0x4000000000000000,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3ca8000000000000,
  0x3ca0000000000000,
  0x0000000000000000,
  0xbfdffffffffffffc,
  0xbfdffffffffffffe,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000002,
  0x4000000000000000,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3fd0000000000001,
  0x3fd0000000000000,
  0x3fcffffffffffffc,
  0xbfcffffffffffffc,
  0xbfd0000000000000,
  0xbfd0000000000004,
  0xbfe8000000000000,
  0xc022800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3ff4000000000000,
  0x3ff4000000000000,
  0x3ff4000000000000,
  0x3ffc000000000000,
  0x3ffc000000000000,
  0x3ffc000000000001,
  0x4002000000000000,
  0x4025800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x4014000000000000,
  0x4014000000000000,
  0x4012000000000000,
  0x4012000000000000,
  0x4012000000000000,
  0x4010000000000000,
  0x4010000000000000,
  0x4010000000000000,
  0x400c000000000000,
  0xc014000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x4014000000000000,
  0x4014000000000000,
  0x4014000000000000,
  0x4014000000000000,
  0x4014000000000000,
  0x4016000000000000,
  0x4016000000000000,
  0x4016000000000000,
  0x4018000000000000,
  0x4018000000000000,
  0x4018000000000000,
  0x401a000000000000,
  0x402e000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x4014000000000000,
  0x4014000000000000,
  0x4014000000000000,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0xffdfffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x000091a2b3c4d5e6,
  0x800f6e5d4c3b2a1a,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800091a2b3c4d5e6,
  0x800f6e5d4c3b2a18,
  0x000091a2b3c4d5e6,
  0x000091a2b3c4d5e6,
  0x001091a2b3c4d5e6,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0001b4e81b4e81b4,
  0x001091a2b3c4d5e6,
  0x000091a2b3c4d5e8,
  0x0008000000000000,
  0x8008000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0006dcba98765432,
  0x8008000000000000,
  0x0007fffffffffffe,
  0x0008000000000000,
  0x0018000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000923456789abcc,
  0x0017fffffffffffe,
  0x0008000000000000,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcc,
  0x800ffffffffffffe,
  0x8000000000000000,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abce,
  0x0010000000000000,
  0x0000000000000002,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8008000000000000,
  0x8018000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800923456789abcd,
  0x8017ffffffffffff,
  0x8008000000000001,
  0x8008000000000000,
  0x0008000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8006dcba98765433,
  0x0007ffffffffffff,
  0x8007ffffffffffff,
  0xbfcfffffffffffff,
  0xbfcfffffffffffff,
  0xbfe7ffffffffffff,
  0xbfe8000000000000,
  0xbfe8000000000001,
  0xbff3ffffffffffff,
  0xbff4000000000000,
  0xbff4000000000001,
  0xbffc000000000000,
  0xc024800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfcfffffffffffff,
  0xbfcfffffffffffff,
  0xbfcfffffffffffff,
  0xbfcfffffffffffff,
  0xbfcfffffffffffff,
  0x3fcfffffffffffff,
  0x3fd0000000000000,
  0x3fd0000000000002,
  0x3fe7ffffffffffff,
  0x3fe8000000000000,
  0x3fe8000000000002,
  0x3ff4000000000000,
  0x4023800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfcfffffffffffff,
  0xbfcfffffffffffff,
  0xbfcfffffffffffff,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbfe8000000000001,
  0xbff4000000000000,
  0xbff4000000000000,
  0xbff4000000000001,
  0xbffc000000000000,
  0xc024800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0x3fcffffffffffffe,
  0x3fd0000000000000,
  0x3fd0000000000002,
  0x3fe7ffffffffffff,
  0x3fe8000000000000,
  0x3fe8000000000002,
  0x3ff4000000000000,
  0x4023800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000001,
  0xbfd0000000000001,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbfe8000000000002,
  0xbff4000000000000,
  0xbff4000000000000,
  0xbff4000000000001,
  0xbffc000000000000,
  0xc024800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfd0000000000001,
  0xbfd0000000000001,
  0xbfd0000000000001,
  0xbfd0000000000001,
  0xbfd0000000000001,
  0x3fcffffffffffffc,
  0x3fcffffffffffffe,
  0x3fd0000000000001,
  0x3fe7fffffffffffe,
  0x3fe8000000000000,
  0x3fe8000000000002,
  0x3ff4000000000000,
  0x4023800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfd0000000000001,
  0xbfd0000000000001,
  0xbfd0000000000001,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff7ffffffffffff,
  0xbff8000000000000,
  0xbff8000000000001,
  0xc000000000000000,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0x0000000000000000,
  0x3c90000000000000,
  0x3ca8000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000002,
  0x3ff0000000000000,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000001,
  0xc000000000000000,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbc90000000000000,
  0x0000000000000000,
  0x3ca0000000000000,
  0x3fdffffffffffffe,
  0x3fe0000000000000,
  0x3fe0000000000002,
  0x3ff0000000000000,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000002,
  0xc000000000000000,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbca8000000000000,
  0xbca0000000000000,
  0x0000000000000000,
  0x3fdffffffffffffc,
  0x3fdffffffffffffe,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbff4000000000000,
  0xbff4000000000000,
  0xbff4000000000000,
  0xbffc000000000000,
  0xbffc000000000000,
  0xbffc000000000001,
  0xc002000000000000,
  0xc025800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbfd0000000000001,
  0xbfd0000000000000,
  0xbfcffffffffffffc,
  0x3fcffffffffffffc,
  0x3fd0000000000000,
  0x3fd0000000000004,
  0x3fe8000000000000,
  0x4022800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xc014000000000000,
  0xc014000000000000,
  0xc016000000000000,
  0xc016000000000000,
  0xc016000000000000,
  0xc018000000000000,
  0xc018000000000000,
  0xc018000000000000,
  0xc01a000000000000,
  0xc02e000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc014000000000000,
  0xc014000000000000,
  0xc014000000000000,
  0xc014000000000000,
  0xc014000000000000,
  0xc012000000000000,
  0xc012000000000000,
  0xc012000000000000,
  0xc010000000000000,
  0xc010000000000000,
  0xc010000000000000,
  0xc00c000000000000,
  0x4014000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc014000000000000,
  0xc014000000000000,
  0xc014000000000000,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0x7fdfffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x800091a2b3c4d5e6,
  0x801091a2b3c4d5e6,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x8001b4e81b4e81b4,
  0x801091a2b3c4d5e6,
  0x800091a2b3c4d5e8,
  0x800091a2b3c4d5e6,
  0x000f6e5d4c3b2a1a,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000091a2b3c4d5e6,
  0x000f6e5d4c3b2a18,
  0x800091a2b3c4d5e6,
  0x8008000000000000,
  0x8018000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800923456789abcc,
  0x8017fffffffffffe,
  0x8008000000000000,
  0x8008000000000000,
  0x0008000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8006dcba98765432,
  0x0008000000000000,
  0x8007fffffffffffe,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abce,
  0x8010000000000000,
  0x8000000000000002,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcc,
  0x000ffffffffffffe,
  0x0000000000000000,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0008000000000000,
  0x8008000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0006dcba98765434,
  0x8007fffffffffffe,
  0x0008000000000000,
  0x0008000000000000,
  0x0018000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000923456789abce,
  0x0018000000000000,
  0x0008000000000002,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0xbfcffffffffffffd,
  0xbfcfffffffffffff,
  0xbfd0000000000002,
  0xbfe7ffffffffffff,
  0xbfe8000000000000,
  0xbfe8000000000002,
  0xbff4000000000000,
  0xc023800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3fe8000000000001,
  0x3ff4000000000000,
  0x3ff4000000000000,
  0x3ff4000000000001,
  0x3ffc000000000000,
  0x4024800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000001,
  0x3fd0000000000001,
  0xbfcffffffffffffc,
  0xbfcffffffffffffe,
  0xbfd0000000000001,
  0xbfe7fffffffffffe,
  0xbfe8000000000000,
  0xbfe8000000000002,
  0xbff4000000000000,
  0xc023800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fd0000000000001,
  0x3fd0000000000001,
  0x3fd0000000000001,
  0x3fd0000000000001,
  0x3fd0000000000001,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3fe8000000000002,
  0x3ff4000000000000,
  0x3ff4000000000000,
  0x3ff4000000000001,
  0x3ffc000000000000,
  0x4024800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fd0000000000001,
  0x3fd0000000000001,
  0x3fd0000000000001,
  0x3fd0000000000002,
  0x3fd0000000000002,
  0xbfcffffffffffffa,
  0xbfcffffffffffffc,
  0xbfd0000000000000,
  0xbfe7fffffffffffe,
  0xbfe7ffffffffffff,
  0xbfe8000000000001,
  0xbff3ffffffffffff,
  0xc023800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fd0000000000002,
  0x3fd0000000000002,
  0x3fd0000000000002,
  0x3fd0000000000002,
  0x3fd0000000000002,
  0x3fe8000000000001,
  0x3fe8000000000001,
  0x3fe8000000000002,
  0x3ff4000000000000,
  0x3ff4000000000001,
  0x3ff4000000000002,
  0x3ffc000000000001,
  0x4024800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fd0000000000002,
  0x3fd0000000000002,
  0x3fd0000000000002,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3c9fffffffffffff,
  0x3c8ffffffffffffe,
  0xbc90000000000001,
  0xbfdffffffffffffd,
  0xbfdfffffffffffff,
  0xbfe0000000000002,
  0xbff0000000000000,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000001,
  0x4000000000000000,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3ca8000000000000,
  0x3ca0000000000000,
  0x0000000000000000,
  0xbfdffffffffffffc,
  0xbfdffffffffffffe,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000002,
  0x4000000000000000,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000002,
  0x3fe0000000000002,
  0x3cb4000000000000,
  0x3cb0000000000000,
  0x3ca0000000000001,
  0xbfdffffffffffffa,
  0xbfdffffffffffffc,
  0xbfe0000000000000,
  0xbfeffffffffffffe,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe0000000000002,
  0x3fe0000000000002,
  0x3fe0000000000002,
  0x3fe0000000000002,
  0x3fe0000000000002,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000002,
  0x3ff8000000000001,
  0x3ff8000000000001,
  0x3ff8000000000002,
  0x4000000000000001,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe0000000000002,
  0x3fe0000000000002,
  0x3fe0000000000002,
  0x3fe8000000000002,
  0x3fe8000000000001,
  0x3fd0000000000004,
  0x3fd0000000000003,
  0x3fd0000000000001,
  0xbfcffffffffffff6,
  0xbfcffffffffffffa,
  0xbfd0000000000001,
  0xbfe7fffffffffffe,
  0xc022800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe8000000000001,
  0x3fe8000000000001,
  0x3fe8000000000001,
  0x3fe8000000000002,
  0x3fe8000000000002,
  0x3ff4000000000000,
  0x3ff4000000000001,
  0x3ff4000000000001,
  0x3ffc000000000000,
  0x3ffc000000000001,
  0x3ffc000000000002,
  0x4002000000000000,
  0x4025800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe8000000000002,
  0x3fe8000000000002,
  0x3fe8000000000002,
  0x4014000000000001,
  0x4014000000000001,
  0x4012000000000001,
  0x4012000000000001,
  0x4012000000000001,
  0x4010000000000001,
  0x4010000000000001,
  0x4010000000000001,
  0x400c000000000002,
  0xc013ffffffffffff,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x4014000000000001,
  0x4014000000000001,
  0x4014000000000001,
  0x4014000000000001,
  0x4014000000000001,
  0x4016000000000001,
  0x4016000000000001,
  0x4016000000000001,
  0x4018000000000001,
  0x4018000000000001,
  0x4018000000000002,
  0x401a000000000001,
  0x402e000000000001,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x4014000000000001,
  0x4014000000000001,
  0x4014000000000001,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0xffdffffffffffffd,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x000091a2b3c4d5e7,
  0x800f6e5d4c3b2a19,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800091a2b3c4d5e6,
  0x800f6e5d4c3b2a18,
  0x000091a2b3c4d5e6,
  0x000091a2b3c4d5e7,
  0x001091a2b3c4d5e7,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0001b4e81b4e81b4,
  0x001091a2b3c4d5e6,
  0x000091a2b3c4d5e8,
  0x0008000000000000,
  0x8008000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0006dcba98765433,
  0x8007ffffffffffff,
  0x0007ffffffffffff,
  0x0008000000000000,
  0x0018000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000923456789abcd,
  0x0017ffffffffffff,
  0x0008000000000001,
  0x0000000000000001,
  0x800fffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcc,
  0x800ffffffffffffe,
  0x8000000000000000,
  0x0000000000000001,
  0x0010000000000001,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abce,
  0x0010000000000000,
  0x0000000000000002,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8008000000000000,
  0x8018000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800923456789abce,
  0x8018000000000000,
  0x8008000000000002,
  0x8008000000000000,
  0x0008000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8006dcba98765434,
  0x0007fffffffffffe,
  0x8008000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbfe8000000000001,
  0xbff4000000000000,
  0xbff4000000000000,
  0xbff4000000000001,
  0xbffc000000000000,
  0xc024800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0x3fcffffffffffffd,
  0x3fcfffffffffffff,
  0x3fd0000000000002,
  0x3fe7ffffffffffff,
  0x3fe8000000000000,
  0x3fe8000000000002,
  0x3ff4000000000000,
  0x4023800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000001,
  0xbfd0000000000001,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbfe8000000000002,
  0xbff4000000000000,
  0xbff4000000000000,
  0xbff4000000000001,
  0xbffc000000000000,
  0xc024800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfd0000000000001,
  0xbfd0000000000001,
  0xbfd0000000000001,
  0xbfd0000000000001,
  0xbfd0000000000001,
  0x3fcffffffffffffc,
  0x3fcffffffffffffe,
  0x3fd0000000000001,
  0x3fe7fffffffffffe,
  0x3fe8000000000000,
  0x3fe8000000000002,
  0x3ff4000000000000,
  0x4023800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfd0000000000001,
  0xbfd0000000000001,
  0xbfd0000000000001,
  0xbfd0000000000002,
  0xbfd0000000000002,
  0xbfe8000000000001,
  0xbfe8000000000001,
  0xbfe8000000000002,
  0xbff4000000000000,
  0xbff4000000000001,
  0xbff4000000000002,
  0xbffc000000000001,
  0xc024800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfd0000000000002,
  0xbfd0000000000002,
  0xbfd0000000000002,
  0xbfd0000000000002,
  0xbfd0000000000002,
  0x3fcffffffffffffa,
  0x3fcffffffffffffc,
  0x3fd0000000000000,
  0x3fe7fffffffffffe,
  0x3fe7ffffffffffff,
  0x3fe8000000000001,
  0x3ff3ffffffffffff,
  0x4023800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfd0000000000002,
  0xbfd0000000000002,
  0xbfd0000000000002,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000001,
  0xc000000000000000,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbc9fffffffffffff,
  0xbc8ffffffffffffe,
  0x3c90000000000001,
  0x3fdffffffffffffd,
  0x3fdfffffffffffff,
  0x3fe0000000000002,
  0x3ff0000000000000,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000002,
  0xc000000000000000,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbca8000000000000,
  0xbca0000000000000,
  0x0000000000000000,
  0x3fdffffffffffffc,
  0x3fdffffffffffffe,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000002,
  0xbfe0000000000002,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000002,
  0xbff8000000000001,
  0xbff8000000000001,
  0xbff8000000000002,
  0xc000000000000001,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe0000000000002,
  0xbfe0000000000002,
  0xbfe0000000000002,
  0xbfe0000000000002,
  0xbfe0000000000002,
  0xbcb4000000000000,
  0xbcb0000000000000,
  0xbca0000000000001,
  0x3fdffffffffffffa,
  0x3fdffffffffffffc,
  0x3fe0000000000000,
  0x3feffffffffffffe,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe0000000000002,
  0xbfe0000000000002,
  0xbfe0000000000002,
  0xbfe8000000000002,
  0xbfe8000000000002,
  0xbff4000000000000,
  0xbff4000000000001,
  0xbff4000000000001,
  0xbffc000000000000,
  0xbffc000000000001,
  0xbffc000000000002,
  0xc002000000000000,
  0xc025800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe8000000000002,
  0xbfe8000000000002,
  0xbfe8000000000002,
  0xbfe8000000000002,
  0xbfe8000000000001,
  0xbfd0000000000004,
  0xbfd0000000000003,
  0xbfd0000000000001,
  0x3fcffffffffffff6,
  0x3fcffffffffffffa,
  0x3fd0000000000001,
  0x3fe7fffffffffffe,
  0x4022800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe8000000000001,
  0xbfe8000000000001,
  0xbfe8000000000001,
  0xc014000000000001,
  0xc014000000000001,
  0xc016000000000001,
  0xc016000000000001,
  0xc016000000000001,
  0xc018000000000001,
  0xc018000000000001,
  0xc018000000000002,
  0xc01a000000000001,
  0xc02e000000000001,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc014000000000001,
  0xc014000000000001,
  0xc014000000000001,
  0xc014000000000001,
  0xc014000000000001,
  0xc012000000000001,
  0xc012000000000001,
  0xc012000000000001,
  0xc010000000000001,
  0xc010000000000001,
  0xc010000000000001,
  0xc00c000000000002,
  0x4013ffffffffffff,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc014000000000001,
  0xc014000000000001,
  0xc014000000000001,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0x7fdffffffffffffd,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x800091a2b3c4d5e7,
  0x801091a2b3c4d5e7,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x8001b4e81b4e81b4,
  0x801091a2b3c4d5e6,
  0x800091a2b3c4d5e8,
  0x800091a2b3c4d5e7,
  0x000f6e5d4c3b2a19,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000091a2b3c4d5e6,
  0x000f6e5d4c3b2a18,
  0x800091a2b3c4d5e6,
  0x8008000000000000,
  0x8018000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800923456789abcd,
  0x8017ffffffffffff,
  0x8008000000000001,
  0x8008000000000000,
  0x0008000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8006dcba98765433,
  0x0007ffffffffffff,
  0x8007ffffffffffff,
  0x8000000000000001,
  0x8010000000000001,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abce,
  0x8010000000000000,
  0x8000000000000002,
  0x8000000000000001,
  0x000fffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcc,
  0x000ffffffffffffe,
  0x0000000000000000,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0010000000000000,
  0x8000000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x000edcba98765432,
  0x0000000000000000,
  0x000ffffffffffffe,
  0x0010000000000000,
  0x0020000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x001123456789abcc,
  0x001ffffffffffffe,
  0x0010000000000000,
  0x3fdffffffffffffe,
  0x3fdffffffffffffe,
  0xbc8fffffffffffff,
  0xbca0000000000000,
  0xbcb0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000003,
  0xbff0000000000000,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fdffffffffffffe,
  0x3fdffffffffffffe,
  0x3fdffffffffffffe,
  0x3fdffffffffffffe,
  0x3fdffffffffffffe,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff7ffffffffffff,
  0x3ff8000000000000,
  0x3ff8000000000001,
  0x4000000000000000,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fdffffffffffffe,
  0x3fdffffffffffffe,
  0x3fdffffffffffffe,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x0000000000000000,
  0xbc90000000000000,
  0xbca8000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000002,
  0xbff0000000000000,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff7ffffffffffff,
  0x3ff8000000000000,
  0x3ff8000000000001,
  0x4000000000000000,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3c9fffffffffffff,
  0x3c8ffffffffffffe,
  0xbc90000000000001,
  0xbfdffffffffffffd,
  0xbfdfffffffffffff,
  0xbfe0000000000002,
  0xbff0000000000000,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000001,
  0x4000000000000000,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3feffffffffffffe,
  0x3feffffffffffffe,
  0x3fdffffffffffffd,
  0x3fdffffffffffffc,
  0x3fdffffffffffffa,
  0xbc9fffffffffffff,
  0xbcb0000000000000,
  0xbcc0000000000000,
  0xbfe0000000000002,
  0xc022000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3feffffffffffffe,
  0x3feffffffffffffe,
  0x3feffffffffffffe,
  0x3feffffffffffffe,
  0x3feffffffffffffe,
  0x3ff7ffffffffffff,
  0x3ff7ffffffffffff,
  0x3ff8000000000000,
  0x3fffffffffffffff,
  0x3fffffffffffffff,
  0x4000000000000000,
  0x4004000000000000,
  0x4026000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3feffffffffffffe,
  0x3feffffffffffffe,
  0x3feffffffffffffe,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fdfffffffffffff,
  0x3fdffffffffffffe,
  0x3fdffffffffffffc,
  0x0000000000000000,
  0xbca0000000000000,
  0xbcb8000000000000,
  0xbfe0000000000001,
  0xc022000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3ff7ffffffffffff,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3fffffffffffffff,
  0x4000000000000000,
  0x4000000000000000,
  0x4004000000000000,
  0x4026000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000000,
  0x3cafffffffffffff,
  0x3c9ffffffffffffe,
  0xbca0000000000001,
  0xbfdffffffffffffe,
  0xc022000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000001,
  0x4000000000000000,
  0x4000000000000000,
  0x4000000000000001,
  0x4004000000000000,
  0x4026000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff7ffffffffffff,
  0x3ff7ffffffffffff,
  0x3fefffffffffffff,
  0x3feffffffffffffe,
  0x3feffffffffffffe,
  0x3fdfffffffffffff,
  0x3fdffffffffffffd,
  0x3fdffffffffffff9,
  0xbca8000000000000,
  0xc021000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3ff7ffffffffffff,
  0x3ff7ffffffffffff,
  0x3ff7ffffffffffff,
  0x3ff7ffffffffffff,
  0x3ff7ffffffffffff,
  0x3fffffffffffffff,
  0x3fffffffffffffff,
  0x4000000000000000,
  0x4003ffffffffffff,
  0x4004000000000000,
  0x4004000000000000,
  0x4008000000000000,
  0x4027000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3ff7ffffffffffff,
  0x3ff7ffffffffffff,
  0x3ff7ffffffffffff,
  0x4023ffffffffffff,
  0x4023ffffffffffff,
  0x4022ffffffffffff,
  0x4022ffffffffffff,
  0x4022ffffffffffff,
  0x4021ffffffffffff,
  0x4021ffffffffffff,
  0x4021ffffffffffff,
  0x4020ffffffffffff,
  0xbcd4000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x4023ffffffffffff,
  0x4023ffffffffffff,
  0x4023ffffffffffff,
  0x4023ffffffffffff,
  0x4023ffffffffffff,
  0x4024ffffffffffff,
  0x4024ffffffffffff,
  0x4024ffffffffffff,
  0x4025ffffffffffff,
  0x4025ffffffffffff,
  0x4026000000000000,
  0x4026ffffffffffff,
  0x4034000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x4023ffffffffffff,
  0x4023ffffffffffff,
  0x4023ffffffffffff,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0xfc9fffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x800edcba98765433,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x8000000000000000,
  0x800edcba98765432,
  0x000123456789abcc,
  0x000123456789abcd,
  0x001123456789abcd,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0002468acf13579a,
  0x001123456789abcc,
  0x000123456789abce,
  0x000fffffffffffff,
  0x8000000000000001,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x000edcba98765432,
  0x8000000000000000,
  0x000ffffffffffffe,
  0x000fffffffffffff,
  0x001fffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x001123456789abcc,
  0x001ffffffffffffe,
  0x0010000000000000,
  0x0000000000000001,
  0x800fffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcc,
  0x800ffffffffffffe,
  0x8000000000000000,
  0x0000000000000001,
  0x0010000000000001,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abce,
  0x0010000000000000,
  0x0000000000000002,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8010000000000000,
  0x8020000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x801123456789abcc,
  0x801ffffffffffffe,
  0x8010000000000000,
  0x8010000000000000,
  0x0000000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x800edcba98765432,
  0x8000000000000000,
  0x800ffffffffffffe,
  0xbfdffffffffffffe,
  0xbfdffffffffffffe,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff7ffffffffffff,
  0xbff8000000000000,
  0xbff8000000000001,
  0xc000000000000000,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfdffffffffffffe,
  0xbfdffffffffffffe,
  0xbfdffffffffffffe,
  0xbfdffffffffffffe,
  0xbfdffffffffffffe,
  0x3c8fffffffffffff,
  0x3ca0000000000000,
  0x3cb0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000003,
  0x3ff0000000000000,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfdffffffffffffe,
  0xbfdffffffffffffe,
  0xbfdffffffffffffe,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff7ffffffffffff,
  0xbff8000000000000,
  0xbff8000000000001,
  0xc000000000000000,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0x0000000000000000,
  0x3c90000000000000,
  0x3ca8000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000002,
  0x3ff0000000000000,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000001,
  0xc000000000000000,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbc9fffffffffffff,
  0xbc8ffffffffffffe,
  0x3c90000000000001,
  0x3fdffffffffffffd,
  0x3fdfffffffffffff,
  0x3fe0000000000002,
  0x3ff0000000000000,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfeffffffffffffe,
  0xbfeffffffffffffe,
  0xbff7ffffffffffff,
  0xbff7ffffffffffff,
  0xbff8000000000000,
  0xbfffffffffffffff,
  0xbfffffffffffffff,
  0xc000000000000000,
  0xc004000000000000,
  0xc026000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfeffffffffffffe,
  0xbfeffffffffffffe,
  0xbfeffffffffffffe,
  0xbfeffffffffffffe,
  0xbfeffffffffffffe,
  0xbfdffffffffffffd,
  0xbfdffffffffffffc,
  0xbfdffffffffffffa,
  0x3c9fffffffffffff,
  0x3cb0000000000000,
  0x3cc0000000000000,
  0x3fe0000000000002,
  0x4022000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfeffffffffffffe,
  0xbfeffffffffffffe,
  0xbfeffffffffffffe,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbff7ffffffffffff,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbfffffffffffffff,
  0xc000000000000000,
  0xc000000000000000,
  0xc004000000000000,
  0xc026000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfdfffffffffffff,
  0xbfdffffffffffffe,
  0xbfdffffffffffffc,
  0x0000000000000000,
  0x3ca0000000000000,
  0x3cb8000000000000,
  0x3fe0000000000001,
  0x4022000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000001,
  0xc000000000000000,
  0xc000000000000000,
  0xc000000000000001,
  0xc004000000000000,
  0xc026000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000000,
  0xbcafffffffffffff,
  0xbc9ffffffffffffe,
  0x3ca0000000000001,
  0x3fdffffffffffffe,
  0x4022000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff7ffffffffffff,
  0xbff7ffffffffffff,
  0xbfffffffffffffff,
  0xbfffffffffffffff,
  0xc000000000000000,
  0xc003ffffffffffff,
  0xc004000000000000,
  0xc004000000000000,
  0xc008000000000000,
  0xc027000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbff7ffffffffffff,
  0xbff7ffffffffffff,
  0xbff7ffffffffffff,
  0xbff7ffffffffffff,
  0xbff7ffffffffffff,
  0xbfefffffffffffff,
  0xbfeffffffffffffe,
  0xbfeffffffffffffe,
  0xbfdfffffffffffff,
  0xbfdffffffffffffd,
  0xbfdffffffffffff9,
  0x3ca8000000000000,
  0x4021000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbff7ffffffffffff,
  0xbff7ffffffffffff,
  0xbff7ffffffffffff,
  0xc023ffffffffffff,
  0xc023ffffffffffff,
  0xc024ffffffffffff,
  0xc024ffffffffffff,
  0xc024ffffffffffff,
  0xc025ffffffffffff,
  0xc025ffffffffffff,
  0xc026000000000000,
  0xc026ffffffffffff,
  0xc034000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc023ffffffffffff,
  0xc023ffffffffffff,
  0xc023ffffffffffff,
  0xc023ffffffffffff,
  0xc023ffffffffffff,
  0xc022ffffffffffff,
  0xc022ffffffffffff,
  0xc022ffffffffffff,
  0xc021ffffffffffff,
  0xc021ffffffffffff,
  0xc021ffffffffffff,
  0xc020ffffffffffff,
  0x3cd4000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc023ffffffffffff,
  0xc023ffffffffffff,
  0xc023ffffffffffff,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0x7c9fffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x800123456789abcd,
  0x801123456789abcd,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x8002468acf13579a,
  0x801123456789abcc,
  0x800123456789abce,
  0x800123456789abcd,
  0x000edcba98765433,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0000000000000000,
  0x000edcba98765432,
  0x800123456789abcc,
  0x800fffffffffffff,
  0x801fffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x801123456789abcc,
  0x801ffffffffffffe,
  0x8010000000000000,
  0x800fffffffffffff,
  0x0000000000000001,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x800edcba98765432,
  0x0000000000000000,
  0x800ffffffffffffe,
  0x8000000000000001,
  0x8010000000000001,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abce,
  0x8010000000000000,
  0x8000000000000002,
  0x8000000000000001,
  0x000fffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcc,
  0x000ffffffffffffe,
  0x0000000000000000,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0010000000000000,
  0x0000000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x000edcba98765433,
  0x0000000000000001,
  0x000fffffffffffff,
  0x0010000000000000,
  0x0020000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x001123456789abcd,
  0x001fffffffffffff,
  0x0010000000000001,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x0000000000000000,
  0xbc90000000000000,
  0xbca8000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000002,
  0xbff0000000000000,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff7ffffffffffff,
  0x3ff8000000000000,
  0x3ff8000000000001,
  0x4000000000000000,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3c90000000000000,
  0x0000000000000000,
  0xbca0000000000000,
  0xbfdffffffffffffe,
  0xbfe0000000000000,
  0xbfe0000000000002,
  0xbff0000000000000,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000001,
  0x4000000000000000,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3ca8000000000000,
  0x3ca0000000000000,
  0x0000000000000000,
  0xbfdffffffffffffc,
  0xbfdffffffffffffe,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000002,
  0x4000000000000000,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fdfffffffffffff,
  0x3fdffffffffffffe,
  0x3fdffffffffffffc,
  0x0000000000000000,
  0xbca0000000000000,
  0xbcb8000000000000,
  0xbfe0000000000001,
  0xc022000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3ff7ffffffffffff,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3fffffffffffffff,
  0x4000000000000000,
  0x4000000000000000,
  0x4004000000000000,
  0x4026000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fdffffffffffffe,
  0x3ca0000000000000,
  0x0000000000000000,
  0xbcb0000000000000,
  0xbfe0000000000000,
  0xc022000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x4000000000000000,
  0x4000000000000000,
  0x4000000000000000,
  0x4004000000000000,
  0x4026000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3fe0000000000002,
  0x3fe0000000000002,
  0x3fe0000000000001,
  0x3cb8000000000000,
  0x3cb0000000000000,
  0x0000000000000000,
  0xbfdffffffffffffc,
  0xc022000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff8000000000001,
  0x3ff8000000000001,
  0x3ff8000000000002,
  0x4000000000000000,
  0x4000000000000000,
  0x4000000000000001,
  0x4004000000000000,
  0x4026000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3fefffffffffffff,
  0x3fe0000000000001,
  0x3fe0000000000000,
  0x3fdffffffffffffc,
  0x0000000000000000,
  0xc021000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x4000000000000000,
  0x4000000000000000,
  0x4000000000000000,
  0x4004000000000000,
  0x4004000000000000,
  0x4004000000000000,
  0x4008000000000000,
  0x4027000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4023000000000000,
  0x4023000000000000,
  0x4023000000000000,
  0x4022000000000000,
  0x4022000000000000,
  0x4022000000000000,
  0x4021000000000000,
  0x0000000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4025000000000000,
  0x4025000000000000,
  0x4025000000000000,
  0x4026000000000000,
  0x4026000000000000,
  0x4026000000000000,
  0x4027000000000000,
  0x4034000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x0000000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x800edcba98765433,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0000000000000000,
  0x800edcba98765432,
  0x000123456789abcc,
  0x000123456789abcd,
  0x001123456789abcd,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0002468acf13579a,
  0x001123456789abcc,
  0x000123456789abce,
  0x000fffffffffffff,
  0x8000000000000001,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x000edcba98765432,
  0x0000000000000000,
  0x000ffffffffffffe,
  0x000fffffffffffff,
  0x001fffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x001123456789abcc,
  0x001ffffffffffffe,
  0x0010000000000000,
  0x0000000000000001,
  0x800fffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcc,
  0x800ffffffffffffe,
  0x0000000000000000,
  0x0000000000000001,
  0x0010000000000001,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abce,
  0x0010000000000000,
  0x0000000000000002,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8010000000000000,
  0x8020000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x801123456789abcd,
  0x801fffffffffffff,
  0x8010000000000001,
  0x8010000000000000,
  0x0000000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x800edcba98765433,
  0x8000000000000001,
  0x800fffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff7ffffffffffff,
  0xbff8000000000000,
  0xbff8000000000001,
  0xc000000000000000,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0x0000000000000000,
  0x3c90000000000000,
  0x3ca8000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000002,
  0x3ff0000000000000,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000001,
  0xc000000000000000,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbc90000000000000,
  0x0000000000000000,
  0x3ca0000000000000,
  0x3fdffffffffffffe,
  0x3fe0000000000000,
  0x3fe0000000000002,
  0x3ff0000000000000,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000002,
  0xc000000000000000,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbca8000000000000,
  0xbca0000000000000,
  0x0000000000000000,
  0x3fdffffffffffffc,
  0x3fdffffffffffffe,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbff7ffffffffffff,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbfffffffffffffff,
  0xc000000000000000,
  0xc000000000000000,
  0xc004000000000000,
  0xc026000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfdfffffffffffff,
  0xbfdffffffffffffe,
  0xbfdffffffffffffc,
  0x0000000000000000,
  0x3ca0000000000000,
  0x3cb8000000000000,
  0x3fe0000000000001,
  0x4022000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xc000000000000000,
  0xc000000000000000,
  0xc000000000000000,
  0xc004000000000000,
  0xc026000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfdffffffffffffe,
  0xbca0000000000000,
  0x0000000000000000,
  0x3cb0000000000000,
  0x3fe0000000000000,
  0x4022000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff8000000000001,
  0xbff8000000000001,
  0xbff8000000000002,
  0xc000000000000000,
  0xc000000000000000,
  0xc000000000000001,
  0xc004000000000000,
  0xc026000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbfe0000000000002,
  0xbfe0000000000002,
  0xbfe0000000000001,
  0xbcb8000000000000,
  0xbcb0000000000000,
  0x0000000000000000,
  0x3fdffffffffffffc,
  0x4022000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff8000000000000,
  0xbff8000000000000,
  0xc000000000000000,
  0xc000000000000000,
  0xc000000000000000,
  0xc004000000000000,
  0xc004000000000000,
  0xc004000000000000,
  0xc008000000000000,
  0xc027000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbfefffffffffffff,
  0xbfe0000000000001,
  0xbfe0000000000000,
  0xbfdffffffffffffc,
  0x0000000000000000,
  0x4021000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc025000000000000,
  0xc025000000000000,
  0xc025000000000000,
  0xc026000000000000,
  0xc026000000000000,
  0xc026000000000000,
  0xc027000000000000,
  0xc034000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc023000000000000,
  0xc023000000000000,
  0xc023000000000000,
  0xc022000000000000,
  0xc022000000000000,
  0xc022000000000000,
  0xc021000000000000,
  0x0000000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0x0000000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x800123456789abcd,
  0x801123456789abcd,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x8002468acf13579a,
  0x801123456789abcc,
  0x800123456789abce,
  0x800123456789abcd,
  0x000edcba98765433,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0000000000000000,
  0x000edcba98765432,
  0x800123456789abcc,
  0x800fffffffffffff,
  0x801fffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x801123456789abcc,
  0x801ffffffffffffe,
  0x8010000000000000,
  0x800fffffffffffff,
  0x0000000000000001,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x800edcba98765432,
  0x0000000000000000,
  0x800ffffffffffffe,
  0x8000000000000001,
  0x8010000000000001,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abce,
  0x8010000000000000,
  0x8000000000000002,
  0x8000000000000001,
  0x000fffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcc,
  0x000ffffffffffffe,
  0x0000000000000000,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0010000000000001,
  0x0000000000000001,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x000edcba98765434,
  0x0000000000000002,
  0x0010000000000000,
  0x0010000000000001,
  0x0020000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x001123456789abce,
  0x0020000000000000,
  0x0010000000000002,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3c9fffffffffffff,
  0x3c8ffffffffffffe,
  0xbc90000000000001,
  0xbfdffffffffffffd,
  0xbfdfffffffffffff,
  0xbfe0000000000002,
  0xbff0000000000000,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000001,
  0x4000000000000000,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3ca8000000000000,
  0x3ca0000000000000,
  0x0000000000000000,
  0xbfdffffffffffffc,
  0xbfdffffffffffffe,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000002,
  0x4000000000000000,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000002,
  0x3fe0000000000002,
  0x3cb4000000000000,
  0x3cb0000000000000,
  0x3ca0000000000001,
  0xbfdffffffffffffa,
  0xbfdffffffffffffc,
  0xbfe0000000000000,
  0xbfeffffffffffffe,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe0000000000002,
  0x3fe0000000000002,
  0x3fe0000000000002,
  0x3fe0000000000002,
  0x3fe0000000000002,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000002,
  0x3ff8000000000001,
  0x3ff8000000000001,
  0x3ff8000000000002,
  0x4000000000000001,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe0000000000002,
  0x3fe0000000000002,
  0x3fe0000000000002,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000000,
  0x3cafffffffffffff,
  0x3c9ffffffffffffe,
  0xbca0000000000001,
  0xbfdffffffffffffe,
  0xc022000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000001,
  0x4000000000000000,
  0x4000000000000000,
  0x4000000000000001,
  0x4004000000000000,
  0x4026000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3fe0000000000002,
  0x3fe0000000000002,
  0x3fe0000000000001,
  0x3cb8000000000000,
  0x3cb0000000000000,
  0x0000000000000000,
  0xbfdffffffffffffc,
  0xc022000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff8000000000001,
  0x3ff8000000000001,
  0x3ff8000000000002,
  0x4000000000000000,
  0x4000000000000000,
  0x4000000000000001,
  0x4004000000000000,
  0x4026000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000002,
  0x3ff0000000000002,
  0x3fe0000000000005,
  0x3fe0000000000004,
  0x3fe0000000000003,
  0x3cc4000000000000,
  0x3cc0000000000000,
  0x3cb0000000000001,
  0xbfdffffffffffff8,
  0xc022000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3ff0000000000002,
  0x3ff0000000000002,
  0x3ff0000000000002,
  0x3ff0000000000002,
  0x3ff0000000000002,
  0x3ff8000000000002,
  0x3ff8000000000002,
  0x3ff8000000000003,
  0x4000000000000001,
  0x4000000000000001,
  0x4000000000000002,
  0x4004000000000001,
  0x4026000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3ff0000000000002,
  0x3ff0000000000002,
  0x3ff0000000000002,
  0x3ff8000000000002,
  0x3ff8000000000001,
  0x3ff0000000000002,
  0x3ff0000000000002,
  0x3ff0000000000001,
  0x3fe0000000000004,
  0x3fe0000000000003,
  0x3fe0000000000001,
  0x3cb8000000000000,
  0xc021000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3ff8000000000001,
  0x3ff8000000000001,
  0x3ff8000000000001,
  0x3ff8000000000002,
  0x3ff8000000000002,
  0x4000000000000001,
  0x4000000000000001,
  0x4000000000000001,
  0x4004000000000000,
  0x4004000000000001,
  0x4004000000000001,
  0x4008000000000001,
  0x4027000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3ff8000000000002,
  0x3ff8000000000002,
  0x3ff8000000000002,
  0x4024000000000001,
  0x4024000000000001,
  0x4023000000000001,
  0x4023000000000001,
  0x4023000000000001,
  0x4022000000000001,
  0x4022000000000001,
  0x4022000000000001,
  0x4021000000000001,
  0x3ce4000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x4024000000000001,
  0x4024000000000001,
  0x4024000000000001,
  0x4024000000000001,
  0x4024000000000001,
  0x4025000000000001,
  0x4025000000000001,
  0x4025000000000001,
  0x4026000000000001,
  0x4026000000000001,
  0x4026000000000001,
  0x4027000000000001,
  0x4034000000000001,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x4024000000000001,
  0x4024000000000001,
  0x4024000000000001,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7cafffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x800edcba98765433,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0000000000000000,
  0x800edcba98765432,
  0x000123456789abcc,
  0x000123456789abcd,
  0x001123456789abcd,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0002468acf13579a,
  0x001123456789abcc,
  0x000123456789abce,
  0x0010000000000000,
  0x8000000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x000edcba98765433,
  0x0000000000000001,
  0x000fffffffffffff,
  0x0010000000000000,
  0x0020000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x001123456789abcd,
  0x001fffffffffffff,
  0x0010000000000001,
  0x0000000000000001,
  0x800fffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcc,
  0x800ffffffffffffe,
  0x0000000000000000,
  0x0000000000000001,
  0x0010000000000001,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abce,
  0x0010000000000000,
  0x0000000000000002,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8010000000000001,
  0x8020000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x801123456789abce,
  0x8020000000000000,
  0x8010000000000002,
  0x8010000000000001,
  0x8000000000000001,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x800edcba98765434,
  0x8000000000000002,
  0x8010000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000001,
  0xc000000000000000,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbc9fffffffffffff,
  0xbc8ffffffffffffe,
  0x3c90000000000001,
  0x3fdffffffffffffd,
  0x3fdfffffffffffff,
  0x3fe0000000000002,
  0x3ff0000000000000,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000002,
  0xc000000000000000,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbca8000000000000,
  0xbca0000000000000,
  0x0000000000000000,
  0x3fdffffffffffffc,
  0x3fdffffffffffffe,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000002,
  0xbfe0000000000002,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000002,
  0xbff8000000000001,
  0xbff8000000000001,
  0xbff8000000000002,
  0xc000000000000001,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe0000000000002,
  0xbfe0000000000002,
  0xbfe0000000000002,
  0xbfe0000000000002,
  0xbfe0000000000002,
  0xbcb4000000000000,
  0xbcb0000000000000,
  0xbca0000000000001,
  0x3fdffffffffffffa,
  0x3fdffffffffffffc,
  0x3fe0000000000000,
  0x3feffffffffffffe,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe0000000000002,
  0xbfe0000000000002,
  0xbfe0000000000002,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000001,
  0xc000000000000000,
  0xc000000000000000,
  0xc000000000000001,
  0xc004000000000000,
  0xc026000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000000,
  0xbcafffffffffffff,
  0xbc9ffffffffffffe,
  0x3ca0000000000001,
  0x3fdffffffffffffe,
  0x4022000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff8000000000001,
  0xbff8000000000001,
  0xbff8000000000002,
  0xc000000000000000,
  0xc000000000000000,
  0xc000000000000001,
  0xc004000000000000,
  0xc026000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbfe0000000000002,
  0xbfe0000000000002,
  0xbfe0000000000001,
  0xbcb8000000000000,
  0xbcb0000000000000,
  0x0000000000000000,
  0x3fdffffffffffffc,
  0x4022000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000002,
  0xbff0000000000002,
  0xbff8000000000002,
  0xbff8000000000002,
  0xbff8000000000003,
  0xc000000000000001,
  0xc000000000000001,
  0xc000000000000002,
  0xc004000000000001,
  0xc026000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbff0000000000002,
  0xbff0000000000002,
  0xbff0000000000002,
  0xbff0000000000002,
  0xbff0000000000002,
  0xbfe0000000000005,
  0xbfe0000000000004,
  0xbfe0000000000003,
  0xbcc4000000000000,
  0xbcc0000000000000,
  0xbcb0000000000001,
  0x3fdffffffffffff8,
  0x4022000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbff0000000000002,
  0xbff0000000000002,
  0xbff0000000000002,
  0xbff8000000000002,
  0xbff8000000000002,
  0xc000000000000001,
  0xc000000000000001,
  0xc000000000000001,
  0xc004000000000000,
  0xc004000000000001,
  0xc004000000000001,
  0xc008000000000001,
  0xc027000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbff8000000000002,
  0xbff8000000000002,
  0xbff8000000000002,
  0xbff8000000000002,
  0xbff8000000000001,
  0xbff0000000000002,
  0xbff0000000000002,
  0xbff0000000000001,
  0xbfe0000000000004,
  0xbfe0000000000003,
  0xbfe0000000000001,
  0xbcb8000000000000,
  0x4021000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbff8000000000001,
  0xbff8000000000001,
  0xbff8000000000001,
  0xc024000000000001,
  0xc024000000000001,
  0xc025000000000001,
  0xc025000000000001,
  0xc025000000000001,
  0xc026000000000001,
  0xc026000000000001,
  0xc026000000000001,
  0xc027000000000001,
  0xc034000000000001,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc024000000000001,
  0xc024000000000001,
  0xc024000000000001,
  0xc024000000000001,
  0xc024000000000001,
  0xc023000000000001,
  0xc023000000000001,
  0xc023000000000001,
  0xc022000000000001,
  0xc022000000000001,
  0xc022000000000001,
  0xc021000000000001,
  0xbce4000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc024000000000001,
  0xc024000000000001,
  0xc024000000000001,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfcafffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x800123456789abcd,
  0x801123456789abcd,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x8002468acf13579a,
  0x801123456789abcc,
  0x800123456789abce,
  0x800123456789abcd,
  0x000edcba98765433,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8000000000000000,
  0x000edcba98765432,
  0x800123456789abcc,
  0x8010000000000000,
  0x8020000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x801123456789abcd,
  0x801fffffffffffff,
  0x8010000000000001,
  0x8010000000000000,
  0x0000000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x800edcba98765433,
  0x8000000000000001,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8010000000000001,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abce,
  0x8010000000000000,
  0x8000000000000002,
  0x8000000000000001,
  0x000fffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcc,
  0x000ffffffffffffe,
  0x8000000000000000,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0018000000000000,
  0x0008000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0016dcba98765433,
  0x0008000000000001,
  0x0017ffffffffffff,
  0x0018000000000000,
  0x0024000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x001923456789abcd,
  0x0024000000000000,
  0x0018000000000001,
  0x3fe7ffffffffffff,
  0x3fe7ffffffffffff,
  0x3fcfffffffffffff,
  0x3fcffffffffffffd,
  0x3fcffffffffffff9,
  0xbfcfffffffffffff,
  0xbfd0000000000002,
  0xbfd0000000000006,
  0xbfe8000000000001,
  0xc022800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe7ffffffffffff,
  0x3fe7ffffffffffff,
  0x3fe7ffffffffffff,
  0x3fe7ffffffffffff,
  0x3fe7ffffffffffff,
  0x3ff3ffffffffffff,
  0x3ff4000000000000,
  0x3ff4000000000000,
  0x3ffbffffffffffff,
  0x3ffc000000000000,
  0x3ffc000000000001,
  0x4002000000000000,
  0x4025800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe7ffffffffffff,
  0x3fe7ffffffffffff,
  0x3fe7ffffffffffff,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3fd0000000000001,
  0x3fd0000000000000,
  0x3fcffffffffffffc,
  0xbfcffffffffffffc,
  0xbfd0000000000000,
  0xbfd0000000000004,
  0xbfe8000000000000,
  0xc022800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3ff4000000000000,
  0x3ff4000000000000,
  0x3ff4000000000000,
  0x3ffc000000000000,
  0x3ffc000000000000,
  0x3ffc000000000001,
  0x4002000000000000,
  0x4025800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3fe8000000000002,
  0x3fe8000000000001,
  0x3fd0000000000004,
  0x3fd0000000000003,
  0x3fd0000000000001,
  0xbfcffffffffffff6,
  0xbfcffffffffffffa,
  0xbfd0000000000001,
  0xbfe7fffffffffffe,
  0xc022800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe8000000000001,
  0x3fe8000000000001,
  0x3fe8000000000001,
  0x3fe8000000000002,
  0x3fe8000000000002,
  0x3ff4000000000000,
  0x3ff4000000000001,
  0x3ff4000000000001,
  0x3ffc000000000000,
  0x3ffc000000000001,
  0x3ffc000000000002,
  0x4002000000000000,
  0x4025800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe8000000000002,
  0x3fe8000000000002,
  0x3fe8000000000002,
  0x3ff7ffffffffffff,
  0x3ff7ffffffffffff,
  0x3fefffffffffffff,
  0x3feffffffffffffe,
  0x3feffffffffffffe,
  0x3fdfffffffffffff,
  0x3fdffffffffffffd,
  0x3fdffffffffffff9,
  0xbca8000000000000,
  0xc021000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3ff7ffffffffffff,
  0x3ff7ffffffffffff,
  0x3ff7ffffffffffff,
  0x3ff7ffffffffffff,
  0x3ff7ffffffffffff,
  0x3fffffffffffffff,
  0x3fffffffffffffff,
  0x4000000000000000,
  0x4003ffffffffffff,
  0x4004000000000000,
  0x4004000000000000,
  0x4008000000000000,
  0x4027000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3ff7ffffffffffff,
  0x3ff7ffffffffffff,
  0x3ff7ffffffffffff,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3fefffffffffffff,
  0x3fe0000000000001,
  0x3fe0000000000000,
  0x3fdffffffffffffc,
  0x0000000000000000,
  0xc021000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x4000000000000000,
  0x4000000000000000,
  0x4000000000000000,
  0x4004000000000000,
  0x4004000000000000,
  0x4004000000000000,
  0x4008000000000000,
  0x4027000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000002,
  0x3ff8000000000001,
  0x3ff0000000000002,
  0x3ff0000000000002,
  0x3ff0000000000001,
  0x3fe0000000000004,
  0x3fe0000000000003,
  0x3fe0000000000001,
  0x3cb8000000000000,
  0xc021000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3ff8000000000001,
  0x3ff8000000000001,
  0x3ff8000000000001,
  0x3ff8000000000002,
  0x3ff8000000000002,
  0x4000000000000001,
  0x4000000000000001,
  0x4000000000000001,
  0x4004000000000000,
  0x4004000000000001,
  0x4004000000000001,
  0x4008000000000001,
  0x4027000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3ff8000000000002,
  0x3ff8000000000002,
  0x3ff8000000000002,
  0x4002000000000000,
  0x4002000000000000,
  0x3ffc000000000000,
  0x3ffc000000000000,
  0x3ffc000000000000,
  0x3ff4000000000000,
  0x3ff4000000000000,
  0x3ff3ffffffffffff,
  0x3fe8000000000000,
  0xc01f000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x4002000000000000,
  0x4002000000000000,
  0x4002000000000000,
  0x4002000000000000,
  0x4002000000000000,
  0x4006000000000000,
  0x4006000000000000,
  0x4006000000000000,
  0x400a000000000000,
  0x400a000000000000,
  0x400a000000000000,
  0x400e000000000000,
  0x4028800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x4002000000000000,
  0x4002000000000000,
  0x4002000000000000,
  0x402e000000000000,
  0x402e000000000000,
  0x402d000000000000,
  0x402d000000000000,
  0x402d000000000000,
  0x402c000000000000,
  0x402c000000000000,
  0x402c000000000000,
  0x402b000000000000,
  0x4014000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x402e000000000000,
  0x402e000000000000,
  0x402e000000000000,
  0x402e000000000000,
  0x402e000000000000,
  0x402f000000000000,
  0x402f000000000000,
  0x402f000000000000,
  0x4030000000000000,
  0x4030000000000000,
  0x4030000000000000,
  0x4030800000000000,
  0x4039000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x402e000000000000,
  0x402e000000000000,
  0x402e000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7fdfffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x0001b4e81b4e81b4,
  0x800e4b17e4b17e4c,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x000091a2b3c4d5e6,
  0x800e4b17e4b17e4c,
  0x0001b4e81b4e81b2,
  0x0001b4e81b4e81b4,
  0x0011b4e81b4e81b4,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0002d82d82d82d80,
  0x0011b4e81b4e81b2,
  0x0001b4e81b4e81b4,
  0x0017fffffffffffe,
  0x0007fffffffffffe,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0016dcba98765432,
  0x0008000000000000,
  0x0017fffffffffffe,
  0x0017fffffffffffe,
  0x0023ffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x001923456789abcc,
  0x0023ffffffffffff,
  0x0018000000000000,
  0x0000000000000002,
  0x800ffffffffffffe,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcc,
  0x800ffffffffffffe,
  0x0000000000000000,
  0x0000000000000002,
  0x0010000000000002,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abce,
  0x0010000000000000,
  0x0000000000000002,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8018000000000000,
  0x8024000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x801923456789abcd,
  0x8024000000000000,
  0x8018000000000001,
  0x8018000000000000,
  0x8008000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8016dcba98765433,
  0x8008000000000001,
  0x8017ffffffffffff,
  0xbfe7ffffffffffff,
  0xbfe7ffffffffffff,
  0xbff3ffffffffffff,
  0xbff4000000000000,
  0xbff4000000000000,
  0xbffbffffffffffff,
  0xbffc000000000000,
  0xbffc000000000001,
  0xc002000000000000,
  0xc025800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe7ffffffffffff,
  0xbfe7ffffffffffff,
  0xbfe7ffffffffffff,
  0xbfe7ffffffffffff,
  0xbfe7ffffffffffff,
  0xbfcfffffffffffff,
  0xbfcffffffffffffd,
  0xbfcffffffffffff9,
  0x3fcfffffffffffff,
  0x3fd0000000000002,
  0x3fd0000000000006,
  0x3fe8000000000001,
  0x4022800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe7ffffffffffff,
  0xbfe7ffffffffffff,
  0xbfe7ffffffffffff,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbff4000000000000,
  0xbff4000000000000,
  0xbff4000000000000,
  0xbffc000000000000,
  0xbffc000000000000,
  0xbffc000000000001,
  0xc002000000000000,
  0xc025800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbfd0000000000001,
  0xbfd0000000000000,
  0xbfcffffffffffffc,
  0x3fcffffffffffffc,
  0x3fd0000000000000,
  0x3fd0000000000004,
  0x3fe8000000000000,
  0x4022800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbfe8000000000002,
  0xbfe8000000000002,
  0xbff4000000000000,
  0xbff4000000000001,
  0xbff4000000000001,
  0xbffc000000000000,
  0xbffc000000000001,
  0xbffc000000000002,
  0xc002000000000000,
  0xc025800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe8000000000002,
  0xbfe8000000000002,
  0xbfe8000000000002,
  0xbfe8000000000002,
  0xbfe8000000000001,
  0xbfd0000000000004,
  0xbfd0000000000003,
  0xbfd0000000000001,
  0x3fcffffffffffff6,
  0x3fcffffffffffffa,
  0x3fd0000000000001,
  0x3fe7fffffffffffe,
  0x4022800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe8000000000001,
  0xbfe8000000000001,
  0xbfe8000000000001,
  0xbff7ffffffffffff,
  0xbff7ffffffffffff,
  0xbfffffffffffffff,
  0xbfffffffffffffff,
  0xc000000000000000,
  0xc003ffffffffffff,
  0xc004000000000000,
  0xc004000000000000,
  0xc008000000000000,
  0xc027000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbff7ffffffffffff,
  0xbff7ffffffffffff,
  0xbff7ffffffffffff,
  0xbff7ffffffffffff,
  0xbff7ffffffffffff,
  0xbfefffffffffffff,
  0xbfeffffffffffffe,
  0xbfeffffffffffffe,
  0xbfdfffffffffffff,
  0xbfdffffffffffffd,
  0xbfdffffffffffff9,
  0x3ca8000000000000,
  0x4021000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbff7ffffffffffff,
  0xbff7ffffffffffff,
  0xbff7ffffffffffff,
  0xbff8000000000000,
  0xbff8000000000000,
  0xc000000000000000,
  0xc000000000000000,
  0xc000000000000000,
  0xc004000000000000,
  0xc004000000000000,
  0xc004000000000000,
  0xc008000000000000,
  0xc027000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbfefffffffffffff,
  0xbfe0000000000001,
  0xbfe0000000000000,
  0xbfdffffffffffffc,
  0x0000000000000000,
  0x4021000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000002,
  0xbff8000000000002,
  0xc000000000000001,
  0xc000000000000001,
  0xc000000000000001,
  0xc004000000000000,
  0xc004000000000001,
  0xc004000000000001,
  0xc008000000000001,
  0xc027000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbff8000000000002,
  0xbff8000000000002,
  0xbff8000000000002,
  0xbff8000000000002,
  0xbff8000000000001,
  0xbff0000000000002,
  0xbff0000000000002,
  0xbff0000000000001,
  0xbfe0000000000004,
  0xbfe0000000000003,
  0xbfe0000000000001,
  0xbcb8000000000000,
  0x4021000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbff8000000000001,
  0xbff8000000000001,
  0xbff8000000000001,
  0xc002000000000000,
  0xc002000000000000,
  0xc006000000000000,
  0xc006000000000000,
  0xc006000000000000,
  0xc00a000000000000,
  0xc00a000000000000,
  0xc00a000000000000,
  0xc00e000000000000,
  0xc028800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc002000000000000,
  0xc002000000000000,
  0xc002000000000000,
  0xc002000000000000,
  0xc002000000000000,
  0xbffc000000000000,
  0xbffc000000000000,
  0xbffc000000000000,
  0xbff4000000000000,
  0xbff4000000000000,
  0xbff3ffffffffffff,
  0xbfe8000000000000,
  0x401f000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc002000000000000,
  0xc002000000000000,
  0xc002000000000000,
  0xc02e000000000000,
  0xc02e000000000000,
  0xc02f000000000000,
  0xc02f000000000000,
  0xc02f000000000000,
  0xc030000000000000,
  0xc030000000000000,
  0xc030000000000000,
  0xc030800000000000,
  0xc039000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc02e000000000000,
  0xc02e000000000000,
  0xc02e000000000000,
  0xc02e000000000000,
  0xc02e000000000000,
  0xc02d000000000000,
  0xc02d000000000000,
  0xc02d000000000000,
  0xc02c000000000000,
  0xc02c000000000000,
  0xc02c000000000000,
  0xc02b000000000000,
  0xc014000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc02e000000000000,
  0xc02e000000000000,
  0xc02e000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xffdfffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x8001b4e81b4e81b4,
  0x8011b4e81b4e81b4,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x8002d82d82d82d80,
  0x8011b4e81b4e81b2,
  0x8001b4e81b4e81b4,
  0x8001b4e81b4e81b4,
  0x000e4b17e4b17e4c,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x800091a2b3c4d5e6,
  0x000e4b17e4b17e4c,
  0x8001b4e81b4e81b2,
  0x8017fffffffffffe,
  0x8023ffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x801923456789abcc,
  0x8023ffffffffffff,
  0x8018000000000000,
  0x8017fffffffffffe,
  0x8007fffffffffffe,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8016dcba98765432,
  0x8008000000000000,
  0x8017fffffffffffe,
  0x8000000000000002,
  0x8010000000000002,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abce,
  0x8010000000000000,
  0x8000000000000002,
  0x8000000000000002,
  0x000ffffffffffffe,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcc,
  0x000ffffffffffffe,
  0x8000000000000000,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0044000000000000,
  0x0042000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0043db97530eca86,
  0x0042000000000000,
  0x0044000000000000,
  0x0044000000000000,
  0x0046000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x00442468acf1357a,
  0x0046000000000000,
  0x0044000000000000,
  0x4013ffffffffffff,
  0x4013ffffffffffff,
  0x4011ffffffffffff,
  0x4011ffffffffffff,
  0x4011ffffffffffff,
  0x400fffffffffffff,
  0x400fffffffffffff,
  0x400ffffffffffffe,
  0x400bffffffffffff,
  0xc014000000000001,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x4013ffffffffffff,
  0x4013ffffffffffff,
  0x4013ffffffffffff,
  0x4013ffffffffffff,
  0x4013ffffffffffff,
  0x4015ffffffffffff,
  0x4015ffffffffffff,
  0x4016000000000000,
  0x4017ffffffffffff,
  0x4017ffffffffffff,
  0x4018000000000000,
  0x4019ffffffffffff,
  0x402e000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x4013ffffffffffff,
  0x4013ffffffffffff,
  0x4013ffffffffffff,
  0x4014000000000000,
  0x4014000000000000,
  0x4012000000000000,
  0x4012000000000000,
  0x4012000000000000,
  0x4010000000000000,
  0x4010000000000000,
  0x4010000000000000,
  0x400c000000000000,
  0xc014000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x4014000000000000,
  0x4014000000000000,
  0x4014000000000000,
  0x4014000000000000,
  0x4014000000000000,
  0x4016000000000000,
  0x4016000000000000,
  0x4016000000000000,
  0x4018000000000000,
  0x4018000000000000,
  0x4018000000000000,
  0x401a000000000000,
  0x402e000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x4014000000000000,
  0x4014000000000000,
  0x4014000000000000,
  0x4014000000000001,
  0x4014000000000001,
  0x4012000000000001,
  0x4012000000000001,
  0x4012000000000001,
  0x4010000000000001,
  0x4010000000000001,
  0x4010000000000001,
  0x400c000000000002,
  0xc013ffffffffffff,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x4014000000000001,
  0x4014000000000001,
  0x4014000000000001,
  0x4014000000000001,
  0x4014000000000001,
  0x4016000000000001,
  0x4016000000000001,
  0x4016000000000001,
  0x4018000000000001,
  0x4018000000000001,
  0x4018000000000002,
  0x401a000000000001,
  0x402e000000000001,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x4014000000000001,
  0x4014000000000001,
  0x4014000000000001,
  0x4023ffffffffffff,
  0x4023ffffffffffff,
  0x4022ffffffffffff,
  0x4022ffffffffffff,
  0x4022ffffffffffff,
  0x4021ffffffffffff,
  0x4021ffffffffffff,
  0x4021ffffffffffff,
  0x4020ffffffffffff,
  0xbcd4000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x4023ffffffffffff,
  0x4023ffffffffffff,
  0x4023ffffffffffff,
  0x4023ffffffffffff,
  0x4023ffffffffffff,
  0x4024ffffffffffff,
  0x4024ffffffffffff,
  0x4024ffffffffffff,
  0x4025ffffffffffff,
  0x4025ffffffffffff,
  0x4026000000000000,
  0x4026ffffffffffff,
  0x4034000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x4023ffffffffffff,
  0x4023ffffffffffff,
  0x4023ffffffffffff,
  0x4024000000000000,
  0x4024000000000000,
  0x4023000000000000,
  0x4023000000000000,
  0x4023000000000000,
  0x4022000000000000,
  0x4022000000000000,
  0x4022000000000000,
  0x4021000000000000,
  0x0000000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4025000000000000,
  0x4025000000000000,
  0x4025000000000000,
  0x4026000000000000,
  0x4026000000000000,
  0x4026000000000000,
  0x4027000000000000,
  0x4034000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4024000000000001,
  0x4024000000000001,
  0x4023000000000001,
  0x4023000000000001,
  0x4023000000000001,
  0x4022000000000001,
  0x4022000000000001,
  0x4022000000000001,
  0x4021000000000001,
  0x3ce4000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x4024000000000001,
  0x4024000000000001,
  0x4024000000000001,
  0x4024000000000001,
  0x4024000000000001,
  0x4025000000000001,
  0x4025000000000001,
  0x4025000000000001,
  0x4026000000000001,
  0x4026000000000001,
  0x4026000000000001,
  0x4027000000000001,
  0x4034000000000001,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x4024000000000001,
  0x4024000000000001,
  0x4024000000000001,
  0x402e000000000000,
  0x402e000000000000,
  0x402d000000000000,
  0x402d000000000000,
  0x402d000000000000,
  0x402c000000000000,
  0x402c000000000000,
  0x402c000000000000,
  0x402b000000000000,
  0x4014000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x402e000000000000,
  0x402e000000000000,
  0x402e000000000000,
  0x402e000000000000,
  0x402e000000000000,
  0x402f000000000000,
  0x402f000000000000,
  0x402f000000000000,
  0x4030000000000000,
  0x4030000000000000,
  0x4030000000000000,
  0x4030800000000000,
  0x4039000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x402e000000000000,
  0x402e000000000000,
  0x402e000000000000,
  0x4059000000000000,
  0x4059000000000000,
  0x4058e00000000000,
  0x4058e00000000000,
  0x4058e00000000000,
  0x4058c00000000000,
  0x4058c00000000000,
  0x4058c00000000000,
  0x4058a00000000000,
  0x4056800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x4059000000000000,
  0x4059000000000000,
  0x4059000000000000,
  0x4059000000000000,
  0x4059000000000000,
  0x4059200000000000,
  0x4059200000000000,
  0x4059200000000000,
  0x4059400000000000,
  0x4059400000000000,
  0x4059400000000000,
  0x4059600000000000,
  0x405b800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x4059000000000000,
  0x4059000000000000,
  0x4059000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x000b60b60b60b602,
  0x80049f49f49f49fe,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x000a3d70a3d70a35,
  0x80049f49f49f49fd,
  0x000b60b60b60b601,
  0x000b60b60b60b602,
  0x001b60b60b60b602,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000c83fb72ea61cf,
  0x001b60b60b60b601,
  0x000b60b60b60b603,
  0x0043ffffffffffff,
  0x0041ffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0043db97530eca85,
  0x0041ffffffffffff,
  0x0043ffffffffffff,
  0x0043ffffffffffff,
  0x0045ffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x00442468acf13578,
  0x0045ffffffffffff,
  0x0043ffffffffffff,
  0x000000000000000a,
  0x800ffffffffffff6,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abc3,
  0x800ffffffffffff5,
  0x0000000000000009,
  0x000000000000000a,
  0x001000000000000a,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abd7,
  0x0010000000000009,
  0x000000000000000b,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8044000000000000,
  0x8046000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x80442468acf1357a,
  0x8046000000000000,
  0x8044000000000000,
  0x8044000000000000,
  0x8042000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8043db97530eca86,
  0x8042000000000000,
  0x8044000000000000,
  0xc013ffffffffffff,
  0xc013ffffffffffff,
  0xc015ffffffffffff,
  0xc015ffffffffffff,
  0xc016000000000000,
  0xc017ffffffffffff,
  0xc017ffffffffffff,
  0xc018000000000000,
  0xc019ffffffffffff,
  0xc02e000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc013ffffffffffff,
  0xc013ffffffffffff,
  0xc013ffffffffffff,
  0xc013ffffffffffff,
  0xc013ffffffffffff,
  0xc011ffffffffffff,
  0xc011ffffffffffff,
  0xc011ffffffffffff,
  0xc00fffffffffffff,
  0xc00fffffffffffff,
  0xc00ffffffffffffe,
  0xc00bffffffffffff,
  0x4014000000000001,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc013ffffffffffff,
  0xc013ffffffffffff,
  0xc013ffffffffffff,
  0xc014000000000000,
  0xc014000000000000,
  0xc016000000000000,
  0xc016000000000000,
  0xc016000000000000,
  0xc018000000000000,
  0xc018000000000000,
  0xc018000000000000,
  0xc01a000000000000,
  0xc02e000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc014000000000000,
  0xc014000000000000,
  0xc014000000000000,
  0xc014000000000000,
  0xc014000000000000,
  0xc012000000000000,
  0xc012000000000000,
  0xc012000000000000,
  0xc010000000000000,
  0xc010000000000000,
  0xc010000000000000,
  0xc00c000000000000,
  0x4014000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc014000000000000,
  0xc014000000000000,
  0xc014000000000000,
  0xc014000000000001,
  0xc014000000000001,
  0xc016000000000001,
  0xc016000000000001,
  0xc016000000000001,
  0xc018000000000001,
  0xc018000000000001,
  0xc018000000000002,
  0xc01a000000000001,
  0xc02e000000000001,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc014000000000001,
  0xc014000000000001,
  0xc014000000000001,
  0xc014000000000001,
  0xc014000000000001,
  0xc012000000000001,
  0xc012000000000001,
  0xc012000000000001,
  0xc010000000000001,
  0xc010000000000001,
  0xc010000000000001,
  0xc00c000000000002,
  0x4013ffffffffffff,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc014000000000001,
  0xc014000000000001,
  0xc014000000000001,
  0xc023ffffffffffff,
  0xc023ffffffffffff,
  0xc024ffffffffffff,
  0xc024ffffffffffff,
  0xc024ffffffffffff,
  0xc025ffffffffffff,
  0xc025ffffffffffff,
  0xc026000000000000,
  0xc026ffffffffffff,
  0xc034000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc023ffffffffffff,
  0xc023ffffffffffff,
  0xc023ffffffffffff,
  0xc023ffffffffffff,
  0xc023ffffffffffff,
  0xc022ffffffffffff,
  0xc022ffffffffffff,
  0xc022ffffffffffff,
  0xc021ffffffffffff,
  0xc021ffffffffffff,
  0xc021ffffffffffff,
  0xc020ffffffffffff,
  0x3cd4000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc023ffffffffffff,
  0xc023ffffffffffff,
  0xc023ffffffffffff,
  0xc024000000000000,
  0xc024000000000000,
  0xc025000000000000,
  0xc025000000000000,
  0xc025000000000000,
  0xc026000000000000,
  0xc026000000000000,
  0xc026000000000000,
  0xc027000000000000,
  0xc034000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc023000000000000,
  0xc023000000000000,
  0xc023000000000000,
  0xc022000000000000,
  0xc022000000000000,
  0xc022000000000000,
  0xc021000000000000,
  0x0000000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc024000000000001,
  0xc024000000000001,
  0xc025000000000001,
  0xc025000000000001,
  0xc025000000000001,
  0xc026000000000001,
  0xc026000000000001,
  0xc026000000000001,
  0xc027000000000001,
  0xc034000000000001,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc024000000000001,
  0xc024000000000001,
  0xc024000000000001,
  0xc024000000000001,
  0xc024000000000001,
  0xc023000000000001,
  0xc023000000000001,
  0xc023000000000001,
  0xc022000000000001,
  0xc022000000000001,
  0xc022000000000001,
  0xc021000000000001,
  0xbce4000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc024000000000001,
  0xc024000000000001,
  0xc024000000000001,
  0xc02e000000000000,
  0xc02e000000000000,
  0xc02f000000000000,
  0xc02f000000000000,
  0xc02f000000000000,
  0xc030000000000000,
  0xc030000000000000,
  0xc030000000000000,
  0xc030800000000000,
  0xc039000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc02e000000000000,
  0xc02e000000000000,
  0xc02e000000000000,
  0xc02e000000000000,
  0xc02e000000000000,
  0xc02d000000000000,
  0xc02d000000000000,
  0xc02d000000000000,
  0xc02c000000000000,
  0xc02c000000000000,
  0xc02c000000000000,
  0xc02b000000000000,
  0xc014000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc02e000000000000,
  0xc02e000000000000,
  0xc02e000000000000,
  0xc059000000000000,
  0xc059000000000000,
  0xc059200000000000,
  0xc059200000000000,
  0xc059200000000000,
  0xc059400000000000,
  0xc059400000000000,
  0xc059400000000000,
  0xc059600000000000,
  0xc05b800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc059000000000000,
  0xc059000000000000,
  0xc059000000000000,
  0xc059000000000000,
  0xc059000000000000,
  0xc058e00000000000,
  0xc058e00000000000,
  0xc058e00000000000,
  0xc058c00000000000,
  0xc058c00000000000,
  0xc058c00000000000,
  0xc058a00000000000,
  0xc056800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc059000000000000,
  0xc059000000000000,
  0xc059000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x800b60b60b60b602,
  0x801b60b60b60b602,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800c83fb72ea61cf,
  0x801b60b60b60b601,
  0x800b60b60b60b603,
  0x800b60b60b60b602,
  0x00049f49f49f49fe,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x800a3d70a3d70a35,
  0x00049f49f49f49fd,
  0x800b60b60b60b601,
  0x8043ffffffffffff,
  0x8045ffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x80442468acf13578,
  0x8045ffffffffffff,
  0x8043ffffffffffff,
  0x8043ffffffffffff,
  0x8041ffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8043db97530eca85,
  0x8041ffffffffffff,
  0x8043ffffffffffff,
  0x800000000000000a,
  0x801000000000000a,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abd7,
  0x8010000000000009,
  0x800000000000000b,
  0x800000000000000a,
  0x000ffffffffffff6,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abc3,
  0x000ffffffffffff5,
  0x8000000000000009,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x400fffffffffffff,
  0x400fffffffffffff,
  0x400bffffffffffff,
  0x400bffffffffffff,
  0x400bffffffffffff,
  0x4007ffffffffffff,
  0x4007ffffffffffff,
  0x4007fffffffffffe,
  0x4003ffffffffffff,
  0xc018000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x400fffffffffffff,
  0x400fffffffffffff,
  0x400fffffffffffff,
  0x400fffffffffffff,
  0x400fffffffffffff,
  0x4011ffffffffffff,
  0x4012000000000000,
  0x4012000000000000,
  0x4013ffffffffffff,
  0x4014000000000000,
  0x4014000000000000,
  0x4016000000000000,
  0x402c000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x400fffffffffffff,
  0x400fffffffffffff,
  0x400fffffffffffff,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0xffe0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0xffdfffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0xffdffffffffffffd,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0xfc9fffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x0000000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7cafffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7fdfffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x3fd23456789abccf,
  0x3fd23456789abccf,
  0xbfcb97530eca865f,
  0xbfcb97530eca8661,
  0xbfcb97530eca8665,
  0xbfe6e5d4c3b2a197,
  0xbfe6e5d4c3b2a198,
  0xbfe6e5d4c3b2a19a,
  0xbff372ea61d950cc,
  0xc0236e5d4c3b2a1a,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fd23456789abccf,
  0x3fd23456789abccf,
  0x3fd23456789abccf,
  0x3fd23456789abccf,
  0x3fd23456789abccf,
  0x3fe91a2b3c4d5e67,
  0x3fe91a2b3c4d5e68,
  0x3fe91a2b3c4d5e69,
  0x3ff48d159e26af33,
  0x3ff48d159e26af34,
  0x3ff48d159e26af35,
  0x3ffc8d159e26af34,
  0x402491a2b3c4d5e6,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fd23456789abccf,
  0x3fd23456789abccf,
  0x3fd23456789abccf,
  0x400ffffffffffffd,
  0x400ffffffffffffd,
  0x400bfffffffffffd,
  0x400bfffffffffffd,
  0x400bfffffffffffd,
  0x4007fffffffffffd,
  0x4007fffffffffffd,
  0x4007fffffffffffd,
  0x4003fffffffffffd,
  0xc018000000000001,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x400ffffffffffffd,
  0x400ffffffffffffd,
  0x400ffffffffffffd,
  0x400ffffffffffffd,
  0x400ffffffffffffd,
  0x4011fffffffffffe,
  0x4011ffffffffffff,
  0x4011ffffffffffff,
  0x4013fffffffffffe,
  0x4013ffffffffffff,
  0x4013ffffffffffff,
  0x4015ffffffffffff,
  0x402bffffffffffff,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x400ffffffffffffd,
  0x400ffffffffffffd,
  0x400ffffffffffffd,
  0x3ccfffffffffffff,
  0x3ccfffffffffffff,
  0xbfdfffffffffffef,
  0xbfdffffffffffff0,
  0xbfdffffffffffff2,
  0xbfeffffffffffff7,
  0xbfeffffffffffff8,
  0xbfeffffffffffffa,
  0xbff7fffffffffffc,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3ccfffffffffffff,
  0x3ccfffffffffffff,
  0x3ccfffffffffffff,
  0x3ccfffffffffffff,
  0x3ccfffffffffffff,
  0x3fe0000000000007,
  0x3fe0000000000008,
  0x3fe0000000000009,
  0x3ff0000000000003,
  0x3ff0000000000004,
  0x3ff0000000000005,
  0x3ff8000000000004,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3ccfffffffffffff,
  0x3ccfffffffffffff,
  0x3ccfffffffffffff,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0xc00fffffffffffff,
  0xc00fffffffffffff,
  0xc011ffffffffffff,
  0xc012000000000000,
  0xc012000000000000,
  0xc013ffffffffffff,
  0xc014000000000000,
  0xc014000000000000,
  0xc016000000000000,
  0xc02c000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc00fffffffffffff,
  0xc00fffffffffffff,
  0xc00fffffffffffff,
  0xc00fffffffffffff,
  0xc00fffffffffffff,
  0xc00bffffffffffff,
  0xc00bffffffffffff,
  0xc00bffffffffffff,
  0xc007ffffffffffff,
  0xc007ffffffffffff,
  0xc007fffffffffffe,
  0xc003ffffffffffff,
  0x4018000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc00fffffffffffff,
  0xc00fffffffffffff,
  0xc00fffffffffffff,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0x7fe0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0x7fdfffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0x7fdffffffffffffd,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0x7c9fffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0x0000000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfcafffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xffdfffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xbfd23456789abccf,
  0xbfd23456789abccf,
  0xbfe91a2b3c4d5e67,
  0xbfe91a2b3c4d5e68,
  0xbfe91a2b3c4d5e69,
  0xbff48d159e26af33,
  0xbff48d159e26af34,
  0xbff48d159e26af35,
  0xbffc8d159e26af34,
  0xc02491a2b3c4d5e6,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfd23456789abccf,
  0xbfd23456789abccf,
  0xbfd23456789abccf,
  0xbfd23456789abccf,
  0xbfd23456789abccf,
  0x3fcb97530eca865f,
  0x3fcb97530eca8661,
  0x3fcb97530eca8665,
  0x3fe6e5d4c3b2a197,
  0x3fe6e5d4c3b2a198,
  0x3fe6e5d4c3b2a19a,
  0x3ff372ea61d950cc,
  0x40236e5d4c3b2a1a,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfd23456789abccf,
  0xbfd23456789abccf,
  0xbfd23456789abccf,
  0xc00ffffffffffffd,
  0xc00ffffffffffffd,
  0xc011fffffffffffe,
  0xc011ffffffffffff,
  0xc011ffffffffffff,
  0xc013fffffffffffe,
  0xc013ffffffffffff,
  0xc013ffffffffffff,
  0xc015ffffffffffff,
  0xc02bffffffffffff,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc00ffffffffffffd,
  0xc00ffffffffffffd,
  0xc00ffffffffffffd,
  0xc00ffffffffffffd,
  0xc00ffffffffffffd,
  0xc00bfffffffffffd,
  0xc00bfffffffffffd,
  0xc00bfffffffffffd,
  0xc007fffffffffffd,
  0xc007fffffffffffd,
  0xc007fffffffffffd,
  0xc003fffffffffffd,
  0x4018000000000001,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc00ffffffffffffd,
  0xc00ffffffffffffd,
  0xc00ffffffffffffd,
  0xbccfffffffffffff,
  0xbccfffffffffffff,
  0xbfe0000000000007,
  0xbfe0000000000008,
  0xbfe0000000000009,
  0xbff0000000000003,
  0xbff0000000000004,
  0xbff0000000000005,
  0xbff8000000000004,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbccfffffffffffff,
  0xbccfffffffffffff,
  0xbccfffffffffffff,
  0xbccfffffffffffff,
  0xbccfffffffffffff,
  0x3fdfffffffffffef,
  0x3fdffffffffffff0,
  0x3fdffffffffffff2,
  0x3feffffffffffff7,
  0x3feffffffffffff8,
  0x3feffffffffffffa,
  0x3ff7fffffffffffc,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbccfffffffffffff,
  0xbccfffffffffffff,
  0xbccfffffffffffff,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x000091a2b3c4d5e6,
  0x800f6e5d4c3b2a1a,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800091a2b3c4d5e7,
  0x800f6e5d4c3b2a19,
  0x000091a2b3c4d5e5,
  0x000091a2b3c4d5e6,
  0x001091a2b3c4d5e6,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0001b4e81b4e81b3,
  0x001091a2b3c4d5e5,
  0x000091a2b3c4d5e7,
  0x000091a2b3c4d5e6,
  0x800f6e5d4c3b2a1a,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800091a2b3c4d5e6,
  0x800f6e5d4c3b2a18,
  0x000091a2b3c4d5e6,
  0x000091a2b3c4d5e6,
  0x001091a2b3c4d5e6,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0001b4e81b4e81b4,
  0x001091a2b3c4d5e6,
  0x000091a2b3c4d5e8,
  0x000091a2b3c4d5e7,
  0x800f6e5d4c3b2a19,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800091a2b3c4d5e6,
  0x800f6e5d4c3b2a18,
  0x000091a2b3c4d5e6,
  0x000091a2b3c4d5e7,
  0x001091a2b3c4d5e7,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0001b4e81b4e81b4,
  0x001091a2b3c4d5e6,
  0x000091a2b3c4d5e8,
  0x000123456789abcd,
  0x800edcba98765433,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x8000000000000000,
  0x800edcba98765432,
  0x000123456789abcc,
  0x000123456789abcd,
  0x001123456789abcd,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0002468acf13579a,
  0x001123456789abcc,
  0x000123456789abce,
  0x000123456789abcd,
  0x800edcba98765433,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0000000000000000,
  0x800edcba98765432,
  0x000123456789abcc,
  0x000123456789abcd,
  0x001123456789abcd,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0002468acf13579a,
  0x001123456789abcc,
  0x000123456789abce,
  0x000123456789abcd,
  0x800edcba98765433,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0000000000000000,
  0x800edcba98765432,
  0x000123456789abcc,
  0x000123456789abcd,
  0x001123456789abcd,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0002468acf13579a,
  0x001123456789abcc,
  0x000123456789abce,
  0x0001b4e81b4e81b4,
  0x800e4b17e4b17e4c,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x000091a2b3c4d5e6,
  0x800e4b17e4b17e4c,
  0x0001b4e81b4e81b2,
  0x0001b4e81b4e81b4,
  0x0011b4e81b4e81b4,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0002d82d82d82d80,
  0x0011b4e81b4e81b2,
  0x0001b4e81b4e81b4,
  0x000b60b60b60b602,
  0x80049f49f49f49fe,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x000a3d70a3d70a35,
  0x80049f49f49f49fd,
  0x000b60b60b60b601,
  0x000b60b60b60b602,
  0x001b60b60b60b602,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000c83fb72ea61cf,
  0x001b60b60b60b601,
  0x000b60b60b60b603,
  0x3fd23456789abccf,
  0x3fd23456789abccf,
  0xbfcb97530eca865f,
  0xbfcb97530eca8661,
  0xbfcb97530eca8665,
  0xbfe6e5d4c3b2a197,
  0xbfe6e5d4c3b2a198,
  0xbfe6e5d4c3b2a19a,
  0xbff372ea61d950cc,
  0xc0236e5d4c3b2a1a,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fd23456789abccf,
  0x3fd23456789abccf,
  0x3fd23456789abccf,
  0x3fd23456789abccf,
  0x3fd23456789abccf,
  0x3fe91a2b3c4d5e67,
  0x3fe91a2b3c4d5e68,
  0x3fe91a2b3c4d5e69,
  0x3ff48d159e26af33,
  0x3ff48d159e26af34,
  0x3ff48d159e26af35,
  0x3ffc8d159e26af34,
  0x402491a2b3c4d5e6,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fd23456789abccf,
  0x3fd23456789abccf,
  0x3fd23456789abccf,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x800091a2b3c4d5e6,
  0x801091a2b3c4d5e6,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x8001b4e81b4e81b3,
  0x801091a2b3c4d5e5,
  0x800091a2b3c4d5e7,
  0x800091a2b3c4d5e6,
  0x000f6e5d4c3b2a1a,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000091a2b3c4d5e7,
  0x000f6e5d4c3b2a19,
  0x800091a2b3c4d5e5,
  0x800091a2b3c4d5e6,
  0x801091a2b3c4d5e6,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x8001b4e81b4e81b4,
  0x801091a2b3c4d5e6,
  0x800091a2b3c4d5e8,
  0x800091a2b3c4d5e6,
  0x000f6e5d4c3b2a1a,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000091a2b3c4d5e6,
  0x000f6e5d4c3b2a18,
  0x800091a2b3c4d5e6,
  0x800091a2b3c4d5e7,
  0x801091a2b3c4d5e7,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x8001b4e81b4e81b4,
  0x801091a2b3c4d5e6,
  0x800091a2b3c4d5e8,
  0x800091a2b3c4d5e7,
  0x000f6e5d4c3b2a19,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000091a2b3c4d5e6,
  0x000f6e5d4c3b2a18,
  0x800091a2b3c4d5e6,
  0x800123456789abcd,
  0x801123456789abcd,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x8002468acf13579a,
  0x801123456789abcc,
  0x800123456789abce,
  0x800123456789abcd,
  0x000edcba98765433,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0000000000000000,
  0x000edcba98765432,
  0x800123456789abcc,
  0x800123456789abcd,
  0x801123456789abcd,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x8002468acf13579a,
  0x801123456789abcc,
  0x800123456789abce,
  0x800123456789abcd,
  0x000edcba98765433,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0000000000000000,
  0x000edcba98765432,
  0x800123456789abcc,
  0x800123456789abcd,
  0x801123456789abcd,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x8002468acf13579a,
  0x801123456789abcc,
  0x800123456789abce,
  0x800123456789abcd,
  0x000edcba98765433,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8000000000000000,
  0x000edcba98765432,
  0x800123456789abcc,
  0x8001b4e81b4e81b4,
  0x8011b4e81b4e81b4,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x8002d82d82d82d80,
  0x8011b4e81b4e81b2,
  0x8001b4e81b4e81b4,
  0x8001b4e81b4e81b4,
  0x000e4b17e4b17e4c,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x800091a2b3c4d5e6,
  0x000e4b17e4b17e4c,
  0x8001b4e81b4e81b2,
  0x800b60b60b60b602,
  0x801b60b60b60b602,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800c83fb72ea61cf,
  0x801b60b60b60b601,
  0x800b60b60b60b603,
  0x800b60b60b60b602,
  0x00049f49f49f49fe,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x800a3d70a3d70a35,
  0x00049f49f49f49fd,
  0x800b60b60b60b601,
  0xbfd23456789abccf,
  0xbfd23456789abccf,
  0xbfe91a2b3c4d5e67,
  0xbfe91a2b3c4d5e68,
  0xbfe91a2b3c4d5e69,
  0xbff48d159e26af33,
  0xbff48d159e26af34,
  0xbff48d159e26af35,
  0xbffc8d159e26af34,
  0xc02491a2b3c4d5e6,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfd23456789abccf,
  0xbfd23456789abccf,
  0xbfd23456789abccf,
  0xbfd23456789abccf,
  0xbfd23456789abccf,
  0x3fcb97530eca865f,
  0x3fcb97530eca8661,
  0x3fcb97530eca8665,
  0x3fe6e5d4c3b2a197,
  0x3fe6e5d4c3b2a198,
  0x3fe6e5d4c3b2a19a,
  0x3ff372ea61d950cc,
  0x40236e5d4c3b2a1a,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfd23456789abccf,
  0xbfd23456789abccf,
  0xbfd23456789abccf,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0007ffffffffffff,
  0x8008000000000001,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0006dcba98765432,
  0x8008000000000000,
  0x0007fffffffffffe,
  0x0007ffffffffffff,
  0x0017ffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000923456789abcc,
  0x0017fffffffffffe,
  0x0008000000000000,
  0x0008000000000000,
  0x8008000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0006dcba98765432,
  0x8008000000000000,
  0x0007fffffffffffe,
  0x0008000000000000,
  0x0018000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000923456789abcc,
  0x0017fffffffffffe,
  0x0008000000000000,
  0x0008000000000000,
  0x8008000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0006dcba98765433,
  0x8007ffffffffffff,
  0x0007ffffffffffff,
  0x0008000000000000,
  0x0018000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000923456789abcd,
  0x0017ffffffffffff,
  0x0008000000000001,
  0x000fffffffffffff,
  0x8000000000000001,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x000edcba98765432,
  0x8000000000000000,
  0x000ffffffffffffe,
  0x000fffffffffffff,
  0x001fffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x001123456789abcc,
  0x001ffffffffffffe,
  0x0010000000000000,
  0x000fffffffffffff,
  0x8000000000000001,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x000edcba98765432,
  0x0000000000000000,
  0x000ffffffffffffe,
  0x000fffffffffffff,
  0x001fffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x001123456789abcc,
  0x001ffffffffffffe,
  0x0010000000000000,
  0x0010000000000000,
  0x8000000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x000edcba98765433,
  0x0000000000000001,
  0x000fffffffffffff,
  0x0010000000000000,
  0x0020000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x001123456789abcd,
  0x001fffffffffffff,
  0x0010000000000001,
  0x0017fffffffffffe,
  0x0007fffffffffffe,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0016dcba98765432,
  0x0008000000000000,
  0x0017fffffffffffe,
  0x0017fffffffffffe,
  0x0023ffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x001923456789abcc,
  0x0023ffffffffffff,
  0x0018000000000000,
  0x0043ffffffffffff,
  0x0041ffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0043db97530eca85,
  0x0041ffffffffffff,
  0x0043ffffffffffff,
  0x0043ffffffffffff,
  0x0045ffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x00442468acf13578,
  0x0045ffffffffffff,
  0x0043ffffffffffff,
  0x400ffffffffffffd,
  0x400ffffffffffffd,
  0x400bfffffffffffd,
  0x400bfffffffffffd,
  0x400bfffffffffffd,
  0x4007fffffffffffd,
  0x4007fffffffffffd,
  0x4007fffffffffffd,
  0x4003fffffffffffd,
  0xc018000000000001,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x400ffffffffffffd,
  0x400ffffffffffffd,
  0x400ffffffffffffd,
  0x400ffffffffffffd,
  0x400ffffffffffffd,
  0x4011fffffffffffe,
  0x4011ffffffffffff,
  0x4011ffffffffffff,
  0x4013fffffffffffe,
  0x4013ffffffffffff,
  0x4013ffffffffffff,
  0x4015ffffffffffff,
  0x402bffffffffffff,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x400ffffffffffffd,
  0x400ffffffffffffd,
  0x400ffffffffffffd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8007ffffffffffff,
  0x8017ffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800923456789abcc,
  0x8017fffffffffffe,
  0x8008000000000000,
  0x8007ffffffffffff,
  0x0008000000000001,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8006dcba98765432,
  0x0008000000000000,
  0x8007fffffffffffe,
  0x8008000000000000,
  0x8018000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800923456789abcc,
  0x8017fffffffffffe,
  0x8008000000000000,
  0x8008000000000000,
  0x0008000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8006dcba98765432,
  0x0008000000000000,
  0x8007fffffffffffe,
  0x8008000000000000,
  0x8018000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800923456789abcd,
  0x8017ffffffffffff,
  0x8008000000000001,
  0x8008000000000000,
  0x0008000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8006dcba98765433,
  0x0007ffffffffffff,
  0x8007ffffffffffff,
  0x800fffffffffffff,
  0x801fffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x801123456789abcc,
  0x801ffffffffffffe,
  0x8010000000000000,
  0x800fffffffffffff,
  0x0000000000000001,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x800edcba98765432,
  0x0000000000000000,
  0x800ffffffffffffe,
  0x800fffffffffffff,
  0x801fffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x801123456789abcc,
  0x801ffffffffffffe,
  0x8010000000000000,
  0x800fffffffffffff,
  0x0000000000000001,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x800edcba98765432,
  0x0000000000000000,
  0x800ffffffffffffe,
  0x8010000000000000,
  0x8020000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x801123456789abcd,
  0x801fffffffffffff,
  0x8010000000000001,
  0x8010000000000000,
  0x0000000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x800edcba98765433,
  0x8000000000000001,
  0x800fffffffffffff,
  0x8017fffffffffffe,
  0x8023ffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x801923456789abcc,
  0x8023ffffffffffff,
  0x8018000000000000,
  0x8017fffffffffffe,
  0x8007fffffffffffe,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8016dcba98765432,
  0x8008000000000000,
  0x8017fffffffffffe,
  0x8043ffffffffffff,
  0x8045ffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x80442468acf13578,
  0x8045ffffffffffff,
  0x8043ffffffffffff,
  0x8043ffffffffffff,
  0x8041ffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8043db97530eca85,
  0x8041ffffffffffff,
  0x8043ffffffffffff,
  0xc00ffffffffffffd,
  0xc00ffffffffffffd,
  0xc011fffffffffffe,
  0xc011ffffffffffff,
  0xc011ffffffffffff,
  0xc013fffffffffffe,
  0xc013ffffffffffff,
  0xc013ffffffffffff,
  0xc015ffffffffffff,
  0xc02bffffffffffff,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc00ffffffffffffd,
  0xc00ffffffffffffd,
  0xc00ffffffffffffd,
  0xc00ffffffffffffd,
  0xc00ffffffffffffd,
  0xc00bfffffffffffd,
  0xc00bfffffffffffd,
  0xc00bfffffffffffd,
  0xc007fffffffffffd,
  0xc007fffffffffffd,
  0xc007fffffffffffd,
  0xc003fffffffffffd,
  0x4018000000000001,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc00ffffffffffffd,
  0xc00ffffffffffffd,
  0xc00ffffffffffffd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcc,
  0x800ffffffffffffe,
  0x8000000000000000,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abce,
  0x0010000000000000,
  0x0000000000000002,
  0x0000000000000001,
  0x800fffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcc,
  0x800ffffffffffffe,
  0x8000000000000000,
  0x0000000000000001,
  0x0010000000000001,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abce,
  0x0010000000000000,
  0x0000000000000002,
  0x0000000000000001,
  0x800fffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcc,
  0x800ffffffffffffe,
  0x8000000000000000,
  0x0000000000000001,
  0x0010000000000001,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abce,
  0x0010000000000000,
  0x0000000000000002,
  0x0000000000000001,
  0x800fffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcc,
  0x800ffffffffffffe,
  0x0000000000000000,
  0x0000000000000001,
  0x0010000000000001,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abce,
  0x0010000000000000,
  0x0000000000000002,
  0x0000000000000001,
  0x800fffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcc,
  0x800ffffffffffffe,
  0x0000000000000000,
  0x0000000000000001,
  0x0010000000000001,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abce,
  0x0010000000000000,
  0x0000000000000002,
  0x0000000000000002,
  0x800ffffffffffffe,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcc,
  0x800ffffffffffffe,
  0x0000000000000000,
  0x0000000000000002,
  0x0010000000000002,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abce,
  0x0010000000000000,
  0x0000000000000002,
  0x000000000000000a,
  0x800ffffffffffff6,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abc3,
  0x800ffffffffffff5,
  0x0000000000000009,
  0x000000000000000a,
  0x001000000000000a,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abd7,
  0x0010000000000009,
  0x000000000000000b,
  0x3ccfffffffffffff,
  0x3ccfffffffffffff,
  0xbfdfffffffffffef,
  0xbfdffffffffffff0,
  0xbfdffffffffffff2,
  0xbfeffffffffffff7,
  0xbfeffffffffffff8,
  0xbfeffffffffffffa,
  0xbff7fffffffffffc,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3ccfffffffffffff,
  0x3ccfffffffffffff,
  0x3ccfffffffffffff,
  0x3ccfffffffffffff,
  0x3ccfffffffffffff,
  0x3fe0000000000007,
  0x3fe0000000000008,
  0x3fe0000000000009,
  0x3ff0000000000003,
  0x3ff0000000000004,
  0x3ff0000000000005,
  0x3ff8000000000004,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3ccfffffffffffff,
  0x3ccfffffffffffff,
  0x3ccfffffffffffff,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abce,
  0x8010000000000000,
  0x8000000000000002,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcc,
  0x000ffffffffffffe,
  0x0000000000000000,
  0x8000000000000001,
  0x8010000000000001,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abce,
  0x8010000000000000,
  0x8000000000000002,
  0x8000000000000001,
  0x000fffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcc,
  0x000ffffffffffffe,
  0x0000000000000000,
  0x8000000000000001,
  0x8010000000000001,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abce,
  0x8010000000000000,
  0x8000000000000002,
  0x8000000000000001,
  0x000fffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcc,
  0x000ffffffffffffe,
  0x0000000000000000,
  0x8000000000000001,
  0x8010000000000001,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abce,
  0x8010000000000000,
  0x8000000000000002,
  0x8000000000000001,
  0x000fffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcc,
  0x000ffffffffffffe,
  0x0000000000000000,
  0x8000000000000001,
  0x8010000000000001,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abce,
  0x8010000000000000,
  0x8000000000000002,
  0x8000000000000001,
  0x000fffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcc,
  0x000ffffffffffffe,
  0x8000000000000000,
  0x8000000000000002,
  0x8010000000000002,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abce,
  0x8010000000000000,
  0x8000000000000002,
  0x8000000000000002,
  0x000ffffffffffffe,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcc,
  0x000ffffffffffffe,
  0x8000000000000000,
  0x800000000000000a,
  0x801000000000000a,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abd7,
  0x8010000000000009,
  0x800000000000000b,
  0x800000000000000a,
  0x000ffffffffffff6,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abc3,
  0x000ffffffffffff5,
  0x8000000000000009,
  0xbccfffffffffffff,
  0xbccfffffffffffff,
  0xbfe0000000000007,
  0xbfe0000000000008,
  0xbfe0000000000009,
  0xbff0000000000003,
  0xbff0000000000004,
  0xbff0000000000005,
  0xbff8000000000004,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbccfffffffffffff,
  0xbccfffffffffffff,
  0xbccfffffffffffff,
  0xbccfffffffffffff,
  0xbccfffffffffffff,
  0x3fdfffffffffffef,
  0x3fdffffffffffff0,
  0x3fdffffffffffff2,
  0x3feffffffffffff7,
  0x3feffffffffffff8,
  0x3feffffffffffffa,
  0x3ff7fffffffffffc,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbccfffffffffffff,
  0xbccfffffffffffff,
  0xbccfffffffffffff,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
};
const unsigned kExpectedCount_fnmadd_d = 54872;

const uint32_t kExpected_fnmadd_s[] = {
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80400000,
  0x80c00000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80523456,
  0x80bfffff,
  0x80400001,
  0x80400000,
  0x00400000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x802dcbaa,
  0x003fffff,
  0x803fffff,
  0x80400000,
  0x80c00000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80523456,
  0x80bfffff,
  0x80400001,
  0x80400000,
  0x00400000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x802dcbaa,
  0x003fffff,
  0x803fffff,
  0x80400000,
  0x80c00000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80523456,
  0x80c00000,
  0x80400002,
  0x80400000,
  0x00400000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x802dcbaa,
  0x003ffffe,
  0x80400000,
  0x80800000,
  0x81000000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80923456,
  0x80fffffe,
  0x80800000,
  0x80800000,
  0x00000000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x806dcbaa,
  0x80000000,
  0x807ffffe,
  0x80800000,
  0x81000000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80923456,
  0x80ffffff,
  0x80800001,
  0x80800000,
  0x00000000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x806dcbaa,
  0x80000001,
  0x807fffff,
  0x80800001,
  0x81000000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80923457,
  0x81000000,
  0x80800002,
  0x80800001,
  0x80000001,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x806dcbab,
  0x80000002,
  0x80800000,
  0x80c00000,
  0x81200000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80d23456,
  0x81200000,
  0x80c00001,
  0x80c00000,
  0x80400000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x80adcbaa,
  0x80400001,
  0x80bfffff,
  0x82200000,
  0x82300000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x8222468b,
  0x82300000,
  0x82200000,
  0x82200000,
  0x82100000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x821db975,
  0x82100000,
  0x82200000,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00400000,
  0x80400000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x002dcbaa,
  0x803fffff,
  0x003fffff,
  0x00400000,
  0x00c00000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00523456,
  0x00bfffff,
  0x00400001,
  0x00400000,
  0x80400000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x002dcbaa,
  0x803fffff,
  0x003fffff,
  0x00400000,
  0x00c00000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00523456,
  0x00bfffff,
  0x00400001,
  0x00400000,
  0x80400000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x002dcbaa,
  0x803ffffe,
  0x00400000,
  0x00400000,
  0x00c00000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00523456,
  0x00c00000,
  0x00400002,
  0x00800000,
  0x80000000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x006dcbaa,
  0x00000000,
  0x007ffffe,
  0x00800000,
  0x01000000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00923456,
  0x00fffffe,
  0x00800000,
  0x00800000,
  0x00000000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x006dcbaa,
  0x00000001,
  0x007fffff,
  0x00800000,
  0x01000000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00923456,
  0x00ffffff,
  0x00800001,
  0x00800001,
  0x00000001,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x006dcbab,
  0x00000002,
  0x00800000,
  0x00800001,
  0x01000000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00923457,
  0x01000000,
  0x00800002,
  0x00c00000,
  0x00400000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x00adcbaa,
  0x00400001,
  0x00bfffff,
  0x00c00000,
  0x01200000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00d23456,
  0x01200000,
  0x00c00001,
  0x02200000,
  0x02100000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x021db975,
  0x02100000,
  0x02200000,
  0x02200000,
  0x02300000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x0222468b,
  0x02300000,
  0x02200000,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80400000,
  0x80c00000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80523456,
  0x80bfffff,
  0x80400001,
  0x80400000,
  0x00400000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x802dcbaa,
  0x003fffff,
  0x803fffff,
  0xbe7ffffe,
  0xbe7ffffe,
  0xbf3fffff,
  0xbf400000,
  0xbf400001,
  0xbf9fffff,
  0xbfa00000,
  0xbfa00001,
  0xbfe00000,
  0xc1240000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbe7ffffe,
  0xbe7ffffe,
  0xbe7ffffe,
  0xbe7ffffe,
  0xbe7ffffe,
  0x3e800000,
  0x3e800001,
  0x3e800003,
  0x3f3fffff,
  0x3f400000,
  0x3f400002,
  0x3fa00000,
  0x411c0000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbe7ffffe,
  0xbe7ffffe,
  0xbe7ffffe,
  0xbe7fffff,
  0xbe7fffff,
  0xbf3fffff,
  0xbf400000,
  0xbf400001,
  0xbf9fffff,
  0xbfa00000,
  0xbfa00001,
  0xbfe00000,
  0xc1240000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbe7fffff,
  0xbe7fffff,
  0xbe7fffff,
  0xbe7fffff,
  0xbe7fffff,
  0x3e7fffff,
  0x3e800000,
  0x3e800002,
  0x3f3fffff,
  0x3f400000,
  0x3f400002,
  0x3fa00000,
  0x411c0000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbe7fffff,
  0xbe7fffff,
  0xbe7fffff,
  0xbe800000,
  0xbe800000,
  0xbf400000,
  0xbf400000,
  0xbf400001,
  0xbfa00000,
  0xbfa00000,
  0xbfa00001,
  0xbfe00000,
  0xc1240000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbe800000,
  0xbe800000,
  0xbe800000,
  0xbe800000,
  0xbe800000,
  0x3e7ffffd,
  0x3e7fffff,
  0x3e800002,
  0x3f3fffff,
  0x3f400000,
  0x3f400002,
  0x3fa00000,
  0x411c0000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbe800000,
  0xbe800000,
  0xbe800000,
  0xbefffffe,
  0xbefffffe,
  0xbf7fffff,
  0xbf7fffff,
  0xbf800000,
  0xbfbfffff,
  0xbfc00000,
  0xbfc00001,
  0xc0000000,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbefffffe,
  0xbefffffe,
  0xbefffffe,
  0xbefffffe,
  0xbefffffe,
  0x32ffffff,
  0x33800000,
  0x34000000,
  0x3f000000,
  0x3f000001,
  0x3f000003,
  0x3f800000,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbefffffe,
  0xbefffffe,
  0xbefffffe,
  0xbeffffff,
  0xbeffffff,
  0xbf7fffff,
  0xbf800000,
  0xbf800000,
  0xbfbfffff,
  0xbfc00000,
  0xbfc00001,
  0xc0000000,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0x00000000,
  0x33000000,
  0x33c00000,
  0x3effffff,
  0x3f000000,
  0x3f000002,
  0x3f800000,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbf000000,
  0xbf000000,
  0xbf800000,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xbfc00000,
  0xbfc00001,
  0xc0000000,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xb37fffff,
  0xb2fffffe,
  0x33000001,
  0x3efffffd,
  0x3effffff,
  0x3f000002,
  0x3f800000,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf3fffff,
  0xbf3fffff,
  0xbf9fffff,
  0xbfa00000,
  0xbfa00000,
  0xbfdfffff,
  0xbfe00000,
  0xbfe00001,
  0xc0100000,
  0xc12c0000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf3fffff,
  0xbf3fffff,
  0xbf3fffff,
  0xbf3fffff,
  0xbf3fffff,
  0xbe7fffff,
  0xbe7ffffd,
  0xbe7ffff9,
  0x3e7fffff,
  0x3e800002,
  0x3e800006,
  0x3f400001,
  0x41140000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf3fffff,
  0xbf3fffff,
  0xbf3fffff,
  0xc09fffff,
  0xc09fffff,
  0xc0afffff,
  0xc0afffff,
  0xc0b00000,
  0xc0bfffff,
  0xc0bfffff,
  0xc0c00000,
  0xc0cfffff,
  0xc1700000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xc09fffff,
  0xc09fffff,
  0xc09fffff,
  0xc09fffff,
  0xc09fffff,
  0xc08fffff,
  0xc08fffff,
  0xc08fffff,
  0xc07fffff,
  0xc07fffff,
  0xc07ffffe,
  0xc05fffff,
  0x40a00001,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xc09fffff,
  0xc09fffff,
  0xc09fffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x80091a2b,
  0x80891a2b,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x801b4e81,
  0x80891a2a,
  0x80091a2c,
  0x80091a2b,
  0x0076e5d5,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00091a2b,
  0x0076e5d4,
  0x80091a2a,
  0x803fffff,
  0x80bfffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80523455,
  0x80bffffe,
  0x80400000,
  0x803fffff,
  0x00400001,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x802dcba9,
  0x00400000,
  0x803ffffe,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00400000,
  0x80400000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x002dcbaa,
  0x803fffff,
  0x003fffff,
  0x00400000,
  0x00c00000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00523456,
  0x00bfffff,
  0x00400001,
  0x3e7ffffe,
  0x3e7ffffe,
  0xbe800000,
  0xbe800001,
  0xbe800003,
  0xbf3fffff,
  0xbf400000,
  0xbf400002,
  0xbfa00000,
  0xc11c0000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3e7ffffe,
  0x3e7ffffe,
  0x3e7ffffe,
  0x3e7ffffe,
  0x3e7ffffe,
  0x3f3fffff,
  0x3f400000,
  0x3f400001,
  0x3f9fffff,
  0x3fa00000,
  0x3fa00001,
  0x3fe00000,
  0x41240000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3e7ffffe,
  0x3e7ffffe,
  0x3e7ffffe,
  0x3e7fffff,
  0x3e7fffff,
  0xbe7fffff,
  0xbe800000,
  0xbe800002,
  0xbf3fffff,
  0xbf400000,
  0xbf400002,
  0xbfa00000,
  0xc11c0000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3e7fffff,
  0x3e7fffff,
  0x3e7fffff,
  0x3e7fffff,
  0x3e7fffff,
  0x3f3fffff,
  0x3f400000,
  0x3f400001,
  0x3f9fffff,
  0x3fa00000,
  0x3fa00001,
  0x3fe00000,
  0x41240000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3e7fffff,
  0x3e7fffff,
  0x3e7fffff,
  0x3e800000,
  0x3e800000,
  0xbe7ffffd,
  0xbe7fffff,
  0xbe800002,
  0xbf3fffff,
  0xbf400000,
  0xbf400002,
  0xbfa00000,
  0xc11c0000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3e800000,
  0x3e800000,
  0x3e800000,
  0x3e800000,
  0x3e800000,
  0x3f400000,
  0x3f400000,
  0x3f400001,
  0x3fa00000,
  0x3fa00000,
  0x3fa00001,
  0x3fe00000,
  0x41240000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3e800000,
  0x3e800000,
  0x3e800000,
  0x3efffffe,
  0x3efffffe,
  0xb2ffffff,
  0xb3800000,
  0xb4000000,
  0xbf000000,
  0xbf000001,
  0xbf000003,
  0xbf800000,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3efffffe,
  0x3efffffe,
  0x3efffffe,
  0x3efffffe,
  0x3efffffe,
  0x3f7fffff,
  0x3f7fffff,
  0x3f800000,
  0x3fbfffff,
  0x3fc00000,
  0x3fc00001,
  0x40000000,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3efffffe,
  0x3efffffe,
  0x3efffffe,
  0x3effffff,
  0x3effffff,
  0x00000000,
  0xb3000000,
  0xb3c00000,
  0xbeffffff,
  0xbf000000,
  0xbf000002,
  0xbf800000,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3f7fffff,
  0x3f800000,
  0x3f800000,
  0x3fbfffff,
  0x3fc00000,
  0x3fc00001,
  0x40000000,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3f000000,
  0x3f000000,
  0x337fffff,
  0x32fffffe,
  0xb3000001,
  0xbefffffd,
  0xbeffffff,
  0xbf000002,
  0xbf800000,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f800000,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x3fc00000,
  0x3fc00001,
  0x40000000,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f3fffff,
  0x3f3fffff,
  0x3e7fffff,
  0x3e7ffffd,
  0x3e7ffff9,
  0xbe7fffff,
  0xbe800002,
  0xbe800006,
  0xbf400001,
  0xc1140000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f3fffff,
  0x3f3fffff,
  0x3f3fffff,
  0x3f3fffff,
  0x3f3fffff,
  0x3f9fffff,
  0x3fa00000,
  0x3fa00000,
  0x3fdfffff,
  0x3fe00000,
  0x3fe00001,
  0x40100000,
  0x412c0000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f3fffff,
  0x3f3fffff,
  0x3f3fffff,
  0x409fffff,
  0x409fffff,
  0x408fffff,
  0x408fffff,
  0x408fffff,
  0x407fffff,
  0x407fffff,
  0x407ffffe,
  0x405fffff,
  0xc0a00001,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x409fffff,
  0x409fffff,
  0x409fffff,
  0x409fffff,
  0x409fffff,
  0x40afffff,
  0x40afffff,
  0x40b00000,
  0x40bfffff,
  0x40bfffff,
  0x40c00000,
  0x40cfffff,
  0x41700000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x409fffff,
  0x409fffff,
  0x409fffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x00091a2b,
  0x8076e5d5,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80091a2b,
  0x8076e5d4,
  0x00091a2a,
  0x00091a2b,
  0x00891a2b,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x001b4e81,
  0x00891a2a,
  0x00091a2c,
  0x003fffff,
  0x80400001,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x002dcba9,
  0x80400000,
  0x003ffffe,
  0x003fffff,
  0x00bfffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00523455,
  0x00bffffe,
  0x00400000,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80400000,
  0x80c00000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80523456,
  0x80bfffff,
  0x80400001,
  0x80400000,
  0x00400000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x802dcbaa,
  0x003fffff,
  0x803fffff,
  0xbe7fffff,
  0xbe7fffff,
  0xbf3fffff,
  0xbf400000,
  0xbf400001,
  0xbf9fffff,
  0xbfa00000,
  0xbfa00001,
  0xbfe00000,
  0xc1240000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbe7fffff,
  0xbe7fffff,
  0xbe7fffff,
  0xbe7fffff,
  0xbe7fffff,
  0x3e7fffff,
  0x3e800000,
  0x3e800002,
  0x3f3fffff,
  0x3f400000,
  0x3f400002,
  0x3fa00000,
  0x411c0000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbe7fffff,
  0xbe7fffff,
  0xbe7fffff,
  0xbe800000,
  0xbe800000,
  0xbf400000,
  0xbf400000,
  0xbf400001,
  0xbfa00000,
  0xbfa00000,
  0xbfa00001,
  0xbfe00000,
  0xc1240000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbe800000,
  0xbe800000,
  0xbe800000,
  0xbe800000,
  0xbe800000,
  0x3e7ffffe,
  0x3e800000,
  0x3e800002,
  0x3f3fffff,
  0x3f400000,
  0x3f400002,
  0x3fa00000,
  0x411c0000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbe800000,
  0xbe800000,
  0xbe800000,
  0xbe800001,
  0xbe800001,
  0xbf400000,
  0xbf400000,
  0xbf400002,
  0xbfa00000,
  0xbfa00000,
  0xbfa00001,
  0xbfe00000,
  0xc1240000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbe800001,
  0xbe800001,
  0xbe800001,
  0xbe800001,
  0xbe800001,
  0x3e7ffffc,
  0x3e7ffffe,
  0x3e800001,
  0x3f3ffffe,
  0x3f400000,
  0x3f400002,
  0x3fa00000,
  0x411c0000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbe800001,
  0xbe800001,
  0xbe800001,
  0xbeffffff,
  0xbeffffff,
  0xbf7fffff,
  0xbf800000,
  0xbf800000,
  0xbfbfffff,
  0xbfc00000,
  0xbfc00001,
  0xc0000000,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0x00000000,
  0x33000000,
  0x33c00000,
  0x3effffff,
  0x3f000000,
  0x3f000002,
  0x3f800000,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbf000000,
  0xbf000000,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbfc00000,
  0xbfc00000,
  0xbfc00001,
  0xc0000000,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xb3000000,
  0x00000000,
  0x33800000,
  0x3efffffe,
  0x3f000000,
  0x3f000002,
  0x3f800000,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000001,
  0xbf000001,
  0xbf800000,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xbfc00000,
  0xbfc00002,
  0xc0000000,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xb3c00000,
  0xb3800000,
  0x00000000,
  0x3efffffc,
  0x3efffffe,
  0x3f000001,
  0x3f7fffff,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf400000,
  0xbf400000,
  0xbfa00000,
  0xbfa00000,
  0xbfa00000,
  0xbfe00000,
  0xbfe00000,
  0xbfe00001,
  0xc0100000,
  0xc12c0000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf400000,
  0xbf400000,
  0xbf400000,
  0xbf400000,
  0xbf400000,
  0xbe800001,
  0xbe800000,
  0xbe7ffffc,
  0x3e7ffffc,
  0x3e800000,
  0x3e800004,
  0x3f400000,
  0x41140000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf400000,
  0xbf400000,
  0xbf400000,
  0xc0a00000,
  0xc0a00000,
  0xc0b00000,
  0xc0b00000,
  0xc0b00000,
  0xc0c00000,
  0xc0c00000,
  0xc0c00000,
  0xc0d00000,
  0xc1700000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xc0a00000,
  0xc0a00000,
  0xc0a00000,
  0xc0a00000,
  0xc0a00000,
  0xc0900000,
  0xc0900000,
  0xc0900000,
  0xc0800000,
  0xc0800000,
  0xc0800000,
  0xc0600000,
  0x40a00000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xc0a00000,
  0xc0a00000,
  0xc0a00000,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x80091a2b,
  0x80891a2b,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x801b4e81,
  0x80891a2a,
  0x80091a2c,
  0x80091a2b,
  0x0076e5d5,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00091a2b,
  0x0076e5d4,
  0x80091a2a,
  0x80400000,
  0x80c00000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80523456,
  0x80bffffe,
  0x80400000,
  0x80400000,
  0x00400000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x802dcbaa,
  0x00400000,
  0x803ffffe,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x80800000,
  0x80000002,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007ffffe,
  0x00000000,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00400000,
  0x80400000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x002dcbaa,
  0x803fffff,
  0x003fffff,
  0x00400000,
  0x00c00000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00523456,
  0x00bfffff,
  0x00400001,
  0x3e7fffff,
  0x3e7fffff,
  0xbe7fffff,
  0xbe800000,
  0xbe800002,
  0xbf3fffff,
  0xbf400000,
  0xbf400002,
  0xbfa00000,
  0xc11c0000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3e7fffff,
  0x3e7fffff,
  0x3e7fffff,
  0x3e7fffff,
  0x3e7fffff,
  0x3f3fffff,
  0x3f400000,
  0x3f400001,
  0x3f9fffff,
  0x3fa00000,
  0x3fa00001,
  0x3fe00000,
  0x41240000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3e7fffff,
  0x3e7fffff,
  0x3e7fffff,
  0x3e800000,
  0x3e800000,
  0xbe7ffffe,
  0xbe800000,
  0xbe800002,
  0xbf3fffff,
  0xbf400000,
  0xbf400002,
  0xbfa00000,
  0xc11c0000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3e800000,
  0x3e800000,
  0x3e800000,
  0x3e800000,
  0x3e800000,
  0x3f400000,
  0x3f400000,
  0x3f400001,
  0x3fa00000,
  0x3fa00000,
  0x3fa00001,
  0x3fe00000,
  0x41240000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3e800000,
  0x3e800000,
  0x3e800000,
  0x3e800001,
  0x3e800001,
  0xbe7ffffc,
  0xbe7ffffe,
  0xbe800001,
  0xbf3ffffe,
  0xbf400000,
  0xbf400002,
  0xbfa00000,
  0xc11c0000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3e800001,
  0x3e800001,
  0x3e800001,
  0x3e800001,
  0x3e800001,
  0x3f400000,
  0x3f400000,
  0x3f400002,
  0x3fa00000,
  0x3fa00000,
  0x3fa00001,
  0x3fe00000,
  0x41240000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3e800001,
  0x3e800001,
  0x3e800001,
  0x3effffff,
  0x3effffff,
  0x00000000,
  0xb3000000,
  0xb3c00000,
  0xbeffffff,
  0xbf000000,
  0xbf000002,
  0xbf800000,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3f7fffff,
  0x3f800000,
  0x3f800000,
  0x3fbfffff,
  0x3fc00000,
  0x3fc00001,
  0x40000000,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3f000000,
  0x3f000000,
  0x33000000,
  0x00000000,
  0xb3800000,
  0xbefffffe,
  0xbf000000,
  0xbf000002,
  0xbf800000,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3fc00000,
  0x3fc00000,
  0x3fc00001,
  0x40000000,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000001,
  0x3f000001,
  0x33c00000,
  0x33800000,
  0x00000000,
  0xbefffffc,
  0xbefffffe,
  0xbf000001,
  0xbf7fffff,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f800000,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x3fc00000,
  0x3fc00002,
  0x40000000,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f400000,
  0x3f400000,
  0x3e800001,
  0x3e800000,
  0x3e7ffffc,
  0xbe7ffffc,
  0xbe800000,
  0xbe800004,
  0xbf400000,
  0xc1140000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f400000,
  0x3f400000,
  0x3f400000,
  0x3f400000,
  0x3f400000,
  0x3fa00000,
  0x3fa00000,
  0x3fa00000,
  0x3fe00000,
  0x3fe00000,
  0x3fe00001,
  0x40100000,
  0x412c0000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f400000,
  0x3f400000,
  0x3f400000,
  0x40a00000,
  0x40a00000,
  0x40900000,
  0x40900000,
  0x40900000,
  0x40800000,
  0x40800000,
  0x40800000,
  0x40600000,
  0xc0a00000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x40a00000,
  0x40a00000,
  0x40a00000,
  0x40a00000,
  0x40a00000,
  0x40b00000,
  0x40b00000,
  0x40b00000,
  0x40c00000,
  0x40c00000,
  0x40c00000,
  0x40d00000,
  0x41700000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x40a00000,
  0x40a00000,
  0x40a00000,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x00091a2b,
  0x8076e5d5,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80091a2b,
  0x8076e5d4,
  0x00091a2a,
  0x00091a2b,
  0x00891a2b,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x001b4e81,
  0x00891a2a,
  0x00091a2c,
  0x00400000,
  0x80400000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x002dcbaa,
  0x80400000,
  0x003ffffe,
  0x00400000,
  0x00c00000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00523456,
  0x00bffffe,
  0x00400000,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807ffffe,
  0x80000000,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x00800000,
  0x00000002,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80400000,
  0x80c00000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80523456,
  0x80c00000,
  0x80400002,
  0x80400000,
  0x00400000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x802dcbaa,
  0x003ffffe,
  0x80400000,
  0xbe800000,
  0xbe800000,
  0xbf400000,
  0xbf400000,
  0xbf400001,
  0xbfa00000,
  0xbfa00000,
  0xbfa00001,
  0xbfe00000,
  0xc1240000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbe800000,
  0xbe800000,
  0xbe800000,
  0xbe800000,
  0xbe800000,
  0x3e7ffffd,
  0x3e7fffff,
  0x3e800002,
  0x3f3fffff,
  0x3f400000,
  0x3f400002,
  0x3fa00000,
  0x411c0000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbe800000,
  0xbe800000,
  0xbe800000,
  0xbe800001,
  0xbe800001,
  0xbf400000,
  0xbf400000,
  0xbf400002,
  0xbfa00000,
  0xbfa00000,
  0xbfa00001,
  0xbfe00000,
  0xc1240000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbe800001,
  0xbe800001,
  0xbe800001,
  0xbe800001,
  0xbe800001,
  0x3e7ffffc,
  0x3e7ffffe,
  0x3e800001,
  0x3f3ffffe,
  0x3f400000,
  0x3f400002,
  0x3fa00000,
  0x411c0000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbe800001,
  0xbe800001,
  0xbe800001,
  0xbe800002,
  0xbe800002,
  0xbf400001,
  0xbf400001,
  0xbf400002,
  0xbfa00000,
  0xbfa00001,
  0xbfa00002,
  0xbfe00001,
  0xc1240000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbe800002,
  0xbe800002,
  0xbe800002,
  0xbe800002,
  0xbe800002,
  0x3e7ffffa,
  0x3e7ffffc,
  0x3e800000,
  0x3f3ffffe,
  0x3f3fffff,
  0x3f400001,
  0x3f9fffff,
  0x411c0000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbe800002,
  0xbe800002,
  0xbe800002,
  0xbf000000,
  0xbf000000,
  0xbf800000,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xbfc00000,
  0xbfc00001,
  0xc0000000,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xb37fffff,
  0xb2fffffe,
  0x33000001,
  0x3efffffd,
  0x3effffff,
  0x3f000002,
  0x3f800000,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000001,
  0xbf000001,
  0xbf800000,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xbfc00000,
  0xbfc00002,
  0xc0000000,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xb3c00000,
  0xb3800000,
  0x00000000,
  0x3efffffc,
  0x3efffffe,
  0x3f000001,
  0x3f7fffff,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf000002,
  0xbf000002,
  0xbf800001,
  0xbf800001,
  0xbf800002,
  0xbfc00001,
  0xbfc00001,
  0xbfc00002,
  0xc0000001,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf000002,
  0xbf000002,
  0xbf000002,
  0xbf000002,
  0xbf000002,
  0xb4200000,
  0xb4000000,
  0xb3800001,
  0x3efffffa,
  0x3efffffc,
  0x3f000000,
  0x3f7ffffe,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf000002,
  0xbf000002,
  0xbf000002,
  0xbf400002,
  0xbf400002,
  0xbfa00000,
  0xbfa00001,
  0xbfa00001,
  0xbfe00000,
  0xbfe00001,
  0xbfe00002,
  0xc0100000,
  0xc12c0000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf400002,
  0xbf400002,
  0xbf400002,
  0xbf400002,
  0xbf400001,
  0xbe800004,
  0xbe800003,
  0xbe800001,
  0x3e7ffff6,
  0x3e7ffffa,
  0x3e800001,
  0x3f3ffffe,
  0x41140000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf400001,
  0xbf400001,
  0xbf400001,
  0xc0a00001,
  0xc0a00001,
  0xc0b00001,
  0xc0b00001,
  0xc0b00001,
  0xc0c00001,
  0xc0c00001,
  0xc0c00002,
  0xc0d00001,
  0xc1700001,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xc0a00001,
  0xc0a00001,
  0xc0a00001,
  0xc0a00001,
  0xc0a00001,
  0xc0900001,
  0xc0900001,
  0xc0900001,
  0xc0800001,
  0xc0800001,
  0xc0800001,
  0xc0600002,
  0x409fffff,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xc0a00001,
  0xc0a00001,
  0xc0a00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x80091a2b,
  0x80891a2b,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x801b4e81,
  0x80891a2a,
  0x80091a2c,
  0x80091a2b,
  0x0076e5d5,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00091a2b,
  0x0076e5d4,
  0x80091a2a,
  0x80400000,
  0x80c00000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80523456,
  0x80bfffff,
  0x80400001,
  0x80400000,
  0x00400000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x802dcbaa,
  0x003fffff,
  0x803fffff,
  0x80000001,
  0x80800001,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123457,
  0x80800000,
  0x80000002,
  0x80000001,
  0x007fffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123455,
  0x007ffffe,
  0x00000000,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00400000,
  0x80400000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x002dcbaa,
  0x803ffffe,
  0x00400000,
  0x00400000,
  0x00c00000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00523456,
  0x00c00000,
  0x00400002,
  0x3e800000,
  0x3e800000,
  0xbe7ffffd,
  0xbe7fffff,
  0xbe800002,
  0xbf3fffff,
  0xbf400000,
  0xbf400002,
  0xbfa00000,
  0xc11c0000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3e800000,
  0x3e800000,
  0x3e800000,
  0x3e800000,
  0x3e800000,
  0x3f400000,
  0x3f400000,
  0x3f400001,
  0x3fa00000,
  0x3fa00000,
  0x3fa00001,
  0x3fe00000,
  0x41240000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3e800000,
  0x3e800000,
  0x3e800000,
  0x3e800001,
  0x3e800001,
  0xbe7ffffc,
  0xbe7ffffe,
  0xbe800001,
  0xbf3ffffe,
  0xbf400000,
  0xbf400002,
  0xbfa00000,
  0xc11c0000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3e800001,
  0x3e800001,
  0x3e800001,
  0x3e800001,
  0x3e800001,
  0x3f400000,
  0x3f400000,
  0x3f400002,
  0x3fa00000,
  0x3fa00000,
  0x3fa00001,
  0x3fe00000,
  0x41240000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3e800001,
  0x3e800001,
  0x3e800001,
  0x3e800002,
  0x3e800002,
  0xbe7ffffa,
  0xbe7ffffc,
  0xbe800000,
  0xbf3ffffe,
  0xbf3fffff,
  0xbf400001,
  0xbf9fffff,
  0xc11c0000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3e800002,
  0x3e800002,
  0x3e800002,
  0x3e800002,
  0x3e800002,
  0x3f400001,
  0x3f400001,
  0x3f400002,
  0x3fa00000,
  0x3fa00001,
  0x3fa00002,
  0x3fe00001,
  0x41240000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3e800002,
  0x3e800002,
  0x3e800002,
  0x3f000000,
  0x3f000000,
  0x337fffff,
  0x32fffffe,
  0xb3000001,
  0xbefffffd,
  0xbeffffff,
  0xbf000002,
  0xbf800000,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f800000,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x3fc00000,
  0x3fc00001,
  0x40000000,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000001,
  0x3f000001,
  0x33c00000,
  0x33800000,
  0x00000000,
  0xbefffffc,
  0xbefffffe,
  0xbf000001,
  0xbf7fffff,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f800000,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x3fc00000,
  0x3fc00002,
  0x40000000,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f000002,
  0x3f000002,
  0x34200000,
  0x34000000,
  0x33800001,
  0xbefffffa,
  0xbefffffc,
  0xbf000000,
  0xbf7ffffe,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f000002,
  0x3f000002,
  0x3f000002,
  0x3f000002,
  0x3f000002,
  0x3f800001,
  0x3f800001,
  0x3f800002,
  0x3fc00001,
  0x3fc00001,
  0x3fc00002,
  0x40000001,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f000002,
  0x3f000002,
  0x3f000002,
  0x3f400002,
  0x3f400001,
  0x3e800004,
  0x3e800003,
  0x3e800001,
  0xbe7ffff6,
  0xbe7ffffa,
  0xbe800001,
  0xbf3ffffe,
  0xc1140000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f400001,
  0x3f400001,
  0x3f400001,
  0x3f400002,
  0x3f400002,
  0x3fa00000,
  0x3fa00001,
  0x3fa00001,
  0x3fe00000,
  0x3fe00001,
  0x3fe00002,
  0x40100000,
  0x412c0000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f400002,
  0x3f400002,
  0x3f400002,
  0x40a00001,
  0x40a00001,
  0x40900001,
  0x40900001,
  0x40900001,
  0x40800001,
  0x40800001,
  0x40800001,
  0x40600002,
  0xc09fffff,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x40a00001,
  0x40a00001,
  0x40a00001,
  0x40a00001,
  0x40a00001,
  0x40b00001,
  0x40b00001,
  0x40b00001,
  0x40c00001,
  0x40c00001,
  0x40c00002,
  0x40d00001,
  0x41700001,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x40a00001,
  0x40a00001,
  0x40a00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x00091a2b,
  0x8076e5d5,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80091a2b,
  0x8076e5d4,
  0x00091a2a,
  0x00091a2b,
  0x00891a2b,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x001b4e81,
  0x00891a2a,
  0x00091a2c,
  0x00400000,
  0x80400000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x002dcbaa,
  0x803fffff,
  0x003fffff,
  0x00400000,
  0x00c00000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00523456,
  0x00bfffff,
  0x00400001,
  0x00000001,
  0x807fffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123455,
  0x807ffffe,
  0x80000000,
  0x00000001,
  0x00800001,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123457,
  0x00800000,
  0x00000002,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80800000,
  0x81000000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80923456,
  0x80fffffe,
  0x80800000,
  0x80800000,
  0x00000000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x806dcbaa,
  0x80000000,
  0x807ffffe,
  0xbefffffe,
  0xbefffffe,
  0xbf7fffff,
  0xbf7fffff,
  0xbf800000,
  0xbfbfffff,
  0xbfc00000,
  0xbfc00001,
  0xc0000000,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbefffffe,
  0xbefffffe,
  0xbefffffe,
  0xbefffffe,
  0xbefffffe,
  0x32ffffff,
  0x33800000,
  0x34000000,
  0x3f000000,
  0x3f000001,
  0x3f000003,
  0x3f800000,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbefffffe,
  0xbefffffe,
  0xbefffffe,
  0xbeffffff,
  0xbeffffff,
  0xbf7fffff,
  0xbf800000,
  0xbf800000,
  0xbfbfffff,
  0xbfc00000,
  0xbfc00001,
  0xc0000000,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0x00000000,
  0x33000000,
  0x33c00000,
  0x3effffff,
  0x3f000000,
  0x3f000002,
  0x3f800000,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbf000000,
  0xbf000000,
  0xbf800000,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xbfc00000,
  0xbfc00001,
  0xc0000000,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xb37fffff,
  0xb2fffffe,
  0x33000001,
  0x3efffffd,
  0x3effffff,
  0x3f000002,
  0x3f800000,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf7ffffe,
  0xbf7ffffe,
  0xbfbfffff,
  0xbfbfffff,
  0xbfc00000,
  0xbfffffff,
  0xbfffffff,
  0xc0000000,
  0xc0200000,
  0xc1300000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf7ffffe,
  0xbf7ffffe,
  0xbf7ffffe,
  0xbf7ffffe,
  0xbf7ffffe,
  0xbefffffd,
  0xbefffffc,
  0xbefffffa,
  0x337fffff,
  0x34000000,
  0x34800000,
  0x3f000002,
  0x41100000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf7ffffe,
  0xbf7ffffe,
  0xbf7ffffe,
  0xbf7fffff,
  0xbf7fffff,
  0xbfbfffff,
  0xbfc00000,
  0xbfc00000,
  0xbfffffff,
  0xc0000000,
  0xc0000000,
  0xc0200000,
  0xc1300000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf7fffff,
  0xbf7fffff,
  0xbf7fffff,
  0xbf7fffff,
  0xbf7fffff,
  0xbeffffff,
  0xbefffffe,
  0xbefffffc,
  0x00000000,
  0x33800000,
  0x34400000,
  0x3f000001,
  0x41100000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf7fffff,
  0xbf7fffff,
  0xbf7fffff,
  0xbf800000,
  0xbf800000,
  0xbfc00000,
  0xbfc00000,
  0xbfc00001,
  0xc0000000,
  0xc0000000,
  0xc0000001,
  0xc0200000,
  0xc1300000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbf000001,
  0xbf000001,
  0xbf000000,
  0xb3ffffff,
  0xb37ffffe,
  0x33800001,
  0x3efffffe,
  0x41100000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbfbfffff,
  0xbfbfffff,
  0xbfffffff,
  0xbfffffff,
  0xc0000000,
  0xc01fffff,
  0xc0200000,
  0xc0200000,
  0xc0400000,
  0xc1380000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbfbfffff,
  0xbfbfffff,
  0xbfbfffff,
  0xbfbfffff,
  0xbfbfffff,
  0xbf7fffff,
  0xbf7ffffe,
  0xbf7ffffe,
  0xbeffffff,
  0xbefffffd,
  0xbefffff9,
  0x33c00000,
  0x41080000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbfbfffff,
  0xbfbfffff,
  0xbfbfffff,
  0xc11fffff,
  0xc11fffff,
  0xc127ffff,
  0xc127ffff,
  0xc127ffff,
  0xc12fffff,
  0xc12fffff,
  0xc1300000,
  0xc137ffff,
  0xc1a00000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xc11fffff,
  0xc11fffff,
  0xc11fffff,
  0xc11fffff,
  0xc11fffff,
  0xc117ffff,
  0xc117ffff,
  0xc117ffff,
  0xc10fffff,
  0xc10fffff,
  0xc10fffff,
  0xc107ffff,
  0x35200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xc11fffff,
  0xc11fffff,
  0xc11fffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x80123456,
  0x80923456,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x802468ac,
  0x80923455,
  0x80123457,
  0x80123456,
  0x006dcbaa,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00000000,
  0x006dcba9,
  0x80123455,
  0x807fffff,
  0x80ffffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80923455,
  0x80fffffe,
  0x80800000,
  0x807fffff,
  0x00000001,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x806dcba9,
  0x00000000,
  0x807ffffe,
  0x80000001,
  0x80800001,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123457,
  0x80800000,
  0x80000002,
  0x80000001,
  0x007fffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123455,
  0x007ffffe,
  0x00000000,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00800000,
  0x80000000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x006dcbaa,
  0x00000000,
  0x007ffffe,
  0x00800000,
  0x01000000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00923456,
  0x00fffffe,
  0x00800000,
  0x3efffffe,
  0x3efffffe,
  0xb2ffffff,
  0xb3800000,
  0xb4000000,
  0xbf000000,
  0xbf000001,
  0xbf000003,
  0xbf800000,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3efffffe,
  0x3efffffe,
  0x3efffffe,
  0x3efffffe,
  0x3efffffe,
  0x3f7fffff,
  0x3f7fffff,
  0x3f800000,
  0x3fbfffff,
  0x3fc00000,
  0x3fc00001,
  0x40000000,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3efffffe,
  0x3efffffe,
  0x3efffffe,
  0x3effffff,
  0x3effffff,
  0x00000000,
  0xb3000000,
  0xb3c00000,
  0xbeffffff,
  0xbf000000,
  0xbf000002,
  0xbf800000,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3f7fffff,
  0x3f800000,
  0x3f800000,
  0x3fbfffff,
  0x3fc00000,
  0x3fc00001,
  0x40000000,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3f000000,
  0x3f000000,
  0x337fffff,
  0x32fffffe,
  0xb3000001,
  0xbefffffd,
  0xbeffffff,
  0xbf000002,
  0xbf800000,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f800000,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x3fc00000,
  0x3fc00001,
  0x40000000,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f7ffffe,
  0x3f7ffffe,
  0x3efffffd,
  0x3efffffc,
  0x3efffffa,
  0xb37fffff,
  0xb4000000,
  0xb4800000,
  0xbf000002,
  0xc1100000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f7ffffe,
  0x3f7ffffe,
  0x3f7ffffe,
  0x3f7ffffe,
  0x3f7ffffe,
  0x3fbfffff,
  0x3fbfffff,
  0x3fc00000,
  0x3fffffff,
  0x3fffffff,
  0x40000000,
  0x40200000,
  0x41300000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f7ffffe,
  0x3f7ffffe,
  0x3f7ffffe,
  0x3f7fffff,
  0x3f7fffff,
  0x3effffff,
  0x3efffffe,
  0x3efffffc,
  0x00000000,
  0xb3800000,
  0xb4400000,
  0xbf000001,
  0xc1100000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f7fffff,
  0x3f7fffff,
  0x3f7fffff,
  0x3f7fffff,
  0x3f7fffff,
  0x3fbfffff,
  0x3fc00000,
  0x3fc00000,
  0x3fffffff,
  0x40000000,
  0x40000000,
  0x40200000,
  0x41300000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f7fffff,
  0x3f7fffff,
  0x3f7fffff,
  0x3f800000,
  0x3f800000,
  0x3f000001,
  0x3f000001,
  0x3f000000,
  0x33ffffff,
  0x337ffffe,
  0xb3800001,
  0xbefffffe,
  0xc1100000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3fc00000,
  0x3fc00000,
  0x3fc00001,
  0x40000000,
  0x40000000,
  0x40000001,
  0x40200000,
  0x41300000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3fbfffff,
  0x3fbfffff,
  0x3f7fffff,
  0x3f7ffffe,
  0x3f7ffffe,
  0x3effffff,
  0x3efffffd,
  0x3efffff9,
  0xb3c00000,
  0xc1080000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3fbfffff,
  0x3fbfffff,
  0x3fbfffff,
  0x3fbfffff,
  0x3fbfffff,
  0x3fffffff,
  0x3fffffff,
  0x40000000,
  0x401fffff,
  0x40200000,
  0x40200000,
  0x40400000,
  0x41380000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3fbfffff,
  0x3fbfffff,
  0x3fbfffff,
  0x411fffff,
  0x411fffff,
  0x4117ffff,
  0x4117ffff,
  0x4117ffff,
  0x410fffff,
  0x410fffff,
  0x410fffff,
  0x4107ffff,
  0xb5200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x411fffff,
  0x411fffff,
  0x411fffff,
  0x411fffff,
  0x411fffff,
  0x4127ffff,
  0x4127ffff,
  0x4127ffff,
  0x412fffff,
  0x412fffff,
  0x41300000,
  0x4137ffff,
  0x41a00000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x411fffff,
  0x411fffff,
  0x411fffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x00123456,
  0x806dcbaa,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80000000,
  0x806dcba9,
  0x00123455,
  0x00123456,
  0x00923456,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x002468ac,
  0x00923455,
  0x00123457,
  0x007fffff,
  0x80000001,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x006dcba9,
  0x80000000,
  0x007ffffe,
  0x007fffff,
  0x00ffffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00923455,
  0x00fffffe,
  0x00800000,
  0x00000001,
  0x807fffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123455,
  0x807ffffe,
  0x80000000,
  0x00000001,
  0x00800001,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123457,
  0x00800000,
  0x00000002,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80800000,
  0x81000000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80923456,
  0x80ffffff,
  0x80800001,
  0x80800000,
  0x00000000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x806dcbaa,
  0x80000001,
  0x807fffff,
  0xbeffffff,
  0xbeffffff,
  0xbf7fffff,
  0xbf800000,
  0xbf800000,
  0xbfbfffff,
  0xbfc00000,
  0xbfc00001,
  0xc0000000,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0x00000000,
  0x33000000,
  0x33c00000,
  0x3effffff,
  0x3f000000,
  0x3f000002,
  0x3f800000,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbf000000,
  0xbf000000,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbfc00000,
  0xbfc00000,
  0xbfc00001,
  0xc0000000,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xb3000000,
  0x00000000,
  0x33800000,
  0x3efffffe,
  0x3f000000,
  0x3f000002,
  0x3f800000,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000001,
  0xbf000001,
  0xbf800000,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xbfc00000,
  0xbfc00002,
  0xc0000000,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xb3c00000,
  0xb3800000,
  0x00000000,
  0x3efffffc,
  0x3efffffe,
  0x3f000001,
  0x3f7fffff,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf7fffff,
  0xbf7fffff,
  0xbfbfffff,
  0xbfc00000,
  0xbfc00000,
  0xbfffffff,
  0xc0000000,
  0xc0000000,
  0xc0200000,
  0xc1300000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf7fffff,
  0xbf7fffff,
  0xbf7fffff,
  0xbf7fffff,
  0xbf7fffff,
  0xbeffffff,
  0xbefffffe,
  0xbefffffc,
  0x00000000,
  0x33800000,
  0x34400000,
  0x3f000001,
  0x41100000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf7fffff,
  0xbf7fffff,
  0xbf7fffff,
  0xbf800000,
  0xbf800000,
  0xbfc00000,
  0xbfc00000,
  0xbfc00000,
  0xc0000000,
  0xc0000000,
  0xc0000000,
  0xc0200000,
  0xc1300000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbf000000,
  0xbf000000,
  0xbefffffe,
  0xb3800000,
  0x00000000,
  0x34000000,
  0x3f000000,
  0x41100000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbf800001,
  0xbf800001,
  0xbfc00001,
  0xbfc00001,
  0xbfc00002,
  0xc0000000,
  0xc0000000,
  0xc0000001,
  0xc0200000,
  0xc1300000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf800001,
  0xbf800001,
  0xbf800001,
  0xbf800001,
  0xbf800001,
  0xbf000002,
  0xbf000002,
  0xbf000001,
  0xb4400000,
  0xb4000000,
  0x00000000,
  0x3efffffc,
  0x41100000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf800001,
  0xbf800001,
  0xbf800001,
  0xbfc00000,
  0xbfc00000,
  0xc0000000,
  0xc0000000,
  0xc0000000,
  0xc0200000,
  0xc0200000,
  0xc0200000,
  0xc0400000,
  0xc1380000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbfc00000,
  0xbfc00000,
  0xbfc00000,
  0xbfc00000,
  0xbfc00000,
  0xbf800000,
  0xbf800000,
  0xbf7fffff,
  0xbf000001,
  0xbf000000,
  0xbefffffc,
  0x00000000,
  0x41080000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbfc00000,
  0xbfc00000,
  0xbfc00000,
  0xc1200000,
  0xc1200000,
  0xc1280000,
  0xc1280000,
  0xc1280000,
  0xc1300000,
  0xc1300000,
  0xc1300000,
  0xc1380000,
  0xc1a00000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xc1200000,
  0xc1200000,
  0xc1200000,
  0xc1200000,
  0xc1200000,
  0xc1180000,
  0xc1180000,
  0xc1180000,
  0xc1100000,
  0xc1100000,
  0xc1100000,
  0xc1080000,
  0x00000000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xc1200000,
  0xc1200000,
  0xc1200000,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x80123456,
  0x80923456,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x802468ac,
  0x80923455,
  0x80123457,
  0x80123456,
  0x006dcbaa,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00000000,
  0x006dcba9,
  0x80123455,
  0x807fffff,
  0x80ffffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80923455,
  0x80fffffe,
  0x80800000,
  0x807fffff,
  0x00000001,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x806dcba9,
  0x00000000,
  0x807ffffe,
  0x80000001,
  0x80800001,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123457,
  0x80800000,
  0x80000002,
  0x80000001,
  0x007fffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123455,
  0x007ffffe,
  0x00000000,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00800000,
  0x00000000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x006dcbaa,
  0x00000001,
  0x007fffff,
  0x00800000,
  0x01000000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00923456,
  0x00ffffff,
  0x00800001,
  0x3effffff,
  0x3effffff,
  0x00000000,
  0xb3000000,
  0xb3c00000,
  0xbeffffff,
  0xbf000000,
  0xbf000002,
  0xbf800000,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3f7fffff,
  0x3f800000,
  0x3f800000,
  0x3fbfffff,
  0x3fc00000,
  0x3fc00001,
  0x40000000,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3f000000,
  0x3f000000,
  0x33000000,
  0x00000000,
  0xb3800000,
  0xbefffffe,
  0xbf000000,
  0xbf000002,
  0xbf800000,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3fc00000,
  0x3fc00000,
  0x3fc00001,
  0x40000000,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000001,
  0x3f000001,
  0x33c00000,
  0x33800000,
  0x00000000,
  0xbefffffc,
  0xbefffffe,
  0xbf000001,
  0xbf7fffff,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f800000,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x3fc00000,
  0x3fc00002,
  0x40000000,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f7fffff,
  0x3f7fffff,
  0x3effffff,
  0x3efffffe,
  0x3efffffc,
  0x00000000,
  0xb3800000,
  0xb4400000,
  0xbf000001,
  0xc1100000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f7fffff,
  0x3f7fffff,
  0x3f7fffff,
  0x3f7fffff,
  0x3f7fffff,
  0x3fbfffff,
  0x3fc00000,
  0x3fc00000,
  0x3fffffff,
  0x40000000,
  0x40000000,
  0x40200000,
  0x41300000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f7fffff,
  0x3f7fffff,
  0x3f7fffff,
  0x3f800000,
  0x3f800000,
  0x3f000000,
  0x3f000000,
  0x3efffffe,
  0x33800000,
  0x00000000,
  0xb4000000,
  0xbf000000,
  0xc1100000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3fc00000,
  0x3fc00000,
  0x3fc00000,
  0x40000000,
  0x40000000,
  0x40000000,
  0x40200000,
  0x41300000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3f800001,
  0x3f800001,
  0x3f000002,
  0x3f000002,
  0x3f000001,
  0x34400000,
  0x34000000,
  0x00000000,
  0xbefffffc,
  0xc1100000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f800001,
  0x3f800001,
  0x3f800001,
  0x3f800001,
  0x3f800001,
  0x3fc00001,
  0x3fc00001,
  0x3fc00002,
  0x40000000,
  0x40000000,
  0x40000001,
  0x40200000,
  0x41300000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f800001,
  0x3f800001,
  0x3f800001,
  0x3fc00000,
  0x3fc00000,
  0x3f800000,
  0x3f800000,
  0x3f7fffff,
  0x3f000001,
  0x3f000000,
  0x3efffffc,
  0x00000000,
  0xc1080000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3fc00000,
  0x3fc00000,
  0x3fc00000,
  0x3fc00000,
  0x3fc00000,
  0x40000000,
  0x40000000,
  0x40000000,
  0x40200000,
  0x40200000,
  0x40200000,
  0x40400000,
  0x41380000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3fc00000,
  0x3fc00000,
  0x3fc00000,
  0x41200000,
  0x41200000,
  0x41180000,
  0x41180000,
  0x41180000,
  0x41100000,
  0x41100000,
  0x41100000,
  0x41080000,
  0x00000000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x41200000,
  0x41200000,
  0x41200000,
  0x41200000,
  0x41200000,
  0x41280000,
  0x41280000,
  0x41280000,
  0x41300000,
  0x41300000,
  0x41300000,
  0x41380000,
  0x41a00000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x41200000,
  0x41200000,
  0x41200000,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x00123456,
  0x806dcbaa,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x00000000,
  0x806dcba9,
  0x00123455,
  0x00123456,
  0x00923456,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x002468ac,
  0x00923455,
  0x00123457,
  0x007fffff,
  0x80000001,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x006dcba9,
  0x00000000,
  0x007ffffe,
  0x007fffff,
  0x00ffffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00923455,
  0x00fffffe,
  0x00800000,
  0x00000001,
  0x807fffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123455,
  0x807ffffe,
  0x00000000,
  0x00000001,
  0x00800001,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123457,
  0x00800000,
  0x00000002,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80800001,
  0x81000000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80923457,
  0x81000000,
  0x80800002,
  0x80800001,
  0x80000001,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x806dcbab,
  0x80000002,
  0x80800000,
  0xbf000000,
  0xbf000000,
  0xbf800000,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xbfc00000,
  0xbfc00001,
  0xc0000000,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xb37fffff,
  0xb2fffffe,
  0x33000001,
  0x3efffffd,
  0x3effffff,
  0x3f000002,
  0x3f800000,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000001,
  0xbf000001,
  0xbf800000,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xbfc00000,
  0xbfc00002,
  0xc0000000,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xb3c00000,
  0xb3800000,
  0x00000000,
  0x3efffffc,
  0x3efffffe,
  0x3f000001,
  0x3f7fffff,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf000002,
  0xbf000002,
  0xbf800001,
  0xbf800001,
  0xbf800002,
  0xbfc00001,
  0xbfc00001,
  0xbfc00002,
  0xc0000001,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf000002,
  0xbf000002,
  0xbf000002,
  0xbf000002,
  0xbf000002,
  0xb4200000,
  0xb4000000,
  0xb3800001,
  0x3efffffa,
  0x3efffffc,
  0x3f000000,
  0x3f7ffffe,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf000002,
  0xbf000002,
  0xbf000002,
  0xbf800000,
  0xbf800000,
  0xbfc00000,
  0xbfc00000,
  0xbfc00001,
  0xc0000000,
  0xc0000000,
  0xc0000001,
  0xc0200000,
  0xc1300000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbf000001,
  0xbf000001,
  0xbf000000,
  0xb3ffffff,
  0xb37ffffe,
  0x33800001,
  0x3efffffe,
  0x41100000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbf800001,
  0xbf800001,
  0xbfc00001,
  0xbfc00001,
  0xbfc00002,
  0xc0000000,
  0xc0000000,
  0xc0000001,
  0xc0200000,
  0xc1300000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf800001,
  0xbf800001,
  0xbf800001,
  0xbf800001,
  0xbf800001,
  0xbf000002,
  0xbf000002,
  0xbf000001,
  0xb4400000,
  0xb4000000,
  0x00000000,
  0x3efffffc,
  0x41100000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf800001,
  0xbf800001,
  0xbf800001,
  0xbf800002,
  0xbf800002,
  0xbfc00002,
  0xbfc00002,
  0xbfc00003,
  0xc0000001,
  0xc0000001,
  0xc0000002,
  0xc0200001,
  0xc1300000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf800002,
  0xbf800002,
  0xbf800002,
  0xbf800002,
  0xbf800002,
  0xbf000005,
  0xbf000004,
  0xbf000003,
  0xb4a00000,
  0xb4800000,
  0xb4000001,
  0x3efffff8,
  0x41100000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf800002,
  0xbf800002,
  0xbf800002,
  0xbfc00002,
  0xbfc00002,
  0xc0000001,
  0xc0000001,
  0xc0000001,
  0xc0200000,
  0xc0200001,
  0xc0200001,
  0xc0400001,
  0xc1380000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbfc00002,
  0xbfc00002,
  0xbfc00002,
  0xbfc00002,
  0xbfc00001,
  0xbf800002,
  0xbf800002,
  0xbf800001,
  0xbf000004,
  0xbf000003,
  0xbf000001,
  0xb4400000,
  0x41080000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbfc00001,
  0xbfc00001,
  0xbfc00001,
  0xc1200001,
  0xc1200001,
  0xc1280001,
  0xc1280001,
  0xc1280001,
  0xc1300001,
  0xc1300001,
  0xc1300001,
  0xc1380001,
  0xc1a00001,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xc1200001,
  0xc1200001,
  0xc1200001,
  0xc1200001,
  0xc1200001,
  0xc1180001,
  0xc1180001,
  0xc1180001,
  0xc1100001,
  0xc1100001,
  0xc1100001,
  0xc1080001,
  0xb5a00000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xc1200001,
  0xc1200001,
  0xc1200001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x80123456,
  0x80923456,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x802468ac,
  0x80923455,
  0x80123457,
  0x80123456,
  0x006dcbaa,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x80000000,
  0x006dcba9,
  0x80123455,
  0x80800000,
  0x81000000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80923456,
  0x80ffffff,
  0x80800001,
  0x80800000,
  0x00000000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x806dcbaa,
  0x80000001,
  0x807fffff,
  0x80000001,
  0x80800001,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123457,
  0x80800000,
  0x80000002,
  0x80000001,
  0x007fffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123455,
  0x007ffffe,
  0x80000000,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00800001,
  0x00000001,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x006dcbab,
  0x00000002,
  0x00800000,
  0x00800001,
  0x01000000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00923457,
  0x01000000,
  0x00800002,
  0x3f000000,
  0x3f000000,
  0x337fffff,
  0x32fffffe,
  0xb3000001,
  0xbefffffd,
  0xbeffffff,
  0xbf000002,
  0xbf800000,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f800000,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x3fc00000,
  0x3fc00001,
  0x40000000,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000001,
  0x3f000001,
  0x33c00000,
  0x33800000,
  0x00000000,
  0xbefffffc,
  0xbefffffe,
  0xbf000001,
  0xbf7fffff,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f800000,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x3fc00000,
  0x3fc00002,
  0x40000000,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f000002,
  0x3f000002,
  0x34200000,
  0x34000000,
  0x33800001,
  0xbefffffa,
  0xbefffffc,
  0xbf000000,
  0xbf7ffffe,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f000002,
  0x3f000002,
  0x3f000002,
  0x3f000002,
  0x3f000002,
  0x3f800001,
  0x3f800001,
  0x3f800002,
  0x3fc00001,
  0x3fc00001,
  0x3fc00002,
  0x40000001,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f000002,
  0x3f000002,
  0x3f000002,
  0x3f800000,
  0x3f800000,
  0x3f000001,
  0x3f000001,
  0x3f000000,
  0x33ffffff,
  0x337ffffe,
  0xb3800001,
  0xbefffffe,
  0xc1100000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3fc00000,
  0x3fc00000,
  0x3fc00001,
  0x40000000,
  0x40000000,
  0x40000001,
  0x40200000,
  0x41300000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3f800001,
  0x3f800001,
  0x3f000002,
  0x3f000002,
  0x3f000001,
  0x34400000,
  0x34000000,
  0x00000000,
  0xbefffffc,
  0xc1100000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f800001,
  0x3f800001,
  0x3f800001,
  0x3f800001,
  0x3f800001,
  0x3fc00001,
  0x3fc00001,
  0x3fc00002,
  0x40000000,
  0x40000000,
  0x40000001,
  0x40200000,
  0x41300000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f800001,
  0x3f800001,
  0x3f800001,
  0x3f800002,
  0x3f800002,
  0x3f000005,
  0x3f000004,
  0x3f000003,
  0x34a00000,
  0x34800000,
  0x34000001,
  0xbefffff8,
  0xc1100000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f800002,
  0x3f800002,
  0x3f800002,
  0x3f800002,
  0x3f800002,
  0x3fc00002,
  0x3fc00002,
  0x3fc00003,
  0x40000001,
  0x40000001,
  0x40000002,
  0x40200001,
  0x41300000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f800002,
  0x3f800002,
  0x3f800002,
  0x3fc00002,
  0x3fc00001,
  0x3f800002,
  0x3f800002,
  0x3f800001,
  0x3f000004,
  0x3f000003,
  0x3f000001,
  0x34400000,
  0xc1080000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3fc00001,
  0x3fc00001,
  0x3fc00001,
  0x3fc00002,
  0x3fc00002,
  0x40000001,
  0x40000001,
  0x40000001,
  0x40200000,
  0x40200001,
  0x40200001,
  0x40400001,
  0x41380000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3fc00002,
  0x3fc00002,
  0x3fc00002,
  0x41200001,
  0x41200001,
  0x41180001,
  0x41180001,
  0x41180001,
  0x41100001,
  0x41100001,
  0x41100001,
  0x41080001,
  0x35a00000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x41200001,
  0x41200001,
  0x41200001,
  0x41200001,
  0x41200001,
  0x41280001,
  0x41280001,
  0x41280001,
  0x41300001,
  0x41300001,
  0x41300001,
  0x41380001,
  0x41a00001,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x41200001,
  0x41200001,
  0x41200001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x00123456,
  0x806dcbaa,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x00000000,
  0x806dcba9,
  0x00123455,
  0x00123456,
  0x00923456,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x002468ac,
  0x00923455,
  0x00123457,
  0x00800000,
  0x80000000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x006dcbaa,
  0x00000001,
  0x007fffff,
  0x00800000,
  0x01000000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00923456,
  0x00ffffff,
  0x00800001,
  0x00000001,
  0x807fffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123455,
  0x807ffffe,
  0x00000000,
  0x00000001,
  0x00800001,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123457,
  0x00800000,
  0x00000002,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80c00000,
  0x81200000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80d23456,
  0x81200000,
  0x80c00001,
  0x80c00000,
  0x80400000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x80adcbaa,
  0x80400001,
  0x80bfffff,
  0xbf3fffff,
  0xbf3fffff,
  0xbf9fffff,
  0xbfa00000,
  0xbfa00000,
  0xbfdfffff,
  0xbfe00000,
  0xbfe00001,
  0xc0100000,
  0xc12c0000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf3fffff,
  0xbf3fffff,
  0xbf3fffff,
  0xbf3fffff,
  0xbf3fffff,
  0xbe7fffff,
  0xbe7ffffd,
  0xbe7ffff9,
  0x3e7fffff,
  0x3e800002,
  0x3e800006,
  0x3f400001,
  0x41140000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf3fffff,
  0xbf3fffff,
  0xbf3fffff,
  0xbf400000,
  0xbf400000,
  0xbfa00000,
  0xbfa00000,
  0xbfa00000,
  0xbfe00000,
  0xbfe00000,
  0xbfe00001,
  0xc0100000,
  0xc12c0000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf400000,
  0xbf400000,
  0xbf400000,
  0xbf400000,
  0xbf400000,
  0xbe800001,
  0xbe800000,
  0xbe7ffffc,
  0x3e7ffffc,
  0x3e800000,
  0x3e800004,
  0x3f400000,
  0x41140000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf400000,
  0xbf400000,
  0xbf400000,
  0xbf400002,
  0xbf400002,
  0xbfa00000,
  0xbfa00001,
  0xbfa00001,
  0xbfe00000,
  0xbfe00001,
  0xbfe00002,
  0xc0100000,
  0xc12c0000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf400002,
  0xbf400002,
  0xbf400002,
  0xbf400002,
  0xbf400001,
  0xbe800004,
  0xbe800003,
  0xbe800001,
  0x3e7ffff6,
  0x3e7ffffa,
  0x3e800001,
  0x3f3ffffe,
  0x41140000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf400001,
  0xbf400001,
  0xbf400001,
  0xbfbfffff,
  0xbfbfffff,
  0xbfffffff,
  0xbfffffff,
  0xc0000000,
  0xc01fffff,
  0xc0200000,
  0xc0200000,
  0xc0400000,
  0xc1380000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbfbfffff,
  0xbfbfffff,
  0xbfbfffff,
  0xbfbfffff,
  0xbfbfffff,
  0xbf7fffff,
  0xbf7ffffe,
  0xbf7ffffe,
  0xbeffffff,
  0xbefffffd,
  0xbefffff9,
  0x33c00000,
  0x41080000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbfbfffff,
  0xbfbfffff,
  0xbfbfffff,
  0xbfc00000,
  0xbfc00000,
  0xc0000000,
  0xc0000000,
  0xc0000000,
  0xc0200000,
  0xc0200000,
  0xc0200000,
  0xc0400000,
  0xc1380000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbfc00000,
  0xbfc00000,
  0xbfc00000,
  0xbfc00000,
  0xbfc00000,
  0xbf800000,
  0xbf800000,
  0xbf7fffff,
  0xbf000001,
  0xbf000000,
  0xbefffffc,
  0x00000000,
  0x41080000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbfc00000,
  0xbfc00000,
  0xbfc00000,
  0xbfc00002,
  0xbfc00002,
  0xc0000001,
  0xc0000001,
  0xc0000001,
  0xc0200000,
  0xc0200001,
  0xc0200001,
  0xc0400001,
  0xc1380000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbfc00002,
  0xbfc00002,
  0xbfc00002,
  0xbfc00002,
  0xbfc00001,
  0xbf800002,
  0xbf800002,
  0xbf800001,
  0xbf000004,
  0xbf000003,
  0xbf000001,
  0xb4400000,
  0x41080000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbfc00001,
  0xbfc00001,
  0xbfc00001,
  0xc0100000,
  0xc0100000,
  0xc0300000,
  0xc0300000,
  0xc0300000,
  0xc0500000,
  0xc0500000,
  0xc0500000,
  0xc0700000,
  0xc1440000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xc0100000,
  0xc0100000,
  0xc0100000,
  0xc0100000,
  0xc0100000,
  0xbfe00000,
  0xbfe00000,
  0xbfe00000,
  0xbfa00000,
  0xbfa00000,
  0xbf9fffff,
  0xbf400000,
  0x40f80000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xc0100000,
  0xc0100000,
  0xc0100000,
  0xc1700000,
  0xc1700000,
  0xc1780000,
  0xc1780000,
  0xc1780000,
  0xc1800000,
  0xc1800000,
  0xc1800000,
  0xc1840000,
  0xc1c80000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xc1700000,
  0xc1700000,
  0xc1700000,
  0xc1700000,
  0xc1700000,
  0xc1680000,
  0xc1680000,
  0xc1680000,
  0xc1600000,
  0xc1600000,
  0xc1600000,
  0xc1580000,
  0xc0a00000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xc1700000,
  0xc1700000,
  0xc1700000,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x801b4e81,
  0x809b4e81,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x802d82d7,
  0x809b4e80,
  0x801b4e82,
  0x801b4e81,
  0x0064b17f,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x80091a2b,
  0x0064b17e,
  0x801b4e80,
  0x80bffffe,
  0x811fffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80d23454,
  0x811fffff,
  0x80c00000,
  0x80bffffe,
  0x803ffffe,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x80adcba8,
  0x80400000,
  0x80bffffe,
  0x80000002,
  0x80800002,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123458,
  0x80800000,
  0x80000002,
  0x80000002,
  0x007ffffe,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123454,
  0x007ffffe,
  0x80000000,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00c00000,
  0x00400000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x00adcbaa,
  0x00400001,
  0x00bfffff,
  0x00c00000,
  0x01200000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00d23456,
  0x01200000,
  0x00c00001,
  0x3f3fffff,
  0x3f3fffff,
  0x3e7fffff,
  0x3e7ffffd,
  0x3e7ffff9,
  0xbe7fffff,
  0xbe800002,
  0xbe800006,
  0xbf400001,
  0xc1140000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f3fffff,
  0x3f3fffff,
  0x3f3fffff,
  0x3f3fffff,
  0x3f3fffff,
  0x3f9fffff,
  0x3fa00000,
  0x3fa00000,
  0x3fdfffff,
  0x3fe00000,
  0x3fe00001,
  0x40100000,
  0x412c0000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f3fffff,
  0x3f3fffff,
  0x3f3fffff,
  0x3f400000,
  0x3f400000,
  0x3e800001,
  0x3e800000,
  0x3e7ffffc,
  0xbe7ffffc,
  0xbe800000,
  0xbe800004,
  0xbf400000,
  0xc1140000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f400000,
  0x3f400000,
  0x3f400000,
  0x3f400000,
  0x3f400000,
  0x3fa00000,
  0x3fa00000,
  0x3fa00000,
  0x3fe00000,
  0x3fe00000,
  0x3fe00001,
  0x40100000,
  0x412c0000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f400000,
  0x3f400000,
  0x3f400000,
  0x3f400002,
  0x3f400001,
  0x3e800004,
  0x3e800003,
  0x3e800001,
  0xbe7ffff6,
  0xbe7ffffa,
  0xbe800001,
  0xbf3ffffe,
  0xc1140000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f400001,
  0x3f400001,
  0x3f400001,
  0x3f400002,
  0x3f400002,
  0x3fa00000,
  0x3fa00001,
  0x3fa00001,
  0x3fe00000,
  0x3fe00001,
  0x3fe00002,
  0x40100000,
  0x412c0000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f400002,
  0x3f400002,
  0x3f400002,
  0x3fbfffff,
  0x3fbfffff,
  0x3f7fffff,
  0x3f7ffffe,
  0x3f7ffffe,
  0x3effffff,
  0x3efffffd,
  0x3efffff9,
  0xb3c00000,
  0xc1080000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3fbfffff,
  0x3fbfffff,
  0x3fbfffff,
  0x3fbfffff,
  0x3fbfffff,
  0x3fffffff,
  0x3fffffff,
  0x40000000,
  0x401fffff,
  0x40200000,
  0x40200000,
  0x40400000,
  0x41380000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3fbfffff,
  0x3fbfffff,
  0x3fbfffff,
  0x3fc00000,
  0x3fc00000,
  0x3f800000,
  0x3f800000,
  0x3f7fffff,
  0x3f000001,
  0x3f000000,
  0x3efffffc,
  0x00000000,
  0xc1080000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3fc00000,
  0x3fc00000,
  0x3fc00000,
  0x3fc00000,
  0x3fc00000,
  0x40000000,
  0x40000000,
  0x40000000,
  0x40200000,
  0x40200000,
  0x40200000,
  0x40400000,
  0x41380000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3fc00000,
  0x3fc00000,
  0x3fc00000,
  0x3fc00002,
  0x3fc00001,
  0x3f800002,
  0x3f800002,
  0x3f800001,
  0x3f000004,
  0x3f000003,
  0x3f000001,
  0x34400000,
  0xc1080000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3fc00001,
  0x3fc00001,
  0x3fc00001,
  0x3fc00002,
  0x3fc00002,
  0x40000001,
  0x40000001,
  0x40000001,
  0x40200000,
  0x40200001,
  0x40200001,
  0x40400001,
  0x41380000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3fc00002,
  0x3fc00002,
  0x3fc00002,
  0x40100000,
  0x40100000,
  0x3fe00000,
  0x3fe00000,
  0x3fe00000,
  0x3fa00000,
  0x3fa00000,
  0x3f9fffff,
  0x3f400000,
  0xc0f80000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x40100000,
  0x40100000,
  0x40100000,
  0x40100000,
  0x40100000,
  0x40300000,
  0x40300000,
  0x40300000,
  0x40500000,
  0x40500000,
  0x40500000,
  0x40700000,
  0x41440000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x40100000,
  0x40100000,
  0x40100000,
  0x41700000,
  0x41700000,
  0x41680000,
  0x41680000,
  0x41680000,
  0x41600000,
  0x41600000,
  0x41600000,
  0x41580000,
  0x40a00000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x41700000,
  0x41700000,
  0x41700000,
  0x41700000,
  0x41700000,
  0x41780000,
  0x41780000,
  0x41780000,
  0x41800000,
  0x41800000,
  0x41800000,
  0x41840000,
  0x41c80000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x41700000,
  0x41700000,
  0x41700000,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x001b4e81,
  0x8064b17f,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x00091a2b,
  0x8064b17e,
  0x001b4e80,
  0x001b4e81,
  0x009b4e81,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x002d82d7,
  0x009b4e80,
  0x001b4e82,
  0x00bffffe,
  0x003ffffe,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x00adcba8,
  0x00400000,
  0x00bffffe,
  0x00bffffe,
  0x011fffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00d23454,
  0x011fffff,
  0x00c00000,
  0x00000002,
  0x807ffffe,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123454,
  0x807ffffe,
  0x00000000,
  0x00000002,
  0x00800002,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123458,
  0x00800000,
  0x00000002,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x82200000,
  0x82300000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x8222468b,
  0x82300000,
  0x82200000,
  0x82200000,
  0x82100000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x821db975,
  0x82100000,
  0x82200000,
  0xc09fffff,
  0xc09fffff,
  0xc0afffff,
  0xc0afffff,
  0xc0b00000,
  0xc0bfffff,
  0xc0bfffff,
  0xc0c00000,
  0xc0cfffff,
  0xc1700000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xc09fffff,
  0xc09fffff,
  0xc09fffff,
  0xc09fffff,
  0xc09fffff,
  0xc08fffff,
  0xc08fffff,
  0xc08fffff,
  0xc07fffff,
  0xc07fffff,
  0xc07ffffe,
  0xc05fffff,
  0x40a00001,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xc09fffff,
  0xc09fffff,
  0xc09fffff,
  0xc0a00000,
  0xc0a00000,
  0xc0b00000,
  0xc0b00000,
  0xc0b00000,
  0xc0c00000,
  0xc0c00000,
  0xc0c00000,
  0xc0d00000,
  0xc1700000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xc0a00000,
  0xc0a00000,
  0xc0a00000,
  0xc0a00000,
  0xc0a00000,
  0xc0900000,
  0xc0900000,
  0xc0900000,
  0xc0800000,
  0xc0800000,
  0xc0800000,
  0xc0600000,
  0x40a00000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xc0a00000,
  0xc0a00000,
  0xc0a00000,
  0xc0a00001,
  0xc0a00001,
  0xc0b00001,
  0xc0b00001,
  0xc0b00001,
  0xc0c00001,
  0xc0c00001,
  0xc0c00002,
  0xc0d00001,
  0xc1700001,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xc0a00001,
  0xc0a00001,
  0xc0a00001,
  0xc0a00001,
  0xc0a00001,
  0xc0900001,
  0xc0900001,
  0xc0900001,
  0xc0800001,
  0xc0800001,
  0xc0800001,
  0xc0600002,
  0x409fffff,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xc0a00001,
  0xc0a00001,
  0xc0a00001,
  0xc11fffff,
  0xc11fffff,
  0xc127ffff,
  0xc127ffff,
  0xc127ffff,
  0xc12fffff,
  0xc12fffff,
  0xc1300000,
  0xc137ffff,
  0xc1a00000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xc11fffff,
  0xc11fffff,
  0xc11fffff,
  0xc11fffff,
  0xc11fffff,
  0xc117ffff,
  0xc117ffff,
  0xc117ffff,
  0xc10fffff,
  0xc10fffff,
  0xc10fffff,
  0xc107ffff,
  0x35200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xc11fffff,
  0xc11fffff,
  0xc11fffff,
  0xc1200000,
  0xc1200000,
  0xc1280000,
  0xc1280000,
  0xc1280000,
  0xc1300000,
  0xc1300000,
  0xc1300000,
  0xc1380000,
  0xc1a00000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xc1200000,
  0xc1200000,
  0xc1200000,
  0xc1200000,
  0xc1200000,
  0xc1180000,
  0xc1180000,
  0xc1180000,
  0xc1100000,
  0xc1100000,
  0xc1100000,
  0xc1080000,
  0x00000000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xc1200000,
  0xc1200000,
  0xc1200000,
  0xc1200001,
  0xc1200001,
  0xc1280001,
  0xc1280001,
  0xc1280001,
  0xc1300001,
  0xc1300001,
  0xc1300001,
  0xc1380001,
  0xc1a00001,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xc1200001,
  0xc1200001,
  0xc1200001,
  0xc1200001,
  0xc1200001,
  0xc1180001,
  0xc1180001,
  0xc1180001,
  0xc1100001,
  0xc1100001,
  0xc1100001,
  0xc1080001,
  0xb5a00000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xc1200001,
  0xc1200001,
  0xc1200001,
  0xc1700000,
  0xc1700000,
  0xc1780000,
  0xc1780000,
  0xc1780000,
  0xc1800000,
  0xc1800000,
  0xc1800000,
  0xc1840000,
  0xc1c80000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xc1700000,
  0xc1700000,
  0xc1700000,
  0xc1700000,
  0xc1700000,
  0xc1680000,
  0xc1680000,
  0xc1680000,
  0xc1600000,
  0xc1600000,
  0xc1600000,
  0xc1580000,
  0xc0a00000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xc1700000,
  0xc1700000,
  0xc1700000,
  0xc2c80000,
  0xc2c80000,
  0xc2c90000,
  0xc2c90000,
  0xc2c90000,
  0xc2ca0000,
  0xc2ca0000,
  0xc2ca0000,
  0xc2cb0000,
  0xc2dc0000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xc2c80000,
  0xc2c80000,
  0xc2c80000,
  0xc2c80000,
  0xc2c80000,
  0xc2c70000,
  0xc2c70000,
  0xc2c70000,
  0xc2c60000,
  0xc2c60000,
  0xc2c60000,
  0xc2c50000,
  0xc2b40000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xc2c80000,
  0xc2c80000,
  0xc2c80000,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x80b60b5c,
  0x811b05ae,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80c83fb2,
  0x811b05ae,
  0x80b60b5d,
  0x80b60b5c,
  0x80360b5c,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x80a3d706,
  0x80360b5d,
  0x80b60b5b,
  0x821fffff,
  0x822fffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x8222468a,
  0x822fffff,
  0x821fffff,
  0x821fffff,
  0x820fffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x821db974,
  0x820fffff,
  0x821fffff,
  0x8000000a,
  0x8080000a,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123460,
  0x80800009,
  0x8000000b,
  0x8000000a,
  0x007ffff6,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x0012344c,
  0x007ffff5,
  0x80000009,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x02200000,
  0x02100000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x021db975,
  0x02100000,
  0x02200000,
  0x02200000,
  0x02300000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x0222468b,
  0x02300000,
  0x02200000,
  0x409fffff,
  0x409fffff,
  0x408fffff,
  0x408fffff,
  0x408fffff,
  0x407fffff,
  0x407fffff,
  0x407ffffe,
  0x405fffff,
  0xc0a00001,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x409fffff,
  0x409fffff,
  0x409fffff,
  0x409fffff,
  0x409fffff,
  0x40afffff,
  0x40afffff,
  0x40b00000,
  0x40bfffff,
  0x40bfffff,
  0x40c00000,
  0x40cfffff,
  0x41700000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x409fffff,
  0x409fffff,
  0x409fffff,
  0x40a00000,
  0x40a00000,
  0x40900000,
  0x40900000,
  0x40900000,
  0x40800000,
  0x40800000,
  0x40800000,
  0x40600000,
  0xc0a00000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x40a00000,
  0x40a00000,
  0x40a00000,
  0x40a00000,
  0x40a00000,
  0x40b00000,
  0x40b00000,
  0x40b00000,
  0x40c00000,
  0x40c00000,
  0x40c00000,
  0x40d00000,
  0x41700000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x40a00000,
  0x40a00000,
  0x40a00000,
  0x40a00001,
  0x40a00001,
  0x40900001,
  0x40900001,
  0x40900001,
  0x40800001,
  0x40800001,
  0x40800001,
  0x40600002,
  0xc09fffff,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x40a00001,
  0x40a00001,
  0x40a00001,
  0x40a00001,
  0x40a00001,
  0x40b00001,
  0x40b00001,
  0x40b00001,
  0x40c00001,
  0x40c00001,
  0x40c00002,
  0x40d00001,
  0x41700001,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x40a00001,
  0x40a00001,
  0x40a00001,
  0x411fffff,
  0x411fffff,
  0x4117ffff,
  0x4117ffff,
  0x4117ffff,
  0x410fffff,
  0x410fffff,
  0x410fffff,
  0x4107ffff,
  0xb5200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x411fffff,
  0x411fffff,
  0x411fffff,
  0x411fffff,
  0x411fffff,
  0x4127ffff,
  0x4127ffff,
  0x4127ffff,
  0x412fffff,
  0x412fffff,
  0x41300000,
  0x4137ffff,
  0x41a00000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x411fffff,
  0x411fffff,
  0x411fffff,
  0x41200000,
  0x41200000,
  0x41180000,
  0x41180000,
  0x41180000,
  0x41100000,
  0x41100000,
  0x41100000,
  0x41080000,
  0x00000000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x41200000,
  0x41200000,
  0x41200000,
  0x41200000,
  0x41200000,
  0x41280000,
  0x41280000,
  0x41280000,
  0x41300000,
  0x41300000,
  0x41300000,
  0x41380000,
  0x41a00000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x41200000,
  0x41200000,
  0x41200000,
  0x41200001,
  0x41200001,
  0x41180001,
  0x41180001,
  0x41180001,
  0x41100001,
  0x41100001,
  0x41100001,
  0x41080001,
  0x35a00000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x41200001,
  0x41200001,
  0x41200001,
  0x41200001,
  0x41200001,
  0x41280001,
  0x41280001,
  0x41280001,
  0x41300001,
  0x41300001,
  0x41300001,
  0x41380001,
  0x41a00001,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x41200001,
  0x41200001,
  0x41200001,
  0x41700000,
  0x41700000,
  0x41680000,
  0x41680000,
  0x41680000,
  0x41600000,
  0x41600000,
  0x41600000,
  0x41580000,
  0x40a00000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x41700000,
  0x41700000,
  0x41700000,
  0x41700000,
  0x41700000,
  0x41780000,
  0x41780000,
  0x41780000,
  0x41800000,
  0x41800000,
  0x41800000,
  0x41840000,
  0x41c80000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x41700000,
  0x41700000,
  0x41700000,
  0x42c80000,
  0x42c80000,
  0x42c70000,
  0x42c70000,
  0x42c70000,
  0x42c60000,
  0x42c60000,
  0x42c60000,
  0x42c50000,
  0x42b40000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x42c80000,
  0x42c80000,
  0x42c80000,
  0x42c80000,
  0x42c80000,
  0x42c90000,
  0x42c90000,
  0x42c90000,
  0x42ca0000,
  0x42ca0000,
  0x42ca0000,
  0x42cb0000,
  0x42dc0000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x42c80000,
  0x42c80000,
  0x42c80000,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x00b60b5c,
  0x00360b5c,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x00a3d706,
  0x00360b5d,
  0x00b60b5b,
  0x00b60b5c,
  0x011b05ae,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00c83fb2,
  0x011b05ae,
  0x00b60b5d,
  0x021fffff,
  0x020fffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x021db974,
  0x020fffff,
  0x021fffff,
  0x021fffff,
  0x022fffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x0222468a,
  0x022fffff,
  0x021fffff,
  0x0000000a,
  0x807ffff6,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x8012344c,
  0x807ffff5,
  0x00000009,
  0x0000000a,
  0x0080000a,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123460,
  0x00800009,
  0x0000000b,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80091a2b,
  0x80891a2b,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x801b4e81,
  0x80891a2a,
  0x80091a2c,
  0x80091a2b,
  0x0076e5d5,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00091a2b,
  0x0076e5d4,
  0x80091a2a,
  0x80091a2b,
  0x80891a2b,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x801b4e81,
  0x80891a2a,
  0x80091a2c,
  0x80091a2b,
  0x0076e5d5,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00091a2b,
  0x0076e5d4,
  0x80091a2a,
  0x80091a2b,
  0x80891a2b,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x801b4e81,
  0x80891a2a,
  0x80091a2c,
  0x80091a2b,
  0x0076e5d5,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00091a2b,
  0x0076e5d4,
  0x80091a2a,
  0x80123456,
  0x80923456,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x802468ac,
  0x80923455,
  0x80123457,
  0x80123456,
  0x006dcbaa,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00000000,
  0x006dcba9,
  0x80123455,
  0x80123456,
  0x80923456,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x802468ac,
  0x80923455,
  0x80123457,
  0x80123456,
  0x006dcbaa,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00000000,
  0x006dcba9,
  0x80123455,
  0x80123456,
  0x80923456,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x802468ac,
  0x80923455,
  0x80123457,
  0x80123456,
  0x006dcbaa,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x80000000,
  0x006dcba9,
  0x80123455,
  0x801b4e81,
  0x809b4e81,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x802d82d7,
  0x809b4e80,
  0x801b4e82,
  0x801b4e81,
  0x0064b17f,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x80091a2b,
  0x0064b17e,
  0x801b4e80,
  0x80b60b5c,
  0x811b05ae,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80c83fb2,
  0x811b05ae,
  0x80b60b5d,
  0x80b60b5c,
  0x80360b5c,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x80a3d706,
  0x80360b5d,
  0x80b60b5b,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00091a2b,
  0x8076e5d5,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80091a2b,
  0x8076e5d4,
  0x00091a2a,
  0x00091a2b,
  0x00891a2b,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x001b4e81,
  0x00891a2a,
  0x00091a2c,
  0x00091a2b,
  0x8076e5d5,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80091a2b,
  0x8076e5d4,
  0x00091a2a,
  0x00091a2b,
  0x00891a2b,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x001b4e81,
  0x00891a2a,
  0x00091a2c,
  0x00091a2b,
  0x8076e5d5,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80091a2b,
  0x8076e5d4,
  0x00091a2a,
  0x00091a2b,
  0x00891a2b,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x001b4e81,
  0x00891a2a,
  0x00091a2c,
  0x00123456,
  0x806dcbaa,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80000000,
  0x806dcba9,
  0x00123455,
  0x00123456,
  0x00923456,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x002468ac,
  0x00923455,
  0x00123457,
  0x00123456,
  0x806dcbaa,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x00000000,
  0x806dcba9,
  0x00123455,
  0x00123456,
  0x00923456,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x002468ac,
  0x00923455,
  0x00123457,
  0x00123456,
  0x806dcbaa,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x00000000,
  0x806dcba9,
  0x00123455,
  0x00123456,
  0x00923456,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x002468ac,
  0x00923455,
  0x00123457,
  0x001b4e81,
  0x8064b17f,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x00091a2b,
  0x8064b17e,
  0x001b4e80,
  0x001b4e81,
  0x009b4e81,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x002d82d7,
  0x009b4e80,
  0x001b4e82,
  0x00b60b5c,
  0x00360b5c,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x00a3d706,
  0x00360b5d,
  0x00b60b5b,
  0x00b60b5c,
  0x011b05ae,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00c83fb2,
  0x011b05ae,
  0x00b60b5d,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x803fffff,
  0x80bfffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80523455,
  0x80bffffe,
  0x80400000,
  0x803fffff,
  0x00400001,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x802dcba9,
  0x00400000,
  0x803ffffe,
  0x80400000,
  0x80c00000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80523456,
  0x80bffffe,
  0x80400000,
  0x80400000,
  0x00400000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x802dcbaa,
  0x00400000,
  0x803ffffe,
  0x80400000,
  0x80c00000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80523456,
  0x80bfffff,
  0x80400001,
  0x80400000,
  0x00400000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x802dcbaa,
  0x003fffff,
  0x803fffff,
  0x807fffff,
  0x80ffffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80923455,
  0x80fffffe,
  0x80800000,
  0x807fffff,
  0x00000001,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x806dcba9,
  0x00000000,
  0x807ffffe,
  0x807fffff,
  0x80ffffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80923455,
  0x80fffffe,
  0x80800000,
  0x807fffff,
  0x00000001,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x806dcba9,
  0x00000000,
  0x807ffffe,
  0x80800000,
  0x81000000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80923456,
  0x80ffffff,
  0x80800001,
  0x80800000,
  0x00000000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x806dcbaa,
  0x80000001,
  0x807fffff,
  0x80bffffe,
  0x811fffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80d23454,
  0x811fffff,
  0x80c00000,
  0x80bffffe,
  0x803ffffe,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x80adcba8,
  0x80400000,
  0x80bffffe,
  0x821fffff,
  0x822fffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x8222468a,
  0x822fffff,
  0x821fffff,
  0x821fffff,
  0x820fffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x821db974,
  0x820fffff,
  0x821fffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x003fffff,
  0x80400001,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x002dcba9,
  0x80400000,
  0x003ffffe,
  0x003fffff,
  0x00bfffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00523455,
  0x00bffffe,
  0x00400000,
  0x00400000,
  0x80400000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x002dcbaa,
  0x80400000,
  0x003ffffe,
  0x00400000,
  0x00c00000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00523456,
  0x00bffffe,
  0x00400000,
  0x00400000,
  0x80400000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x002dcbaa,
  0x803fffff,
  0x003fffff,
  0x00400000,
  0x00c00000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00523456,
  0x00bfffff,
  0x00400001,
  0x007fffff,
  0x80000001,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x006dcba9,
  0x80000000,
  0x007ffffe,
  0x007fffff,
  0x00ffffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00923455,
  0x00fffffe,
  0x00800000,
  0x007fffff,
  0x80000001,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x006dcba9,
  0x00000000,
  0x007ffffe,
  0x007fffff,
  0x00ffffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00923455,
  0x00fffffe,
  0x00800000,
  0x00800000,
  0x80000000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x006dcbaa,
  0x00000001,
  0x007fffff,
  0x00800000,
  0x01000000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00923456,
  0x00ffffff,
  0x00800001,
  0x00bffffe,
  0x003ffffe,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x00adcba8,
  0x00400000,
  0x00bffffe,
  0x00bffffe,
  0x011fffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00d23454,
  0x011fffff,
  0x00c00000,
  0x021fffff,
  0x020fffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x021db974,
  0x020fffff,
  0x021fffff,
  0x021fffff,
  0x022fffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x0222468a,
  0x022fffff,
  0x021fffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x80800000,
  0x80000002,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007ffffe,
  0x00000000,
  0x80000001,
  0x80800001,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123457,
  0x80800000,
  0x80000002,
  0x80000001,
  0x007fffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123455,
  0x007ffffe,
  0x00000000,
  0x80000001,
  0x80800001,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123457,
  0x80800000,
  0x80000002,
  0x80000001,
  0x007fffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123455,
  0x007ffffe,
  0x00000000,
  0x80000001,
  0x80800001,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123457,
  0x80800000,
  0x80000002,
  0x80000001,
  0x007fffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123455,
  0x007ffffe,
  0x00000000,
  0x80000001,
  0x80800001,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123457,
  0x80800000,
  0x80000002,
  0x80000001,
  0x007fffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123455,
  0x007ffffe,
  0x80000000,
  0x80000002,
  0x80800002,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123458,
  0x80800000,
  0x80000002,
  0x80000002,
  0x007ffffe,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123454,
  0x007ffffe,
  0x80000000,
  0x8000000a,
  0x8080000a,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123460,
  0x80800009,
  0x8000000b,
  0x8000000a,
  0x007ffff6,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x0012344c,
  0x007ffff5,
  0x80000009,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807ffffe,
  0x80000000,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x00800000,
  0x00000002,
  0x00000001,
  0x807fffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123455,
  0x807ffffe,
  0x80000000,
  0x00000001,
  0x00800001,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123457,
  0x00800000,
  0x00000002,
  0x00000001,
  0x807fffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123455,
  0x807ffffe,
  0x80000000,
  0x00000001,
  0x00800001,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123457,
  0x00800000,
  0x00000002,
  0x00000001,
  0x807fffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123455,
  0x807ffffe,
  0x00000000,
  0x00000001,
  0x00800001,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123457,
  0x00800000,
  0x00000002,
  0x00000001,
  0x807fffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123455,
  0x807ffffe,
  0x00000000,
  0x00000001,
  0x00800001,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123457,
  0x00800000,
  0x00000002,
  0x00000002,
  0x807ffffe,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123454,
  0x807ffffe,
  0x00000000,
  0x00000002,
  0x00800002,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123458,
  0x00800000,
  0x00000002,
  0x0000000a,
  0x807ffff6,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x8012344c,
  0x807ffff5,
  0x00000009,
  0x0000000a,
  0x0080000a,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123460,
  0x00800009,
  0x0000000b,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00400000,
  0x80400000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x002dcbaa,
  0x803fffff,
  0x003fffff,
  0x00400000,
  0x00c00000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00523456,
  0x00bfffff,
  0x00400001,
  0x00400000,
  0x80400000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x002dcbaa,
  0x803fffff,
  0x003fffff,
  0x00400000,
  0x00c00000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00523456,
  0x00bfffff,
  0x00400001,
  0x00400000,
  0x80400000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x002dcbaa,
  0x803ffffe,
  0x00400000,
  0x00400000,
  0x00c00000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00523456,
  0x00c00000,
  0x00400002,
  0x00800000,
  0x80000000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x006dcbaa,
  0x00000000,
  0x007ffffe,
  0x00800000,
  0x01000000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00923456,
  0x00fffffe,
  0x00800000,
  0x00800000,
  0x00000000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x006dcbaa,
  0x00000001,
  0x007fffff,
  0x00800000,
  0x01000000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00923456,
  0x00ffffff,
  0x00800001,
  0x00800001,
  0x00000001,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x006dcbab,
  0x00000002,
  0x00800000,
  0x00800001,
  0x01000000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00923457,
  0x01000000,
  0x00800002,
  0x00c00000,
  0x00400000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x00adcbaa,
  0x00400001,
  0x00bfffff,
  0x00c00000,
  0x01200000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00d23456,
  0x01200000,
  0x00c00001,
  0x02200000,
  0x02100000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x021db975,
  0x02100000,
  0x02200000,
  0x02200000,
  0x02300000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x0222468b,
  0x02300000,
  0x02200000,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80400000,
  0x80c00000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80523456,
  0x80bfffff,
  0x80400001,
  0x80400000,
  0x00400000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x802dcbaa,
  0x003fffff,
  0x803fffff,
  0x80400000,
  0x80c00000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80523456,
  0x80bfffff,
  0x80400001,
  0x80400000,
  0x00400000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x802dcbaa,
  0x003fffff,
  0x803fffff,
  0x80400000,
  0x80c00000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80523456,
  0x80c00000,
  0x80400002,
  0x80400000,
  0x00400000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x802dcbaa,
  0x003ffffe,
  0x80400000,
  0x80800000,
  0x81000000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80923456,
  0x80fffffe,
  0x80800000,
  0x80800000,
  0x00000000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x806dcbaa,
  0x80000000,
  0x807ffffe,
  0x80800000,
  0x81000000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80923456,
  0x80ffffff,
  0x80800001,
  0x80800000,
  0x00000000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x806dcbaa,
  0x80000001,
  0x807fffff,
  0x80800001,
  0x81000000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80923457,
  0x81000000,
  0x80800002,
  0x80800001,
  0x80000001,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x806dcbab,
  0x80000002,
  0x80800000,
  0x80c00000,
  0x81200000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80d23456,
  0x81200000,
  0x80c00001,
  0x80c00000,
  0x80400000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x80adcbaa,
  0x80400001,
  0x80bfffff,
  0x82200000,
  0x82300000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x8222468b,
  0x82300000,
  0x82200000,
  0x82200000,
  0x82100000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x821db975,
  0x82100000,
  0x82200000,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00400000,
  0x80400000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x002dcbaa,
  0x803fffff,
  0x003fffff,
  0x00400000,
  0x00c00000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00523456,
  0x00bfffff,
  0x00400001,
  0x3e7ffffe,
  0x3e7ffffe,
  0xbe800000,
  0xbe800001,
  0xbe800003,
  0xbf3fffff,
  0xbf400000,
  0xbf400002,
  0xbfa00000,
  0xc11c0000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3e7ffffe,
  0x3e7ffffe,
  0x3e7ffffe,
  0x3e7ffffe,
  0x3e7ffffe,
  0x3f3fffff,
  0x3f400000,
  0x3f400001,
  0x3f9fffff,
  0x3fa00000,
  0x3fa00001,
  0x3fe00000,
  0x41240000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3e7ffffe,
  0x3e7ffffe,
  0x3e7ffffe,
  0x3e7fffff,
  0x3e7fffff,
  0xbe7fffff,
  0xbe800000,
  0xbe800002,
  0xbf3fffff,
  0xbf400000,
  0xbf400002,
  0xbfa00000,
  0xc11c0000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3e7fffff,
  0x3e7fffff,
  0x3e7fffff,
  0x3e7fffff,
  0x3e7fffff,
  0x3f3fffff,
  0x3f400000,
  0x3f400001,
  0x3f9fffff,
  0x3fa00000,
  0x3fa00001,
  0x3fe00000,
  0x41240000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3e7fffff,
  0x3e7fffff,
  0x3e7fffff,
  0x3e800000,
  0x3e800000,
  0xbe7ffffd,
  0xbe7fffff,
  0xbe800002,
  0xbf3fffff,
  0xbf400000,
  0xbf400002,
  0xbfa00000,
  0xc11c0000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3e800000,
  0x3e800000,
  0x3e800000,
  0x3e800000,
  0x3e800000,
  0x3f400000,
  0x3f400000,
  0x3f400001,
  0x3fa00000,
  0x3fa00000,
  0x3fa00001,
  0x3fe00000,
  0x41240000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3e800000,
  0x3e800000,
  0x3e800000,
  0x3efffffe,
  0x3efffffe,
  0xb2ffffff,
  0xb3800000,
  0xb4000000,
  0xbf000000,
  0xbf000001,
  0xbf000003,
  0xbf800000,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3efffffe,
  0x3efffffe,
  0x3efffffe,
  0x3efffffe,
  0x3efffffe,
  0x3f7fffff,
  0x3f7fffff,
  0x3f800000,
  0x3fbfffff,
  0x3fc00000,
  0x3fc00001,
  0x40000000,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3efffffe,
  0x3efffffe,
  0x3efffffe,
  0x3effffff,
  0x3effffff,
  0x00000000,
  0xb3000000,
  0xb3c00000,
  0xbeffffff,
  0xbf000000,
  0xbf000002,
  0xbf800000,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3f7fffff,
  0x3f800000,
  0x3f800000,
  0x3fbfffff,
  0x3fc00000,
  0x3fc00001,
  0x40000000,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3f000000,
  0x3f000000,
  0x337fffff,
  0x32fffffe,
  0xb3000001,
  0xbefffffd,
  0xbeffffff,
  0xbf000002,
  0xbf800000,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f800000,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x3fc00000,
  0x3fc00001,
  0x40000000,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f3fffff,
  0x3f3fffff,
  0x3e7fffff,
  0x3e7ffffd,
  0x3e7ffff9,
  0xbe7fffff,
  0xbe800002,
  0xbe800006,
  0xbf400001,
  0xc1140000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f3fffff,
  0x3f3fffff,
  0x3f3fffff,
  0x3f3fffff,
  0x3f3fffff,
  0x3f9fffff,
  0x3fa00000,
  0x3fa00000,
  0x3fdfffff,
  0x3fe00000,
  0x3fe00001,
  0x40100000,
  0x412c0000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f3fffff,
  0x3f3fffff,
  0x3f3fffff,
  0x409fffff,
  0x409fffff,
  0x408fffff,
  0x408fffff,
  0x408fffff,
  0x407fffff,
  0x407fffff,
  0x407ffffe,
  0x405fffff,
  0xc0a00001,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x409fffff,
  0x409fffff,
  0x409fffff,
  0x409fffff,
  0x409fffff,
  0x40afffff,
  0x40afffff,
  0x40b00000,
  0x40bfffff,
  0x40bfffff,
  0x40c00000,
  0x40cfffff,
  0x41700000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x409fffff,
  0x409fffff,
  0x409fffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x00091a2b,
  0x8076e5d5,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80091a2b,
  0x8076e5d4,
  0x00091a2a,
  0x00091a2b,
  0x00891a2b,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x001b4e81,
  0x00891a2a,
  0x00091a2c,
  0x003fffff,
  0x80400001,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x002dcba9,
  0x80400000,
  0x003ffffe,
  0x003fffff,
  0x00bfffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00523455,
  0x00bffffe,
  0x00400000,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80400000,
  0x80c00000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80523456,
  0x80bfffff,
  0x80400001,
  0x80400000,
  0x00400000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x802dcbaa,
  0x003fffff,
  0x803fffff,
  0xbe7ffffe,
  0xbe7ffffe,
  0xbf3fffff,
  0xbf400000,
  0xbf400001,
  0xbf9fffff,
  0xbfa00000,
  0xbfa00001,
  0xbfe00000,
  0xc1240000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbe7ffffe,
  0xbe7ffffe,
  0xbe7ffffe,
  0xbe7ffffe,
  0xbe7ffffe,
  0x3e800000,
  0x3e800001,
  0x3e800003,
  0x3f3fffff,
  0x3f400000,
  0x3f400002,
  0x3fa00000,
  0x411c0000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbe7ffffe,
  0xbe7ffffe,
  0xbe7ffffe,
  0xbe7fffff,
  0xbe7fffff,
  0xbf3fffff,
  0xbf400000,
  0xbf400001,
  0xbf9fffff,
  0xbfa00000,
  0xbfa00001,
  0xbfe00000,
  0xc1240000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbe7fffff,
  0xbe7fffff,
  0xbe7fffff,
  0xbe7fffff,
  0xbe7fffff,
  0x3e7fffff,
  0x3e800000,
  0x3e800002,
  0x3f3fffff,
  0x3f400000,
  0x3f400002,
  0x3fa00000,
  0x411c0000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbe7fffff,
  0xbe7fffff,
  0xbe7fffff,
  0xbe800000,
  0xbe800000,
  0xbf400000,
  0xbf400000,
  0xbf400001,
  0xbfa00000,
  0xbfa00000,
  0xbfa00001,
  0xbfe00000,
  0xc1240000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbe800000,
  0xbe800000,
  0xbe800000,
  0xbe800000,
  0xbe800000,
  0x3e7ffffd,
  0x3e7fffff,
  0x3e800002,
  0x3f3fffff,
  0x3f400000,
  0x3f400002,
  0x3fa00000,
  0x411c0000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbe800000,
  0xbe800000,
  0xbe800000,
  0xbefffffe,
  0xbefffffe,
  0xbf7fffff,
  0xbf7fffff,
  0xbf800000,
  0xbfbfffff,
  0xbfc00000,
  0xbfc00001,
  0xc0000000,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbefffffe,
  0xbefffffe,
  0xbefffffe,
  0xbefffffe,
  0xbefffffe,
  0x32ffffff,
  0x33800000,
  0x34000000,
  0x3f000000,
  0x3f000001,
  0x3f000003,
  0x3f800000,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbefffffe,
  0xbefffffe,
  0xbefffffe,
  0xbeffffff,
  0xbeffffff,
  0xbf7fffff,
  0xbf800000,
  0xbf800000,
  0xbfbfffff,
  0xbfc00000,
  0xbfc00001,
  0xc0000000,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0x00000000,
  0x33000000,
  0x33c00000,
  0x3effffff,
  0x3f000000,
  0x3f000002,
  0x3f800000,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbf000000,
  0xbf000000,
  0xbf800000,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xbfc00000,
  0xbfc00001,
  0xc0000000,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xb37fffff,
  0xb2fffffe,
  0x33000001,
  0x3efffffd,
  0x3effffff,
  0x3f000002,
  0x3f800000,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf3fffff,
  0xbf3fffff,
  0xbf9fffff,
  0xbfa00000,
  0xbfa00000,
  0xbfdfffff,
  0xbfe00000,
  0xbfe00001,
  0xc0100000,
  0xc12c0000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf3fffff,
  0xbf3fffff,
  0xbf3fffff,
  0xbf3fffff,
  0xbf3fffff,
  0xbe7fffff,
  0xbe7ffffd,
  0xbe7ffff9,
  0x3e7fffff,
  0x3e800002,
  0x3e800006,
  0x3f400001,
  0x41140000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf3fffff,
  0xbf3fffff,
  0xbf3fffff,
  0xc09fffff,
  0xc09fffff,
  0xc0afffff,
  0xc0afffff,
  0xc0b00000,
  0xc0bfffff,
  0xc0bfffff,
  0xc0c00000,
  0xc0cfffff,
  0xc1700000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xc09fffff,
  0xc09fffff,
  0xc09fffff,
  0xc09fffff,
  0xc09fffff,
  0xc08fffff,
  0xc08fffff,
  0xc08fffff,
  0xc07fffff,
  0xc07fffff,
  0xc07ffffe,
  0xc05fffff,
  0x40a00001,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xc09fffff,
  0xc09fffff,
  0xc09fffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x80091a2b,
  0x80891a2b,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x801b4e81,
  0x80891a2a,
  0x80091a2c,
  0x80091a2b,
  0x0076e5d5,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00091a2b,
  0x0076e5d4,
  0x80091a2a,
  0x803fffff,
  0x80bfffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80523455,
  0x80bffffe,
  0x80400000,
  0x803fffff,
  0x00400001,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x802dcba9,
  0x00400000,
  0x803ffffe,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00400000,
  0x80400000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x002dcbaa,
  0x803fffff,
  0x003fffff,
  0x00400000,
  0x00c00000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00523456,
  0x00bfffff,
  0x00400001,
  0x3e7fffff,
  0x3e7fffff,
  0xbe7fffff,
  0xbe800000,
  0xbe800002,
  0xbf3fffff,
  0xbf400000,
  0xbf400002,
  0xbfa00000,
  0xc11c0000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3e7fffff,
  0x3e7fffff,
  0x3e7fffff,
  0x3e7fffff,
  0x3e7fffff,
  0x3f3fffff,
  0x3f400000,
  0x3f400001,
  0x3f9fffff,
  0x3fa00000,
  0x3fa00001,
  0x3fe00000,
  0x41240000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3e7fffff,
  0x3e7fffff,
  0x3e7fffff,
  0x3e800000,
  0x3e800000,
  0xbe7ffffe,
  0xbe800000,
  0xbe800002,
  0xbf3fffff,
  0xbf400000,
  0xbf400002,
  0xbfa00000,
  0xc11c0000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3e800000,
  0x3e800000,
  0x3e800000,
  0x3e800000,
  0x3e800000,
  0x3f400000,
  0x3f400000,
  0x3f400001,
  0x3fa00000,
  0x3fa00000,
  0x3fa00001,
  0x3fe00000,
  0x41240000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3e800000,
  0x3e800000,
  0x3e800000,
  0x3e800001,
  0x3e800001,
  0xbe7ffffc,
  0xbe7ffffe,
  0xbe800001,
  0xbf3ffffe,
  0xbf400000,
  0xbf400002,
  0xbfa00000,
  0xc11c0000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3e800001,
  0x3e800001,
  0x3e800001,
  0x3e800001,
  0x3e800001,
  0x3f400000,
  0x3f400000,
  0x3f400002,
  0x3fa00000,
  0x3fa00000,
  0x3fa00001,
  0x3fe00000,
  0x41240000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3e800001,
  0x3e800001,
  0x3e800001,
  0x3effffff,
  0x3effffff,
  0x00000000,
  0xb3000000,
  0xb3c00000,
  0xbeffffff,
  0xbf000000,
  0xbf000002,
  0xbf800000,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3f7fffff,
  0x3f800000,
  0x3f800000,
  0x3fbfffff,
  0x3fc00000,
  0x3fc00001,
  0x40000000,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3f000000,
  0x3f000000,
  0x33000000,
  0x00000000,
  0xb3800000,
  0xbefffffe,
  0xbf000000,
  0xbf000002,
  0xbf800000,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3fc00000,
  0x3fc00000,
  0x3fc00001,
  0x40000000,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000001,
  0x3f000001,
  0x33c00000,
  0x33800000,
  0x00000000,
  0xbefffffc,
  0xbefffffe,
  0xbf000001,
  0xbf7fffff,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f800000,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x3fc00000,
  0x3fc00002,
  0x40000000,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f400000,
  0x3f400000,
  0x3e800001,
  0x3e800000,
  0x3e7ffffc,
  0xbe7ffffc,
  0xbe800000,
  0xbe800004,
  0xbf400000,
  0xc1140000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f400000,
  0x3f400000,
  0x3f400000,
  0x3f400000,
  0x3f400000,
  0x3fa00000,
  0x3fa00000,
  0x3fa00000,
  0x3fe00000,
  0x3fe00000,
  0x3fe00001,
  0x40100000,
  0x412c0000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f400000,
  0x3f400000,
  0x3f400000,
  0x40a00000,
  0x40a00000,
  0x40900000,
  0x40900000,
  0x40900000,
  0x40800000,
  0x40800000,
  0x40800000,
  0x40600000,
  0xc0a00000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x40a00000,
  0x40a00000,
  0x40a00000,
  0x40a00000,
  0x40a00000,
  0x40b00000,
  0x40b00000,
  0x40b00000,
  0x40c00000,
  0x40c00000,
  0x40c00000,
  0x40d00000,
  0x41700000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x40a00000,
  0x40a00000,
  0x40a00000,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x00091a2b,
  0x8076e5d5,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80091a2b,
  0x8076e5d4,
  0x00091a2a,
  0x00091a2b,
  0x00891a2b,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x001b4e81,
  0x00891a2a,
  0x00091a2c,
  0x00400000,
  0x80400000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x002dcbaa,
  0x80400000,
  0x003ffffe,
  0x00400000,
  0x00c00000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00523456,
  0x00bffffe,
  0x00400000,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807ffffe,
  0x80000000,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x00800000,
  0x00000002,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80400000,
  0x80c00000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80523456,
  0x80bfffff,
  0x80400001,
  0x80400000,
  0x00400000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x802dcbaa,
  0x003fffff,
  0x803fffff,
  0xbe7fffff,
  0xbe7fffff,
  0xbf3fffff,
  0xbf400000,
  0xbf400001,
  0xbf9fffff,
  0xbfa00000,
  0xbfa00001,
  0xbfe00000,
  0xc1240000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbe7fffff,
  0xbe7fffff,
  0xbe7fffff,
  0xbe7fffff,
  0xbe7fffff,
  0x3e7fffff,
  0x3e800000,
  0x3e800002,
  0x3f3fffff,
  0x3f400000,
  0x3f400002,
  0x3fa00000,
  0x411c0000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbe7fffff,
  0xbe7fffff,
  0xbe7fffff,
  0xbe800000,
  0xbe800000,
  0xbf400000,
  0xbf400000,
  0xbf400001,
  0xbfa00000,
  0xbfa00000,
  0xbfa00001,
  0xbfe00000,
  0xc1240000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbe800000,
  0xbe800000,
  0xbe800000,
  0xbe800000,
  0xbe800000,
  0x3e7ffffe,
  0x3e800000,
  0x3e800002,
  0x3f3fffff,
  0x3f400000,
  0x3f400002,
  0x3fa00000,
  0x411c0000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbe800000,
  0xbe800000,
  0xbe800000,
  0xbe800001,
  0xbe800001,
  0xbf400000,
  0xbf400000,
  0xbf400002,
  0xbfa00000,
  0xbfa00000,
  0xbfa00001,
  0xbfe00000,
  0xc1240000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbe800001,
  0xbe800001,
  0xbe800001,
  0xbe800001,
  0xbe800001,
  0x3e7ffffc,
  0x3e7ffffe,
  0x3e800001,
  0x3f3ffffe,
  0x3f400000,
  0x3f400002,
  0x3fa00000,
  0x411c0000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbe800001,
  0xbe800001,
  0xbe800001,
  0xbeffffff,
  0xbeffffff,
  0xbf7fffff,
  0xbf800000,
  0xbf800000,
  0xbfbfffff,
  0xbfc00000,
  0xbfc00001,
  0xc0000000,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0x00000000,
  0x33000000,
  0x33c00000,
  0x3effffff,
  0x3f000000,
  0x3f000002,
  0x3f800000,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbf000000,
  0xbf000000,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbfc00000,
  0xbfc00000,
  0xbfc00001,
  0xc0000000,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xb3000000,
  0x00000000,
  0x33800000,
  0x3efffffe,
  0x3f000000,
  0x3f000002,
  0x3f800000,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000001,
  0xbf000001,
  0xbf800000,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xbfc00000,
  0xbfc00002,
  0xc0000000,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xb3c00000,
  0xb3800000,
  0x00000000,
  0x3efffffc,
  0x3efffffe,
  0x3f000001,
  0x3f7fffff,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf400000,
  0xbf400000,
  0xbfa00000,
  0xbfa00000,
  0xbfa00000,
  0xbfe00000,
  0xbfe00000,
  0xbfe00001,
  0xc0100000,
  0xc12c0000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf400000,
  0xbf400000,
  0xbf400000,
  0xbf400000,
  0xbf400000,
  0xbe800001,
  0xbe800000,
  0xbe7ffffc,
  0x3e7ffffc,
  0x3e800000,
  0x3e800004,
  0x3f400000,
  0x41140000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf400000,
  0xbf400000,
  0xbf400000,
  0xc0a00000,
  0xc0a00000,
  0xc0b00000,
  0xc0b00000,
  0xc0b00000,
  0xc0c00000,
  0xc0c00000,
  0xc0c00000,
  0xc0d00000,
  0xc1700000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xc0a00000,
  0xc0a00000,
  0xc0a00000,
  0xc0a00000,
  0xc0a00000,
  0xc0900000,
  0xc0900000,
  0xc0900000,
  0xc0800000,
  0xc0800000,
  0xc0800000,
  0xc0600000,
  0x40a00000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xc0a00000,
  0xc0a00000,
  0xc0a00000,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x80091a2b,
  0x80891a2b,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x801b4e81,
  0x80891a2a,
  0x80091a2c,
  0x80091a2b,
  0x0076e5d5,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00091a2b,
  0x0076e5d4,
  0x80091a2a,
  0x80400000,
  0x80c00000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80523456,
  0x80bffffe,
  0x80400000,
  0x80400000,
  0x00400000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x802dcbaa,
  0x00400000,
  0x803ffffe,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x80800000,
  0x80000002,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007ffffe,
  0x00000000,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00400000,
  0x80400000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x002dcbaa,
  0x803ffffe,
  0x00400000,
  0x00400000,
  0x00c00000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00523456,
  0x00c00000,
  0x00400002,
  0x3e800000,
  0x3e800000,
  0xbe7ffffd,
  0xbe7fffff,
  0xbe800002,
  0xbf3fffff,
  0xbf400000,
  0xbf400002,
  0xbfa00000,
  0xc11c0000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3e800000,
  0x3e800000,
  0x3e800000,
  0x3e800000,
  0x3e800000,
  0x3f400000,
  0x3f400000,
  0x3f400001,
  0x3fa00000,
  0x3fa00000,
  0x3fa00001,
  0x3fe00000,
  0x41240000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3e800000,
  0x3e800000,
  0x3e800000,
  0x3e800001,
  0x3e800001,
  0xbe7ffffc,
  0xbe7ffffe,
  0xbe800001,
  0xbf3ffffe,
  0xbf400000,
  0xbf400002,
  0xbfa00000,
  0xc11c0000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3e800001,
  0x3e800001,
  0x3e800001,
  0x3e800001,
  0x3e800001,
  0x3f400000,
  0x3f400000,
  0x3f400002,
  0x3fa00000,
  0x3fa00000,
  0x3fa00001,
  0x3fe00000,
  0x41240000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3e800001,
  0x3e800001,
  0x3e800001,
  0x3e800002,
  0x3e800002,
  0xbe7ffffa,
  0xbe7ffffc,
  0xbe800000,
  0xbf3ffffe,
  0xbf3fffff,
  0xbf400001,
  0xbf9fffff,
  0xc11c0000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3e800002,
  0x3e800002,
  0x3e800002,
  0x3e800002,
  0x3e800002,
  0x3f400001,
  0x3f400001,
  0x3f400002,
  0x3fa00000,
  0x3fa00001,
  0x3fa00002,
  0x3fe00001,
  0x41240000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3e800002,
  0x3e800002,
  0x3e800002,
  0x3f000000,
  0x3f000000,
  0x337fffff,
  0x32fffffe,
  0xb3000001,
  0xbefffffd,
  0xbeffffff,
  0xbf000002,
  0xbf800000,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f800000,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x3fc00000,
  0x3fc00001,
  0x40000000,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000001,
  0x3f000001,
  0x33c00000,
  0x33800000,
  0x00000000,
  0xbefffffc,
  0xbefffffe,
  0xbf000001,
  0xbf7fffff,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f800000,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x3fc00000,
  0x3fc00002,
  0x40000000,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f000002,
  0x3f000002,
  0x34200000,
  0x34000000,
  0x33800001,
  0xbefffffa,
  0xbefffffc,
  0xbf000000,
  0xbf7ffffe,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f000002,
  0x3f000002,
  0x3f000002,
  0x3f000002,
  0x3f000002,
  0x3f800001,
  0x3f800001,
  0x3f800002,
  0x3fc00001,
  0x3fc00001,
  0x3fc00002,
  0x40000001,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f000002,
  0x3f000002,
  0x3f000002,
  0x3f400002,
  0x3f400001,
  0x3e800004,
  0x3e800003,
  0x3e800001,
  0xbe7ffff6,
  0xbe7ffffa,
  0xbe800001,
  0xbf3ffffe,
  0xc1140000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f400001,
  0x3f400001,
  0x3f400001,
  0x3f400002,
  0x3f400002,
  0x3fa00000,
  0x3fa00001,
  0x3fa00001,
  0x3fe00000,
  0x3fe00001,
  0x3fe00002,
  0x40100000,
  0x412c0000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f400002,
  0x3f400002,
  0x3f400002,
  0x40a00001,
  0x40a00001,
  0x40900001,
  0x40900001,
  0x40900001,
  0x40800001,
  0x40800001,
  0x40800001,
  0x40600002,
  0xc09fffff,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x40a00001,
  0x40a00001,
  0x40a00001,
  0x40a00001,
  0x40a00001,
  0x40b00001,
  0x40b00001,
  0x40b00001,
  0x40c00001,
  0x40c00001,
  0x40c00002,
  0x40d00001,
  0x41700001,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x40a00001,
  0x40a00001,
  0x40a00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x00091a2b,
  0x8076e5d5,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80091a2b,
  0x8076e5d4,
  0x00091a2a,
  0x00091a2b,
  0x00891a2b,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x001b4e81,
  0x00891a2a,
  0x00091a2c,
  0x00400000,
  0x80400000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x002dcbaa,
  0x803fffff,
  0x003fffff,
  0x00400000,
  0x00c00000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00523456,
  0x00bfffff,
  0x00400001,
  0x00000001,
  0x807fffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123455,
  0x807ffffe,
  0x80000000,
  0x00000001,
  0x00800001,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123457,
  0x00800000,
  0x00000002,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80400000,
  0x80c00000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80523456,
  0x80c00000,
  0x80400002,
  0x80400000,
  0x00400000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x802dcbaa,
  0x003ffffe,
  0x80400000,
  0xbe800000,
  0xbe800000,
  0xbf400000,
  0xbf400000,
  0xbf400001,
  0xbfa00000,
  0xbfa00000,
  0xbfa00001,
  0xbfe00000,
  0xc1240000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbe800000,
  0xbe800000,
  0xbe800000,
  0xbe800000,
  0xbe800000,
  0x3e7ffffd,
  0x3e7fffff,
  0x3e800002,
  0x3f3fffff,
  0x3f400000,
  0x3f400002,
  0x3fa00000,
  0x411c0000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbe800000,
  0xbe800000,
  0xbe800000,
  0xbe800001,
  0xbe800001,
  0xbf400000,
  0xbf400000,
  0xbf400002,
  0xbfa00000,
  0xbfa00000,
  0xbfa00001,
  0xbfe00000,
  0xc1240000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbe800001,
  0xbe800001,
  0xbe800001,
  0xbe800001,
  0xbe800001,
  0x3e7ffffc,
  0x3e7ffffe,
  0x3e800001,
  0x3f3ffffe,
  0x3f400000,
  0x3f400002,
  0x3fa00000,
  0x411c0000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbe800001,
  0xbe800001,
  0xbe800001,
  0xbe800002,
  0xbe800002,
  0xbf400001,
  0xbf400001,
  0xbf400002,
  0xbfa00000,
  0xbfa00001,
  0xbfa00002,
  0xbfe00001,
  0xc1240000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbe800002,
  0xbe800002,
  0xbe800002,
  0xbe800002,
  0xbe800002,
  0x3e7ffffa,
  0x3e7ffffc,
  0x3e800000,
  0x3f3ffffe,
  0x3f3fffff,
  0x3f400001,
  0x3f9fffff,
  0x411c0000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbe800002,
  0xbe800002,
  0xbe800002,
  0xbf000000,
  0xbf000000,
  0xbf800000,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xbfc00000,
  0xbfc00001,
  0xc0000000,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xb37fffff,
  0xb2fffffe,
  0x33000001,
  0x3efffffd,
  0x3effffff,
  0x3f000002,
  0x3f800000,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000001,
  0xbf000001,
  0xbf800000,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xbfc00000,
  0xbfc00002,
  0xc0000000,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xb3c00000,
  0xb3800000,
  0x00000000,
  0x3efffffc,
  0x3efffffe,
  0x3f000001,
  0x3f7fffff,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf000002,
  0xbf000002,
  0xbf800001,
  0xbf800001,
  0xbf800002,
  0xbfc00001,
  0xbfc00001,
  0xbfc00002,
  0xc0000001,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf000002,
  0xbf000002,
  0xbf000002,
  0xbf000002,
  0xbf000002,
  0xb4200000,
  0xb4000000,
  0xb3800001,
  0x3efffffa,
  0x3efffffc,
  0x3f000000,
  0x3f7ffffe,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf000002,
  0xbf000002,
  0xbf000002,
  0xbf400002,
  0xbf400002,
  0xbfa00000,
  0xbfa00001,
  0xbfa00001,
  0xbfe00000,
  0xbfe00001,
  0xbfe00002,
  0xc0100000,
  0xc12c0000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf400002,
  0xbf400002,
  0xbf400002,
  0xbf400002,
  0xbf400001,
  0xbe800004,
  0xbe800003,
  0xbe800001,
  0x3e7ffff6,
  0x3e7ffffa,
  0x3e800001,
  0x3f3ffffe,
  0x41140000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf400001,
  0xbf400001,
  0xbf400001,
  0xc0a00001,
  0xc0a00001,
  0xc0b00001,
  0xc0b00001,
  0xc0b00001,
  0xc0c00001,
  0xc0c00001,
  0xc0c00002,
  0xc0d00001,
  0xc1700001,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xc0a00001,
  0xc0a00001,
  0xc0a00001,
  0xc0a00001,
  0xc0a00001,
  0xc0900001,
  0xc0900001,
  0xc0900001,
  0xc0800001,
  0xc0800001,
  0xc0800001,
  0xc0600002,
  0x409fffff,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xc0a00001,
  0xc0a00001,
  0xc0a00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x80091a2b,
  0x80891a2b,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x801b4e81,
  0x80891a2a,
  0x80091a2c,
  0x80091a2b,
  0x0076e5d5,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00091a2b,
  0x0076e5d4,
  0x80091a2a,
  0x80400000,
  0x80c00000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80523456,
  0x80bfffff,
  0x80400001,
  0x80400000,
  0x00400000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x802dcbaa,
  0x003fffff,
  0x803fffff,
  0x80000001,
  0x80800001,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123457,
  0x80800000,
  0x80000002,
  0x80000001,
  0x007fffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123455,
  0x007ffffe,
  0x00000000,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00800000,
  0x80000000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x006dcbaa,
  0x00000000,
  0x007ffffe,
  0x00800000,
  0x01000000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00923456,
  0x00fffffe,
  0x00800000,
  0x3efffffe,
  0x3efffffe,
  0xb2ffffff,
  0xb3800000,
  0xb4000000,
  0xbf000000,
  0xbf000001,
  0xbf000003,
  0xbf800000,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3efffffe,
  0x3efffffe,
  0x3efffffe,
  0x3efffffe,
  0x3efffffe,
  0x3f7fffff,
  0x3f7fffff,
  0x3f800000,
  0x3fbfffff,
  0x3fc00000,
  0x3fc00001,
  0x40000000,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3efffffe,
  0x3efffffe,
  0x3efffffe,
  0x3effffff,
  0x3effffff,
  0x00000000,
  0xb3000000,
  0xb3c00000,
  0xbeffffff,
  0xbf000000,
  0xbf000002,
  0xbf800000,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3f7fffff,
  0x3f800000,
  0x3f800000,
  0x3fbfffff,
  0x3fc00000,
  0x3fc00001,
  0x40000000,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3f000000,
  0x3f000000,
  0x337fffff,
  0x32fffffe,
  0xb3000001,
  0xbefffffd,
  0xbeffffff,
  0xbf000002,
  0xbf800000,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f800000,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x3fc00000,
  0x3fc00001,
  0x40000000,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f7ffffe,
  0x3f7ffffe,
  0x3efffffd,
  0x3efffffc,
  0x3efffffa,
  0xb37fffff,
  0xb4000000,
  0xb4800000,
  0xbf000002,
  0xc1100000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f7ffffe,
  0x3f7ffffe,
  0x3f7ffffe,
  0x3f7ffffe,
  0x3f7ffffe,
  0x3fbfffff,
  0x3fbfffff,
  0x3fc00000,
  0x3fffffff,
  0x3fffffff,
  0x40000000,
  0x40200000,
  0x41300000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f7ffffe,
  0x3f7ffffe,
  0x3f7ffffe,
  0x3f7fffff,
  0x3f7fffff,
  0x3effffff,
  0x3efffffe,
  0x3efffffc,
  0x00000000,
  0xb3800000,
  0xb4400000,
  0xbf000001,
  0xc1100000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f7fffff,
  0x3f7fffff,
  0x3f7fffff,
  0x3f7fffff,
  0x3f7fffff,
  0x3fbfffff,
  0x3fc00000,
  0x3fc00000,
  0x3fffffff,
  0x40000000,
  0x40000000,
  0x40200000,
  0x41300000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f7fffff,
  0x3f7fffff,
  0x3f7fffff,
  0x3f800000,
  0x3f800000,
  0x3f000001,
  0x3f000001,
  0x3f000000,
  0x33ffffff,
  0x337ffffe,
  0xb3800001,
  0xbefffffe,
  0xc1100000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3fc00000,
  0x3fc00000,
  0x3fc00001,
  0x40000000,
  0x40000000,
  0x40000001,
  0x40200000,
  0x41300000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3fbfffff,
  0x3fbfffff,
  0x3f7fffff,
  0x3f7ffffe,
  0x3f7ffffe,
  0x3effffff,
  0x3efffffd,
  0x3efffff9,
  0xb3c00000,
  0xc1080000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3fbfffff,
  0x3fbfffff,
  0x3fbfffff,
  0x3fbfffff,
  0x3fbfffff,
  0x3fffffff,
  0x3fffffff,
  0x40000000,
  0x401fffff,
  0x40200000,
  0x40200000,
  0x40400000,
  0x41380000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3fbfffff,
  0x3fbfffff,
  0x3fbfffff,
  0x411fffff,
  0x411fffff,
  0x4117ffff,
  0x4117ffff,
  0x4117ffff,
  0x410fffff,
  0x410fffff,
  0x410fffff,
  0x4107ffff,
  0xb5200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x411fffff,
  0x411fffff,
  0x411fffff,
  0x411fffff,
  0x411fffff,
  0x4127ffff,
  0x4127ffff,
  0x4127ffff,
  0x412fffff,
  0x412fffff,
  0x41300000,
  0x4137ffff,
  0x41a00000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x411fffff,
  0x411fffff,
  0x411fffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x00123456,
  0x806dcbaa,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80000000,
  0x806dcba9,
  0x00123455,
  0x00123456,
  0x00923456,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x002468ac,
  0x00923455,
  0x00123457,
  0x007fffff,
  0x80000001,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x006dcba9,
  0x80000000,
  0x007ffffe,
  0x007fffff,
  0x00ffffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00923455,
  0x00fffffe,
  0x00800000,
  0x00000001,
  0x807fffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123455,
  0x807ffffe,
  0x80000000,
  0x00000001,
  0x00800001,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123457,
  0x00800000,
  0x00000002,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80800000,
  0x81000000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80923456,
  0x80fffffe,
  0x80800000,
  0x80800000,
  0x00000000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x806dcbaa,
  0x80000000,
  0x807ffffe,
  0xbefffffe,
  0xbefffffe,
  0xbf7fffff,
  0xbf7fffff,
  0xbf800000,
  0xbfbfffff,
  0xbfc00000,
  0xbfc00001,
  0xc0000000,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbefffffe,
  0xbefffffe,
  0xbefffffe,
  0xbefffffe,
  0xbefffffe,
  0x32ffffff,
  0x33800000,
  0x34000000,
  0x3f000000,
  0x3f000001,
  0x3f000003,
  0x3f800000,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbefffffe,
  0xbefffffe,
  0xbefffffe,
  0xbeffffff,
  0xbeffffff,
  0xbf7fffff,
  0xbf800000,
  0xbf800000,
  0xbfbfffff,
  0xbfc00000,
  0xbfc00001,
  0xc0000000,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0x00000000,
  0x33000000,
  0x33c00000,
  0x3effffff,
  0x3f000000,
  0x3f000002,
  0x3f800000,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbf000000,
  0xbf000000,
  0xbf800000,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xbfc00000,
  0xbfc00001,
  0xc0000000,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xb37fffff,
  0xb2fffffe,
  0x33000001,
  0x3efffffd,
  0x3effffff,
  0x3f000002,
  0x3f800000,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf7ffffe,
  0xbf7ffffe,
  0xbfbfffff,
  0xbfbfffff,
  0xbfc00000,
  0xbfffffff,
  0xbfffffff,
  0xc0000000,
  0xc0200000,
  0xc1300000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf7ffffe,
  0xbf7ffffe,
  0xbf7ffffe,
  0xbf7ffffe,
  0xbf7ffffe,
  0xbefffffd,
  0xbefffffc,
  0xbefffffa,
  0x337fffff,
  0x34000000,
  0x34800000,
  0x3f000002,
  0x41100000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf7ffffe,
  0xbf7ffffe,
  0xbf7ffffe,
  0xbf7fffff,
  0xbf7fffff,
  0xbfbfffff,
  0xbfc00000,
  0xbfc00000,
  0xbfffffff,
  0xc0000000,
  0xc0000000,
  0xc0200000,
  0xc1300000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf7fffff,
  0xbf7fffff,
  0xbf7fffff,
  0xbf7fffff,
  0xbf7fffff,
  0xbeffffff,
  0xbefffffe,
  0xbefffffc,
  0x00000000,
  0x33800000,
  0x34400000,
  0x3f000001,
  0x41100000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf7fffff,
  0xbf7fffff,
  0xbf7fffff,
  0xbf800000,
  0xbf800000,
  0xbfc00000,
  0xbfc00000,
  0xbfc00001,
  0xc0000000,
  0xc0000000,
  0xc0000001,
  0xc0200000,
  0xc1300000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbf000001,
  0xbf000001,
  0xbf000000,
  0xb3ffffff,
  0xb37ffffe,
  0x33800001,
  0x3efffffe,
  0x41100000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbfbfffff,
  0xbfbfffff,
  0xbfffffff,
  0xbfffffff,
  0xc0000000,
  0xc01fffff,
  0xc0200000,
  0xc0200000,
  0xc0400000,
  0xc1380000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbfbfffff,
  0xbfbfffff,
  0xbfbfffff,
  0xbfbfffff,
  0xbfbfffff,
  0xbf7fffff,
  0xbf7ffffe,
  0xbf7ffffe,
  0xbeffffff,
  0xbefffffd,
  0xbefffff9,
  0x33c00000,
  0x41080000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbfbfffff,
  0xbfbfffff,
  0xbfbfffff,
  0xc11fffff,
  0xc11fffff,
  0xc127ffff,
  0xc127ffff,
  0xc127ffff,
  0xc12fffff,
  0xc12fffff,
  0xc1300000,
  0xc137ffff,
  0xc1a00000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xc11fffff,
  0xc11fffff,
  0xc11fffff,
  0xc11fffff,
  0xc11fffff,
  0xc117ffff,
  0xc117ffff,
  0xc117ffff,
  0xc10fffff,
  0xc10fffff,
  0xc10fffff,
  0xc107ffff,
  0x35200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xc11fffff,
  0xc11fffff,
  0xc11fffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x80123456,
  0x80923456,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x802468ac,
  0x80923455,
  0x80123457,
  0x80123456,
  0x006dcbaa,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00000000,
  0x006dcba9,
  0x80123455,
  0x807fffff,
  0x80ffffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80923455,
  0x80fffffe,
  0x80800000,
  0x807fffff,
  0x00000001,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x806dcba9,
  0x00000000,
  0x807ffffe,
  0x80000001,
  0x80800001,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123457,
  0x80800000,
  0x80000002,
  0x80000001,
  0x007fffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123455,
  0x007ffffe,
  0x00000000,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00800000,
  0x00000000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x006dcbaa,
  0x00000001,
  0x007fffff,
  0x00800000,
  0x01000000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00923456,
  0x00ffffff,
  0x00800001,
  0x3effffff,
  0x3effffff,
  0x00000000,
  0xb3000000,
  0xb3c00000,
  0xbeffffff,
  0xbf000000,
  0xbf000002,
  0xbf800000,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3f7fffff,
  0x3f800000,
  0x3f800000,
  0x3fbfffff,
  0x3fc00000,
  0x3fc00001,
  0x40000000,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3f000000,
  0x3f000000,
  0x33000000,
  0x00000000,
  0xb3800000,
  0xbefffffe,
  0xbf000000,
  0xbf000002,
  0xbf800000,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3fc00000,
  0x3fc00000,
  0x3fc00001,
  0x40000000,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000001,
  0x3f000001,
  0x33c00000,
  0x33800000,
  0x00000000,
  0xbefffffc,
  0xbefffffe,
  0xbf000001,
  0xbf7fffff,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f800000,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x3fc00000,
  0x3fc00002,
  0x40000000,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f7fffff,
  0x3f7fffff,
  0x3effffff,
  0x3efffffe,
  0x3efffffc,
  0x00000000,
  0xb3800000,
  0xb4400000,
  0xbf000001,
  0xc1100000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f7fffff,
  0x3f7fffff,
  0x3f7fffff,
  0x3f7fffff,
  0x3f7fffff,
  0x3fbfffff,
  0x3fc00000,
  0x3fc00000,
  0x3fffffff,
  0x40000000,
  0x40000000,
  0x40200000,
  0x41300000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f7fffff,
  0x3f7fffff,
  0x3f7fffff,
  0x3f800000,
  0x3f800000,
  0x3f000000,
  0x3f000000,
  0x3efffffe,
  0x33800000,
  0x00000000,
  0xb4000000,
  0xbf000000,
  0xc1100000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3fc00000,
  0x3fc00000,
  0x3fc00000,
  0x40000000,
  0x40000000,
  0x40000000,
  0x40200000,
  0x41300000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3f800001,
  0x3f800001,
  0x3f000002,
  0x3f000002,
  0x3f000001,
  0x34400000,
  0x34000000,
  0x00000000,
  0xbefffffc,
  0xc1100000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f800001,
  0x3f800001,
  0x3f800001,
  0x3f800001,
  0x3f800001,
  0x3fc00001,
  0x3fc00001,
  0x3fc00002,
  0x40000000,
  0x40000000,
  0x40000001,
  0x40200000,
  0x41300000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f800001,
  0x3f800001,
  0x3f800001,
  0x3fc00000,
  0x3fc00000,
  0x3f800000,
  0x3f800000,
  0x3f7fffff,
  0x3f000001,
  0x3f000000,
  0x3efffffc,
  0x00000000,
  0xc1080000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3fc00000,
  0x3fc00000,
  0x3fc00000,
  0x3fc00000,
  0x3fc00000,
  0x40000000,
  0x40000000,
  0x40000000,
  0x40200000,
  0x40200000,
  0x40200000,
  0x40400000,
  0x41380000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3fc00000,
  0x3fc00000,
  0x3fc00000,
  0x41200000,
  0x41200000,
  0x41180000,
  0x41180000,
  0x41180000,
  0x41100000,
  0x41100000,
  0x41100000,
  0x41080000,
  0x00000000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x41200000,
  0x41200000,
  0x41200000,
  0x41200000,
  0x41200000,
  0x41280000,
  0x41280000,
  0x41280000,
  0x41300000,
  0x41300000,
  0x41300000,
  0x41380000,
  0x41a00000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x41200000,
  0x41200000,
  0x41200000,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x00123456,
  0x806dcbaa,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x00000000,
  0x806dcba9,
  0x00123455,
  0x00123456,
  0x00923456,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x002468ac,
  0x00923455,
  0x00123457,
  0x007fffff,
  0x80000001,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x006dcba9,
  0x00000000,
  0x007ffffe,
  0x007fffff,
  0x00ffffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00923455,
  0x00fffffe,
  0x00800000,
  0x00000001,
  0x807fffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123455,
  0x807ffffe,
  0x00000000,
  0x00000001,
  0x00800001,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123457,
  0x00800000,
  0x00000002,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80800000,
  0x81000000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80923456,
  0x80ffffff,
  0x80800001,
  0x80800000,
  0x00000000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x806dcbaa,
  0x80000001,
  0x807fffff,
  0xbeffffff,
  0xbeffffff,
  0xbf7fffff,
  0xbf800000,
  0xbf800000,
  0xbfbfffff,
  0xbfc00000,
  0xbfc00001,
  0xc0000000,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0x00000000,
  0x33000000,
  0x33c00000,
  0x3effffff,
  0x3f000000,
  0x3f000002,
  0x3f800000,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbf000000,
  0xbf000000,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbfc00000,
  0xbfc00000,
  0xbfc00001,
  0xc0000000,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xb3000000,
  0x00000000,
  0x33800000,
  0x3efffffe,
  0x3f000000,
  0x3f000002,
  0x3f800000,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000001,
  0xbf000001,
  0xbf800000,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xbfc00000,
  0xbfc00002,
  0xc0000000,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xb3c00000,
  0xb3800000,
  0x00000000,
  0x3efffffc,
  0x3efffffe,
  0x3f000001,
  0x3f7fffff,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf7fffff,
  0xbf7fffff,
  0xbfbfffff,
  0xbfc00000,
  0xbfc00000,
  0xbfffffff,
  0xc0000000,
  0xc0000000,
  0xc0200000,
  0xc1300000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf7fffff,
  0xbf7fffff,
  0xbf7fffff,
  0xbf7fffff,
  0xbf7fffff,
  0xbeffffff,
  0xbefffffe,
  0xbefffffc,
  0x00000000,
  0x33800000,
  0x34400000,
  0x3f000001,
  0x41100000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf7fffff,
  0xbf7fffff,
  0xbf7fffff,
  0xbf800000,
  0xbf800000,
  0xbfc00000,
  0xbfc00000,
  0xbfc00000,
  0xc0000000,
  0xc0000000,
  0xc0000000,
  0xc0200000,
  0xc1300000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbf000000,
  0xbf000000,
  0xbefffffe,
  0xb3800000,
  0x00000000,
  0x34000000,
  0x3f000000,
  0x41100000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbf800001,
  0xbf800001,
  0xbfc00001,
  0xbfc00001,
  0xbfc00002,
  0xc0000000,
  0xc0000000,
  0xc0000001,
  0xc0200000,
  0xc1300000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf800001,
  0xbf800001,
  0xbf800001,
  0xbf800001,
  0xbf800001,
  0xbf000002,
  0xbf000002,
  0xbf000001,
  0xb4400000,
  0xb4000000,
  0x00000000,
  0x3efffffc,
  0x41100000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf800001,
  0xbf800001,
  0xbf800001,
  0xbfc00000,
  0xbfc00000,
  0xc0000000,
  0xc0000000,
  0xc0000000,
  0xc0200000,
  0xc0200000,
  0xc0200000,
  0xc0400000,
  0xc1380000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbfc00000,
  0xbfc00000,
  0xbfc00000,
  0xbfc00000,
  0xbfc00000,
  0xbf800000,
  0xbf800000,
  0xbf7fffff,
  0xbf000001,
  0xbf000000,
  0xbefffffc,
  0x00000000,
  0x41080000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbfc00000,
  0xbfc00000,
  0xbfc00000,
  0xc1200000,
  0xc1200000,
  0xc1280000,
  0xc1280000,
  0xc1280000,
  0xc1300000,
  0xc1300000,
  0xc1300000,
  0xc1380000,
  0xc1a00000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xc1200000,
  0xc1200000,
  0xc1200000,
  0xc1200000,
  0xc1200000,
  0xc1180000,
  0xc1180000,
  0xc1180000,
  0xc1100000,
  0xc1100000,
  0xc1100000,
  0xc1080000,
  0x00000000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xc1200000,
  0xc1200000,
  0xc1200000,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x80123456,
  0x80923456,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x802468ac,
  0x80923455,
  0x80123457,
  0x80123456,
  0x006dcbaa,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00000000,
  0x006dcba9,
  0x80123455,
  0x807fffff,
  0x80ffffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80923455,
  0x80fffffe,
  0x80800000,
  0x807fffff,
  0x00000001,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x806dcba9,
  0x00000000,
  0x807ffffe,
  0x80000001,
  0x80800001,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123457,
  0x80800000,
  0x80000002,
  0x80000001,
  0x007fffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123455,
  0x007ffffe,
  0x00000000,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00800001,
  0x00000001,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x006dcbab,
  0x00000002,
  0x00800000,
  0x00800001,
  0x01000000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00923457,
  0x01000000,
  0x00800002,
  0x3f000000,
  0x3f000000,
  0x337fffff,
  0x32fffffe,
  0xb3000001,
  0xbefffffd,
  0xbeffffff,
  0xbf000002,
  0xbf800000,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f800000,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x3fc00000,
  0x3fc00001,
  0x40000000,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000001,
  0x3f000001,
  0x33c00000,
  0x33800000,
  0x00000000,
  0xbefffffc,
  0xbefffffe,
  0xbf000001,
  0xbf7fffff,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f800000,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x3fc00000,
  0x3fc00002,
  0x40000000,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f000002,
  0x3f000002,
  0x34200000,
  0x34000000,
  0x33800001,
  0xbefffffa,
  0xbefffffc,
  0xbf000000,
  0xbf7ffffe,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f000002,
  0x3f000002,
  0x3f000002,
  0x3f000002,
  0x3f000002,
  0x3f800001,
  0x3f800001,
  0x3f800002,
  0x3fc00001,
  0x3fc00001,
  0x3fc00002,
  0x40000001,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f000002,
  0x3f000002,
  0x3f000002,
  0x3f800000,
  0x3f800000,
  0x3f000001,
  0x3f000001,
  0x3f000000,
  0x33ffffff,
  0x337ffffe,
  0xb3800001,
  0xbefffffe,
  0xc1100000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3fc00000,
  0x3fc00000,
  0x3fc00001,
  0x40000000,
  0x40000000,
  0x40000001,
  0x40200000,
  0x41300000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3f800001,
  0x3f800001,
  0x3f000002,
  0x3f000002,
  0x3f000001,
  0x34400000,
  0x34000000,
  0x00000000,
  0xbefffffc,
  0xc1100000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f800001,
  0x3f800001,
  0x3f800001,
  0x3f800001,
  0x3f800001,
  0x3fc00001,
  0x3fc00001,
  0x3fc00002,
  0x40000000,
  0x40000000,
  0x40000001,
  0x40200000,
  0x41300000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f800001,
  0x3f800001,
  0x3f800001,
  0x3f800002,
  0x3f800002,
  0x3f000005,
  0x3f000004,
  0x3f000003,
  0x34a00000,
  0x34800000,
  0x34000001,
  0xbefffff8,
  0xc1100000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f800002,
  0x3f800002,
  0x3f800002,
  0x3f800002,
  0x3f800002,
  0x3fc00002,
  0x3fc00002,
  0x3fc00003,
  0x40000001,
  0x40000001,
  0x40000002,
  0x40200001,
  0x41300000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f800002,
  0x3f800002,
  0x3f800002,
  0x3fc00002,
  0x3fc00001,
  0x3f800002,
  0x3f800002,
  0x3f800001,
  0x3f000004,
  0x3f000003,
  0x3f000001,
  0x34400000,
  0xc1080000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3fc00001,
  0x3fc00001,
  0x3fc00001,
  0x3fc00002,
  0x3fc00002,
  0x40000001,
  0x40000001,
  0x40000001,
  0x40200000,
  0x40200001,
  0x40200001,
  0x40400001,
  0x41380000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3fc00002,
  0x3fc00002,
  0x3fc00002,
  0x41200001,
  0x41200001,
  0x41180001,
  0x41180001,
  0x41180001,
  0x41100001,
  0x41100001,
  0x41100001,
  0x41080001,
  0x35a00000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x41200001,
  0x41200001,
  0x41200001,
  0x41200001,
  0x41200001,
  0x41280001,
  0x41280001,
  0x41280001,
  0x41300001,
  0x41300001,
  0x41300001,
  0x41380001,
  0x41a00001,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x41200001,
  0x41200001,
  0x41200001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x00123456,
  0x806dcbaa,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x00000000,
  0x806dcba9,
  0x00123455,
  0x00123456,
  0x00923456,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x002468ac,
  0x00923455,
  0x00123457,
  0x00800000,
  0x80000000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x006dcbaa,
  0x00000001,
  0x007fffff,
  0x00800000,
  0x01000000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00923456,
  0x00ffffff,
  0x00800001,
  0x00000001,
  0x807fffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123455,
  0x807ffffe,
  0x00000000,
  0x00000001,
  0x00800001,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123457,
  0x00800000,
  0x00000002,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80800001,
  0x81000000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80923457,
  0x81000000,
  0x80800002,
  0x80800001,
  0x80000001,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x806dcbab,
  0x80000002,
  0x80800000,
  0xbf000000,
  0xbf000000,
  0xbf800000,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xbfc00000,
  0xbfc00001,
  0xc0000000,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xb37fffff,
  0xb2fffffe,
  0x33000001,
  0x3efffffd,
  0x3effffff,
  0x3f000002,
  0x3f800000,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000001,
  0xbf000001,
  0xbf800000,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xbfc00000,
  0xbfc00002,
  0xc0000000,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xb3c00000,
  0xb3800000,
  0x00000000,
  0x3efffffc,
  0x3efffffe,
  0x3f000001,
  0x3f7fffff,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf000002,
  0xbf000002,
  0xbf800001,
  0xbf800001,
  0xbf800002,
  0xbfc00001,
  0xbfc00001,
  0xbfc00002,
  0xc0000001,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf000002,
  0xbf000002,
  0xbf000002,
  0xbf000002,
  0xbf000002,
  0xb4200000,
  0xb4000000,
  0xb3800001,
  0x3efffffa,
  0x3efffffc,
  0x3f000000,
  0x3f7ffffe,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf000002,
  0xbf000002,
  0xbf000002,
  0xbf800000,
  0xbf800000,
  0xbfc00000,
  0xbfc00000,
  0xbfc00001,
  0xc0000000,
  0xc0000000,
  0xc0000001,
  0xc0200000,
  0xc1300000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbf000001,
  0xbf000001,
  0xbf000000,
  0xb3ffffff,
  0xb37ffffe,
  0x33800001,
  0x3efffffe,
  0x41100000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbf800001,
  0xbf800001,
  0xbfc00001,
  0xbfc00001,
  0xbfc00002,
  0xc0000000,
  0xc0000000,
  0xc0000001,
  0xc0200000,
  0xc1300000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf800001,
  0xbf800001,
  0xbf800001,
  0xbf800001,
  0xbf800001,
  0xbf000002,
  0xbf000002,
  0xbf000001,
  0xb4400000,
  0xb4000000,
  0x00000000,
  0x3efffffc,
  0x41100000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf800001,
  0xbf800001,
  0xbf800001,
  0xbf800002,
  0xbf800002,
  0xbfc00002,
  0xbfc00002,
  0xbfc00003,
  0xc0000001,
  0xc0000001,
  0xc0000002,
  0xc0200001,
  0xc1300000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf800002,
  0xbf800002,
  0xbf800002,
  0xbf800002,
  0xbf800002,
  0xbf000005,
  0xbf000004,
  0xbf000003,
  0xb4a00000,
  0xb4800000,
  0xb4000001,
  0x3efffff8,
  0x41100000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf800002,
  0xbf800002,
  0xbf800002,
  0xbfc00002,
  0xbfc00002,
  0xc0000001,
  0xc0000001,
  0xc0000001,
  0xc0200000,
  0xc0200001,
  0xc0200001,
  0xc0400001,
  0xc1380000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbfc00002,
  0xbfc00002,
  0xbfc00002,
  0xbfc00002,
  0xbfc00001,
  0xbf800002,
  0xbf800002,
  0xbf800001,
  0xbf000004,
  0xbf000003,
  0xbf000001,
  0xb4400000,
  0x41080000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbfc00001,
  0xbfc00001,
  0xbfc00001,
  0xc1200001,
  0xc1200001,
  0xc1280001,
  0xc1280001,
  0xc1280001,
  0xc1300001,
  0xc1300001,
  0xc1300001,
  0xc1380001,
  0xc1a00001,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xc1200001,
  0xc1200001,
  0xc1200001,
  0xc1200001,
  0xc1200001,
  0xc1180001,
  0xc1180001,
  0xc1180001,
  0xc1100001,
  0xc1100001,
  0xc1100001,
  0xc1080001,
  0xb5a00000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xc1200001,
  0xc1200001,
  0xc1200001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x80123456,
  0x80923456,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x802468ac,
  0x80923455,
  0x80123457,
  0x80123456,
  0x006dcbaa,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x80000000,
  0x006dcba9,
  0x80123455,
  0x80800000,
  0x81000000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80923456,
  0x80ffffff,
  0x80800001,
  0x80800000,
  0x00000000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x806dcbaa,
  0x80000001,
  0x807fffff,
  0x80000001,
  0x80800001,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123457,
  0x80800000,
  0x80000002,
  0x80000001,
  0x007fffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123455,
  0x007ffffe,
  0x80000000,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00c00000,
  0x00400000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x00adcbaa,
  0x00400001,
  0x00bfffff,
  0x00c00000,
  0x01200000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00d23456,
  0x01200000,
  0x00c00001,
  0x3f3fffff,
  0x3f3fffff,
  0x3e7fffff,
  0x3e7ffffd,
  0x3e7ffff9,
  0xbe7fffff,
  0xbe800002,
  0xbe800006,
  0xbf400001,
  0xc1140000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f3fffff,
  0x3f3fffff,
  0x3f3fffff,
  0x3f3fffff,
  0x3f3fffff,
  0x3f9fffff,
  0x3fa00000,
  0x3fa00000,
  0x3fdfffff,
  0x3fe00000,
  0x3fe00001,
  0x40100000,
  0x412c0000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f3fffff,
  0x3f3fffff,
  0x3f3fffff,
  0x3f400000,
  0x3f400000,
  0x3e800001,
  0x3e800000,
  0x3e7ffffc,
  0xbe7ffffc,
  0xbe800000,
  0xbe800004,
  0xbf400000,
  0xc1140000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f400000,
  0x3f400000,
  0x3f400000,
  0x3f400000,
  0x3f400000,
  0x3fa00000,
  0x3fa00000,
  0x3fa00000,
  0x3fe00000,
  0x3fe00000,
  0x3fe00001,
  0x40100000,
  0x412c0000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f400000,
  0x3f400000,
  0x3f400000,
  0x3f400002,
  0x3f400001,
  0x3e800004,
  0x3e800003,
  0x3e800001,
  0xbe7ffff6,
  0xbe7ffffa,
  0xbe800001,
  0xbf3ffffe,
  0xc1140000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f400001,
  0x3f400001,
  0x3f400001,
  0x3f400002,
  0x3f400002,
  0x3fa00000,
  0x3fa00001,
  0x3fa00001,
  0x3fe00000,
  0x3fe00001,
  0x3fe00002,
  0x40100000,
  0x412c0000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f400002,
  0x3f400002,
  0x3f400002,
  0x3fbfffff,
  0x3fbfffff,
  0x3f7fffff,
  0x3f7ffffe,
  0x3f7ffffe,
  0x3effffff,
  0x3efffffd,
  0x3efffff9,
  0xb3c00000,
  0xc1080000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3fbfffff,
  0x3fbfffff,
  0x3fbfffff,
  0x3fbfffff,
  0x3fbfffff,
  0x3fffffff,
  0x3fffffff,
  0x40000000,
  0x401fffff,
  0x40200000,
  0x40200000,
  0x40400000,
  0x41380000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3fbfffff,
  0x3fbfffff,
  0x3fbfffff,
  0x3fc00000,
  0x3fc00000,
  0x3f800000,
  0x3f800000,
  0x3f7fffff,
  0x3f000001,
  0x3f000000,
  0x3efffffc,
  0x00000000,
  0xc1080000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3fc00000,
  0x3fc00000,
  0x3fc00000,
  0x3fc00000,
  0x3fc00000,
  0x40000000,
  0x40000000,
  0x40000000,
  0x40200000,
  0x40200000,
  0x40200000,
  0x40400000,
  0x41380000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3fc00000,
  0x3fc00000,
  0x3fc00000,
  0x3fc00002,
  0x3fc00001,
  0x3f800002,
  0x3f800002,
  0x3f800001,
  0x3f000004,
  0x3f000003,
  0x3f000001,
  0x34400000,
  0xc1080000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3fc00001,
  0x3fc00001,
  0x3fc00001,
  0x3fc00002,
  0x3fc00002,
  0x40000001,
  0x40000001,
  0x40000001,
  0x40200000,
  0x40200001,
  0x40200001,
  0x40400001,
  0x41380000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3fc00002,
  0x3fc00002,
  0x3fc00002,
  0x40100000,
  0x40100000,
  0x3fe00000,
  0x3fe00000,
  0x3fe00000,
  0x3fa00000,
  0x3fa00000,
  0x3f9fffff,
  0x3f400000,
  0xc0f80000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x40100000,
  0x40100000,
  0x40100000,
  0x40100000,
  0x40100000,
  0x40300000,
  0x40300000,
  0x40300000,
  0x40500000,
  0x40500000,
  0x40500000,
  0x40700000,
  0x41440000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x40100000,
  0x40100000,
  0x40100000,
  0x41700000,
  0x41700000,
  0x41680000,
  0x41680000,
  0x41680000,
  0x41600000,
  0x41600000,
  0x41600000,
  0x41580000,
  0x40a00000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x41700000,
  0x41700000,
  0x41700000,
  0x41700000,
  0x41700000,
  0x41780000,
  0x41780000,
  0x41780000,
  0x41800000,
  0x41800000,
  0x41800000,
  0x41840000,
  0x41c80000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x41700000,
  0x41700000,
  0x41700000,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x001b4e81,
  0x8064b17f,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x00091a2b,
  0x8064b17e,
  0x001b4e80,
  0x001b4e81,
  0x009b4e81,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x002d82d7,
  0x009b4e80,
  0x001b4e82,
  0x00bffffe,
  0x003ffffe,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x00adcba8,
  0x00400000,
  0x00bffffe,
  0x00bffffe,
  0x011fffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00d23454,
  0x011fffff,
  0x00c00000,
  0x00000002,
  0x807ffffe,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123454,
  0x807ffffe,
  0x00000000,
  0x00000002,
  0x00800002,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123458,
  0x00800000,
  0x00000002,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80c00000,
  0x81200000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80d23456,
  0x81200000,
  0x80c00001,
  0x80c00000,
  0x80400000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x80adcbaa,
  0x80400001,
  0x80bfffff,
  0xbf3fffff,
  0xbf3fffff,
  0xbf9fffff,
  0xbfa00000,
  0xbfa00000,
  0xbfdfffff,
  0xbfe00000,
  0xbfe00001,
  0xc0100000,
  0xc12c0000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf3fffff,
  0xbf3fffff,
  0xbf3fffff,
  0xbf3fffff,
  0xbf3fffff,
  0xbe7fffff,
  0xbe7ffffd,
  0xbe7ffff9,
  0x3e7fffff,
  0x3e800002,
  0x3e800006,
  0x3f400001,
  0x41140000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf3fffff,
  0xbf3fffff,
  0xbf3fffff,
  0xbf400000,
  0xbf400000,
  0xbfa00000,
  0xbfa00000,
  0xbfa00000,
  0xbfe00000,
  0xbfe00000,
  0xbfe00001,
  0xc0100000,
  0xc12c0000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf400000,
  0xbf400000,
  0xbf400000,
  0xbf400000,
  0xbf400000,
  0xbe800001,
  0xbe800000,
  0xbe7ffffc,
  0x3e7ffffc,
  0x3e800000,
  0x3e800004,
  0x3f400000,
  0x41140000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf400000,
  0xbf400000,
  0xbf400000,
  0xbf400002,
  0xbf400002,
  0xbfa00000,
  0xbfa00001,
  0xbfa00001,
  0xbfe00000,
  0xbfe00001,
  0xbfe00002,
  0xc0100000,
  0xc12c0000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf400002,
  0xbf400002,
  0xbf400002,
  0xbf400002,
  0xbf400001,
  0xbe800004,
  0xbe800003,
  0xbe800001,
  0x3e7ffff6,
  0x3e7ffffa,
  0x3e800001,
  0x3f3ffffe,
  0x41140000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf400001,
  0xbf400001,
  0xbf400001,
  0xbfbfffff,
  0xbfbfffff,
  0xbfffffff,
  0xbfffffff,
  0xc0000000,
  0xc01fffff,
  0xc0200000,
  0xc0200000,
  0xc0400000,
  0xc1380000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbfbfffff,
  0xbfbfffff,
  0xbfbfffff,
  0xbfbfffff,
  0xbfbfffff,
  0xbf7fffff,
  0xbf7ffffe,
  0xbf7ffffe,
  0xbeffffff,
  0xbefffffd,
  0xbefffff9,
  0x33c00000,
  0x41080000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbfbfffff,
  0xbfbfffff,
  0xbfbfffff,
  0xbfc00000,
  0xbfc00000,
  0xc0000000,
  0xc0000000,
  0xc0000000,
  0xc0200000,
  0xc0200000,
  0xc0200000,
  0xc0400000,
  0xc1380000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbfc00000,
  0xbfc00000,
  0xbfc00000,
  0xbfc00000,
  0xbfc00000,
  0xbf800000,
  0xbf800000,
  0xbf7fffff,
  0xbf000001,
  0xbf000000,
  0xbefffffc,
  0x00000000,
  0x41080000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbfc00000,
  0xbfc00000,
  0xbfc00000,
  0xbfc00002,
  0xbfc00002,
  0xc0000001,
  0xc0000001,
  0xc0000001,
  0xc0200000,
  0xc0200001,
  0xc0200001,
  0xc0400001,
  0xc1380000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbfc00002,
  0xbfc00002,
  0xbfc00002,
  0xbfc00002,
  0xbfc00001,
  0xbf800002,
  0xbf800002,
  0xbf800001,
  0xbf000004,
  0xbf000003,
  0xbf000001,
  0xb4400000,
  0x41080000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbfc00001,
  0xbfc00001,
  0xbfc00001,
  0xc0100000,
  0xc0100000,
  0xc0300000,
  0xc0300000,
  0xc0300000,
  0xc0500000,
  0xc0500000,
  0xc0500000,
  0xc0700000,
  0xc1440000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xc0100000,
  0xc0100000,
  0xc0100000,
  0xc0100000,
  0xc0100000,
  0xbfe00000,
  0xbfe00000,
  0xbfe00000,
  0xbfa00000,
  0xbfa00000,
  0xbf9fffff,
  0xbf400000,
  0x40f80000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xc0100000,
  0xc0100000,
  0xc0100000,
  0xc1700000,
  0xc1700000,
  0xc1780000,
  0xc1780000,
  0xc1780000,
  0xc1800000,
  0xc1800000,
  0xc1800000,
  0xc1840000,
  0xc1c80000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xc1700000,
  0xc1700000,
  0xc1700000,
  0xc1700000,
  0xc1700000,
  0xc1680000,
  0xc1680000,
  0xc1680000,
  0xc1600000,
  0xc1600000,
  0xc1600000,
  0xc1580000,
  0xc0a00000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xc1700000,
  0xc1700000,
  0xc1700000,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x801b4e81,
  0x809b4e81,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x802d82d7,
  0x809b4e80,
  0x801b4e82,
  0x801b4e81,
  0x0064b17f,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x80091a2b,
  0x0064b17e,
  0x801b4e80,
  0x80bffffe,
  0x811fffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80d23454,
  0x811fffff,
  0x80c00000,
  0x80bffffe,
  0x803ffffe,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x80adcba8,
  0x80400000,
  0x80bffffe,
  0x80000002,
  0x80800002,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123458,
  0x80800000,
  0x80000002,
  0x80000002,
  0x007ffffe,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123454,
  0x007ffffe,
  0x80000000,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x02200000,
  0x02100000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x021db975,
  0x02100000,
  0x02200000,
  0x02200000,
  0x02300000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x0222468b,
  0x02300000,
  0x02200000,
  0x409fffff,
  0x409fffff,
  0x408fffff,
  0x408fffff,
  0x408fffff,
  0x407fffff,
  0x407fffff,
  0x407ffffe,
  0x405fffff,
  0xc0a00001,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x409fffff,
  0x409fffff,
  0x409fffff,
  0x409fffff,
  0x409fffff,
  0x40afffff,
  0x40afffff,
  0x40b00000,
  0x40bfffff,
  0x40bfffff,
  0x40c00000,
  0x40cfffff,
  0x41700000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x409fffff,
  0x409fffff,
  0x409fffff,
  0x40a00000,
  0x40a00000,
  0x40900000,
  0x40900000,
  0x40900000,
  0x40800000,
  0x40800000,
  0x40800000,
  0x40600000,
  0xc0a00000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x40a00000,
  0x40a00000,
  0x40a00000,
  0x40a00000,
  0x40a00000,
  0x40b00000,
  0x40b00000,
  0x40b00000,
  0x40c00000,
  0x40c00000,
  0x40c00000,
  0x40d00000,
  0x41700000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x40a00000,
  0x40a00000,
  0x40a00000,
  0x40a00001,
  0x40a00001,
  0x40900001,
  0x40900001,
  0x40900001,
  0x40800001,
  0x40800001,
  0x40800001,
  0x40600002,
  0xc09fffff,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x40a00001,
  0x40a00001,
  0x40a00001,
  0x40a00001,
  0x40a00001,
  0x40b00001,
  0x40b00001,
  0x40b00001,
  0x40c00001,
  0x40c00001,
  0x40c00002,
  0x40d00001,
  0x41700001,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x40a00001,
  0x40a00001,
  0x40a00001,
  0x411fffff,
  0x411fffff,
  0x4117ffff,
  0x4117ffff,
  0x4117ffff,
  0x410fffff,
  0x410fffff,
  0x410fffff,
  0x4107ffff,
  0xb5200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x411fffff,
  0x411fffff,
  0x411fffff,
  0x411fffff,
  0x411fffff,
  0x4127ffff,
  0x4127ffff,
  0x4127ffff,
  0x412fffff,
  0x412fffff,
  0x41300000,
  0x4137ffff,
  0x41a00000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x411fffff,
  0x411fffff,
  0x411fffff,
  0x41200000,
  0x41200000,
  0x41180000,
  0x41180000,
  0x41180000,
  0x41100000,
  0x41100000,
  0x41100000,
  0x41080000,
  0x00000000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x41200000,
  0x41200000,
  0x41200000,
  0x41200000,
  0x41200000,
  0x41280000,
  0x41280000,
  0x41280000,
  0x41300000,
  0x41300000,
  0x41300000,
  0x41380000,
  0x41a00000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x41200000,
  0x41200000,
  0x41200000,
  0x41200001,
  0x41200001,
  0x41180001,
  0x41180001,
  0x41180001,
  0x41100001,
  0x41100001,
  0x41100001,
  0x41080001,
  0x35a00000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x41200001,
  0x41200001,
  0x41200001,
  0x41200001,
  0x41200001,
  0x41280001,
  0x41280001,
  0x41280001,
  0x41300001,
  0x41300001,
  0x41300001,
  0x41380001,
  0x41a00001,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x41200001,
  0x41200001,
  0x41200001,
  0x41700000,
  0x41700000,
  0x41680000,
  0x41680000,
  0x41680000,
  0x41600000,
  0x41600000,
  0x41600000,
  0x41580000,
  0x40a00000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x41700000,
  0x41700000,
  0x41700000,
  0x41700000,
  0x41700000,
  0x41780000,
  0x41780000,
  0x41780000,
  0x41800000,
  0x41800000,
  0x41800000,
  0x41840000,
  0x41c80000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x41700000,
  0x41700000,
  0x41700000,
  0x42c80000,
  0x42c80000,
  0x42c70000,
  0x42c70000,
  0x42c70000,
  0x42c60000,
  0x42c60000,
  0x42c60000,
  0x42c50000,
  0x42b40000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x42c80000,
  0x42c80000,
  0x42c80000,
  0x42c80000,
  0x42c80000,
  0x42c90000,
  0x42c90000,
  0x42c90000,
  0x42ca0000,
  0x42ca0000,
  0x42ca0000,
  0x42cb0000,
  0x42dc0000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x42c80000,
  0x42c80000,
  0x42c80000,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x00b60b5c,
  0x00360b5c,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x00a3d706,
  0x00360b5d,
  0x00b60b5b,
  0x00b60b5c,
  0x011b05ae,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00c83fb2,
  0x011b05ae,
  0x00b60b5d,
  0x021fffff,
  0x020fffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x021db974,
  0x020fffff,
  0x021fffff,
  0x021fffff,
  0x022fffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x0222468a,
  0x022fffff,
  0x021fffff,
  0x0000000a,
  0x807ffff6,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x8012344c,
  0x807ffff5,
  0x00000009,
  0x0000000a,
  0x0080000a,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123460,
  0x00800009,
  0x0000000b,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x82200000,
  0x82300000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x8222468b,
  0x82300000,
  0x82200000,
  0x82200000,
  0x82100000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x821db975,
  0x82100000,
  0x82200000,
  0xc09fffff,
  0xc09fffff,
  0xc0afffff,
  0xc0afffff,
  0xc0b00000,
  0xc0bfffff,
  0xc0bfffff,
  0xc0c00000,
  0xc0cfffff,
  0xc1700000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xc09fffff,
  0xc09fffff,
  0xc09fffff,
  0xc09fffff,
  0xc09fffff,
  0xc08fffff,
  0xc08fffff,
  0xc08fffff,
  0xc07fffff,
  0xc07fffff,
  0xc07ffffe,
  0xc05fffff,
  0x40a00001,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xc09fffff,
  0xc09fffff,
  0xc09fffff,
  0xc0a00000,
  0xc0a00000,
  0xc0b00000,
  0xc0b00000,
  0xc0b00000,
  0xc0c00000,
  0xc0c00000,
  0xc0c00000,
  0xc0d00000,
  0xc1700000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xc0a00000,
  0xc0a00000,
  0xc0a00000,
  0xc0a00000,
  0xc0a00000,
  0xc0900000,
  0xc0900000,
  0xc0900000,
  0xc0800000,
  0xc0800000,
  0xc0800000,
  0xc0600000,
  0x40a00000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xc0a00000,
  0xc0a00000,
  0xc0a00000,
  0xc0a00001,
  0xc0a00001,
  0xc0b00001,
  0xc0b00001,
  0xc0b00001,
  0xc0c00001,
  0xc0c00001,
  0xc0c00002,
  0xc0d00001,
  0xc1700001,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xc0a00001,
  0xc0a00001,
  0xc0a00001,
  0xc0a00001,
  0xc0a00001,
  0xc0900001,
  0xc0900001,
  0xc0900001,
  0xc0800001,
  0xc0800001,
  0xc0800001,
  0xc0600002,
  0x409fffff,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xc0a00001,
  0xc0a00001,
  0xc0a00001,
  0xc11fffff,
  0xc11fffff,
  0xc127ffff,
  0xc127ffff,
  0xc127ffff,
  0xc12fffff,
  0xc12fffff,
  0xc1300000,
  0xc137ffff,
  0xc1a00000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xc11fffff,
  0xc11fffff,
  0xc11fffff,
  0xc11fffff,
  0xc11fffff,
  0xc117ffff,
  0xc117ffff,
  0xc117ffff,
  0xc10fffff,
  0xc10fffff,
  0xc10fffff,
  0xc107ffff,
  0x35200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xc11fffff,
  0xc11fffff,
  0xc11fffff,
  0xc1200000,
  0xc1200000,
  0xc1280000,
  0xc1280000,
  0xc1280000,
  0xc1300000,
  0xc1300000,
  0xc1300000,
  0xc1380000,
  0xc1a00000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xc1200000,
  0xc1200000,
  0xc1200000,
  0xc1200000,
  0xc1200000,
  0xc1180000,
  0xc1180000,
  0xc1180000,
  0xc1100000,
  0xc1100000,
  0xc1100000,
  0xc1080000,
  0x00000000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xc1200000,
  0xc1200000,
  0xc1200000,
  0xc1200001,
  0xc1200001,
  0xc1280001,
  0xc1280001,
  0xc1280001,
  0xc1300001,
  0xc1300001,
  0xc1300001,
  0xc1380001,
  0xc1a00001,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xc1200001,
  0xc1200001,
  0xc1200001,
  0xc1200001,
  0xc1200001,
  0xc1180001,
  0xc1180001,
  0xc1180001,
  0xc1100001,
  0xc1100001,
  0xc1100001,
  0xc1080001,
  0xb5a00000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xc1200001,
  0xc1200001,
  0xc1200001,
  0xc1700000,
  0xc1700000,
  0xc1780000,
  0xc1780000,
  0xc1780000,
  0xc1800000,
  0xc1800000,
  0xc1800000,
  0xc1840000,
  0xc1c80000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xc1700000,
  0xc1700000,
  0xc1700000,
  0xc1700000,
  0xc1700000,
  0xc1680000,
  0xc1680000,
  0xc1680000,
  0xc1600000,
  0xc1600000,
  0xc1600000,
  0xc1580000,
  0xc0a00000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xc1700000,
  0xc1700000,
  0xc1700000,
  0xc2c80000,
  0xc2c80000,
  0xc2c90000,
  0xc2c90000,
  0xc2c90000,
  0xc2ca0000,
  0xc2ca0000,
  0xc2ca0000,
  0xc2cb0000,
  0xc2dc0000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xc2c80000,
  0xc2c80000,
  0xc2c80000,
  0xc2c80000,
  0xc2c80000,
  0xc2c70000,
  0xc2c70000,
  0xc2c70000,
  0xc2c60000,
  0xc2c60000,
  0xc2c60000,
  0xc2c50000,
  0xc2b40000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xc2c80000,
  0xc2c80000,
  0xc2c80000,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x80b60b5c,
  0x811b05ae,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80c83fb2,
  0x811b05ae,
  0x80b60b5d,
  0x80b60b5c,
  0x80360b5c,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x80a3d706,
  0x80360b5d,
  0x80b60b5b,
  0x821fffff,
  0x822fffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x8222468a,
  0x822fffff,
  0x821fffff,
  0x821fffff,
  0x820fffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x821db974,
  0x820fffff,
  0x821fffff,
  0x8000000a,
  0x8080000a,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123460,
  0x80800009,
  0x8000000b,
  0x8000000a,
  0x007ffff6,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x0012344c,
  0x007ffff5,
  0x80000009,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00091a2b,
  0x8076e5d5,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80091a2b,
  0x8076e5d4,
  0x00091a2a,
  0x00091a2b,
  0x00891a2b,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x001b4e81,
  0x00891a2a,
  0x00091a2c,
  0x00091a2b,
  0x8076e5d5,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80091a2b,
  0x8076e5d4,
  0x00091a2a,
  0x00091a2b,
  0x00891a2b,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x001b4e81,
  0x00891a2a,
  0x00091a2c,
  0x00091a2b,
  0x8076e5d5,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80091a2b,
  0x8076e5d4,
  0x00091a2a,
  0x00091a2b,
  0x00891a2b,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x001b4e81,
  0x00891a2a,
  0x00091a2c,
  0x00123456,
  0x806dcbaa,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80000000,
  0x806dcba9,
  0x00123455,
  0x00123456,
  0x00923456,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x002468ac,
  0x00923455,
  0x00123457,
  0x00123456,
  0x806dcbaa,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x00000000,
  0x806dcba9,
  0x00123455,
  0x00123456,
  0x00923456,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x002468ac,
  0x00923455,
  0x00123457,
  0x00123456,
  0x806dcbaa,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x00000000,
  0x806dcba9,
  0x00123455,
  0x00123456,
  0x00923456,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x002468ac,
  0x00923455,
  0x00123457,
  0x001b4e81,
  0x8064b17f,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x00091a2b,
  0x8064b17e,
  0x001b4e80,
  0x001b4e81,
  0x009b4e81,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x002d82d7,
  0x009b4e80,
  0x001b4e82,
  0x00b60b5c,
  0x00360b5c,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x00a3d706,
  0x00360b5d,
  0x00b60b5b,
  0x00b60b5c,
  0x011b05ae,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00c83fb2,
  0x011b05ae,
  0x00b60b5d,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80091a2b,
  0x80891a2b,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x801b4e81,
  0x80891a2a,
  0x80091a2c,
  0x80091a2b,
  0x0076e5d5,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00091a2b,
  0x0076e5d4,
  0x80091a2a,
  0x80091a2b,
  0x80891a2b,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x801b4e81,
  0x80891a2a,
  0x80091a2c,
  0x80091a2b,
  0x0076e5d5,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00091a2b,
  0x0076e5d4,
  0x80091a2a,
  0x80091a2b,
  0x80891a2b,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x801b4e81,
  0x80891a2a,
  0x80091a2c,
  0x80091a2b,
  0x0076e5d5,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00091a2b,
  0x0076e5d4,
  0x80091a2a,
  0x80123456,
  0x80923456,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x802468ac,
  0x80923455,
  0x80123457,
  0x80123456,
  0x006dcbaa,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00000000,
  0x006dcba9,
  0x80123455,
  0x80123456,
  0x80923456,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x802468ac,
  0x80923455,
  0x80123457,
  0x80123456,
  0x006dcbaa,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00000000,
  0x006dcba9,
  0x80123455,
  0x80123456,
  0x80923456,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x802468ac,
  0x80923455,
  0x80123457,
  0x80123456,
  0x006dcbaa,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x80000000,
  0x006dcba9,
  0x80123455,
  0x801b4e81,
  0x809b4e81,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x802d82d7,
  0x809b4e80,
  0x801b4e82,
  0x801b4e81,
  0x0064b17f,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x80091a2b,
  0x0064b17e,
  0x801b4e80,
  0x80b60b5c,
  0x811b05ae,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80c83fb2,
  0x811b05ae,
  0x80b60b5d,
  0x80b60b5c,
  0x80360b5c,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x80a3d706,
  0x80360b5d,
  0x80b60b5b,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x003fffff,
  0x80400001,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x002dcba9,
  0x80400000,
  0x003ffffe,
  0x003fffff,
  0x00bfffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00523455,
  0x00bffffe,
  0x00400000,
  0x00400000,
  0x80400000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x002dcbaa,
  0x80400000,
  0x003ffffe,
  0x00400000,
  0x00c00000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00523456,
  0x00bffffe,
  0x00400000,
  0x00400000,
  0x80400000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x002dcbaa,
  0x803fffff,
  0x003fffff,
  0x00400000,
  0x00c00000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00523456,
  0x00bfffff,
  0x00400001,
  0x007fffff,
  0x80000001,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x006dcba9,
  0x80000000,
  0x007ffffe,
  0x007fffff,
  0x00ffffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00923455,
  0x00fffffe,
  0x00800000,
  0x007fffff,
  0x80000001,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x006dcba9,
  0x00000000,
  0x007ffffe,
  0x007fffff,
  0x00ffffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00923455,
  0x00fffffe,
  0x00800000,
  0x00800000,
  0x80000000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x006dcbaa,
  0x00000001,
  0x007fffff,
  0x00800000,
  0x01000000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00923456,
  0x00ffffff,
  0x00800001,
  0x00bffffe,
  0x003ffffe,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x00adcba8,
  0x00400000,
  0x00bffffe,
  0x00bffffe,
  0x011fffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00d23454,
  0x011fffff,
  0x00c00000,
  0x021fffff,
  0x020fffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x021db974,
  0x020fffff,
  0x021fffff,
  0x021fffff,
  0x022fffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x0222468a,
  0x022fffff,
  0x021fffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x803fffff,
  0x80bfffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80523455,
  0x80bffffe,
  0x80400000,
  0x803fffff,
  0x00400001,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x802dcba9,
  0x00400000,
  0x803ffffe,
  0x80400000,
  0x80c00000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80523456,
  0x80bffffe,
  0x80400000,
  0x80400000,
  0x00400000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x802dcbaa,
  0x00400000,
  0x803ffffe,
  0x80400000,
  0x80c00000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80523456,
  0x80bfffff,
  0x80400001,
  0x80400000,
  0x00400000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x802dcbaa,
  0x003fffff,
  0x803fffff,
  0x807fffff,
  0x80ffffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80923455,
  0x80fffffe,
  0x80800000,
  0x807fffff,
  0x00000001,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x806dcba9,
  0x00000000,
  0x807ffffe,
  0x807fffff,
  0x80ffffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80923455,
  0x80fffffe,
  0x80800000,
  0x807fffff,
  0x00000001,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x806dcba9,
  0x00000000,
  0x807ffffe,
  0x80800000,
  0x81000000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80923456,
  0x80ffffff,
  0x80800001,
  0x80800000,
  0x00000000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x806dcbaa,
  0x80000001,
  0x807fffff,
  0x80bffffe,
  0x811fffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80d23454,
  0x811fffff,
  0x80c00000,
  0x80bffffe,
  0x803ffffe,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x80adcba8,
  0x80400000,
  0x80bffffe,
  0x821fffff,
  0x822fffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x8222468a,
  0x822fffff,
  0x821fffff,
  0x821fffff,
  0x820fffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x821db974,
  0x820fffff,
  0x821fffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807ffffe,
  0x80000000,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x00800000,
  0x00000002,
  0x00000001,
  0x807fffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123455,
  0x807ffffe,
  0x80000000,
  0x00000001,
  0x00800001,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123457,
  0x00800000,
  0x00000002,
  0x00000001,
  0x807fffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123455,
  0x807ffffe,
  0x80000000,
  0x00000001,
  0x00800001,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123457,
  0x00800000,
  0x00000002,
  0x00000001,
  0x807fffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123455,
  0x807ffffe,
  0x00000000,
  0x00000001,
  0x00800001,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123457,
  0x00800000,
  0x00000002,
  0x00000001,
  0x807fffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123455,
  0x807ffffe,
  0x00000000,
  0x00000001,
  0x00800001,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123457,
  0x00800000,
  0x00000002,
  0x00000002,
  0x807ffffe,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123454,
  0x807ffffe,
  0x00000000,
  0x00000002,
  0x00800002,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123458,
  0x00800000,
  0x00000002,
  0x0000000a,
  0x807ffff6,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x8012344c,
  0x807ffff5,
  0x00000009,
  0x0000000a,
  0x0080000a,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123460,
  0x00800009,
  0x0000000b,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x80800000,
  0x80000002,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007ffffe,
  0x00000000,
  0x80000001,
  0x80800001,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123457,
  0x80800000,
  0x80000002,
  0x80000001,
  0x007fffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123455,
  0x007ffffe,
  0x00000000,
  0x80000001,
  0x80800001,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123457,
  0x80800000,
  0x80000002,
  0x80000001,
  0x007fffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123455,
  0x007ffffe,
  0x00000000,
  0x80000001,
  0x80800001,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123457,
  0x80800000,
  0x80000002,
  0x80000001,
  0x007fffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123455,
  0x007ffffe,
  0x00000000,
  0x80000001,
  0x80800001,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123457,
  0x80800000,
  0x80000002,
  0x80000001,
  0x007fffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123455,
  0x007ffffe,
  0x80000000,
  0x80000002,
  0x80800002,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123458,
  0x80800000,
  0x80000002,
  0x80000002,
  0x007ffffe,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123454,
  0x007ffffe,
  0x80000000,
  0x8000000a,
  0x8080000a,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123460,
  0x80800009,
  0x8000000b,
  0x8000000a,
  0x007ffff6,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x0012344c,
  0x007ffff5,
  0x80000009,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
};
const unsigned kExpectedCount_fnmadd_s = 54872;

const uint64_t kExpected_fnmsub_d[] = {
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0008000000000000,
  0x8008000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0006dcba98765433,
  0x8007ffffffffffff,
  0x0007ffffffffffff,
  0x0008000000000000,
  0x0018000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000923456789abcd,
  0x0017ffffffffffff,
  0x0008000000000001,
  0x0008000000000000,
  0x8008000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0006dcba98765433,
  0x8007ffffffffffff,
  0x0007ffffffffffff,
  0x0008000000000000,
  0x0018000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000923456789abcd,
  0x0017ffffffffffff,
  0x0008000000000001,
  0x0008000000000000,
  0x8008000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0006dcba98765434,
  0x8007fffffffffffe,
  0x0008000000000000,
  0x0008000000000000,
  0x0018000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000923456789abce,
  0x0018000000000000,
  0x0008000000000002,
  0x0010000000000000,
  0x8000000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x000edcba98765432,
  0x0000000000000000,
  0x000ffffffffffffe,
  0x0010000000000000,
  0x0020000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x001123456789abcc,
  0x001ffffffffffffe,
  0x0010000000000000,
  0x0010000000000000,
  0x0000000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x000edcba98765433,
  0x0000000000000001,
  0x000fffffffffffff,
  0x0010000000000000,
  0x0020000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x001123456789abcd,
  0x001fffffffffffff,
  0x0010000000000001,
  0x0010000000000001,
  0x0000000000000001,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x000edcba98765434,
  0x0000000000000002,
  0x0010000000000000,
  0x0010000000000001,
  0x0020000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x001123456789abce,
  0x0020000000000000,
  0x0010000000000002,
  0x0018000000000000,
  0x0008000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0016dcba98765433,
  0x0008000000000001,
  0x0017ffffffffffff,
  0x0018000000000000,
  0x0024000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x001923456789abcd,
  0x0024000000000000,
  0x0018000000000001,
  0x0044000000000000,
  0x0042000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0043db97530eca86,
  0x0042000000000000,
  0x0044000000000000,
  0x0044000000000000,
  0x0046000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x00442468acf1357a,
  0x0046000000000000,
  0x0044000000000000,
  0x400fffffffffffff,
  0x400fffffffffffff,
  0x400bffffffffffff,
  0x400bffffffffffff,
  0x400bffffffffffff,
  0x4007ffffffffffff,
  0x4007ffffffffffff,
  0x4007fffffffffffe,
  0x4003ffffffffffff,
  0xc018000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x400fffffffffffff,
  0x400fffffffffffff,
  0x400fffffffffffff,
  0x400fffffffffffff,
  0x400fffffffffffff,
  0x4011ffffffffffff,
  0x4012000000000000,
  0x4012000000000000,
  0x4013ffffffffffff,
  0x4014000000000000,
  0x4014000000000000,
  0x4016000000000000,
  0x402c000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x400fffffffffffff,
  0x400fffffffffffff,
  0x400fffffffffffff,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8008000000000000,
  0x8018000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800923456789abcd,
  0x8017ffffffffffff,
  0x8008000000000001,
  0x8008000000000000,
  0x0008000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8006dcba98765433,
  0x0007ffffffffffff,
  0x8007ffffffffffff,
  0x8008000000000000,
  0x8018000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800923456789abcd,
  0x8017ffffffffffff,
  0x8008000000000001,
  0x8008000000000000,
  0x0008000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8006dcba98765433,
  0x0007ffffffffffff,
  0x8007ffffffffffff,
  0x8008000000000000,
  0x8018000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800923456789abce,
  0x8018000000000000,
  0x8008000000000002,
  0x8008000000000000,
  0x0008000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8006dcba98765434,
  0x0007fffffffffffe,
  0x8008000000000000,
  0x8010000000000000,
  0x8020000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x801123456789abcc,
  0x801ffffffffffffe,
  0x8010000000000000,
  0x8010000000000000,
  0x0000000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x800edcba98765432,
  0x8000000000000000,
  0x800ffffffffffffe,
  0x8010000000000000,
  0x8020000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x801123456789abcd,
  0x801fffffffffffff,
  0x8010000000000001,
  0x8010000000000000,
  0x0000000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x800edcba98765433,
  0x8000000000000001,
  0x800fffffffffffff,
  0x8010000000000001,
  0x8020000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x801123456789abce,
  0x8020000000000000,
  0x8010000000000002,
  0x8010000000000001,
  0x8000000000000001,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x800edcba98765434,
  0x8000000000000002,
  0x8010000000000000,
  0x8018000000000000,
  0x8024000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x801923456789abcd,
  0x8024000000000000,
  0x8018000000000001,
  0x8018000000000000,
  0x8008000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8016dcba98765433,
  0x8008000000000001,
  0x8017ffffffffffff,
  0x8044000000000000,
  0x8046000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x80442468acf1357a,
  0x8046000000000000,
  0x8044000000000000,
  0x8044000000000000,
  0x8042000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8043db97530eca86,
  0x8042000000000000,
  0x8044000000000000,
  0xc00fffffffffffff,
  0xc00fffffffffffff,
  0xc011ffffffffffff,
  0xc012000000000000,
  0xc012000000000000,
  0xc013ffffffffffff,
  0xc014000000000000,
  0xc014000000000000,
  0xc016000000000000,
  0xc02c000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc00fffffffffffff,
  0xc00fffffffffffff,
  0xc00fffffffffffff,
  0xc00fffffffffffff,
  0xc00fffffffffffff,
  0xc00bffffffffffff,
  0xc00bffffffffffff,
  0xc00bffffffffffff,
  0xc007ffffffffffff,
  0xc007ffffffffffff,
  0xc007fffffffffffe,
  0xc003ffffffffffff,
  0x4018000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc00fffffffffffff,
  0xc00fffffffffffff,
  0xc00fffffffffffff,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0008000000000000,
  0x8008000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0006dcba98765433,
  0x8007ffffffffffff,
  0x0007ffffffffffff,
  0x0008000000000000,
  0x0018000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000923456789abcd,
  0x0017ffffffffffff,
  0x0008000000000001,
  0x3fcffffffffffffe,
  0x3fcffffffffffffe,
  0xbfd0000000000000,
  0xbfd0000000000001,
  0xbfd0000000000003,
  0xbfe7ffffffffffff,
  0xbfe8000000000000,
  0xbfe8000000000002,
  0xbff4000000000000,
  0xc023800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fcffffffffffffe,
  0x3fcffffffffffffe,
  0x3fcffffffffffffe,
  0x3fcffffffffffffe,
  0x3fcffffffffffffe,
  0x3fe7ffffffffffff,
  0x3fe8000000000000,
  0x3fe8000000000001,
  0x3ff3ffffffffffff,
  0x3ff4000000000000,
  0x3ff4000000000001,
  0x3ffc000000000000,
  0x4024800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fcffffffffffffe,
  0x3fcffffffffffffe,
  0x3fcffffffffffffe,
  0x3fcfffffffffffff,
  0x3fcfffffffffffff,
  0xbfcfffffffffffff,
  0xbfd0000000000000,
  0xbfd0000000000002,
  0xbfe7ffffffffffff,
  0xbfe8000000000000,
  0xbfe8000000000002,
  0xbff4000000000000,
  0xc023800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fcfffffffffffff,
  0x3fcfffffffffffff,
  0x3fcfffffffffffff,
  0x3fcfffffffffffff,
  0x3fcfffffffffffff,
  0x3fe7ffffffffffff,
  0x3fe8000000000000,
  0x3fe8000000000001,
  0x3ff3ffffffffffff,
  0x3ff4000000000000,
  0x3ff4000000000001,
  0x3ffc000000000000,
  0x4024800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fcfffffffffffff,
  0x3fcfffffffffffff,
  0x3fcfffffffffffff,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0xbfcffffffffffffd,
  0xbfcfffffffffffff,
  0xbfd0000000000002,
  0xbfe7ffffffffffff,
  0xbfe8000000000000,
  0xbfe8000000000002,
  0xbff4000000000000,
  0xc023800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3fe8000000000001,
  0x3ff4000000000000,
  0x3ff4000000000000,
  0x3ff4000000000001,
  0x3ffc000000000000,
  0x4024800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fdffffffffffffe,
  0x3fdffffffffffffe,
  0xbc8fffffffffffff,
  0xbca0000000000000,
  0xbcb0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000003,
  0xbff0000000000000,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fdffffffffffffe,
  0x3fdffffffffffffe,
  0x3fdffffffffffffe,
  0x3fdffffffffffffe,
  0x3fdffffffffffffe,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff7ffffffffffff,
  0x3ff8000000000000,
  0x3ff8000000000001,
  0x4000000000000000,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fdffffffffffffe,
  0x3fdffffffffffffe,
  0x3fdffffffffffffe,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x0000000000000000,
  0xbc90000000000000,
  0xbca8000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000002,
  0xbff0000000000000,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff7ffffffffffff,
  0x3ff8000000000000,
  0x3ff8000000000001,
  0x4000000000000000,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3c9fffffffffffff,
  0x3c8ffffffffffffe,
  0xbc90000000000001,
  0xbfdffffffffffffd,
  0xbfdfffffffffffff,
  0xbfe0000000000002,
  0xbff0000000000000,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000001,
  0x4000000000000000,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe7ffffffffffff,
  0x3fe7ffffffffffff,
  0x3fcfffffffffffff,
  0x3fcffffffffffffd,
  0x3fcffffffffffff9,
  0xbfcfffffffffffff,
  0xbfd0000000000002,
  0xbfd0000000000006,
  0xbfe8000000000001,
  0xc022800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe7ffffffffffff,
  0x3fe7ffffffffffff,
  0x3fe7ffffffffffff,
  0x3fe7ffffffffffff,
  0x3fe7ffffffffffff,
  0x3ff3ffffffffffff,
  0x3ff4000000000000,
  0x3ff4000000000000,
  0x3ffbffffffffffff,
  0x3ffc000000000000,
  0x3ffc000000000001,
  0x4002000000000000,
  0x4025800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe7ffffffffffff,
  0x3fe7ffffffffffff,
  0x3fe7ffffffffffff,
  0x4013ffffffffffff,
  0x4013ffffffffffff,
  0x4011ffffffffffff,
  0x4011ffffffffffff,
  0x4011ffffffffffff,
  0x400fffffffffffff,
  0x400fffffffffffff,
  0x400ffffffffffffe,
  0x400bffffffffffff,
  0xc014000000000001,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x4013ffffffffffff,
  0x4013ffffffffffff,
  0x4013ffffffffffff,
  0x4013ffffffffffff,
  0x4013ffffffffffff,
  0x4015ffffffffffff,
  0x4015ffffffffffff,
  0x4016000000000000,
  0x4017ffffffffffff,
  0x4017ffffffffffff,
  0x4018000000000000,
  0x4019ffffffffffff,
  0x402e000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x4013ffffffffffff,
  0x4013ffffffffffff,
  0x4013ffffffffffff,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0xffe0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x000091a2b3c4d5e6,
  0x800f6e5d4c3b2a1a,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800091a2b3c4d5e7,
  0x800f6e5d4c3b2a19,
  0x000091a2b3c4d5e5,
  0x000091a2b3c4d5e6,
  0x001091a2b3c4d5e6,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0001b4e81b4e81b3,
  0x001091a2b3c4d5e5,
  0x000091a2b3c4d5e7,
  0x0007ffffffffffff,
  0x8008000000000001,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0006dcba98765432,
  0x8008000000000000,
  0x0007fffffffffffe,
  0x0007ffffffffffff,
  0x0017ffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000923456789abcc,
  0x0017fffffffffffe,
  0x0008000000000000,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8008000000000000,
  0x8018000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800923456789abcd,
  0x8017ffffffffffff,
  0x8008000000000001,
  0x8008000000000000,
  0x0008000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8006dcba98765433,
  0x0007ffffffffffff,
  0x8007ffffffffffff,
  0xbfcffffffffffffe,
  0xbfcffffffffffffe,
  0xbfe7ffffffffffff,
  0xbfe8000000000000,
  0xbfe8000000000001,
  0xbff3ffffffffffff,
  0xbff4000000000000,
  0xbff4000000000001,
  0xbffc000000000000,
  0xc024800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfcffffffffffffe,
  0xbfcffffffffffffe,
  0xbfcffffffffffffe,
  0xbfcffffffffffffe,
  0xbfcffffffffffffe,
  0x3fd0000000000000,
  0x3fd0000000000001,
  0x3fd0000000000003,
  0x3fe7ffffffffffff,
  0x3fe8000000000000,
  0x3fe8000000000002,
  0x3ff4000000000000,
  0x4023800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfcffffffffffffe,
  0xbfcffffffffffffe,
  0xbfcffffffffffffe,
  0xbfcfffffffffffff,
  0xbfcfffffffffffff,
  0xbfe7ffffffffffff,
  0xbfe8000000000000,
  0xbfe8000000000001,
  0xbff3ffffffffffff,
  0xbff4000000000000,
  0xbff4000000000001,
  0xbffc000000000000,
  0xc024800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfcfffffffffffff,
  0xbfcfffffffffffff,
  0xbfcfffffffffffff,
  0xbfcfffffffffffff,
  0xbfcfffffffffffff,
  0x3fcfffffffffffff,
  0x3fd0000000000000,
  0x3fd0000000000002,
  0x3fe7ffffffffffff,
  0x3fe8000000000000,
  0x3fe8000000000002,
  0x3ff4000000000000,
  0x4023800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfcfffffffffffff,
  0xbfcfffffffffffff,
  0xbfcfffffffffffff,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbfe8000000000001,
  0xbff4000000000000,
  0xbff4000000000000,
  0xbff4000000000001,
  0xbffc000000000000,
  0xc024800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0x3fcffffffffffffd,
  0x3fcfffffffffffff,
  0x3fd0000000000002,
  0x3fe7ffffffffffff,
  0x3fe8000000000000,
  0x3fe8000000000002,
  0x3ff4000000000000,
  0x4023800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfdffffffffffffe,
  0xbfdffffffffffffe,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff7ffffffffffff,
  0xbff8000000000000,
  0xbff8000000000001,
  0xc000000000000000,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfdffffffffffffe,
  0xbfdffffffffffffe,
  0xbfdffffffffffffe,
  0xbfdffffffffffffe,
  0xbfdffffffffffffe,
  0x3c8fffffffffffff,
  0x3ca0000000000000,
  0x3cb0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000003,
  0x3ff0000000000000,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfdffffffffffffe,
  0xbfdffffffffffffe,
  0xbfdffffffffffffe,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff7ffffffffffff,
  0xbff8000000000000,
  0xbff8000000000001,
  0xc000000000000000,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0x0000000000000000,
  0x3c90000000000000,
  0x3ca8000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000002,
  0x3ff0000000000000,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000001,
  0xc000000000000000,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbc9fffffffffffff,
  0xbc8ffffffffffffe,
  0x3c90000000000001,
  0x3fdffffffffffffd,
  0x3fdfffffffffffff,
  0x3fe0000000000002,
  0x3ff0000000000000,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe7ffffffffffff,
  0xbfe7ffffffffffff,
  0xbff3ffffffffffff,
  0xbff4000000000000,
  0xbff4000000000000,
  0xbffbffffffffffff,
  0xbffc000000000000,
  0xbffc000000000001,
  0xc002000000000000,
  0xc025800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe7ffffffffffff,
  0xbfe7ffffffffffff,
  0xbfe7ffffffffffff,
  0xbfe7ffffffffffff,
  0xbfe7ffffffffffff,
  0xbfcfffffffffffff,
  0xbfcffffffffffffd,
  0xbfcffffffffffff9,
  0x3fcfffffffffffff,
  0x3fd0000000000002,
  0x3fd0000000000006,
  0x3fe8000000000001,
  0x4022800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe7ffffffffffff,
  0xbfe7ffffffffffff,
  0xbfe7ffffffffffff,
  0xc013ffffffffffff,
  0xc013ffffffffffff,
  0xc015ffffffffffff,
  0xc015ffffffffffff,
  0xc016000000000000,
  0xc017ffffffffffff,
  0xc017ffffffffffff,
  0xc018000000000000,
  0xc019ffffffffffff,
  0xc02e000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc013ffffffffffff,
  0xc013ffffffffffff,
  0xc013ffffffffffff,
  0xc013ffffffffffff,
  0xc013ffffffffffff,
  0xc011ffffffffffff,
  0xc011ffffffffffff,
  0xc011ffffffffffff,
  0xc00fffffffffffff,
  0xc00fffffffffffff,
  0xc00ffffffffffffe,
  0xc00bffffffffffff,
  0x4014000000000001,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc013ffffffffffff,
  0xc013ffffffffffff,
  0xc013ffffffffffff,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0x7fe0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x800091a2b3c4d5e6,
  0x801091a2b3c4d5e6,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x8001b4e81b4e81b3,
  0x801091a2b3c4d5e5,
  0x800091a2b3c4d5e7,
  0x800091a2b3c4d5e6,
  0x000f6e5d4c3b2a1a,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000091a2b3c4d5e7,
  0x000f6e5d4c3b2a19,
  0x800091a2b3c4d5e5,
  0x8007ffffffffffff,
  0x8017ffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800923456789abcc,
  0x8017fffffffffffe,
  0x8008000000000000,
  0x8007ffffffffffff,
  0x0008000000000001,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8006dcba98765432,
  0x0008000000000000,
  0x8007fffffffffffe,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0008000000000000,
  0x8008000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0006dcba98765433,
  0x8007ffffffffffff,
  0x0007ffffffffffff,
  0x0008000000000000,
  0x0018000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000923456789abcd,
  0x0017ffffffffffff,
  0x0008000000000001,
  0x3fcfffffffffffff,
  0x3fcfffffffffffff,
  0xbfcfffffffffffff,
  0xbfd0000000000000,
  0xbfd0000000000002,
  0xbfe7ffffffffffff,
  0xbfe8000000000000,
  0xbfe8000000000002,
  0xbff4000000000000,
  0xc023800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fcfffffffffffff,
  0x3fcfffffffffffff,
  0x3fcfffffffffffff,
  0x3fcfffffffffffff,
  0x3fcfffffffffffff,
  0x3fe7ffffffffffff,
  0x3fe8000000000000,
  0x3fe8000000000001,
  0x3ff3ffffffffffff,
  0x3ff4000000000000,
  0x3ff4000000000001,
  0x3ffc000000000000,
  0x4024800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fcfffffffffffff,
  0x3fcfffffffffffff,
  0x3fcfffffffffffff,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0xbfcffffffffffffe,
  0xbfd0000000000000,
  0xbfd0000000000002,
  0xbfe7ffffffffffff,
  0xbfe8000000000000,
  0xbfe8000000000002,
  0xbff4000000000000,
  0xc023800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3fe8000000000001,
  0x3ff4000000000000,
  0x3ff4000000000000,
  0x3ff4000000000001,
  0x3ffc000000000000,
  0x4024800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000001,
  0x3fd0000000000001,
  0xbfcffffffffffffc,
  0xbfcffffffffffffe,
  0xbfd0000000000001,
  0xbfe7fffffffffffe,
  0xbfe8000000000000,
  0xbfe8000000000002,
  0xbff4000000000000,
  0xc023800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fd0000000000001,
  0x3fd0000000000001,
  0x3fd0000000000001,
  0x3fd0000000000001,
  0x3fd0000000000001,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3fe8000000000002,
  0x3ff4000000000000,
  0x3ff4000000000000,
  0x3ff4000000000001,
  0x3ffc000000000000,
  0x4024800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fd0000000000001,
  0x3fd0000000000001,
  0x3fd0000000000001,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x0000000000000000,
  0xbc90000000000000,
  0xbca8000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000002,
  0xbff0000000000000,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff7ffffffffffff,
  0x3ff8000000000000,
  0x3ff8000000000001,
  0x4000000000000000,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3c90000000000000,
  0x0000000000000000,
  0xbca0000000000000,
  0xbfdffffffffffffe,
  0xbfe0000000000000,
  0xbfe0000000000002,
  0xbff0000000000000,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000001,
  0x4000000000000000,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3ca8000000000000,
  0x3ca0000000000000,
  0x0000000000000000,
  0xbfdffffffffffffc,
  0xbfdffffffffffffe,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000002,
  0x4000000000000000,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3fd0000000000001,
  0x3fd0000000000000,
  0x3fcffffffffffffc,
  0xbfcffffffffffffc,
  0xbfd0000000000000,
  0xbfd0000000000004,
  0xbfe8000000000000,
  0xc022800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3ff4000000000000,
  0x3ff4000000000000,
  0x3ff4000000000000,
  0x3ffc000000000000,
  0x3ffc000000000000,
  0x3ffc000000000001,
  0x4002000000000000,
  0x4025800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x4014000000000000,
  0x4014000000000000,
  0x4012000000000000,
  0x4012000000000000,
  0x4012000000000000,
  0x4010000000000000,
  0x4010000000000000,
  0x4010000000000000,
  0x400c000000000000,
  0xc014000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x4014000000000000,
  0x4014000000000000,
  0x4014000000000000,
  0x4014000000000000,
  0x4014000000000000,
  0x4016000000000000,
  0x4016000000000000,
  0x4016000000000000,
  0x4018000000000000,
  0x4018000000000000,
  0x4018000000000000,
  0x401a000000000000,
  0x402e000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x4014000000000000,
  0x4014000000000000,
  0x4014000000000000,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0xffdfffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x000091a2b3c4d5e6,
  0x800f6e5d4c3b2a1a,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800091a2b3c4d5e6,
  0x800f6e5d4c3b2a18,
  0x000091a2b3c4d5e6,
  0x000091a2b3c4d5e6,
  0x001091a2b3c4d5e6,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0001b4e81b4e81b4,
  0x001091a2b3c4d5e6,
  0x000091a2b3c4d5e8,
  0x0008000000000000,
  0x8008000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0006dcba98765432,
  0x8008000000000000,
  0x0007fffffffffffe,
  0x0008000000000000,
  0x0018000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000923456789abcc,
  0x0017fffffffffffe,
  0x0008000000000000,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcc,
  0x800ffffffffffffe,
  0x8000000000000000,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abce,
  0x0010000000000000,
  0x0000000000000002,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8008000000000000,
  0x8018000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800923456789abcd,
  0x8017ffffffffffff,
  0x8008000000000001,
  0x8008000000000000,
  0x0008000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8006dcba98765433,
  0x0007ffffffffffff,
  0x8007ffffffffffff,
  0xbfcfffffffffffff,
  0xbfcfffffffffffff,
  0xbfe7ffffffffffff,
  0xbfe8000000000000,
  0xbfe8000000000001,
  0xbff3ffffffffffff,
  0xbff4000000000000,
  0xbff4000000000001,
  0xbffc000000000000,
  0xc024800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfcfffffffffffff,
  0xbfcfffffffffffff,
  0xbfcfffffffffffff,
  0xbfcfffffffffffff,
  0xbfcfffffffffffff,
  0x3fcfffffffffffff,
  0x3fd0000000000000,
  0x3fd0000000000002,
  0x3fe7ffffffffffff,
  0x3fe8000000000000,
  0x3fe8000000000002,
  0x3ff4000000000000,
  0x4023800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfcfffffffffffff,
  0xbfcfffffffffffff,
  0xbfcfffffffffffff,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbfe8000000000001,
  0xbff4000000000000,
  0xbff4000000000000,
  0xbff4000000000001,
  0xbffc000000000000,
  0xc024800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0x3fcffffffffffffe,
  0x3fd0000000000000,
  0x3fd0000000000002,
  0x3fe7ffffffffffff,
  0x3fe8000000000000,
  0x3fe8000000000002,
  0x3ff4000000000000,
  0x4023800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000001,
  0xbfd0000000000001,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbfe8000000000002,
  0xbff4000000000000,
  0xbff4000000000000,
  0xbff4000000000001,
  0xbffc000000000000,
  0xc024800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfd0000000000001,
  0xbfd0000000000001,
  0xbfd0000000000001,
  0xbfd0000000000001,
  0xbfd0000000000001,
  0x3fcffffffffffffc,
  0x3fcffffffffffffe,
  0x3fd0000000000001,
  0x3fe7fffffffffffe,
  0x3fe8000000000000,
  0x3fe8000000000002,
  0x3ff4000000000000,
  0x4023800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfd0000000000001,
  0xbfd0000000000001,
  0xbfd0000000000001,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff7ffffffffffff,
  0xbff8000000000000,
  0xbff8000000000001,
  0xc000000000000000,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0x0000000000000000,
  0x3c90000000000000,
  0x3ca8000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000002,
  0x3ff0000000000000,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000001,
  0xc000000000000000,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbc90000000000000,
  0x0000000000000000,
  0x3ca0000000000000,
  0x3fdffffffffffffe,
  0x3fe0000000000000,
  0x3fe0000000000002,
  0x3ff0000000000000,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000002,
  0xc000000000000000,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbca8000000000000,
  0xbca0000000000000,
  0x0000000000000000,
  0x3fdffffffffffffc,
  0x3fdffffffffffffe,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbff4000000000000,
  0xbff4000000000000,
  0xbff4000000000000,
  0xbffc000000000000,
  0xbffc000000000000,
  0xbffc000000000001,
  0xc002000000000000,
  0xc025800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbfd0000000000001,
  0xbfd0000000000000,
  0xbfcffffffffffffc,
  0x3fcffffffffffffc,
  0x3fd0000000000000,
  0x3fd0000000000004,
  0x3fe8000000000000,
  0x4022800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xc014000000000000,
  0xc014000000000000,
  0xc016000000000000,
  0xc016000000000000,
  0xc016000000000000,
  0xc018000000000000,
  0xc018000000000000,
  0xc018000000000000,
  0xc01a000000000000,
  0xc02e000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc014000000000000,
  0xc014000000000000,
  0xc014000000000000,
  0xc014000000000000,
  0xc014000000000000,
  0xc012000000000000,
  0xc012000000000000,
  0xc012000000000000,
  0xc010000000000000,
  0xc010000000000000,
  0xc010000000000000,
  0xc00c000000000000,
  0x4014000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc014000000000000,
  0xc014000000000000,
  0xc014000000000000,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0x7fdfffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x800091a2b3c4d5e6,
  0x801091a2b3c4d5e6,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x8001b4e81b4e81b4,
  0x801091a2b3c4d5e6,
  0x800091a2b3c4d5e8,
  0x800091a2b3c4d5e6,
  0x000f6e5d4c3b2a1a,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000091a2b3c4d5e6,
  0x000f6e5d4c3b2a18,
  0x800091a2b3c4d5e6,
  0x8008000000000000,
  0x8018000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800923456789abcc,
  0x8017fffffffffffe,
  0x8008000000000000,
  0x8008000000000000,
  0x0008000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8006dcba98765432,
  0x0008000000000000,
  0x8007fffffffffffe,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abce,
  0x8010000000000000,
  0x8000000000000002,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcc,
  0x000ffffffffffffe,
  0x0000000000000000,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0008000000000000,
  0x8008000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0006dcba98765434,
  0x8007fffffffffffe,
  0x0008000000000000,
  0x0008000000000000,
  0x0018000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000923456789abce,
  0x0018000000000000,
  0x0008000000000002,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0xbfcffffffffffffd,
  0xbfcfffffffffffff,
  0xbfd0000000000002,
  0xbfe7ffffffffffff,
  0xbfe8000000000000,
  0xbfe8000000000002,
  0xbff4000000000000,
  0xc023800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3fe8000000000001,
  0x3ff4000000000000,
  0x3ff4000000000000,
  0x3ff4000000000001,
  0x3ffc000000000000,
  0x4024800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000001,
  0x3fd0000000000001,
  0xbfcffffffffffffc,
  0xbfcffffffffffffe,
  0xbfd0000000000001,
  0xbfe7fffffffffffe,
  0xbfe8000000000000,
  0xbfe8000000000002,
  0xbff4000000000000,
  0xc023800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fd0000000000001,
  0x3fd0000000000001,
  0x3fd0000000000001,
  0x3fd0000000000001,
  0x3fd0000000000001,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3fe8000000000002,
  0x3ff4000000000000,
  0x3ff4000000000000,
  0x3ff4000000000001,
  0x3ffc000000000000,
  0x4024800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fd0000000000001,
  0x3fd0000000000001,
  0x3fd0000000000001,
  0x3fd0000000000002,
  0x3fd0000000000002,
  0xbfcffffffffffffa,
  0xbfcffffffffffffc,
  0xbfd0000000000000,
  0xbfe7fffffffffffe,
  0xbfe7ffffffffffff,
  0xbfe8000000000001,
  0xbff3ffffffffffff,
  0xc023800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fd0000000000002,
  0x3fd0000000000002,
  0x3fd0000000000002,
  0x3fd0000000000002,
  0x3fd0000000000002,
  0x3fe8000000000001,
  0x3fe8000000000001,
  0x3fe8000000000002,
  0x3ff4000000000000,
  0x3ff4000000000001,
  0x3ff4000000000002,
  0x3ffc000000000001,
  0x4024800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fd0000000000002,
  0x3fd0000000000002,
  0x3fd0000000000002,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3c9fffffffffffff,
  0x3c8ffffffffffffe,
  0xbc90000000000001,
  0xbfdffffffffffffd,
  0xbfdfffffffffffff,
  0xbfe0000000000002,
  0xbff0000000000000,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000001,
  0x4000000000000000,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3ca8000000000000,
  0x3ca0000000000000,
  0x0000000000000000,
  0xbfdffffffffffffc,
  0xbfdffffffffffffe,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000002,
  0x4000000000000000,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000002,
  0x3fe0000000000002,
  0x3cb4000000000000,
  0x3cb0000000000000,
  0x3ca0000000000001,
  0xbfdffffffffffffa,
  0xbfdffffffffffffc,
  0xbfe0000000000000,
  0xbfeffffffffffffe,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe0000000000002,
  0x3fe0000000000002,
  0x3fe0000000000002,
  0x3fe0000000000002,
  0x3fe0000000000002,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000002,
  0x3ff8000000000001,
  0x3ff8000000000001,
  0x3ff8000000000002,
  0x4000000000000001,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe0000000000002,
  0x3fe0000000000002,
  0x3fe0000000000002,
  0x3fe8000000000002,
  0x3fe8000000000001,
  0x3fd0000000000004,
  0x3fd0000000000003,
  0x3fd0000000000001,
  0xbfcffffffffffff6,
  0xbfcffffffffffffa,
  0xbfd0000000000001,
  0xbfe7fffffffffffe,
  0xc022800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe8000000000001,
  0x3fe8000000000001,
  0x3fe8000000000001,
  0x3fe8000000000002,
  0x3fe8000000000002,
  0x3ff4000000000000,
  0x3ff4000000000001,
  0x3ff4000000000001,
  0x3ffc000000000000,
  0x3ffc000000000001,
  0x3ffc000000000002,
  0x4002000000000000,
  0x4025800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe8000000000002,
  0x3fe8000000000002,
  0x3fe8000000000002,
  0x4014000000000001,
  0x4014000000000001,
  0x4012000000000001,
  0x4012000000000001,
  0x4012000000000001,
  0x4010000000000001,
  0x4010000000000001,
  0x4010000000000001,
  0x400c000000000002,
  0xc013ffffffffffff,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x4014000000000001,
  0x4014000000000001,
  0x4014000000000001,
  0x4014000000000001,
  0x4014000000000001,
  0x4016000000000001,
  0x4016000000000001,
  0x4016000000000001,
  0x4018000000000001,
  0x4018000000000001,
  0x4018000000000002,
  0x401a000000000001,
  0x402e000000000001,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x4014000000000001,
  0x4014000000000001,
  0x4014000000000001,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0xffdffffffffffffd,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x000091a2b3c4d5e7,
  0x800f6e5d4c3b2a19,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800091a2b3c4d5e6,
  0x800f6e5d4c3b2a18,
  0x000091a2b3c4d5e6,
  0x000091a2b3c4d5e7,
  0x001091a2b3c4d5e7,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0001b4e81b4e81b4,
  0x001091a2b3c4d5e6,
  0x000091a2b3c4d5e8,
  0x0008000000000000,
  0x8008000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0006dcba98765433,
  0x8007ffffffffffff,
  0x0007ffffffffffff,
  0x0008000000000000,
  0x0018000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000923456789abcd,
  0x0017ffffffffffff,
  0x0008000000000001,
  0x0000000000000001,
  0x800fffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcc,
  0x800ffffffffffffe,
  0x8000000000000000,
  0x0000000000000001,
  0x0010000000000001,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abce,
  0x0010000000000000,
  0x0000000000000002,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8008000000000000,
  0x8018000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800923456789abce,
  0x8018000000000000,
  0x8008000000000002,
  0x8008000000000000,
  0x0008000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8006dcba98765434,
  0x0007fffffffffffe,
  0x8008000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbfe8000000000001,
  0xbff4000000000000,
  0xbff4000000000000,
  0xbff4000000000001,
  0xbffc000000000000,
  0xc024800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0x3fcffffffffffffd,
  0x3fcfffffffffffff,
  0x3fd0000000000002,
  0x3fe7ffffffffffff,
  0x3fe8000000000000,
  0x3fe8000000000002,
  0x3ff4000000000000,
  0x4023800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000001,
  0xbfd0000000000001,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbfe8000000000002,
  0xbff4000000000000,
  0xbff4000000000000,
  0xbff4000000000001,
  0xbffc000000000000,
  0xc024800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfd0000000000001,
  0xbfd0000000000001,
  0xbfd0000000000001,
  0xbfd0000000000001,
  0xbfd0000000000001,
  0x3fcffffffffffffc,
  0x3fcffffffffffffe,
  0x3fd0000000000001,
  0x3fe7fffffffffffe,
  0x3fe8000000000000,
  0x3fe8000000000002,
  0x3ff4000000000000,
  0x4023800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfd0000000000001,
  0xbfd0000000000001,
  0xbfd0000000000001,
  0xbfd0000000000002,
  0xbfd0000000000002,
  0xbfe8000000000001,
  0xbfe8000000000001,
  0xbfe8000000000002,
  0xbff4000000000000,
  0xbff4000000000001,
  0xbff4000000000002,
  0xbffc000000000001,
  0xc024800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfd0000000000002,
  0xbfd0000000000002,
  0xbfd0000000000002,
  0xbfd0000000000002,
  0xbfd0000000000002,
  0x3fcffffffffffffa,
  0x3fcffffffffffffc,
  0x3fd0000000000000,
  0x3fe7fffffffffffe,
  0x3fe7ffffffffffff,
  0x3fe8000000000001,
  0x3ff3ffffffffffff,
  0x4023800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfd0000000000002,
  0xbfd0000000000002,
  0xbfd0000000000002,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000001,
  0xc000000000000000,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbc9fffffffffffff,
  0xbc8ffffffffffffe,
  0x3c90000000000001,
  0x3fdffffffffffffd,
  0x3fdfffffffffffff,
  0x3fe0000000000002,
  0x3ff0000000000000,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000002,
  0xc000000000000000,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbca8000000000000,
  0xbca0000000000000,
  0x0000000000000000,
  0x3fdffffffffffffc,
  0x3fdffffffffffffe,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000002,
  0xbfe0000000000002,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000002,
  0xbff8000000000001,
  0xbff8000000000001,
  0xbff8000000000002,
  0xc000000000000001,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe0000000000002,
  0xbfe0000000000002,
  0xbfe0000000000002,
  0xbfe0000000000002,
  0xbfe0000000000002,
  0xbcb4000000000000,
  0xbcb0000000000000,
  0xbca0000000000001,
  0x3fdffffffffffffa,
  0x3fdffffffffffffc,
  0x3fe0000000000000,
  0x3feffffffffffffe,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe0000000000002,
  0xbfe0000000000002,
  0xbfe0000000000002,
  0xbfe8000000000002,
  0xbfe8000000000002,
  0xbff4000000000000,
  0xbff4000000000001,
  0xbff4000000000001,
  0xbffc000000000000,
  0xbffc000000000001,
  0xbffc000000000002,
  0xc002000000000000,
  0xc025800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe8000000000002,
  0xbfe8000000000002,
  0xbfe8000000000002,
  0xbfe8000000000002,
  0xbfe8000000000001,
  0xbfd0000000000004,
  0xbfd0000000000003,
  0xbfd0000000000001,
  0x3fcffffffffffff6,
  0x3fcffffffffffffa,
  0x3fd0000000000001,
  0x3fe7fffffffffffe,
  0x4022800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe8000000000001,
  0xbfe8000000000001,
  0xbfe8000000000001,
  0xc014000000000001,
  0xc014000000000001,
  0xc016000000000001,
  0xc016000000000001,
  0xc016000000000001,
  0xc018000000000001,
  0xc018000000000001,
  0xc018000000000002,
  0xc01a000000000001,
  0xc02e000000000001,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc014000000000001,
  0xc014000000000001,
  0xc014000000000001,
  0xc014000000000001,
  0xc014000000000001,
  0xc012000000000001,
  0xc012000000000001,
  0xc012000000000001,
  0xc010000000000001,
  0xc010000000000001,
  0xc010000000000001,
  0xc00c000000000002,
  0x4013ffffffffffff,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc014000000000001,
  0xc014000000000001,
  0xc014000000000001,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0x7fdffffffffffffd,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x800091a2b3c4d5e7,
  0x801091a2b3c4d5e7,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x8001b4e81b4e81b4,
  0x801091a2b3c4d5e6,
  0x800091a2b3c4d5e8,
  0x800091a2b3c4d5e7,
  0x000f6e5d4c3b2a19,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000091a2b3c4d5e6,
  0x000f6e5d4c3b2a18,
  0x800091a2b3c4d5e6,
  0x8008000000000000,
  0x8018000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800923456789abcd,
  0x8017ffffffffffff,
  0x8008000000000001,
  0x8008000000000000,
  0x0008000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8006dcba98765433,
  0x0007ffffffffffff,
  0x8007ffffffffffff,
  0x8000000000000001,
  0x8010000000000001,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abce,
  0x8010000000000000,
  0x8000000000000002,
  0x8000000000000001,
  0x000fffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcc,
  0x000ffffffffffffe,
  0x0000000000000000,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0010000000000000,
  0x8000000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x000edcba98765432,
  0x0000000000000000,
  0x000ffffffffffffe,
  0x0010000000000000,
  0x0020000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x001123456789abcc,
  0x001ffffffffffffe,
  0x0010000000000000,
  0x3fdffffffffffffe,
  0x3fdffffffffffffe,
  0xbc8fffffffffffff,
  0xbca0000000000000,
  0xbcb0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000003,
  0xbff0000000000000,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fdffffffffffffe,
  0x3fdffffffffffffe,
  0x3fdffffffffffffe,
  0x3fdffffffffffffe,
  0x3fdffffffffffffe,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff7ffffffffffff,
  0x3ff8000000000000,
  0x3ff8000000000001,
  0x4000000000000000,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fdffffffffffffe,
  0x3fdffffffffffffe,
  0x3fdffffffffffffe,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x0000000000000000,
  0xbc90000000000000,
  0xbca8000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000002,
  0xbff0000000000000,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff7ffffffffffff,
  0x3ff8000000000000,
  0x3ff8000000000001,
  0x4000000000000000,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3c9fffffffffffff,
  0x3c8ffffffffffffe,
  0xbc90000000000001,
  0xbfdffffffffffffd,
  0xbfdfffffffffffff,
  0xbfe0000000000002,
  0xbff0000000000000,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000001,
  0x4000000000000000,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3feffffffffffffe,
  0x3feffffffffffffe,
  0x3fdffffffffffffd,
  0x3fdffffffffffffc,
  0x3fdffffffffffffa,
  0xbc9fffffffffffff,
  0xbcb0000000000000,
  0xbcc0000000000000,
  0xbfe0000000000002,
  0xc022000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3feffffffffffffe,
  0x3feffffffffffffe,
  0x3feffffffffffffe,
  0x3feffffffffffffe,
  0x3feffffffffffffe,
  0x3ff7ffffffffffff,
  0x3ff7ffffffffffff,
  0x3ff8000000000000,
  0x3fffffffffffffff,
  0x3fffffffffffffff,
  0x4000000000000000,
  0x4004000000000000,
  0x4026000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3feffffffffffffe,
  0x3feffffffffffffe,
  0x3feffffffffffffe,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fdfffffffffffff,
  0x3fdffffffffffffe,
  0x3fdffffffffffffc,
  0x0000000000000000,
  0xbca0000000000000,
  0xbcb8000000000000,
  0xbfe0000000000001,
  0xc022000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3ff7ffffffffffff,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3fffffffffffffff,
  0x4000000000000000,
  0x4000000000000000,
  0x4004000000000000,
  0x4026000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000000,
  0x3cafffffffffffff,
  0x3c9ffffffffffffe,
  0xbca0000000000001,
  0xbfdffffffffffffe,
  0xc022000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000001,
  0x4000000000000000,
  0x4000000000000000,
  0x4000000000000001,
  0x4004000000000000,
  0x4026000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff7ffffffffffff,
  0x3ff7ffffffffffff,
  0x3fefffffffffffff,
  0x3feffffffffffffe,
  0x3feffffffffffffe,
  0x3fdfffffffffffff,
  0x3fdffffffffffffd,
  0x3fdffffffffffff9,
  0xbca8000000000000,
  0xc021000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3ff7ffffffffffff,
  0x3ff7ffffffffffff,
  0x3ff7ffffffffffff,
  0x3ff7ffffffffffff,
  0x3ff7ffffffffffff,
  0x3fffffffffffffff,
  0x3fffffffffffffff,
  0x4000000000000000,
  0x4003ffffffffffff,
  0x4004000000000000,
  0x4004000000000000,
  0x4008000000000000,
  0x4027000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3ff7ffffffffffff,
  0x3ff7ffffffffffff,
  0x3ff7ffffffffffff,
  0x4023ffffffffffff,
  0x4023ffffffffffff,
  0x4022ffffffffffff,
  0x4022ffffffffffff,
  0x4022ffffffffffff,
  0x4021ffffffffffff,
  0x4021ffffffffffff,
  0x4021ffffffffffff,
  0x4020ffffffffffff,
  0xbcd4000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x4023ffffffffffff,
  0x4023ffffffffffff,
  0x4023ffffffffffff,
  0x4023ffffffffffff,
  0x4023ffffffffffff,
  0x4024ffffffffffff,
  0x4024ffffffffffff,
  0x4024ffffffffffff,
  0x4025ffffffffffff,
  0x4025ffffffffffff,
  0x4026000000000000,
  0x4026ffffffffffff,
  0x4034000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x4023ffffffffffff,
  0x4023ffffffffffff,
  0x4023ffffffffffff,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0xfc9fffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x800edcba98765433,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x8000000000000000,
  0x800edcba98765432,
  0x000123456789abcc,
  0x000123456789abcd,
  0x001123456789abcd,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0002468acf13579a,
  0x001123456789abcc,
  0x000123456789abce,
  0x000fffffffffffff,
  0x8000000000000001,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x000edcba98765432,
  0x8000000000000000,
  0x000ffffffffffffe,
  0x000fffffffffffff,
  0x001fffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x001123456789abcc,
  0x001ffffffffffffe,
  0x0010000000000000,
  0x0000000000000001,
  0x800fffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcc,
  0x800ffffffffffffe,
  0x8000000000000000,
  0x0000000000000001,
  0x0010000000000001,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abce,
  0x0010000000000000,
  0x0000000000000002,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8010000000000000,
  0x8020000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x801123456789abcc,
  0x801ffffffffffffe,
  0x8010000000000000,
  0x8010000000000000,
  0x0000000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x800edcba98765432,
  0x8000000000000000,
  0x800ffffffffffffe,
  0xbfdffffffffffffe,
  0xbfdffffffffffffe,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff7ffffffffffff,
  0xbff8000000000000,
  0xbff8000000000001,
  0xc000000000000000,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfdffffffffffffe,
  0xbfdffffffffffffe,
  0xbfdffffffffffffe,
  0xbfdffffffffffffe,
  0xbfdffffffffffffe,
  0x3c8fffffffffffff,
  0x3ca0000000000000,
  0x3cb0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000003,
  0x3ff0000000000000,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfdffffffffffffe,
  0xbfdffffffffffffe,
  0xbfdffffffffffffe,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff7ffffffffffff,
  0xbff8000000000000,
  0xbff8000000000001,
  0xc000000000000000,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0x0000000000000000,
  0x3c90000000000000,
  0x3ca8000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000002,
  0x3ff0000000000000,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000001,
  0xc000000000000000,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbc9fffffffffffff,
  0xbc8ffffffffffffe,
  0x3c90000000000001,
  0x3fdffffffffffffd,
  0x3fdfffffffffffff,
  0x3fe0000000000002,
  0x3ff0000000000000,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfeffffffffffffe,
  0xbfeffffffffffffe,
  0xbff7ffffffffffff,
  0xbff7ffffffffffff,
  0xbff8000000000000,
  0xbfffffffffffffff,
  0xbfffffffffffffff,
  0xc000000000000000,
  0xc004000000000000,
  0xc026000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfeffffffffffffe,
  0xbfeffffffffffffe,
  0xbfeffffffffffffe,
  0xbfeffffffffffffe,
  0xbfeffffffffffffe,
  0xbfdffffffffffffd,
  0xbfdffffffffffffc,
  0xbfdffffffffffffa,
  0x3c9fffffffffffff,
  0x3cb0000000000000,
  0x3cc0000000000000,
  0x3fe0000000000002,
  0x4022000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfeffffffffffffe,
  0xbfeffffffffffffe,
  0xbfeffffffffffffe,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbff7ffffffffffff,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbfffffffffffffff,
  0xc000000000000000,
  0xc000000000000000,
  0xc004000000000000,
  0xc026000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfdfffffffffffff,
  0xbfdffffffffffffe,
  0xbfdffffffffffffc,
  0x0000000000000000,
  0x3ca0000000000000,
  0x3cb8000000000000,
  0x3fe0000000000001,
  0x4022000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000001,
  0xc000000000000000,
  0xc000000000000000,
  0xc000000000000001,
  0xc004000000000000,
  0xc026000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000000,
  0xbcafffffffffffff,
  0xbc9ffffffffffffe,
  0x3ca0000000000001,
  0x3fdffffffffffffe,
  0x4022000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff7ffffffffffff,
  0xbff7ffffffffffff,
  0xbfffffffffffffff,
  0xbfffffffffffffff,
  0xc000000000000000,
  0xc003ffffffffffff,
  0xc004000000000000,
  0xc004000000000000,
  0xc008000000000000,
  0xc027000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbff7ffffffffffff,
  0xbff7ffffffffffff,
  0xbff7ffffffffffff,
  0xbff7ffffffffffff,
  0xbff7ffffffffffff,
  0xbfefffffffffffff,
  0xbfeffffffffffffe,
  0xbfeffffffffffffe,
  0xbfdfffffffffffff,
  0xbfdffffffffffffd,
  0xbfdffffffffffff9,
  0x3ca8000000000000,
  0x4021000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbff7ffffffffffff,
  0xbff7ffffffffffff,
  0xbff7ffffffffffff,
  0xc023ffffffffffff,
  0xc023ffffffffffff,
  0xc024ffffffffffff,
  0xc024ffffffffffff,
  0xc024ffffffffffff,
  0xc025ffffffffffff,
  0xc025ffffffffffff,
  0xc026000000000000,
  0xc026ffffffffffff,
  0xc034000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc023ffffffffffff,
  0xc023ffffffffffff,
  0xc023ffffffffffff,
  0xc023ffffffffffff,
  0xc023ffffffffffff,
  0xc022ffffffffffff,
  0xc022ffffffffffff,
  0xc022ffffffffffff,
  0xc021ffffffffffff,
  0xc021ffffffffffff,
  0xc021ffffffffffff,
  0xc020ffffffffffff,
  0x3cd4000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc023ffffffffffff,
  0xc023ffffffffffff,
  0xc023ffffffffffff,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0x7c9fffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x800123456789abcd,
  0x801123456789abcd,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x8002468acf13579a,
  0x801123456789abcc,
  0x800123456789abce,
  0x800123456789abcd,
  0x000edcba98765433,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0000000000000000,
  0x000edcba98765432,
  0x800123456789abcc,
  0x800fffffffffffff,
  0x801fffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x801123456789abcc,
  0x801ffffffffffffe,
  0x8010000000000000,
  0x800fffffffffffff,
  0x0000000000000001,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x800edcba98765432,
  0x0000000000000000,
  0x800ffffffffffffe,
  0x8000000000000001,
  0x8010000000000001,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abce,
  0x8010000000000000,
  0x8000000000000002,
  0x8000000000000001,
  0x000fffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcc,
  0x000ffffffffffffe,
  0x0000000000000000,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0010000000000000,
  0x0000000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x000edcba98765433,
  0x0000000000000001,
  0x000fffffffffffff,
  0x0010000000000000,
  0x0020000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x001123456789abcd,
  0x001fffffffffffff,
  0x0010000000000001,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x0000000000000000,
  0xbc90000000000000,
  0xbca8000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000002,
  0xbff0000000000000,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff7ffffffffffff,
  0x3ff8000000000000,
  0x3ff8000000000001,
  0x4000000000000000,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3c90000000000000,
  0x0000000000000000,
  0xbca0000000000000,
  0xbfdffffffffffffe,
  0xbfe0000000000000,
  0xbfe0000000000002,
  0xbff0000000000000,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000001,
  0x4000000000000000,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3ca8000000000000,
  0x3ca0000000000000,
  0x0000000000000000,
  0xbfdffffffffffffc,
  0xbfdffffffffffffe,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000002,
  0x4000000000000000,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fdfffffffffffff,
  0x3fdffffffffffffe,
  0x3fdffffffffffffc,
  0x0000000000000000,
  0xbca0000000000000,
  0xbcb8000000000000,
  0xbfe0000000000001,
  0xc022000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3ff7ffffffffffff,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3fffffffffffffff,
  0x4000000000000000,
  0x4000000000000000,
  0x4004000000000000,
  0x4026000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fdffffffffffffe,
  0x3ca0000000000000,
  0x0000000000000000,
  0xbcb0000000000000,
  0xbfe0000000000000,
  0xc022000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x4000000000000000,
  0x4000000000000000,
  0x4000000000000000,
  0x4004000000000000,
  0x4026000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3fe0000000000002,
  0x3fe0000000000002,
  0x3fe0000000000001,
  0x3cb8000000000000,
  0x3cb0000000000000,
  0x0000000000000000,
  0xbfdffffffffffffc,
  0xc022000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff8000000000001,
  0x3ff8000000000001,
  0x3ff8000000000002,
  0x4000000000000000,
  0x4000000000000000,
  0x4000000000000001,
  0x4004000000000000,
  0x4026000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3fefffffffffffff,
  0x3fe0000000000001,
  0x3fe0000000000000,
  0x3fdffffffffffffc,
  0x0000000000000000,
  0xc021000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x4000000000000000,
  0x4000000000000000,
  0x4000000000000000,
  0x4004000000000000,
  0x4004000000000000,
  0x4004000000000000,
  0x4008000000000000,
  0x4027000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4023000000000000,
  0x4023000000000000,
  0x4023000000000000,
  0x4022000000000000,
  0x4022000000000000,
  0x4022000000000000,
  0x4021000000000000,
  0x0000000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4025000000000000,
  0x4025000000000000,
  0x4025000000000000,
  0x4026000000000000,
  0x4026000000000000,
  0x4026000000000000,
  0x4027000000000000,
  0x4034000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x0000000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x800edcba98765433,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0000000000000000,
  0x800edcba98765432,
  0x000123456789abcc,
  0x000123456789abcd,
  0x001123456789abcd,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0002468acf13579a,
  0x001123456789abcc,
  0x000123456789abce,
  0x000fffffffffffff,
  0x8000000000000001,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x000edcba98765432,
  0x0000000000000000,
  0x000ffffffffffffe,
  0x000fffffffffffff,
  0x001fffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x001123456789abcc,
  0x001ffffffffffffe,
  0x0010000000000000,
  0x0000000000000001,
  0x800fffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcc,
  0x800ffffffffffffe,
  0x0000000000000000,
  0x0000000000000001,
  0x0010000000000001,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abce,
  0x0010000000000000,
  0x0000000000000002,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8010000000000000,
  0x8020000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x801123456789abcd,
  0x801fffffffffffff,
  0x8010000000000001,
  0x8010000000000000,
  0x0000000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x800edcba98765433,
  0x8000000000000001,
  0x800fffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff7ffffffffffff,
  0xbff8000000000000,
  0xbff8000000000001,
  0xc000000000000000,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0x0000000000000000,
  0x3c90000000000000,
  0x3ca8000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000002,
  0x3ff0000000000000,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000001,
  0xc000000000000000,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbc90000000000000,
  0x0000000000000000,
  0x3ca0000000000000,
  0x3fdffffffffffffe,
  0x3fe0000000000000,
  0x3fe0000000000002,
  0x3ff0000000000000,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000002,
  0xc000000000000000,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbca8000000000000,
  0xbca0000000000000,
  0x0000000000000000,
  0x3fdffffffffffffc,
  0x3fdffffffffffffe,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbff7ffffffffffff,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbfffffffffffffff,
  0xc000000000000000,
  0xc000000000000000,
  0xc004000000000000,
  0xc026000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfdfffffffffffff,
  0xbfdffffffffffffe,
  0xbfdffffffffffffc,
  0x0000000000000000,
  0x3ca0000000000000,
  0x3cb8000000000000,
  0x3fe0000000000001,
  0x4022000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xc000000000000000,
  0xc000000000000000,
  0xc000000000000000,
  0xc004000000000000,
  0xc026000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfdffffffffffffe,
  0xbca0000000000000,
  0x0000000000000000,
  0x3cb0000000000000,
  0x3fe0000000000000,
  0x4022000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff8000000000001,
  0xbff8000000000001,
  0xbff8000000000002,
  0xc000000000000000,
  0xc000000000000000,
  0xc000000000000001,
  0xc004000000000000,
  0xc026000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbfe0000000000002,
  0xbfe0000000000002,
  0xbfe0000000000001,
  0xbcb8000000000000,
  0xbcb0000000000000,
  0x0000000000000000,
  0x3fdffffffffffffc,
  0x4022000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff8000000000000,
  0xbff8000000000000,
  0xc000000000000000,
  0xc000000000000000,
  0xc000000000000000,
  0xc004000000000000,
  0xc004000000000000,
  0xc004000000000000,
  0xc008000000000000,
  0xc027000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbfefffffffffffff,
  0xbfe0000000000001,
  0xbfe0000000000000,
  0xbfdffffffffffffc,
  0x0000000000000000,
  0x4021000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc025000000000000,
  0xc025000000000000,
  0xc025000000000000,
  0xc026000000000000,
  0xc026000000000000,
  0xc026000000000000,
  0xc027000000000000,
  0xc034000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc023000000000000,
  0xc023000000000000,
  0xc023000000000000,
  0xc022000000000000,
  0xc022000000000000,
  0xc022000000000000,
  0xc021000000000000,
  0x0000000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0x0000000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x800123456789abcd,
  0x801123456789abcd,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x8002468acf13579a,
  0x801123456789abcc,
  0x800123456789abce,
  0x800123456789abcd,
  0x000edcba98765433,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0000000000000000,
  0x000edcba98765432,
  0x800123456789abcc,
  0x800fffffffffffff,
  0x801fffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x801123456789abcc,
  0x801ffffffffffffe,
  0x8010000000000000,
  0x800fffffffffffff,
  0x0000000000000001,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x800edcba98765432,
  0x0000000000000000,
  0x800ffffffffffffe,
  0x8000000000000001,
  0x8010000000000001,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abce,
  0x8010000000000000,
  0x8000000000000002,
  0x8000000000000001,
  0x000fffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcc,
  0x000ffffffffffffe,
  0x0000000000000000,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0010000000000001,
  0x0000000000000001,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x000edcba98765434,
  0x0000000000000002,
  0x0010000000000000,
  0x0010000000000001,
  0x0020000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x001123456789abce,
  0x0020000000000000,
  0x0010000000000002,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3c9fffffffffffff,
  0x3c8ffffffffffffe,
  0xbc90000000000001,
  0xbfdffffffffffffd,
  0xbfdfffffffffffff,
  0xbfe0000000000002,
  0xbff0000000000000,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000001,
  0x4000000000000000,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3ca8000000000000,
  0x3ca0000000000000,
  0x0000000000000000,
  0xbfdffffffffffffc,
  0xbfdffffffffffffe,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000002,
  0x4000000000000000,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000002,
  0x3fe0000000000002,
  0x3cb4000000000000,
  0x3cb0000000000000,
  0x3ca0000000000001,
  0xbfdffffffffffffa,
  0xbfdffffffffffffc,
  0xbfe0000000000000,
  0xbfeffffffffffffe,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe0000000000002,
  0x3fe0000000000002,
  0x3fe0000000000002,
  0x3fe0000000000002,
  0x3fe0000000000002,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000002,
  0x3ff8000000000001,
  0x3ff8000000000001,
  0x3ff8000000000002,
  0x4000000000000001,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe0000000000002,
  0x3fe0000000000002,
  0x3fe0000000000002,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000000,
  0x3cafffffffffffff,
  0x3c9ffffffffffffe,
  0xbca0000000000001,
  0xbfdffffffffffffe,
  0xc022000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000001,
  0x4000000000000000,
  0x4000000000000000,
  0x4000000000000001,
  0x4004000000000000,
  0x4026000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3fe0000000000002,
  0x3fe0000000000002,
  0x3fe0000000000001,
  0x3cb8000000000000,
  0x3cb0000000000000,
  0x0000000000000000,
  0xbfdffffffffffffc,
  0xc022000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff8000000000001,
  0x3ff8000000000001,
  0x3ff8000000000002,
  0x4000000000000000,
  0x4000000000000000,
  0x4000000000000001,
  0x4004000000000000,
  0x4026000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000002,
  0x3ff0000000000002,
  0x3fe0000000000005,
  0x3fe0000000000004,
  0x3fe0000000000003,
  0x3cc4000000000000,
  0x3cc0000000000000,
  0x3cb0000000000001,
  0xbfdffffffffffff8,
  0xc022000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3ff0000000000002,
  0x3ff0000000000002,
  0x3ff0000000000002,
  0x3ff0000000000002,
  0x3ff0000000000002,
  0x3ff8000000000002,
  0x3ff8000000000002,
  0x3ff8000000000003,
  0x4000000000000001,
  0x4000000000000001,
  0x4000000000000002,
  0x4004000000000001,
  0x4026000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3ff0000000000002,
  0x3ff0000000000002,
  0x3ff0000000000002,
  0x3ff8000000000002,
  0x3ff8000000000001,
  0x3ff0000000000002,
  0x3ff0000000000002,
  0x3ff0000000000001,
  0x3fe0000000000004,
  0x3fe0000000000003,
  0x3fe0000000000001,
  0x3cb8000000000000,
  0xc021000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3ff8000000000001,
  0x3ff8000000000001,
  0x3ff8000000000001,
  0x3ff8000000000002,
  0x3ff8000000000002,
  0x4000000000000001,
  0x4000000000000001,
  0x4000000000000001,
  0x4004000000000000,
  0x4004000000000001,
  0x4004000000000001,
  0x4008000000000001,
  0x4027000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3ff8000000000002,
  0x3ff8000000000002,
  0x3ff8000000000002,
  0x4024000000000001,
  0x4024000000000001,
  0x4023000000000001,
  0x4023000000000001,
  0x4023000000000001,
  0x4022000000000001,
  0x4022000000000001,
  0x4022000000000001,
  0x4021000000000001,
  0x3ce4000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x4024000000000001,
  0x4024000000000001,
  0x4024000000000001,
  0x4024000000000001,
  0x4024000000000001,
  0x4025000000000001,
  0x4025000000000001,
  0x4025000000000001,
  0x4026000000000001,
  0x4026000000000001,
  0x4026000000000001,
  0x4027000000000001,
  0x4034000000000001,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x4024000000000001,
  0x4024000000000001,
  0x4024000000000001,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7cafffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x800edcba98765433,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0000000000000000,
  0x800edcba98765432,
  0x000123456789abcc,
  0x000123456789abcd,
  0x001123456789abcd,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0002468acf13579a,
  0x001123456789abcc,
  0x000123456789abce,
  0x0010000000000000,
  0x8000000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x000edcba98765433,
  0x0000000000000001,
  0x000fffffffffffff,
  0x0010000000000000,
  0x0020000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x001123456789abcd,
  0x001fffffffffffff,
  0x0010000000000001,
  0x0000000000000001,
  0x800fffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcc,
  0x800ffffffffffffe,
  0x0000000000000000,
  0x0000000000000001,
  0x0010000000000001,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abce,
  0x0010000000000000,
  0x0000000000000002,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8010000000000001,
  0x8020000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x801123456789abce,
  0x8020000000000000,
  0x8010000000000002,
  0x8010000000000001,
  0x8000000000000001,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x800edcba98765434,
  0x8000000000000002,
  0x8010000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000001,
  0xc000000000000000,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbc9fffffffffffff,
  0xbc8ffffffffffffe,
  0x3c90000000000001,
  0x3fdffffffffffffd,
  0x3fdfffffffffffff,
  0x3fe0000000000002,
  0x3ff0000000000000,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000002,
  0xc000000000000000,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbca8000000000000,
  0xbca0000000000000,
  0x0000000000000000,
  0x3fdffffffffffffc,
  0x3fdffffffffffffe,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000002,
  0xbfe0000000000002,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000002,
  0xbff8000000000001,
  0xbff8000000000001,
  0xbff8000000000002,
  0xc000000000000001,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe0000000000002,
  0xbfe0000000000002,
  0xbfe0000000000002,
  0xbfe0000000000002,
  0xbfe0000000000002,
  0xbcb4000000000000,
  0xbcb0000000000000,
  0xbca0000000000001,
  0x3fdffffffffffffa,
  0x3fdffffffffffffc,
  0x3fe0000000000000,
  0x3feffffffffffffe,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe0000000000002,
  0xbfe0000000000002,
  0xbfe0000000000002,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000001,
  0xc000000000000000,
  0xc000000000000000,
  0xc000000000000001,
  0xc004000000000000,
  0xc026000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000000,
  0xbcafffffffffffff,
  0xbc9ffffffffffffe,
  0x3ca0000000000001,
  0x3fdffffffffffffe,
  0x4022000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff8000000000001,
  0xbff8000000000001,
  0xbff8000000000002,
  0xc000000000000000,
  0xc000000000000000,
  0xc000000000000001,
  0xc004000000000000,
  0xc026000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbfe0000000000002,
  0xbfe0000000000002,
  0xbfe0000000000001,
  0xbcb8000000000000,
  0xbcb0000000000000,
  0x0000000000000000,
  0x3fdffffffffffffc,
  0x4022000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000002,
  0xbff0000000000002,
  0xbff8000000000002,
  0xbff8000000000002,
  0xbff8000000000003,
  0xc000000000000001,
  0xc000000000000001,
  0xc000000000000002,
  0xc004000000000001,
  0xc026000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbff0000000000002,
  0xbff0000000000002,
  0xbff0000000000002,
  0xbff0000000000002,
  0xbff0000000000002,
  0xbfe0000000000005,
  0xbfe0000000000004,
  0xbfe0000000000003,
  0xbcc4000000000000,
  0xbcc0000000000000,
  0xbcb0000000000001,
  0x3fdffffffffffff8,
  0x4022000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbff0000000000002,
  0xbff0000000000002,
  0xbff0000000000002,
  0xbff8000000000002,
  0xbff8000000000002,
  0xc000000000000001,
  0xc000000000000001,
  0xc000000000000001,
  0xc004000000000000,
  0xc004000000000001,
  0xc004000000000001,
  0xc008000000000001,
  0xc027000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbff8000000000002,
  0xbff8000000000002,
  0xbff8000000000002,
  0xbff8000000000002,
  0xbff8000000000001,
  0xbff0000000000002,
  0xbff0000000000002,
  0xbff0000000000001,
  0xbfe0000000000004,
  0xbfe0000000000003,
  0xbfe0000000000001,
  0xbcb8000000000000,
  0x4021000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbff8000000000001,
  0xbff8000000000001,
  0xbff8000000000001,
  0xc024000000000001,
  0xc024000000000001,
  0xc025000000000001,
  0xc025000000000001,
  0xc025000000000001,
  0xc026000000000001,
  0xc026000000000001,
  0xc026000000000001,
  0xc027000000000001,
  0xc034000000000001,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc024000000000001,
  0xc024000000000001,
  0xc024000000000001,
  0xc024000000000001,
  0xc024000000000001,
  0xc023000000000001,
  0xc023000000000001,
  0xc023000000000001,
  0xc022000000000001,
  0xc022000000000001,
  0xc022000000000001,
  0xc021000000000001,
  0xbce4000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc024000000000001,
  0xc024000000000001,
  0xc024000000000001,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfcafffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x800123456789abcd,
  0x801123456789abcd,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x8002468acf13579a,
  0x801123456789abcc,
  0x800123456789abce,
  0x800123456789abcd,
  0x000edcba98765433,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8000000000000000,
  0x000edcba98765432,
  0x800123456789abcc,
  0x8010000000000000,
  0x8020000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x801123456789abcd,
  0x801fffffffffffff,
  0x8010000000000001,
  0x8010000000000000,
  0x0000000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x800edcba98765433,
  0x8000000000000001,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8010000000000001,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abce,
  0x8010000000000000,
  0x8000000000000002,
  0x8000000000000001,
  0x000fffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcc,
  0x000ffffffffffffe,
  0x8000000000000000,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0018000000000000,
  0x0008000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0016dcba98765433,
  0x0008000000000001,
  0x0017ffffffffffff,
  0x0018000000000000,
  0x0024000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x001923456789abcd,
  0x0024000000000000,
  0x0018000000000001,
  0x3fe7ffffffffffff,
  0x3fe7ffffffffffff,
  0x3fcfffffffffffff,
  0x3fcffffffffffffd,
  0x3fcffffffffffff9,
  0xbfcfffffffffffff,
  0xbfd0000000000002,
  0xbfd0000000000006,
  0xbfe8000000000001,
  0xc022800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe7ffffffffffff,
  0x3fe7ffffffffffff,
  0x3fe7ffffffffffff,
  0x3fe7ffffffffffff,
  0x3fe7ffffffffffff,
  0x3ff3ffffffffffff,
  0x3ff4000000000000,
  0x3ff4000000000000,
  0x3ffbffffffffffff,
  0x3ffc000000000000,
  0x3ffc000000000001,
  0x4002000000000000,
  0x4025800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe7ffffffffffff,
  0x3fe7ffffffffffff,
  0x3fe7ffffffffffff,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3fd0000000000001,
  0x3fd0000000000000,
  0x3fcffffffffffffc,
  0xbfcffffffffffffc,
  0xbfd0000000000000,
  0xbfd0000000000004,
  0xbfe8000000000000,
  0xc022800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3ff4000000000000,
  0x3ff4000000000000,
  0x3ff4000000000000,
  0x3ffc000000000000,
  0x3ffc000000000000,
  0x3ffc000000000001,
  0x4002000000000000,
  0x4025800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3fe8000000000002,
  0x3fe8000000000001,
  0x3fd0000000000004,
  0x3fd0000000000003,
  0x3fd0000000000001,
  0xbfcffffffffffff6,
  0xbfcffffffffffffa,
  0xbfd0000000000001,
  0xbfe7fffffffffffe,
  0xc022800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe8000000000001,
  0x3fe8000000000001,
  0x3fe8000000000001,
  0x3fe8000000000002,
  0x3fe8000000000002,
  0x3ff4000000000000,
  0x3ff4000000000001,
  0x3ff4000000000001,
  0x3ffc000000000000,
  0x3ffc000000000001,
  0x3ffc000000000002,
  0x4002000000000000,
  0x4025800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe8000000000002,
  0x3fe8000000000002,
  0x3fe8000000000002,
  0x3ff7ffffffffffff,
  0x3ff7ffffffffffff,
  0x3fefffffffffffff,
  0x3feffffffffffffe,
  0x3feffffffffffffe,
  0x3fdfffffffffffff,
  0x3fdffffffffffffd,
  0x3fdffffffffffff9,
  0xbca8000000000000,
  0xc021000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3ff7ffffffffffff,
  0x3ff7ffffffffffff,
  0x3ff7ffffffffffff,
  0x3ff7ffffffffffff,
  0x3ff7ffffffffffff,
  0x3fffffffffffffff,
  0x3fffffffffffffff,
  0x4000000000000000,
  0x4003ffffffffffff,
  0x4004000000000000,
  0x4004000000000000,
  0x4008000000000000,
  0x4027000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3ff7ffffffffffff,
  0x3ff7ffffffffffff,
  0x3ff7ffffffffffff,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3fefffffffffffff,
  0x3fe0000000000001,
  0x3fe0000000000000,
  0x3fdffffffffffffc,
  0x0000000000000000,
  0xc021000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x4000000000000000,
  0x4000000000000000,
  0x4000000000000000,
  0x4004000000000000,
  0x4004000000000000,
  0x4004000000000000,
  0x4008000000000000,
  0x4027000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000002,
  0x3ff8000000000001,
  0x3ff0000000000002,
  0x3ff0000000000002,
  0x3ff0000000000001,
  0x3fe0000000000004,
  0x3fe0000000000003,
  0x3fe0000000000001,
  0x3cb8000000000000,
  0xc021000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3ff8000000000001,
  0x3ff8000000000001,
  0x3ff8000000000001,
  0x3ff8000000000002,
  0x3ff8000000000002,
  0x4000000000000001,
  0x4000000000000001,
  0x4000000000000001,
  0x4004000000000000,
  0x4004000000000001,
  0x4004000000000001,
  0x4008000000000001,
  0x4027000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3ff8000000000002,
  0x3ff8000000000002,
  0x3ff8000000000002,
  0x4002000000000000,
  0x4002000000000000,
  0x3ffc000000000000,
  0x3ffc000000000000,
  0x3ffc000000000000,
  0x3ff4000000000000,
  0x3ff4000000000000,
  0x3ff3ffffffffffff,
  0x3fe8000000000000,
  0xc01f000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x4002000000000000,
  0x4002000000000000,
  0x4002000000000000,
  0x4002000000000000,
  0x4002000000000000,
  0x4006000000000000,
  0x4006000000000000,
  0x4006000000000000,
  0x400a000000000000,
  0x400a000000000000,
  0x400a000000000000,
  0x400e000000000000,
  0x4028800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x4002000000000000,
  0x4002000000000000,
  0x4002000000000000,
  0x402e000000000000,
  0x402e000000000000,
  0x402d000000000000,
  0x402d000000000000,
  0x402d000000000000,
  0x402c000000000000,
  0x402c000000000000,
  0x402c000000000000,
  0x402b000000000000,
  0x4014000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x402e000000000000,
  0x402e000000000000,
  0x402e000000000000,
  0x402e000000000000,
  0x402e000000000000,
  0x402f000000000000,
  0x402f000000000000,
  0x402f000000000000,
  0x4030000000000000,
  0x4030000000000000,
  0x4030000000000000,
  0x4030800000000000,
  0x4039000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x402e000000000000,
  0x402e000000000000,
  0x402e000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7fdfffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x0001b4e81b4e81b4,
  0x800e4b17e4b17e4c,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x000091a2b3c4d5e6,
  0x800e4b17e4b17e4c,
  0x0001b4e81b4e81b2,
  0x0001b4e81b4e81b4,
  0x0011b4e81b4e81b4,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0002d82d82d82d80,
  0x0011b4e81b4e81b2,
  0x0001b4e81b4e81b4,
  0x0017fffffffffffe,
  0x0007fffffffffffe,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0016dcba98765432,
  0x0008000000000000,
  0x0017fffffffffffe,
  0x0017fffffffffffe,
  0x0023ffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x001923456789abcc,
  0x0023ffffffffffff,
  0x0018000000000000,
  0x0000000000000002,
  0x800ffffffffffffe,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcc,
  0x800ffffffffffffe,
  0x0000000000000000,
  0x0000000000000002,
  0x0010000000000002,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abce,
  0x0010000000000000,
  0x0000000000000002,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8018000000000000,
  0x8024000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x801923456789abcd,
  0x8024000000000000,
  0x8018000000000001,
  0x8018000000000000,
  0x8008000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8016dcba98765433,
  0x8008000000000001,
  0x8017ffffffffffff,
  0xbfe7ffffffffffff,
  0xbfe7ffffffffffff,
  0xbff3ffffffffffff,
  0xbff4000000000000,
  0xbff4000000000000,
  0xbffbffffffffffff,
  0xbffc000000000000,
  0xbffc000000000001,
  0xc002000000000000,
  0xc025800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe7ffffffffffff,
  0xbfe7ffffffffffff,
  0xbfe7ffffffffffff,
  0xbfe7ffffffffffff,
  0xbfe7ffffffffffff,
  0xbfcfffffffffffff,
  0xbfcffffffffffffd,
  0xbfcffffffffffff9,
  0x3fcfffffffffffff,
  0x3fd0000000000002,
  0x3fd0000000000006,
  0x3fe8000000000001,
  0x4022800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe7ffffffffffff,
  0xbfe7ffffffffffff,
  0xbfe7ffffffffffff,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbff4000000000000,
  0xbff4000000000000,
  0xbff4000000000000,
  0xbffc000000000000,
  0xbffc000000000000,
  0xbffc000000000001,
  0xc002000000000000,
  0xc025800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbfd0000000000001,
  0xbfd0000000000000,
  0xbfcffffffffffffc,
  0x3fcffffffffffffc,
  0x3fd0000000000000,
  0x3fd0000000000004,
  0x3fe8000000000000,
  0x4022800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbfe8000000000002,
  0xbfe8000000000002,
  0xbff4000000000000,
  0xbff4000000000001,
  0xbff4000000000001,
  0xbffc000000000000,
  0xbffc000000000001,
  0xbffc000000000002,
  0xc002000000000000,
  0xc025800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe8000000000002,
  0xbfe8000000000002,
  0xbfe8000000000002,
  0xbfe8000000000002,
  0xbfe8000000000001,
  0xbfd0000000000004,
  0xbfd0000000000003,
  0xbfd0000000000001,
  0x3fcffffffffffff6,
  0x3fcffffffffffffa,
  0x3fd0000000000001,
  0x3fe7fffffffffffe,
  0x4022800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe8000000000001,
  0xbfe8000000000001,
  0xbfe8000000000001,
  0xbff7ffffffffffff,
  0xbff7ffffffffffff,
  0xbfffffffffffffff,
  0xbfffffffffffffff,
  0xc000000000000000,
  0xc003ffffffffffff,
  0xc004000000000000,
  0xc004000000000000,
  0xc008000000000000,
  0xc027000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbff7ffffffffffff,
  0xbff7ffffffffffff,
  0xbff7ffffffffffff,
  0xbff7ffffffffffff,
  0xbff7ffffffffffff,
  0xbfefffffffffffff,
  0xbfeffffffffffffe,
  0xbfeffffffffffffe,
  0xbfdfffffffffffff,
  0xbfdffffffffffffd,
  0xbfdffffffffffff9,
  0x3ca8000000000000,
  0x4021000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbff7ffffffffffff,
  0xbff7ffffffffffff,
  0xbff7ffffffffffff,
  0xbff8000000000000,
  0xbff8000000000000,
  0xc000000000000000,
  0xc000000000000000,
  0xc000000000000000,
  0xc004000000000000,
  0xc004000000000000,
  0xc004000000000000,
  0xc008000000000000,
  0xc027000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbfefffffffffffff,
  0xbfe0000000000001,
  0xbfe0000000000000,
  0xbfdffffffffffffc,
  0x0000000000000000,
  0x4021000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000002,
  0xbff8000000000002,
  0xc000000000000001,
  0xc000000000000001,
  0xc000000000000001,
  0xc004000000000000,
  0xc004000000000001,
  0xc004000000000001,
  0xc008000000000001,
  0xc027000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbff8000000000002,
  0xbff8000000000002,
  0xbff8000000000002,
  0xbff8000000000002,
  0xbff8000000000001,
  0xbff0000000000002,
  0xbff0000000000002,
  0xbff0000000000001,
  0xbfe0000000000004,
  0xbfe0000000000003,
  0xbfe0000000000001,
  0xbcb8000000000000,
  0x4021000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbff8000000000001,
  0xbff8000000000001,
  0xbff8000000000001,
  0xc002000000000000,
  0xc002000000000000,
  0xc006000000000000,
  0xc006000000000000,
  0xc006000000000000,
  0xc00a000000000000,
  0xc00a000000000000,
  0xc00a000000000000,
  0xc00e000000000000,
  0xc028800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc002000000000000,
  0xc002000000000000,
  0xc002000000000000,
  0xc002000000000000,
  0xc002000000000000,
  0xbffc000000000000,
  0xbffc000000000000,
  0xbffc000000000000,
  0xbff4000000000000,
  0xbff4000000000000,
  0xbff3ffffffffffff,
  0xbfe8000000000000,
  0x401f000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc002000000000000,
  0xc002000000000000,
  0xc002000000000000,
  0xc02e000000000000,
  0xc02e000000000000,
  0xc02f000000000000,
  0xc02f000000000000,
  0xc02f000000000000,
  0xc030000000000000,
  0xc030000000000000,
  0xc030000000000000,
  0xc030800000000000,
  0xc039000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc02e000000000000,
  0xc02e000000000000,
  0xc02e000000000000,
  0xc02e000000000000,
  0xc02e000000000000,
  0xc02d000000000000,
  0xc02d000000000000,
  0xc02d000000000000,
  0xc02c000000000000,
  0xc02c000000000000,
  0xc02c000000000000,
  0xc02b000000000000,
  0xc014000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc02e000000000000,
  0xc02e000000000000,
  0xc02e000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xffdfffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x8001b4e81b4e81b4,
  0x8011b4e81b4e81b4,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x8002d82d82d82d80,
  0x8011b4e81b4e81b2,
  0x8001b4e81b4e81b4,
  0x8001b4e81b4e81b4,
  0x000e4b17e4b17e4c,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x800091a2b3c4d5e6,
  0x000e4b17e4b17e4c,
  0x8001b4e81b4e81b2,
  0x8017fffffffffffe,
  0x8023ffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x801923456789abcc,
  0x8023ffffffffffff,
  0x8018000000000000,
  0x8017fffffffffffe,
  0x8007fffffffffffe,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8016dcba98765432,
  0x8008000000000000,
  0x8017fffffffffffe,
  0x8000000000000002,
  0x8010000000000002,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abce,
  0x8010000000000000,
  0x8000000000000002,
  0x8000000000000002,
  0x000ffffffffffffe,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcc,
  0x000ffffffffffffe,
  0x8000000000000000,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0044000000000000,
  0x0042000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0043db97530eca86,
  0x0042000000000000,
  0x0044000000000000,
  0x0044000000000000,
  0x0046000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x00442468acf1357a,
  0x0046000000000000,
  0x0044000000000000,
  0x4013ffffffffffff,
  0x4013ffffffffffff,
  0x4011ffffffffffff,
  0x4011ffffffffffff,
  0x4011ffffffffffff,
  0x400fffffffffffff,
  0x400fffffffffffff,
  0x400ffffffffffffe,
  0x400bffffffffffff,
  0xc014000000000001,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x4013ffffffffffff,
  0x4013ffffffffffff,
  0x4013ffffffffffff,
  0x4013ffffffffffff,
  0x4013ffffffffffff,
  0x4015ffffffffffff,
  0x4015ffffffffffff,
  0x4016000000000000,
  0x4017ffffffffffff,
  0x4017ffffffffffff,
  0x4018000000000000,
  0x4019ffffffffffff,
  0x402e000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x4013ffffffffffff,
  0x4013ffffffffffff,
  0x4013ffffffffffff,
  0x4014000000000000,
  0x4014000000000000,
  0x4012000000000000,
  0x4012000000000000,
  0x4012000000000000,
  0x4010000000000000,
  0x4010000000000000,
  0x4010000000000000,
  0x400c000000000000,
  0xc014000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x4014000000000000,
  0x4014000000000000,
  0x4014000000000000,
  0x4014000000000000,
  0x4014000000000000,
  0x4016000000000000,
  0x4016000000000000,
  0x4016000000000000,
  0x4018000000000000,
  0x4018000000000000,
  0x4018000000000000,
  0x401a000000000000,
  0x402e000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x4014000000000000,
  0x4014000000000000,
  0x4014000000000000,
  0x4014000000000001,
  0x4014000000000001,
  0x4012000000000001,
  0x4012000000000001,
  0x4012000000000001,
  0x4010000000000001,
  0x4010000000000001,
  0x4010000000000001,
  0x400c000000000002,
  0xc013ffffffffffff,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x4014000000000001,
  0x4014000000000001,
  0x4014000000000001,
  0x4014000000000001,
  0x4014000000000001,
  0x4016000000000001,
  0x4016000000000001,
  0x4016000000000001,
  0x4018000000000001,
  0x4018000000000001,
  0x4018000000000002,
  0x401a000000000001,
  0x402e000000000001,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x4014000000000001,
  0x4014000000000001,
  0x4014000000000001,
  0x4023ffffffffffff,
  0x4023ffffffffffff,
  0x4022ffffffffffff,
  0x4022ffffffffffff,
  0x4022ffffffffffff,
  0x4021ffffffffffff,
  0x4021ffffffffffff,
  0x4021ffffffffffff,
  0x4020ffffffffffff,
  0xbcd4000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x4023ffffffffffff,
  0x4023ffffffffffff,
  0x4023ffffffffffff,
  0x4023ffffffffffff,
  0x4023ffffffffffff,
  0x4024ffffffffffff,
  0x4024ffffffffffff,
  0x4024ffffffffffff,
  0x4025ffffffffffff,
  0x4025ffffffffffff,
  0x4026000000000000,
  0x4026ffffffffffff,
  0x4034000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x4023ffffffffffff,
  0x4023ffffffffffff,
  0x4023ffffffffffff,
  0x4024000000000000,
  0x4024000000000000,
  0x4023000000000000,
  0x4023000000000000,
  0x4023000000000000,
  0x4022000000000000,
  0x4022000000000000,
  0x4022000000000000,
  0x4021000000000000,
  0x0000000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4025000000000000,
  0x4025000000000000,
  0x4025000000000000,
  0x4026000000000000,
  0x4026000000000000,
  0x4026000000000000,
  0x4027000000000000,
  0x4034000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4024000000000001,
  0x4024000000000001,
  0x4023000000000001,
  0x4023000000000001,
  0x4023000000000001,
  0x4022000000000001,
  0x4022000000000001,
  0x4022000000000001,
  0x4021000000000001,
  0x3ce4000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x4024000000000001,
  0x4024000000000001,
  0x4024000000000001,
  0x4024000000000001,
  0x4024000000000001,
  0x4025000000000001,
  0x4025000000000001,
  0x4025000000000001,
  0x4026000000000001,
  0x4026000000000001,
  0x4026000000000001,
  0x4027000000000001,
  0x4034000000000001,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x4024000000000001,
  0x4024000000000001,
  0x4024000000000001,
  0x402e000000000000,
  0x402e000000000000,
  0x402d000000000000,
  0x402d000000000000,
  0x402d000000000000,
  0x402c000000000000,
  0x402c000000000000,
  0x402c000000000000,
  0x402b000000000000,
  0x4014000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x402e000000000000,
  0x402e000000000000,
  0x402e000000000000,
  0x402e000000000000,
  0x402e000000000000,
  0x402f000000000000,
  0x402f000000000000,
  0x402f000000000000,
  0x4030000000000000,
  0x4030000000000000,
  0x4030000000000000,
  0x4030800000000000,
  0x4039000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x402e000000000000,
  0x402e000000000000,
  0x402e000000000000,
  0x4059000000000000,
  0x4059000000000000,
  0x4058e00000000000,
  0x4058e00000000000,
  0x4058e00000000000,
  0x4058c00000000000,
  0x4058c00000000000,
  0x4058c00000000000,
  0x4058a00000000000,
  0x4056800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x4059000000000000,
  0x4059000000000000,
  0x4059000000000000,
  0x4059000000000000,
  0x4059000000000000,
  0x4059200000000000,
  0x4059200000000000,
  0x4059200000000000,
  0x4059400000000000,
  0x4059400000000000,
  0x4059400000000000,
  0x4059600000000000,
  0x405b800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x4059000000000000,
  0x4059000000000000,
  0x4059000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x000b60b60b60b602,
  0x80049f49f49f49fe,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x000a3d70a3d70a35,
  0x80049f49f49f49fd,
  0x000b60b60b60b601,
  0x000b60b60b60b602,
  0x001b60b60b60b602,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000c83fb72ea61cf,
  0x001b60b60b60b601,
  0x000b60b60b60b603,
  0x0043ffffffffffff,
  0x0041ffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0043db97530eca85,
  0x0041ffffffffffff,
  0x0043ffffffffffff,
  0x0043ffffffffffff,
  0x0045ffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x00442468acf13578,
  0x0045ffffffffffff,
  0x0043ffffffffffff,
  0x000000000000000a,
  0x800ffffffffffff6,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abc3,
  0x800ffffffffffff5,
  0x0000000000000009,
  0x000000000000000a,
  0x001000000000000a,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abd7,
  0x0010000000000009,
  0x000000000000000b,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8044000000000000,
  0x8046000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x80442468acf1357a,
  0x8046000000000000,
  0x8044000000000000,
  0x8044000000000000,
  0x8042000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8043db97530eca86,
  0x8042000000000000,
  0x8044000000000000,
  0xc013ffffffffffff,
  0xc013ffffffffffff,
  0xc015ffffffffffff,
  0xc015ffffffffffff,
  0xc016000000000000,
  0xc017ffffffffffff,
  0xc017ffffffffffff,
  0xc018000000000000,
  0xc019ffffffffffff,
  0xc02e000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc013ffffffffffff,
  0xc013ffffffffffff,
  0xc013ffffffffffff,
  0xc013ffffffffffff,
  0xc013ffffffffffff,
  0xc011ffffffffffff,
  0xc011ffffffffffff,
  0xc011ffffffffffff,
  0xc00fffffffffffff,
  0xc00fffffffffffff,
  0xc00ffffffffffffe,
  0xc00bffffffffffff,
  0x4014000000000001,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc013ffffffffffff,
  0xc013ffffffffffff,
  0xc013ffffffffffff,
  0xc014000000000000,
  0xc014000000000000,
  0xc016000000000000,
  0xc016000000000000,
  0xc016000000000000,
  0xc018000000000000,
  0xc018000000000000,
  0xc018000000000000,
  0xc01a000000000000,
  0xc02e000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc014000000000000,
  0xc014000000000000,
  0xc014000000000000,
  0xc014000000000000,
  0xc014000000000000,
  0xc012000000000000,
  0xc012000000000000,
  0xc012000000000000,
  0xc010000000000000,
  0xc010000000000000,
  0xc010000000000000,
  0xc00c000000000000,
  0x4014000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc014000000000000,
  0xc014000000000000,
  0xc014000000000000,
  0xc014000000000001,
  0xc014000000000001,
  0xc016000000000001,
  0xc016000000000001,
  0xc016000000000001,
  0xc018000000000001,
  0xc018000000000001,
  0xc018000000000002,
  0xc01a000000000001,
  0xc02e000000000001,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc014000000000001,
  0xc014000000000001,
  0xc014000000000001,
  0xc014000000000001,
  0xc014000000000001,
  0xc012000000000001,
  0xc012000000000001,
  0xc012000000000001,
  0xc010000000000001,
  0xc010000000000001,
  0xc010000000000001,
  0xc00c000000000002,
  0x4013ffffffffffff,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc014000000000001,
  0xc014000000000001,
  0xc014000000000001,
  0xc023ffffffffffff,
  0xc023ffffffffffff,
  0xc024ffffffffffff,
  0xc024ffffffffffff,
  0xc024ffffffffffff,
  0xc025ffffffffffff,
  0xc025ffffffffffff,
  0xc026000000000000,
  0xc026ffffffffffff,
  0xc034000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc023ffffffffffff,
  0xc023ffffffffffff,
  0xc023ffffffffffff,
  0xc023ffffffffffff,
  0xc023ffffffffffff,
  0xc022ffffffffffff,
  0xc022ffffffffffff,
  0xc022ffffffffffff,
  0xc021ffffffffffff,
  0xc021ffffffffffff,
  0xc021ffffffffffff,
  0xc020ffffffffffff,
  0x3cd4000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc023ffffffffffff,
  0xc023ffffffffffff,
  0xc023ffffffffffff,
  0xc024000000000000,
  0xc024000000000000,
  0xc025000000000000,
  0xc025000000000000,
  0xc025000000000000,
  0xc026000000000000,
  0xc026000000000000,
  0xc026000000000000,
  0xc027000000000000,
  0xc034000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc023000000000000,
  0xc023000000000000,
  0xc023000000000000,
  0xc022000000000000,
  0xc022000000000000,
  0xc022000000000000,
  0xc021000000000000,
  0x0000000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc024000000000001,
  0xc024000000000001,
  0xc025000000000001,
  0xc025000000000001,
  0xc025000000000001,
  0xc026000000000001,
  0xc026000000000001,
  0xc026000000000001,
  0xc027000000000001,
  0xc034000000000001,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc024000000000001,
  0xc024000000000001,
  0xc024000000000001,
  0xc024000000000001,
  0xc024000000000001,
  0xc023000000000001,
  0xc023000000000001,
  0xc023000000000001,
  0xc022000000000001,
  0xc022000000000001,
  0xc022000000000001,
  0xc021000000000001,
  0xbce4000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc024000000000001,
  0xc024000000000001,
  0xc024000000000001,
  0xc02e000000000000,
  0xc02e000000000000,
  0xc02f000000000000,
  0xc02f000000000000,
  0xc02f000000000000,
  0xc030000000000000,
  0xc030000000000000,
  0xc030000000000000,
  0xc030800000000000,
  0xc039000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc02e000000000000,
  0xc02e000000000000,
  0xc02e000000000000,
  0xc02e000000000000,
  0xc02e000000000000,
  0xc02d000000000000,
  0xc02d000000000000,
  0xc02d000000000000,
  0xc02c000000000000,
  0xc02c000000000000,
  0xc02c000000000000,
  0xc02b000000000000,
  0xc014000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc02e000000000000,
  0xc02e000000000000,
  0xc02e000000000000,
  0xc059000000000000,
  0xc059000000000000,
  0xc059200000000000,
  0xc059200000000000,
  0xc059200000000000,
  0xc059400000000000,
  0xc059400000000000,
  0xc059400000000000,
  0xc059600000000000,
  0xc05b800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc059000000000000,
  0xc059000000000000,
  0xc059000000000000,
  0xc059000000000000,
  0xc059000000000000,
  0xc058e00000000000,
  0xc058e00000000000,
  0xc058e00000000000,
  0xc058c00000000000,
  0xc058c00000000000,
  0xc058c00000000000,
  0xc058a00000000000,
  0xc056800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc059000000000000,
  0xc059000000000000,
  0xc059000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x800b60b60b60b602,
  0x801b60b60b60b602,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800c83fb72ea61cf,
  0x801b60b60b60b601,
  0x800b60b60b60b603,
  0x800b60b60b60b602,
  0x00049f49f49f49fe,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x800a3d70a3d70a35,
  0x00049f49f49f49fd,
  0x800b60b60b60b601,
  0x8043ffffffffffff,
  0x8045ffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x80442468acf13578,
  0x8045ffffffffffff,
  0x8043ffffffffffff,
  0x8043ffffffffffff,
  0x8041ffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8043db97530eca85,
  0x8041ffffffffffff,
  0x8043ffffffffffff,
  0x800000000000000a,
  0x801000000000000a,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abd7,
  0x8010000000000009,
  0x800000000000000b,
  0x800000000000000a,
  0x000ffffffffffff6,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abc3,
  0x000ffffffffffff5,
  0x8000000000000009,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x400fffffffffffff,
  0x400fffffffffffff,
  0x400bffffffffffff,
  0x400bffffffffffff,
  0x400bffffffffffff,
  0x4007ffffffffffff,
  0x4007ffffffffffff,
  0x4007fffffffffffe,
  0x4003ffffffffffff,
  0xc018000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x400fffffffffffff,
  0x400fffffffffffff,
  0x400fffffffffffff,
  0x400fffffffffffff,
  0x400fffffffffffff,
  0x4011ffffffffffff,
  0x4012000000000000,
  0x4012000000000000,
  0x4013ffffffffffff,
  0x4014000000000000,
  0x4014000000000000,
  0x4016000000000000,
  0x402c000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x400fffffffffffff,
  0x400fffffffffffff,
  0x400fffffffffffff,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0xffe0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0xffdfffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0xffdffffffffffffd,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0xfc9fffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x0000000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7cafffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7fdfffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x3fd23456789abccf,
  0x3fd23456789abccf,
  0xbfcb97530eca865f,
  0xbfcb97530eca8661,
  0xbfcb97530eca8665,
  0xbfe6e5d4c3b2a197,
  0xbfe6e5d4c3b2a198,
  0xbfe6e5d4c3b2a19a,
  0xbff372ea61d950cc,
  0xc0236e5d4c3b2a1a,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fd23456789abccf,
  0x3fd23456789abccf,
  0x3fd23456789abccf,
  0x3fd23456789abccf,
  0x3fd23456789abccf,
  0x3fe91a2b3c4d5e67,
  0x3fe91a2b3c4d5e68,
  0x3fe91a2b3c4d5e69,
  0x3ff48d159e26af33,
  0x3ff48d159e26af34,
  0x3ff48d159e26af35,
  0x3ffc8d159e26af34,
  0x402491a2b3c4d5e6,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fd23456789abccf,
  0x3fd23456789abccf,
  0x3fd23456789abccf,
  0x400ffffffffffffd,
  0x400ffffffffffffd,
  0x400bfffffffffffd,
  0x400bfffffffffffd,
  0x400bfffffffffffd,
  0x4007fffffffffffd,
  0x4007fffffffffffd,
  0x4007fffffffffffd,
  0x4003fffffffffffd,
  0xc018000000000001,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x400ffffffffffffd,
  0x400ffffffffffffd,
  0x400ffffffffffffd,
  0x400ffffffffffffd,
  0x400ffffffffffffd,
  0x4011fffffffffffe,
  0x4011ffffffffffff,
  0x4011ffffffffffff,
  0x4013fffffffffffe,
  0x4013ffffffffffff,
  0x4013ffffffffffff,
  0x4015ffffffffffff,
  0x402bffffffffffff,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x400ffffffffffffd,
  0x400ffffffffffffd,
  0x400ffffffffffffd,
  0x3ccfffffffffffff,
  0x3ccfffffffffffff,
  0xbfdfffffffffffef,
  0xbfdffffffffffff0,
  0xbfdffffffffffff2,
  0xbfeffffffffffff7,
  0xbfeffffffffffff8,
  0xbfeffffffffffffa,
  0xbff7fffffffffffc,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3ccfffffffffffff,
  0x3ccfffffffffffff,
  0x3ccfffffffffffff,
  0x3ccfffffffffffff,
  0x3ccfffffffffffff,
  0x3fe0000000000007,
  0x3fe0000000000008,
  0x3fe0000000000009,
  0x3ff0000000000003,
  0x3ff0000000000004,
  0x3ff0000000000005,
  0x3ff8000000000004,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3ccfffffffffffff,
  0x3ccfffffffffffff,
  0x3ccfffffffffffff,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0xc00fffffffffffff,
  0xc00fffffffffffff,
  0xc011ffffffffffff,
  0xc012000000000000,
  0xc012000000000000,
  0xc013ffffffffffff,
  0xc014000000000000,
  0xc014000000000000,
  0xc016000000000000,
  0xc02c000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc00fffffffffffff,
  0xc00fffffffffffff,
  0xc00fffffffffffff,
  0xc00fffffffffffff,
  0xc00fffffffffffff,
  0xc00bffffffffffff,
  0xc00bffffffffffff,
  0xc00bffffffffffff,
  0xc007ffffffffffff,
  0xc007ffffffffffff,
  0xc007fffffffffffe,
  0xc003ffffffffffff,
  0x4018000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc00fffffffffffff,
  0xc00fffffffffffff,
  0xc00fffffffffffff,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0x7fe0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0x7fdfffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0x7fdffffffffffffd,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0x7c9fffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0x0000000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfcafffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xffdfffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xbfd23456789abccf,
  0xbfd23456789abccf,
  0xbfe91a2b3c4d5e67,
  0xbfe91a2b3c4d5e68,
  0xbfe91a2b3c4d5e69,
  0xbff48d159e26af33,
  0xbff48d159e26af34,
  0xbff48d159e26af35,
  0xbffc8d159e26af34,
  0xc02491a2b3c4d5e6,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfd23456789abccf,
  0xbfd23456789abccf,
  0xbfd23456789abccf,
  0xbfd23456789abccf,
  0xbfd23456789abccf,
  0x3fcb97530eca865f,
  0x3fcb97530eca8661,
  0x3fcb97530eca8665,
  0x3fe6e5d4c3b2a197,
  0x3fe6e5d4c3b2a198,
  0x3fe6e5d4c3b2a19a,
  0x3ff372ea61d950cc,
  0x40236e5d4c3b2a1a,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfd23456789abccf,
  0xbfd23456789abccf,
  0xbfd23456789abccf,
  0xc00ffffffffffffd,
  0xc00ffffffffffffd,
  0xc011fffffffffffe,
  0xc011ffffffffffff,
  0xc011ffffffffffff,
  0xc013fffffffffffe,
  0xc013ffffffffffff,
  0xc013ffffffffffff,
  0xc015ffffffffffff,
  0xc02bffffffffffff,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc00ffffffffffffd,
  0xc00ffffffffffffd,
  0xc00ffffffffffffd,
  0xc00ffffffffffffd,
  0xc00ffffffffffffd,
  0xc00bfffffffffffd,
  0xc00bfffffffffffd,
  0xc00bfffffffffffd,
  0xc007fffffffffffd,
  0xc007fffffffffffd,
  0xc007fffffffffffd,
  0xc003fffffffffffd,
  0x4018000000000001,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc00ffffffffffffd,
  0xc00ffffffffffffd,
  0xc00ffffffffffffd,
  0xbccfffffffffffff,
  0xbccfffffffffffff,
  0xbfe0000000000007,
  0xbfe0000000000008,
  0xbfe0000000000009,
  0xbff0000000000003,
  0xbff0000000000004,
  0xbff0000000000005,
  0xbff8000000000004,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbccfffffffffffff,
  0xbccfffffffffffff,
  0xbccfffffffffffff,
  0xbccfffffffffffff,
  0xbccfffffffffffff,
  0x3fdfffffffffffef,
  0x3fdffffffffffff0,
  0x3fdffffffffffff2,
  0x3feffffffffffff7,
  0x3feffffffffffff8,
  0x3feffffffffffffa,
  0x3ff7fffffffffffc,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbccfffffffffffff,
  0xbccfffffffffffff,
  0xbccfffffffffffff,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x000091a2b3c4d5e6,
  0x800f6e5d4c3b2a1a,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800091a2b3c4d5e7,
  0x800f6e5d4c3b2a19,
  0x000091a2b3c4d5e5,
  0x000091a2b3c4d5e6,
  0x001091a2b3c4d5e6,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0001b4e81b4e81b3,
  0x001091a2b3c4d5e5,
  0x000091a2b3c4d5e7,
  0x000091a2b3c4d5e6,
  0x800f6e5d4c3b2a1a,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800091a2b3c4d5e6,
  0x800f6e5d4c3b2a18,
  0x000091a2b3c4d5e6,
  0x000091a2b3c4d5e6,
  0x001091a2b3c4d5e6,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0001b4e81b4e81b4,
  0x001091a2b3c4d5e6,
  0x000091a2b3c4d5e8,
  0x000091a2b3c4d5e7,
  0x800f6e5d4c3b2a19,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800091a2b3c4d5e6,
  0x800f6e5d4c3b2a18,
  0x000091a2b3c4d5e6,
  0x000091a2b3c4d5e7,
  0x001091a2b3c4d5e7,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0001b4e81b4e81b4,
  0x001091a2b3c4d5e6,
  0x000091a2b3c4d5e8,
  0x000123456789abcd,
  0x800edcba98765433,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x8000000000000000,
  0x800edcba98765432,
  0x000123456789abcc,
  0x000123456789abcd,
  0x001123456789abcd,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0002468acf13579a,
  0x001123456789abcc,
  0x000123456789abce,
  0x000123456789abcd,
  0x800edcba98765433,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0000000000000000,
  0x800edcba98765432,
  0x000123456789abcc,
  0x000123456789abcd,
  0x001123456789abcd,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0002468acf13579a,
  0x001123456789abcc,
  0x000123456789abce,
  0x000123456789abcd,
  0x800edcba98765433,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0000000000000000,
  0x800edcba98765432,
  0x000123456789abcc,
  0x000123456789abcd,
  0x001123456789abcd,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0002468acf13579a,
  0x001123456789abcc,
  0x000123456789abce,
  0x0001b4e81b4e81b4,
  0x800e4b17e4b17e4c,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x000091a2b3c4d5e6,
  0x800e4b17e4b17e4c,
  0x0001b4e81b4e81b2,
  0x0001b4e81b4e81b4,
  0x0011b4e81b4e81b4,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0002d82d82d82d80,
  0x0011b4e81b4e81b2,
  0x0001b4e81b4e81b4,
  0x000b60b60b60b602,
  0x80049f49f49f49fe,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x000a3d70a3d70a35,
  0x80049f49f49f49fd,
  0x000b60b60b60b601,
  0x000b60b60b60b602,
  0x001b60b60b60b602,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000c83fb72ea61cf,
  0x001b60b60b60b601,
  0x000b60b60b60b603,
  0x3fd23456789abccf,
  0x3fd23456789abccf,
  0xbfcb97530eca865f,
  0xbfcb97530eca8661,
  0xbfcb97530eca8665,
  0xbfe6e5d4c3b2a197,
  0xbfe6e5d4c3b2a198,
  0xbfe6e5d4c3b2a19a,
  0xbff372ea61d950cc,
  0xc0236e5d4c3b2a1a,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fd23456789abccf,
  0x3fd23456789abccf,
  0x3fd23456789abccf,
  0x3fd23456789abccf,
  0x3fd23456789abccf,
  0x3fe91a2b3c4d5e67,
  0x3fe91a2b3c4d5e68,
  0x3fe91a2b3c4d5e69,
  0x3ff48d159e26af33,
  0x3ff48d159e26af34,
  0x3ff48d159e26af35,
  0x3ffc8d159e26af34,
  0x402491a2b3c4d5e6,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fd23456789abccf,
  0x3fd23456789abccf,
  0x3fd23456789abccf,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x800091a2b3c4d5e6,
  0x801091a2b3c4d5e6,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x8001b4e81b4e81b3,
  0x801091a2b3c4d5e5,
  0x800091a2b3c4d5e7,
  0x800091a2b3c4d5e6,
  0x000f6e5d4c3b2a1a,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000091a2b3c4d5e7,
  0x000f6e5d4c3b2a19,
  0x800091a2b3c4d5e5,
  0x800091a2b3c4d5e6,
  0x801091a2b3c4d5e6,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x8001b4e81b4e81b4,
  0x801091a2b3c4d5e6,
  0x800091a2b3c4d5e8,
  0x800091a2b3c4d5e6,
  0x000f6e5d4c3b2a1a,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000091a2b3c4d5e6,
  0x000f6e5d4c3b2a18,
  0x800091a2b3c4d5e6,
  0x800091a2b3c4d5e7,
  0x801091a2b3c4d5e7,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x8001b4e81b4e81b4,
  0x801091a2b3c4d5e6,
  0x800091a2b3c4d5e8,
  0x800091a2b3c4d5e7,
  0x000f6e5d4c3b2a19,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000091a2b3c4d5e6,
  0x000f6e5d4c3b2a18,
  0x800091a2b3c4d5e6,
  0x800123456789abcd,
  0x801123456789abcd,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x8002468acf13579a,
  0x801123456789abcc,
  0x800123456789abce,
  0x800123456789abcd,
  0x000edcba98765433,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0000000000000000,
  0x000edcba98765432,
  0x800123456789abcc,
  0x800123456789abcd,
  0x801123456789abcd,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x8002468acf13579a,
  0x801123456789abcc,
  0x800123456789abce,
  0x800123456789abcd,
  0x000edcba98765433,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0000000000000000,
  0x000edcba98765432,
  0x800123456789abcc,
  0x800123456789abcd,
  0x801123456789abcd,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x8002468acf13579a,
  0x801123456789abcc,
  0x800123456789abce,
  0x800123456789abcd,
  0x000edcba98765433,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8000000000000000,
  0x000edcba98765432,
  0x800123456789abcc,
  0x8001b4e81b4e81b4,
  0x8011b4e81b4e81b4,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x8002d82d82d82d80,
  0x8011b4e81b4e81b2,
  0x8001b4e81b4e81b4,
  0x8001b4e81b4e81b4,
  0x000e4b17e4b17e4c,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x800091a2b3c4d5e6,
  0x000e4b17e4b17e4c,
  0x8001b4e81b4e81b2,
  0x800b60b60b60b602,
  0x801b60b60b60b602,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800c83fb72ea61cf,
  0x801b60b60b60b601,
  0x800b60b60b60b603,
  0x800b60b60b60b602,
  0x00049f49f49f49fe,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x800a3d70a3d70a35,
  0x00049f49f49f49fd,
  0x800b60b60b60b601,
  0xbfd23456789abccf,
  0xbfd23456789abccf,
  0xbfe91a2b3c4d5e67,
  0xbfe91a2b3c4d5e68,
  0xbfe91a2b3c4d5e69,
  0xbff48d159e26af33,
  0xbff48d159e26af34,
  0xbff48d159e26af35,
  0xbffc8d159e26af34,
  0xc02491a2b3c4d5e6,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfd23456789abccf,
  0xbfd23456789abccf,
  0xbfd23456789abccf,
  0xbfd23456789abccf,
  0xbfd23456789abccf,
  0x3fcb97530eca865f,
  0x3fcb97530eca8661,
  0x3fcb97530eca8665,
  0x3fe6e5d4c3b2a197,
  0x3fe6e5d4c3b2a198,
  0x3fe6e5d4c3b2a19a,
  0x3ff372ea61d950cc,
  0x40236e5d4c3b2a1a,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfd23456789abccf,
  0xbfd23456789abccf,
  0xbfd23456789abccf,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0007ffffffffffff,
  0x8008000000000001,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0006dcba98765432,
  0x8008000000000000,
  0x0007fffffffffffe,
  0x0007ffffffffffff,
  0x0017ffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000923456789abcc,
  0x0017fffffffffffe,
  0x0008000000000000,
  0x0008000000000000,
  0x8008000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0006dcba98765432,
  0x8008000000000000,
  0x0007fffffffffffe,
  0x0008000000000000,
  0x0018000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000923456789abcc,
  0x0017fffffffffffe,
  0x0008000000000000,
  0x0008000000000000,
  0x8008000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0006dcba98765433,
  0x8007ffffffffffff,
  0x0007ffffffffffff,
  0x0008000000000000,
  0x0018000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000923456789abcd,
  0x0017ffffffffffff,
  0x0008000000000001,
  0x000fffffffffffff,
  0x8000000000000001,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x000edcba98765432,
  0x8000000000000000,
  0x000ffffffffffffe,
  0x000fffffffffffff,
  0x001fffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x001123456789abcc,
  0x001ffffffffffffe,
  0x0010000000000000,
  0x000fffffffffffff,
  0x8000000000000001,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x000edcba98765432,
  0x0000000000000000,
  0x000ffffffffffffe,
  0x000fffffffffffff,
  0x001fffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x001123456789abcc,
  0x001ffffffffffffe,
  0x0010000000000000,
  0x0010000000000000,
  0x8000000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x000edcba98765433,
  0x0000000000000001,
  0x000fffffffffffff,
  0x0010000000000000,
  0x0020000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x001123456789abcd,
  0x001fffffffffffff,
  0x0010000000000001,
  0x0017fffffffffffe,
  0x0007fffffffffffe,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0016dcba98765432,
  0x0008000000000000,
  0x0017fffffffffffe,
  0x0017fffffffffffe,
  0x0023ffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x001923456789abcc,
  0x0023ffffffffffff,
  0x0018000000000000,
  0x0043ffffffffffff,
  0x0041ffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0043db97530eca85,
  0x0041ffffffffffff,
  0x0043ffffffffffff,
  0x0043ffffffffffff,
  0x0045ffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x00442468acf13578,
  0x0045ffffffffffff,
  0x0043ffffffffffff,
  0x400ffffffffffffd,
  0x400ffffffffffffd,
  0x400bfffffffffffd,
  0x400bfffffffffffd,
  0x400bfffffffffffd,
  0x4007fffffffffffd,
  0x4007fffffffffffd,
  0x4007fffffffffffd,
  0x4003fffffffffffd,
  0xc018000000000001,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x400ffffffffffffd,
  0x400ffffffffffffd,
  0x400ffffffffffffd,
  0x400ffffffffffffd,
  0x400ffffffffffffd,
  0x4011fffffffffffe,
  0x4011ffffffffffff,
  0x4011ffffffffffff,
  0x4013fffffffffffe,
  0x4013ffffffffffff,
  0x4013ffffffffffff,
  0x4015ffffffffffff,
  0x402bffffffffffff,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x400ffffffffffffd,
  0x400ffffffffffffd,
  0x400ffffffffffffd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8007ffffffffffff,
  0x8017ffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800923456789abcc,
  0x8017fffffffffffe,
  0x8008000000000000,
  0x8007ffffffffffff,
  0x0008000000000001,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8006dcba98765432,
  0x0008000000000000,
  0x8007fffffffffffe,
  0x8008000000000000,
  0x8018000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800923456789abcc,
  0x8017fffffffffffe,
  0x8008000000000000,
  0x8008000000000000,
  0x0008000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8006dcba98765432,
  0x0008000000000000,
  0x8007fffffffffffe,
  0x8008000000000000,
  0x8018000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800923456789abcd,
  0x8017ffffffffffff,
  0x8008000000000001,
  0x8008000000000000,
  0x0008000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8006dcba98765433,
  0x0007ffffffffffff,
  0x8007ffffffffffff,
  0x800fffffffffffff,
  0x801fffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x801123456789abcc,
  0x801ffffffffffffe,
  0x8010000000000000,
  0x800fffffffffffff,
  0x0000000000000001,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x800edcba98765432,
  0x0000000000000000,
  0x800ffffffffffffe,
  0x800fffffffffffff,
  0x801fffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x801123456789abcc,
  0x801ffffffffffffe,
  0x8010000000000000,
  0x800fffffffffffff,
  0x0000000000000001,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x800edcba98765432,
  0x0000000000000000,
  0x800ffffffffffffe,
  0x8010000000000000,
  0x8020000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x801123456789abcd,
  0x801fffffffffffff,
  0x8010000000000001,
  0x8010000000000000,
  0x0000000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x800edcba98765433,
  0x8000000000000001,
  0x800fffffffffffff,
  0x8017fffffffffffe,
  0x8023ffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x801923456789abcc,
  0x8023ffffffffffff,
  0x8018000000000000,
  0x8017fffffffffffe,
  0x8007fffffffffffe,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8016dcba98765432,
  0x8008000000000000,
  0x8017fffffffffffe,
  0x8043ffffffffffff,
  0x8045ffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x80442468acf13578,
  0x8045ffffffffffff,
  0x8043ffffffffffff,
  0x8043ffffffffffff,
  0x8041ffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8043db97530eca85,
  0x8041ffffffffffff,
  0x8043ffffffffffff,
  0xc00ffffffffffffd,
  0xc00ffffffffffffd,
  0xc011fffffffffffe,
  0xc011ffffffffffff,
  0xc011ffffffffffff,
  0xc013fffffffffffe,
  0xc013ffffffffffff,
  0xc013ffffffffffff,
  0xc015ffffffffffff,
  0xc02bffffffffffff,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc00ffffffffffffd,
  0xc00ffffffffffffd,
  0xc00ffffffffffffd,
  0xc00ffffffffffffd,
  0xc00ffffffffffffd,
  0xc00bfffffffffffd,
  0xc00bfffffffffffd,
  0xc00bfffffffffffd,
  0xc007fffffffffffd,
  0xc007fffffffffffd,
  0xc007fffffffffffd,
  0xc003fffffffffffd,
  0x4018000000000001,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc00ffffffffffffd,
  0xc00ffffffffffffd,
  0xc00ffffffffffffd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcc,
  0x800ffffffffffffe,
  0x8000000000000000,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abce,
  0x0010000000000000,
  0x0000000000000002,
  0x0000000000000001,
  0x800fffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcc,
  0x800ffffffffffffe,
  0x8000000000000000,
  0x0000000000000001,
  0x0010000000000001,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abce,
  0x0010000000000000,
  0x0000000000000002,
  0x0000000000000001,
  0x800fffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcc,
  0x800ffffffffffffe,
  0x8000000000000000,
  0x0000000000000001,
  0x0010000000000001,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abce,
  0x0010000000000000,
  0x0000000000000002,
  0x0000000000000001,
  0x800fffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcc,
  0x800ffffffffffffe,
  0x0000000000000000,
  0x0000000000000001,
  0x0010000000000001,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abce,
  0x0010000000000000,
  0x0000000000000002,
  0x0000000000000001,
  0x800fffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcc,
  0x800ffffffffffffe,
  0x0000000000000000,
  0x0000000000000001,
  0x0010000000000001,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abce,
  0x0010000000000000,
  0x0000000000000002,
  0x0000000000000002,
  0x800ffffffffffffe,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcc,
  0x800ffffffffffffe,
  0x0000000000000000,
  0x0000000000000002,
  0x0010000000000002,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abce,
  0x0010000000000000,
  0x0000000000000002,
  0x000000000000000a,
  0x800ffffffffffff6,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abc3,
  0x800ffffffffffff5,
  0x0000000000000009,
  0x000000000000000a,
  0x001000000000000a,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abd7,
  0x0010000000000009,
  0x000000000000000b,
  0x3ccfffffffffffff,
  0x3ccfffffffffffff,
  0xbfdfffffffffffef,
  0xbfdffffffffffff0,
  0xbfdffffffffffff2,
  0xbfeffffffffffff7,
  0xbfeffffffffffff8,
  0xbfeffffffffffffa,
  0xbff7fffffffffffc,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3ccfffffffffffff,
  0x3ccfffffffffffff,
  0x3ccfffffffffffff,
  0x3ccfffffffffffff,
  0x3ccfffffffffffff,
  0x3fe0000000000007,
  0x3fe0000000000008,
  0x3fe0000000000009,
  0x3ff0000000000003,
  0x3ff0000000000004,
  0x3ff0000000000005,
  0x3ff8000000000004,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3ccfffffffffffff,
  0x3ccfffffffffffff,
  0x3ccfffffffffffff,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abce,
  0x8010000000000000,
  0x8000000000000002,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcc,
  0x000ffffffffffffe,
  0x0000000000000000,
  0x8000000000000001,
  0x8010000000000001,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abce,
  0x8010000000000000,
  0x8000000000000002,
  0x8000000000000001,
  0x000fffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcc,
  0x000ffffffffffffe,
  0x0000000000000000,
  0x8000000000000001,
  0x8010000000000001,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abce,
  0x8010000000000000,
  0x8000000000000002,
  0x8000000000000001,
  0x000fffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcc,
  0x000ffffffffffffe,
  0x0000000000000000,
  0x8000000000000001,
  0x8010000000000001,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abce,
  0x8010000000000000,
  0x8000000000000002,
  0x8000000000000001,
  0x000fffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcc,
  0x000ffffffffffffe,
  0x0000000000000000,
  0x8000000000000001,
  0x8010000000000001,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abce,
  0x8010000000000000,
  0x8000000000000002,
  0x8000000000000001,
  0x000fffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcc,
  0x000ffffffffffffe,
  0x8000000000000000,
  0x8000000000000002,
  0x8010000000000002,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abce,
  0x8010000000000000,
  0x8000000000000002,
  0x8000000000000002,
  0x000ffffffffffffe,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcc,
  0x000ffffffffffffe,
  0x8000000000000000,
  0x800000000000000a,
  0x801000000000000a,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abd7,
  0x8010000000000009,
  0x800000000000000b,
  0x800000000000000a,
  0x000ffffffffffff6,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abc3,
  0x000ffffffffffff5,
  0x8000000000000009,
  0xbccfffffffffffff,
  0xbccfffffffffffff,
  0xbfe0000000000007,
  0xbfe0000000000008,
  0xbfe0000000000009,
  0xbff0000000000003,
  0xbff0000000000004,
  0xbff0000000000005,
  0xbff8000000000004,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbccfffffffffffff,
  0xbccfffffffffffff,
  0xbccfffffffffffff,
  0xbccfffffffffffff,
  0xbccfffffffffffff,
  0x3fdfffffffffffef,
  0x3fdffffffffffff0,
  0x3fdffffffffffff2,
  0x3feffffffffffff7,
  0x3feffffffffffff8,
  0x3feffffffffffffa,
  0x3ff7fffffffffffc,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbccfffffffffffff,
  0xbccfffffffffffff,
  0xbccfffffffffffff,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8008000000000000,
  0x8018000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800923456789abcd,
  0x8017ffffffffffff,
  0x8008000000000001,
  0x8008000000000000,
  0x0008000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8006dcba98765433,
  0x0007ffffffffffff,
  0x8007ffffffffffff,
  0x8008000000000000,
  0x8018000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800923456789abcd,
  0x8017ffffffffffff,
  0x8008000000000001,
  0x8008000000000000,
  0x0008000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8006dcba98765433,
  0x0007ffffffffffff,
  0x8007ffffffffffff,
  0x8008000000000000,
  0x8018000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800923456789abce,
  0x8018000000000000,
  0x8008000000000002,
  0x8008000000000000,
  0x0008000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8006dcba98765434,
  0x0007fffffffffffe,
  0x8008000000000000,
  0x8010000000000000,
  0x8020000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x801123456789abcc,
  0x801ffffffffffffe,
  0x8010000000000000,
  0x8010000000000000,
  0x0000000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x800edcba98765432,
  0x8000000000000000,
  0x800ffffffffffffe,
  0x8010000000000000,
  0x8020000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x801123456789abcd,
  0x801fffffffffffff,
  0x8010000000000001,
  0x8010000000000000,
  0x0000000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x800edcba98765433,
  0x8000000000000001,
  0x800fffffffffffff,
  0x8010000000000001,
  0x8020000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x801123456789abce,
  0x8020000000000000,
  0x8010000000000002,
  0x8010000000000001,
  0x8000000000000001,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x800edcba98765434,
  0x8000000000000002,
  0x8010000000000000,
  0x8018000000000000,
  0x8024000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x801923456789abcd,
  0x8024000000000000,
  0x8018000000000001,
  0x8018000000000000,
  0x8008000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8016dcba98765433,
  0x8008000000000001,
  0x8017ffffffffffff,
  0x8044000000000000,
  0x8046000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x80442468acf1357a,
  0x8046000000000000,
  0x8044000000000000,
  0x8044000000000000,
  0x8042000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8043db97530eca86,
  0x8042000000000000,
  0x8044000000000000,
  0xc00fffffffffffff,
  0xc00fffffffffffff,
  0xc011ffffffffffff,
  0xc012000000000000,
  0xc012000000000000,
  0xc013ffffffffffff,
  0xc014000000000000,
  0xc014000000000000,
  0xc016000000000000,
  0xc02c000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc00fffffffffffff,
  0xc00fffffffffffff,
  0xc00fffffffffffff,
  0xc00fffffffffffff,
  0xc00fffffffffffff,
  0xc00bffffffffffff,
  0xc00bffffffffffff,
  0xc00bffffffffffff,
  0xc007ffffffffffff,
  0xc007ffffffffffff,
  0xc007fffffffffffe,
  0xc003ffffffffffff,
  0x4018000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc00fffffffffffff,
  0xc00fffffffffffff,
  0xc00fffffffffffff,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0008000000000000,
  0x8008000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0006dcba98765433,
  0x8007ffffffffffff,
  0x0007ffffffffffff,
  0x0008000000000000,
  0x0018000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000923456789abcd,
  0x0017ffffffffffff,
  0x0008000000000001,
  0x0008000000000000,
  0x8008000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0006dcba98765433,
  0x8007ffffffffffff,
  0x0007ffffffffffff,
  0x0008000000000000,
  0x0018000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000923456789abcd,
  0x0017ffffffffffff,
  0x0008000000000001,
  0x0008000000000000,
  0x8008000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0006dcba98765434,
  0x8007fffffffffffe,
  0x0008000000000000,
  0x0008000000000000,
  0x0018000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000923456789abce,
  0x0018000000000000,
  0x0008000000000002,
  0x0010000000000000,
  0x8000000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x000edcba98765432,
  0x0000000000000000,
  0x000ffffffffffffe,
  0x0010000000000000,
  0x0020000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x001123456789abcc,
  0x001ffffffffffffe,
  0x0010000000000000,
  0x0010000000000000,
  0x0000000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x000edcba98765433,
  0x0000000000000001,
  0x000fffffffffffff,
  0x0010000000000000,
  0x0020000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x001123456789abcd,
  0x001fffffffffffff,
  0x0010000000000001,
  0x0010000000000001,
  0x0000000000000001,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x000edcba98765434,
  0x0000000000000002,
  0x0010000000000000,
  0x0010000000000001,
  0x0020000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x001123456789abce,
  0x0020000000000000,
  0x0010000000000002,
  0x0018000000000000,
  0x0008000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0016dcba98765433,
  0x0008000000000001,
  0x0017ffffffffffff,
  0x0018000000000000,
  0x0024000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x001923456789abcd,
  0x0024000000000000,
  0x0018000000000001,
  0x0044000000000000,
  0x0042000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0043db97530eca86,
  0x0042000000000000,
  0x0044000000000000,
  0x0044000000000000,
  0x0046000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x00442468acf1357a,
  0x0046000000000000,
  0x0044000000000000,
  0x400fffffffffffff,
  0x400fffffffffffff,
  0x400bffffffffffff,
  0x400bffffffffffff,
  0x400bffffffffffff,
  0x4007ffffffffffff,
  0x4007ffffffffffff,
  0x4007fffffffffffe,
  0x4003ffffffffffff,
  0xc018000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x400fffffffffffff,
  0x400fffffffffffff,
  0x400fffffffffffff,
  0x400fffffffffffff,
  0x400fffffffffffff,
  0x4011ffffffffffff,
  0x4012000000000000,
  0x4012000000000000,
  0x4013ffffffffffff,
  0x4014000000000000,
  0x4014000000000000,
  0x4016000000000000,
  0x402c000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x400fffffffffffff,
  0x400fffffffffffff,
  0x400fffffffffffff,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8008000000000000,
  0x8018000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800923456789abcd,
  0x8017ffffffffffff,
  0x8008000000000001,
  0x8008000000000000,
  0x0008000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8006dcba98765433,
  0x0007ffffffffffff,
  0x8007ffffffffffff,
  0xbfcffffffffffffe,
  0xbfcffffffffffffe,
  0xbfe7ffffffffffff,
  0xbfe8000000000000,
  0xbfe8000000000001,
  0xbff3ffffffffffff,
  0xbff4000000000000,
  0xbff4000000000001,
  0xbffc000000000000,
  0xc024800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfcffffffffffffe,
  0xbfcffffffffffffe,
  0xbfcffffffffffffe,
  0xbfcffffffffffffe,
  0xbfcffffffffffffe,
  0x3fd0000000000000,
  0x3fd0000000000001,
  0x3fd0000000000003,
  0x3fe7ffffffffffff,
  0x3fe8000000000000,
  0x3fe8000000000002,
  0x3ff4000000000000,
  0x4023800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfcffffffffffffe,
  0xbfcffffffffffffe,
  0xbfcffffffffffffe,
  0xbfcfffffffffffff,
  0xbfcfffffffffffff,
  0xbfe7ffffffffffff,
  0xbfe8000000000000,
  0xbfe8000000000001,
  0xbff3ffffffffffff,
  0xbff4000000000000,
  0xbff4000000000001,
  0xbffc000000000000,
  0xc024800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfcfffffffffffff,
  0xbfcfffffffffffff,
  0xbfcfffffffffffff,
  0xbfcfffffffffffff,
  0xbfcfffffffffffff,
  0x3fcfffffffffffff,
  0x3fd0000000000000,
  0x3fd0000000000002,
  0x3fe7ffffffffffff,
  0x3fe8000000000000,
  0x3fe8000000000002,
  0x3ff4000000000000,
  0x4023800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfcfffffffffffff,
  0xbfcfffffffffffff,
  0xbfcfffffffffffff,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbfe8000000000001,
  0xbff4000000000000,
  0xbff4000000000000,
  0xbff4000000000001,
  0xbffc000000000000,
  0xc024800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0x3fcffffffffffffd,
  0x3fcfffffffffffff,
  0x3fd0000000000002,
  0x3fe7ffffffffffff,
  0x3fe8000000000000,
  0x3fe8000000000002,
  0x3ff4000000000000,
  0x4023800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfdffffffffffffe,
  0xbfdffffffffffffe,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff7ffffffffffff,
  0xbff8000000000000,
  0xbff8000000000001,
  0xc000000000000000,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfdffffffffffffe,
  0xbfdffffffffffffe,
  0xbfdffffffffffffe,
  0xbfdffffffffffffe,
  0xbfdffffffffffffe,
  0x3c8fffffffffffff,
  0x3ca0000000000000,
  0x3cb0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000003,
  0x3ff0000000000000,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfdffffffffffffe,
  0xbfdffffffffffffe,
  0xbfdffffffffffffe,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff7ffffffffffff,
  0xbff8000000000000,
  0xbff8000000000001,
  0xc000000000000000,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0x0000000000000000,
  0x3c90000000000000,
  0x3ca8000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000002,
  0x3ff0000000000000,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000001,
  0xc000000000000000,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbc9fffffffffffff,
  0xbc8ffffffffffffe,
  0x3c90000000000001,
  0x3fdffffffffffffd,
  0x3fdfffffffffffff,
  0x3fe0000000000002,
  0x3ff0000000000000,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe7ffffffffffff,
  0xbfe7ffffffffffff,
  0xbff3ffffffffffff,
  0xbff4000000000000,
  0xbff4000000000000,
  0xbffbffffffffffff,
  0xbffc000000000000,
  0xbffc000000000001,
  0xc002000000000000,
  0xc025800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe7ffffffffffff,
  0xbfe7ffffffffffff,
  0xbfe7ffffffffffff,
  0xbfe7ffffffffffff,
  0xbfe7ffffffffffff,
  0xbfcfffffffffffff,
  0xbfcffffffffffffd,
  0xbfcffffffffffff9,
  0x3fcfffffffffffff,
  0x3fd0000000000002,
  0x3fd0000000000006,
  0x3fe8000000000001,
  0x4022800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe7ffffffffffff,
  0xbfe7ffffffffffff,
  0xbfe7ffffffffffff,
  0xc013ffffffffffff,
  0xc013ffffffffffff,
  0xc015ffffffffffff,
  0xc015ffffffffffff,
  0xc016000000000000,
  0xc017ffffffffffff,
  0xc017ffffffffffff,
  0xc018000000000000,
  0xc019ffffffffffff,
  0xc02e000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc013ffffffffffff,
  0xc013ffffffffffff,
  0xc013ffffffffffff,
  0xc013ffffffffffff,
  0xc013ffffffffffff,
  0xc011ffffffffffff,
  0xc011ffffffffffff,
  0xc011ffffffffffff,
  0xc00fffffffffffff,
  0xc00fffffffffffff,
  0xc00ffffffffffffe,
  0xc00bffffffffffff,
  0x4014000000000001,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc013ffffffffffff,
  0xc013ffffffffffff,
  0xc013ffffffffffff,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0x7fe0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x800091a2b3c4d5e6,
  0x801091a2b3c4d5e6,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x8001b4e81b4e81b3,
  0x801091a2b3c4d5e5,
  0x800091a2b3c4d5e7,
  0x800091a2b3c4d5e6,
  0x000f6e5d4c3b2a1a,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000091a2b3c4d5e7,
  0x000f6e5d4c3b2a19,
  0x800091a2b3c4d5e5,
  0x8007ffffffffffff,
  0x8017ffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800923456789abcc,
  0x8017fffffffffffe,
  0x8008000000000000,
  0x8007ffffffffffff,
  0x0008000000000001,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8006dcba98765432,
  0x0008000000000000,
  0x8007fffffffffffe,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0008000000000000,
  0x8008000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0006dcba98765433,
  0x8007ffffffffffff,
  0x0007ffffffffffff,
  0x0008000000000000,
  0x0018000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000923456789abcd,
  0x0017ffffffffffff,
  0x0008000000000001,
  0x3fcffffffffffffe,
  0x3fcffffffffffffe,
  0xbfd0000000000000,
  0xbfd0000000000001,
  0xbfd0000000000003,
  0xbfe7ffffffffffff,
  0xbfe8000000000000,
  0xbfe8000000000002,
  0xbff4000000000000,
  0xc023800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fcffffffffffffe,
  0x3fcffffffffffffe,
  0x3fcffffffffffffe,
  0x3fcffffffffffffe,
  0x3fcffffffffffffe,
  0x3fe7ffffffffffff,
  0x3fe8000000000000,
  0x3fe8000000000001,
  0x3ff3ffffffffffff,
  0x3ff4000000000000,
  0x3ff4000000000001,
  0x3ffc000000000000,
  0x4024800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fcffffffffffffe,
  0x3fcffffffffffffe,
  0x3fcffffffffffffe,
  0x3fcfffffffffffff,
  0x3fcfffffffffffff,
  0xbfcfffffffffffff,
  0xbfd0000000000000,
  0xbfd0000000000002,
  0xbfe7ffffffffffff,
  0xbfe8000000000000,
  0xbfe8000000000002,
  0xbff4000000000000,
  0xc023800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fcfffffffffffff,
  0x3fcfffffffffffff,
  0x3fcfffffffffffff,
  0x3fcfffffffffffff,
  0x3fcfffffffffffff,
  0x3fe7ffffffffffff,
  0x3fe8000000000000,
  0x3fe8000000000001,
  0x3ff3ffffffffffff,
  0x3ff4000000000000,
  0x3ff4000000000001,
  0x3ffc000000000000,
  0x4024800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fcfffffffffffff,
  0x3fcfffffffffffff,
  0x3fcfffffffffffff,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0xbfcffffffffffffd,
  0xbfcfffffffffffff,
  0xbfd0000000000002,
  0xbfe7ffffffffffff,
  0xbfe8000000000000,
  0xbfe8000000000002,
  0xbff4000000000000,
  0xc023800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3fe8000000000001,
  0x3ff4000000000000,
  0x3ff4000000000000,
  0x3ff4000000000001,
  0x3ffc000000000000,
  0x4024800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fdffffffffffffe,
  0x3fdffffffffffffe,
  0xbc8fffffffffffff,
  0xbca0000000000000,
  0xbcb0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000003,
  0xbff0000000000000,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fdffffffffffffe,
  0x3fdffffffffffffe,
  0x3fdffffffffffffe,
  0x3fdffffffffffffe,
  0x3fdffffffffffffe,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff7ffffffffffff,
  0x3ff8000000000000,
  0x3ff8000000000001,
  0x4000000000000000,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fdffffffffffffe,
  0x3fdffffffffffffe,
  0x3fdffffffffffffe,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x0000000000000000,
  0xbc90000000000000,
  0xbca8000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000002,
  0xbff0000000000000,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff7ffffffffffff,
  0x3ff8000000000000,
  0x3ff8000000000001,
  0x4000000000000000,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3c9fffffffffffff,
  0x3c8ffffffffffffe,
  0xbc90000000000001,
  0xbfdffffffffffffd,
  0xbfdfffffffffffff,
  0xbfe0000000000002,
  0xbff0000000000000,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000001,
  0x4000000000000000,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe7ffffffffffff,
  0x3fe7ffffffffffff,
  0x3fcfffffffffffff,
  0x3fcffffffffffffd,
  0x3fcffffffffffff9,
  0xbfcfffffffffffff,
  0xbfd0000000000002,
  0xbfd0000000000006,
  0xbfe8000000000001,
  0xc022800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe7ffffffffffff,
  0x3fe7ffffffffffff,
  0x3fe7ffffffffffff,
  0x3fe7ffffffffffff,
  0x3fe7ffffffffffff,
  0x3ff3ffffffffffff,
  0x3ff4000000000000,
  0x3ff4000000000000,
  0x3ffbffffffffffff,
  0x3ffc000000000000,
  0x3ffc000000000001,
  0x4002000000000000,
  0x4025800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe7ffffffffffff,
  0x3fe7ffffffffffff,
  0x3fe7ffffffffffff,
  0x4013ffffffffffff,
  0x4013ffffffffffff,
  0x4011ffffffffffff,
  0x4011ffffffffffff,
  0x4011ffffffffffff,
  0x400fffffffffffff,
  0x400fffffffffffff,
  0x400ffffffffffffe,
  0x400bffffffffffff,
  0xc014000000000001,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x4013ffffffffffff,
  0x4013ffffffffffff,
  0x4013ffffffffffff,
  0x4013ffffffffffff,
  0x4013ffffffffffff,
  0x4015ffffffffffff,
  0x4015ffffffffffff,
  0x4016000000000000,
  0x4017ffffffffffff,
  0x4017ffffffffffff,
  0x4018000000000000,
  0x4019ffffffffffff,
  0x402e000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x4013ffffffffffff,
  0x4013ffffffffffff,
  0x4013ffffffffffff,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0xffe0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x000091a2b3c4d5e6,
  0x800f6e5d4c3b2a1a,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800091a2b3c4d5e7,
  0x800f6e5d4c3b2a19,
  0x000091a2b3c4d5e5,
  0x000091a2b3c4d5e6,
  0x001091a2b3c4d5e6,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0001b4e81b4e81b3,
  0x001091a2b3c4d5e5,
  0x000091a2b3c4d5e7,
  0x0007ffffffffffff,
  0x8008000000000001,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0006dcba98765432,
  0x8008000000000000,
  0x0007fffffffffffe,
  0x0007ffffffffffff,
  0x0017ffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000923456789abcc,
  0x0017fffffffffffe,
  0x0008000000000000,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8008000000000000,
  0x8018000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800923456789abcd,
  0x8017ffffffffffff,
  0x8008000000000001,
  0x8008000000000000,
  0x0008000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8006dcba98765433,
  0x0007ffffffffffff,
  0x8007ffffffffffff,
  0xbfcfffffffffffff,
  0xbfcfffffffffffff,
  0xbfe7ffffffffffff,
  0xbfe8000000000000,
  0xbfe8000000000001,
  0xbff3ffffffffffff,
  0xbff4000000000000,
  0xbff4000000000001,
  0xbffc000000000000,
  0xc024800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfcfffffffffffff,
  0xbfcfffffffffffff,
  0xbfcfffffffffffff,
  0xbfcfffffffffffff,
  0xbfcfffffffffffff,
  0x3fcfffffffffffff,
  0x3fd0000000000000,
  0x3fd0000000000002,
  0x3fe7ffffffffffff,
  0x3fe8000000000000,
  0x3fe8000000000002,
  0x3ff4000000000000,
  0x4023800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfcfffffffffffff,
  0xbfcfffffffffffff,
  0xbfcfffffffffffff,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbfe8000000000001,
  0xbff4000000000000,
  0xbff4000000000000,
  0xbff4000000000001,
  0xbffc000000000000,
  0xc024800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0x3fcffffffffffffe,
  0x3fd0000000000000,
  0x3fd0000000000002,
  0x3fe7ffffffffffff,
  0x3fe8000000000000,
  0x3fe8000000000002,
  0x3ff4000000000000,
  0x4023800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000001,
  0xbfd0000000000001,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbfe8000000000002,
  0xbff4000000000000,
  0xbff4000000000000,
  0xbff4000000000001,
  0xbffc000000000000,
  0xc024800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfd0000000000001,
  0xbfd0000000000001,
  0xbfd0000000000001,
  0xbfd0000000000001,
  0xbfd0000000000001,
  0x3fcffffffffffffc,
  0x3fcffffffffffffe,
  0x3fd0000000000001,
  0x3fe7fffffffffffe,
  0x3fe8000000000000,
  0x3fe8000000000002,
  0x3ff4000000000000,
  0x4023800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfd0000000000001,
  0xbfd0000000000001,
  0xbfd0000000000001,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff7ffffffffffff,
  0xbff8000000000000,
  0xbff8000000000001,
  0xc000000000000000,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0x0000000000000000,
  0x3c90000000000000,
  0x3ca8000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000002,
  0x3ff0000000000000,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000001,
  0xc000000000000000,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbc90000000000000,
  0x0000000000000000,
  0x3ca0000000000000,
  0x3fdffffffffffffe,
  0x3fe0000000000000,
  0x3fe0000000000002,
  0x3ff0000000000000,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000002,
  0xc000000000000000,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbca8000000000000,
  0xbca0000000000000,
  0x0000000000000000,
  0x3fdffffffffffffc,
  0x3fdffffffffffffe,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbff4000000000000,
  0xbff4000000000000,
  0xbff4000000000000,
  0xbffc000000000000,
  0xbffc000000000000,
  0xbffc000000000001,
  0xc002000000000000,
  0xc025800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbfd0000000000001,
  0xbfd0000000000000,
  0xbfcffffffffffffc,
  0x3fcffffffffffffc,
  0x3fd0000000000000,
  0x3fd0000000000004,
  0x3fe8000000000000,
  0x4022800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xc014000000000000,
  0xc014000000000000,
  0xc016000000000000,
  0xc016000000000000,
  0xc016000000000000,
  0xc018000000000000,
  0xc018000000000000,
  0xc018000000000000,
  0xc01a000000000000,
  0xc02e000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc014000000000000,
  0xc014000000000000,
  0xc014000000000000,
  0xc014000000000000,
  0xc014000000000000,
  0xc012000000000000,
  0xc012000000000000,
  0xc012000000000000,
  0xc010000000000000,
  0xc010000000000000,
  0xc010000000000000,
  0xc00c000000000000,
  0x4014000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc014000000000000,
  0xc014000000000000,
  0xc014000000000000,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0x7fdfffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x800091a2b3c4d5e6,
  0x801091a2b3c4d5e6,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x8001b4e81b4e81b4,
  0x801091a2b3c4d5e6,
  0x800091a2b3c4d5e8,
  0x800091a2b3c4d5e6,
  0x000f6e5d4c3b2a1a,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000091a2b3c4d5e6,
  0x000f6e5d4c3b2a18,
  0x800091a2b3c4d5e6,
  0x8008000000000000,
  0x8018000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800923456789abcc,
  0x8017fffffffffffe,
  0x8008000000000000,
  0x8008000000000000,
  0x0008000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8006dcba98765432,
  0x0008000000000000,
  0x8007fffffffffffe,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abce,
  0x8010000000000000,
  0x8000000000000002,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcc,
  0x000ffffffffffffe,
  0x0000000000000000,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0008000000000000,
  0x8008000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0006dcba98765433,
  0x8007ffffffffffff,
  0x0007ffffffffffff,
  0x0008000000000000,
  0x0018000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000923456789abcd,
  0x0017ffffffffffff,
  0x0008000000000001,
  0x3fcfffffffffffff,
  0x3fcfffffffffffff,
  0xbfcfffffffffffff,
  0xbfd0000000000000,
  0xbfd0000000000002,
  0xbfe7ffffffffffff,
  0xbfe8000000000000,
  0xbfe8000000000002,
  0xbff4000000000000,
  0xc023800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fcfffffffffffff,
  0x3fcfffffffffffff,
  0x3fcfffffffffffff,
  0x3fcfffffffffffff,
  0x3fcfffffffffffff,
  0x3fe7ffffffffffff,
  0x3fe8000000000000,
  0x3fe8000000000001,
  0x3ff3ffffffffffff,
  0x3ff4000000000000,
  0x3ff4000000000001,
  0x3ffc000000000000,
  0x4024800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fcfffffffffffff,
  0x3fcfffffffffffff,
  0x3fcfffffffffffff,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0xbfcffffffffffffe,
  0xbfd0000000000000,
  0xbfd0000000000002,
  0xbfe7ffffffffffff,
  0xbfe8000000000000,
  0xbfe8000000000002,
  0xbff4000000000000,
  0xc023800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3fe8000000000001,
  0x3ff4000000000000,
  0x3ff4000000000000,
  0x3ff4000000000001,
  0x3ffc000000000000,
  0x4024800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000001,
  0x3fd0000000000001,
  0xbfcffffffffffffc,
  0xbfcffffffffffffe,
  0xbfd0000000000001,
  0xbfe7fffffffffffe,
  0xbfe8000000000000,
  0xbfe8000000000002,
  0xbff4000000000000,
  0xc023800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fd0000000000001,
  0x3fd0000000000001,
  0x3fd0000000000001,
  0x3fd0000000000001,
  0x3fd0000000000001,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3fe8000000000002,
  0x3ff4000000000000,
  0x3ff4000000000000,
  0x3ff4000000000001,
  0x3ffc000000000000,
  0x4024800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fd0000000000001,
  0x3fd0000000000001,
  0x3fd0000000000001,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x0000000000000000,
  0xbc90000000000000,
  0xbca8000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000002,
  0xbff0000000000000,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff7ffffffffffff,
  0x3ff8000000000000,
  0x3ff8000000000001,
  0x4000000000000000,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3c90000000000000,
  0x0000000000000000,
  0xbca0000000000000,
  0xbfdffffffffffffe,
  0xbfe0000000000000,
  0xbfe0000000000002,
  0xbff0000000000000,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000001,
  0x4000000000000000,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3ca8000000000000,
  0x3ca0000000000000,
  0x0000000000000000,
  0xbfdffffffffffffc,
  0xbfdffffffffffffe,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000002,
  0x4000000000000000,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3fd0000000000001,
  0x3fd0000000000000,
  0x3fcffffffffffffc,
  0xbfcffffffffffffc,
  0xbfd0000000000000,
  0xbfd0000000000004,
  0xbfe8000000000000,
  0xc022800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3ff4000000000000,
  0x3ff4000000000000,
  0x3ff4000000000000,
  0x3ffc000000000000,
  0x3ffc000000000000,
  0x3ffc000000000001,
  0x4002000000000000,
  0x4025800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x4014000000000000,
  0x4014000000000000,
  0x4012000000000000,
  0x4012000000000000,
  0x4012000000000000,
  0x4010000000000000,
  0x4010000000000000,
  0x4010000000000000,
  0x400c000000000000,
  0xc014000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x4014000000000000,
  0x4014000000000000,
  0x4014000000000000,
  0x4014000000000000,
  0x4014000000000000,
  0x4016000000000000,
  0x4016000000000000,
  0x4016000000000000,
  0x4018000000000000,
  0x4018000000000000,
  0x4018000000000000,
  0x401a000000000000,
  0x402e000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x4014000000000000,
  0x4014000000000000,
  0x4014000000000000,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0xffdfffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x000091a2b3c4d5e6,
  0x800f6e5d4c3b2a1a,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800091a2b3c4d5e6,
  0x800f6e5d4c3b2a18,
  0x000091a2b3c4d5e6,
  0x000091a2b3c4d5e6,
  0x001091a2b3c4d5e6,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0001b4e81b4e81b4,
  0x001091a2b3c4d5e6,
  0x000091a2b3c4d5e8,
  0x0008000000000000,
  0x8008000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0006dcba98765432,
  0x8008000000000000,
  0x0007fffffffffffe,
  0x0008000000000000,
  0x0018000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000923456789abcc,
  0x0017fffffffffffe,
  0x0008000000000000,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcc,
  0x800ffffffffffffe,
  0x8000000000000000,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abce,
  0x0010000000000000,
  0x0000000000000002,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8008000000000000,
  0x8018000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800923456789abce,
  0x8018000000000000,
  0x8008000000000002,
  0x8008000000000000,
  0x0008000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8006dcba98765434,
  0x0007fffffffffffe,
  0x8008000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbfe8000000000001,
  0xbff4000000000000,
  0xbff4000000000000,
  0xbff4000000000001,
  0xbffc000000000000,
  0xc024800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0x3fcffffffffffffd,
  0x3fcfffffffffffff,
  0x3fd0000000000002,
  0x3fe7ffffffffffff,
  0x3fe8000000000000,
  0x3fe8000000000002,
  0x3ff4000000000000,
  0x4023800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000000,
  0xbfd0000000000001,
  0xbfd0000000000001,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbfe8000000000002,
  0xbff4000000000000,
  0xbff4000000000000,
  0xbff4000000000001,
  0xbffc000000000000,
  0xc024800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfd0000000000001,
  0xbfd0000000000001,
  0xbfd0000000000001,
  0xbfd0000000000001,
  0xbfd0000000000001,
  0x3fcffffffffffffc,
  0x3fcffffffffffffe,
  0x3fd0000000000001,
  0x3fe7fffffffffffe,
  0x3fe8000000000000,
  0x3fe8000000000002,
  0x3ff4000000000000,
  0x4023800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfd0000000000001,
  0xbfd0000000000001,
  0xbfd0000000000001,
  0xbfd0000000000002,
  0xbfd0000000000002,
  0xbfe8000000000001,
  0xbfe8000000000001,
  0xbfe8000000000002,
  0xbff4000000000000,
  0xbff4000000000001,
  0xbff4000000000002,
  0xbffc000000000001,
  0xc024800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfd0000000000002,
  0xbfd0000000000002,
  0xbfd0000000000002,
  0xbfd0000000000002,
  0xbfd0000000000002,
  0x3fcffffffffffffa,
  0x3fcffffffffffffc,
  0x3fd0000000000000,
  0x3fe7fffffffffffe,
  0x3fe7ffffffffffff,
  0x3fe8000000000001,
  0x3ff3ffffffffffff,
  0x4023800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfd0000000000002,
  0xbfd0000000000002,
  0xbfd0000000000002,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000001,
  0xc000000000000000,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbc9fffffffffffff,
  0xbc8ffffffffffffe,
  0x3c90000000000001,
  0x3fdffffffffffffd,
  0x3fdfffffffffffff,
  0x3fe0000000000002,
  0x3ff0000000000000,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000002,
  0xc000000000000000,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbca8000000000000,
  0xbca0000000000000,
  0x0000000000000000,
  0x3fdffffffffffffc,
  0x3fdffffffffffffe,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000002,
  0xbfe0000000000002,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000002,
  0xbff8000000000001,
  0xbff8000000000001,
  0xbff8000000000002,
  0xc000000000000001,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe0000000000002,
  0xbfe0000000000002,
  0xbfe0000000000002,
  0xbfe0000000000002,
  0xbfe0000000000002,
  0xbcb4000000000000,
  0xbcb0000000000000,
  0xbca0000000000001,
  0x3fdffffffffffffa,
  0x3fdffffffffffffc,
  0x3fe0000000000000,
  0x3feffffffffffffe,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe0000000000002,
  0xbfe0000000000002,
  0xbfe0000000000002,
  0xbfe8000000000002,
  0xbfe8000000000002,
  0xbff4000000000000,
  0xbff4000000000001,
  0xbff4000000000001,
  0xbffc000000000000,
  0xbffc000000000001,
  0xbffc000000000002,
  0xc002000000000000,
  0xc025800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe8000000000002,
  0xbfe8000000000002,
  0xbfe8000000000002,
  0xbfe8000000000002,
  0xbfe8000000000001,
  0xbfd0000000000004,
  0xbfd0000000000003,
  0xbfd0000000000001,
  0x3fcffffffffffff6,
  0x3fcffffffffffffa,
  0x3fd0000000000001,
  0x3fe7fffffffffffe,
  0x4022800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe8000000000001,
  0xbfe8000000000001,
  0xbfe8000000000001,
  0xc014000000000001,
  0xc014000000000001,
  0xc016000000000001,
  0xc016000000000001,
  0xc016000000000001,
  0xc018000000000001,
  0xc018000000000001,
  0xc018000000000002,
  0xc01a000000000001,
  0xc02e000000000001,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc014000000000001,
  0xc014000000000001,
  0xc014000000000001,
  0xc014000000000001,
  0xc014000000000001,
  0xc012000000000001,
  0xc012000000000001,
  0xc012000000000001,
  0xc010000000000001,
  0xc010000000000001,
  0xc010000000000001,
  0xc00c000000000002,
  0x4013ffffffffffff,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc014000000000001,
  0xc014000000000001,
  0xc014000000000001,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0x7fdffffffffffffd,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x800091a2b3c4d5e7,
  0x801091a2b3c4d5e7,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x8001b4e81b4e81b4,
  0x801091a2b3c4d5e6,
  0x800091a2b3c4d5e8,
  0x800091a2b3c4d5e7,
  0x000f6e5d4c3b2a19,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000091a2b3c4d5e6,
  0x000f6e5d4c3b2a18,
  0x800091a2b3c4d5e6,
  0x8008000000000000,
  0x8018000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800923456789abcd,
  0x8017ffffffffffff,
  0x8008000000000001,
  0x8008000000000000,
  0x0008000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8006dcba98765433,
  0x0007ffffffffffff,
  0x8007ffffffffffff,
  0x8000000000000001,
  0x8010000000000001,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abce,
  0x8010000000000000,
  0x8000000000000002,
  0x8000000000000001,
  0x000fffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcc,
  0x000ffffffffffffe,
  0x0000000000000000,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0008000000000000,
  0x8008000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0006dcba98765434,
  0x8007fffffffffffe,
  0x0008000000000000,
  0x0008000000000000,
  0x0018000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000923456789abce,
  0x0018000000000000,
  0x0008000000000002,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0xbfcffffffffffffd,
  0xbfcfffffffffffff,
  0xbfd0000000000002,
  0xbfe7ffffffffffff,
  0xbfe8000000000000,
  0xbfe8000000000002,
  0xbff4000000000000,
  0xc023800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3fe8000000000001,
  0x3ff4000000000000,
  0x3ff4000000000000,
  0x3ff4000000000001,
  0x3ffc000000000000,
  0x4024800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000000,
  0x3fd0000000000001,
  0x3fd0000000000001,
  0xbfcffffffffffffc,
  0xbfcffffffffffffe,
  0xbfd0000000000001,
  0xbfe7fffffffffffe,
  0xbfe8000000000000,
  0xbfe8000000000002,
  0xbff4000000000000,
  0xc023800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fd0000000000001,
  0x3fd0000000000001,
  0x3fd0000000000001,
  0x3fd0000000000001,
  0x3fd0000000000001,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3fe8000000000002,
  0x3ff4000000000000,
  0x3ff4000000000000,
  0x3ff4000000000001,
  0x3ffc000000000000,
  0x4024800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fd0000000000001,
  0x3fd0000000000001,
  0x3fd0000000000001,
  0x3fd0000000000002,
  0x3fd0000000000002,
  0xbfcffffffffffffa,
  0xbfcffffffffffffc,
  0xbfd0000000000000,
  0xbfe7fffffffffffe,
  0xbfe7ffffffffffff,
  0xbfe8000000000001,
  0xbff3ffffffffffff,
  0xc023800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fd0000000000002,
  0x3fd0000000000002,
  0x3fd0000000000002,
  0x3fd0000000000002,
  0x3fd0000000000002,
  0x3fe8000000000001,
  0x3fe8000000000001,
  0x3fe8000000000002,
  0x3ff4000000000000,
  0x3ff4000000000001,
  0x3ff4000000000002,
  0x3ffc000000000001,
  0x4024800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fd0000000000002,
  0x3fd0000000000002,
  0x3fd0000000000002,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3c9fffffffffffff,
  0x3c8ffffffffffffe,
  0xbc90000000000001,
  0xbfdffffffffffffd,
  0xbfdfffffffffffff,
  0xbfe0000000000002,
  0xbff0000000000000,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000001,
  0x4000000000000000,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3ca8000000000000,
  0x3ca0000000000000,
  0x0000000000000000,
  0xbfdffffffffffffc,
  0xbfdffffffffffffe,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000002,
  0x4000000000000000,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000002,
  0x3fe0000000000002,
  0x3cb4000000000000,
  0x3cb0000000000000,
  0x3ca0000000000001,
  0xbfdffffffffffffa,
  0xbfdffffffffffffc,
  0xbfe0000000000000,
  0xbfeffffffffffffe,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe0000000000002,
  0x3fe0000000000002,
  0x3fe0000000000002,
  0x3fe0000000000002,
  0x3fe0000000000002,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000002,
  0x3ff8000000000001,
  0x3ff8000000000001,
  0x3ff8000000000002,
  0x4000000000000001,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe0000000000002,
  0x3fe0000000000002,
  0x3fe0000000000002,
  0x3fe8000000000002,
  0x3fe8000000000001,
  0x3fd0000000000004,
  0x3fd0000000000003,
  0x3fd0000000000001,
  0xbfcffffffffffff6,
  0xbfcffffffffffffa,
  0xbfd0000000000001,
  0xbfe7fffffffffffe,
  0xc022800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe8000000000001,
  0x3fe8000000000001,
  0x3fe8000000000001,
  0x3fe8000000000002,
  0x3fe8000000000002,
  0x3ff4000000000000,
  0x3ff4000000000001,
  0x3ff4000000000001,
  0x3ffc000000000000,
  0x3ffc000000000001,
  0x3ffc000000000002,
  0x4002000000000000,
  0x4025800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe8000000000002,
  0x3fe8000000000002,
  0x3fe8000000000002,
  0x4014000000000001,
  0x4014000000000001,
  0x4012000000000001,
  0x4012000000000001,
  0x4012000000000001,
  0x4010000000000001,
  0x4010000000000001,
  0x4010000000000001,
  0x400c000000000002,
  0xc013ffffffffffff,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x4014000000000001,
  0x4014000000000001,
  0x4014000000000001,
  0x4014000000000001,
  0x4014000000000001,
  0x4016000000000001,
  0x4016000000000001,
  0x4016000000000001,
  0x4018000000000001,
  0x4018000000000001,
  0x4018000000000002,
  0x401a000000000001,
  0x402e000000000001,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x4014000000000001,
  0x4014000000000001,
  0x4014000000000001,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0xffdffffffffffffd,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x000091a2b3c4d5e7,
  0x800f6e5d4c3b2a19,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800091a2b3c4d5e6,
  0x800f6e5d4c3b2a18,
  0x000091a2b3c4d5e6,
  0x000091a2b3c4d5e7,
  0x001091a2b3c4d5e7,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0001b4e81b4e81b4,
  0x001091a2b3c4d5e6,
  0x000091a2b3c4d5e8,
  0x0008000000000000,
  0x8008000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0006dcba98765433,
  0x8007ffffffffffff,
  0x0007ffffffffffff,
  0x0008000000000000,
  0x0018000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000923456789abcd,
  0x0017ffffffffffff,
  0x0008000000000001,
  0x0000000000000001,
  0x800fffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcc,
  0x800ffffffffffffe,
  0x8000000000000000,
  0x0000000000000001,
  0x0010000000000001,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abce,
  0x0010000000000000,
  0x0000000000000002,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8010000000000000,
  0x8020000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x801123456789abcc,
  0x801ffffffffffffe,
  0x8010000000000000,
  0x8010000000000000,
  0x0000000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x800edcba98765432,
  0x8000000000000000,
  0x800ffffffffffffe,
  0xbfdffffffffffffe,
  0xbfdffffffffffffe,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff7ffffffffffff,
  0xbff8000000000000,
  0xbff8000000000001,
  0xc000000000000000,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfdffffffffffffe,
  0xbfdffffffffffffe,
  0xbfdffffffffffffe,
  0xbfdffffffffffffe,
  0xbfdffffffffffffe,
  0x3c8fffffffffffff,
  0x3ca0000000000000,
  0x3cb0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000003,
  0x3ff0000000000000,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfdffffffffffffe,
  0xbfdffffffffffffe,
  0xbfdffffffffffffe,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff7ffffffffffff,
  0xbff8000000000000,
  0xbff8000000000001,
  0xc000000000000000,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0x0000000000000000,
  0x3c90000000000000,
  0x3ca8000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000002,
  0x3ff0000000000000,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000001,
  0xc000000000000000,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbc9fffffffffffff,
  0xbc8ffffffffffffe,
  0x3c90000000000001,
  0x3fdffffffffffffd,
  0x3fdfffffffffffff,
  0x3fe0000000000002,
  0x3ff0000000000000,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfeffffffffffffe,
  0xbfeffffffffffffe,
  0xbff7ffffffffffff,
  0xbff7ffffffffffff,
  0xbff8000000000000,
  0xbfffffffffffffff,
  0xbfffffffffffffff,
  0xc000000000000000,
  0xc004000000000000,
  0xc026000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfeffffffffffffe,
  0xbfeffffffffffffe,
  0xbfeffffffffffffe,
  0xbfeffffffffffffe,
  0xbfeffffffffffffe,
  0xbfdffffffffffffd,
  0xbfdffffffffffffc,
  0xbfdffffffffffffa,
  0x3c9fffffffffffff,
  0x3cb0000000000000,
  0x3cc0000000000000,
  0x3fe0000000000002,
  0x4022000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfeffffffffffffe,
  0xbfeffffffffffffe,
  0xbfeffffffffffffe,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbff7ffffffffffff,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbfffffffffffffff,
  0xc000000000000000,
  0xc000000000000000,
  0xc004000000000000,
  0xc026000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfdfffffffffffff,
  0xbfdffffffffffffe,
  0xbfdffffffffffffc,
  0x0000000000000000,
  0x3ca0000000000000,
  0x3cb8000000000000,
  0x3fe0000000000001,
  0x4022000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000001,
  0xc000000000000000,
  0xc000000000000000,
  0xc000000000000001,
  0xc004000000000000,
  0xc026000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000000,
  0xbcafffffffffffff,
  0xbc9ffffffffffffe,
  0x3ca0000000000001,
  0x3fdffffffffffffe,
  0x4022000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff7ffffffffffff,
  0xbff7ffffffffffff,
  0xbfffffffffffffff,
  0xbfffffffffffffff,
  0xc000000000000000,
  0xc003ffffffffffff,
  0xc004000000000000,
  0xc004000000000000,
  0xc008000000000000,
  0xc027000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbff7ffffffffffff,
  0xbff7ffffffffffff,
  0xbff7ffffffffffff,
  0xbff7ffffffffffff,
  0xbff7ffffffffffff,
  0xbfefffffffffffff,
  0xbfeffffffffffffe,
  0xbfeffffffffffffe,
  0xbfdfffffffffffff,
  0xbfdffffffffffffd,
  0xbfdffffffffffff9,
  0x3ca8000000000000,
  0x4021000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbff7ffffffffffff,
  0xbff7ffffffffffff,
  0xbff7ffffffffffff,
  0xc023ffffffffffff,
  0xc023ffffffffffff,
  0xc024ffffffffffff,
  0xc024ffffffffffff,
  0xc024ffffffffffff,
  0xc025ffffffffffff,
  0xc025ffffffffffff,
  0xc026000000000000,
  0xc026ffffffffffff,
  0xc034000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc023ffffffffffff,
  0xc023ffffffffffff,
  0xc023ffffffffffff,
  0xc023ffffffffffff,
  0xc023ffffffffffff,
  0xc022ffffffffffff,
  0xc022ffffffffffff,
  0xc022ffffffffffff,
  0xc021ffffffffffff,
  0xc021ffffffffffff,
  0xc021ffffffffffff,
  0xc020ffffffffffff,
  0x3cd4000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc023ffffffffffff,
  0xc023ffffffffffff,
  0xc023ffffffffffff,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0x7c9fffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x800123456789abcd,
  0x801123456789abcd,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x8002468acf13579a,
  0x801123456789abcc,
  0x800123456789abce,
  0x800123456789abcd,
  0x000edcba98765433,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0000000000000000,
  0x000edcba98765432,
  0x800123456789abcc,
  0x800fffffffffffff,
  0x801fffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x801123456789abcc,
  0x801ffffffffffffe,
  0x8010000000000000,
  0x800fffffffffffff,
  0x0000000000000001,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x800edcba98765432,
  0x0000000000000000,
  0x800ffffffffffffe,
  0x8000000000000001,
  0x8010000000000001,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abce,
  0x8010000000000000,
  0x8000000000000002,
  0x8000000000000001,
  0x000fffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcc,
  0x000ffffffffffffe,
  0x0000000000000000,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0010000000000000,
  0x8000000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x000edcba98765432,
  0x0000000000000000,
  0x000ffffffffffffe,
  0x0010000000000000,
  0x0020000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x001123456789abcc,
  0x001ffffffffffffe,
  0x0010000000000000,
  0x3fdffffffffffffe,
  0x3fdffffffffffffe,
  0xbc8fffffffffffff,
  0xbca0000000000000,
  0xbcb0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000003,
  0xbff0000000000000,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fdffffffffffffe,
  0x3fdffffffffffffe,
  0x3fdffffffffffffe,
  0x3fdffffffffffffe,
  0x3fdffffffffffffe,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff7ffffffffffff,
  0x3ff8000000000000,
  0x3ff8000000000001,
  0x4000000000000000,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fdffffffffffffe,
  0x3fdffffffffffffe,
  0x3fdffffffffffffe,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x0000000000000000,
  0xbc90000000000000,
  0xbca8000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000002,
  0xbff0000000000000,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff7ffffffffffff,
  0x3ff8000000000000,
  0x3ff8000000000001,
  0x4000000000000000,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3c9fffffffffffff,
  0x3c8ffffffffffffe,
  0xbc90000000000001,
  0xbfdffffffffffffd,
  0xbfdfffffffffffff,
  0xbfe0000000000002,
  0xbff0000000000000,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000001,
  0x4000000000000000,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3feffffffffffffe,
  0x3feffffffffffffe,
  0x3fdffffffffffffd,
  0x3fdffffffffffffc,
  0x3fdffffffffffffa,
  0xbc9fffffffffffff,
  0xbcb0000000000000,
  0xbcc0000000000000,
  0xbfe0000000000002,
  0xc022000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3feffffffffffffe,
  0x3feffffffffffffe,
  0x3feffffffffffffe,
  0x3feffffffffffffe,
  0x3feffffffffffffe,
  0x3ff7ffffffffffff,
  0x3ff7ffffffffffff,
  0x3ff8000000000000,
  0x3fffffffffffffff,
  0x3fffffffffffffff,
  0x4000000000000000,
  0x4004000000000000,
  0x4026000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3feffffffffffffe,
  0x3feffffffffffffe,
  0x3feffffffffffffe,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fdfffffffffffff,
  0x3fdffffffffffffe,
  0x3fdffffffffffffc,
  0x0000000000000000,
  0xbca0000000000000,
  0xbcb8000000000000,
  0xbfe0000000000001,
  0xc022000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3ff7ffffffffffff,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3fffffffffffffff,
  0x4000000000000000,
  0x4000000000000000,
  0x4004000000000000,
  0x4026000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000000,
  0x3cafffffffffffff,
  0x3c9ffffffffffffe,
  0xbca0000000000001,
  0xbfdffffffffffffe,
  0xc022000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000001,
  0x4000000000000000,
  0x4000000000000000,
  0x4000000000000001,
  0x4004000000000000,
  0x4026000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff7ffffffffffff,
  0x3ff7ffffffffffff,
  0x3fefffffffffffff,
  0x3feffffffffffffe,
  0x3feffffffffffffe,
  0x3fdfffffffffffff,
  0x3fdffffffffffffd,
  0x3fdffffffffffff9,
  0xbca8000000000000,
  0xc021000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3ff7ffffffffffff,
  0x3ff7ffffffffffff,
  0x3ff7ffffffffffff,
  0x3ff7ffffffffffff,
  0x3ff7ffffffffffff,
  0x3fffffffffffffff,
  0x3fffffffffffffff,
  0x4000000000000000,
  0x4003ffffffffffff,
  0x4004000000000000,
  0x4004000000000000,
  0x4008000000000000,
  0x4027000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3ff7ffffffffffff,
  0x3ff7ffffffffffff,
  0x3ff7ffffffffffff,
  0x4023ffffffffffff,
  0x4023ffffffffffff,
  0x4022ffffffffffff,
  0x4022ffffffffffff,
  0x4022ffffffffffff,
  0x4021ffffffffffff,
  0x4021ffffffffffff,
  0x4021ffffffffffff,
  0x4020ffffffffffff,
  0xbcd4000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x4023ffffffffffff,
  0x4023ffffffffffff,
  0x4023ffffffffffff,
  0x4023ffffffffffff,
  0x4023ffffffffffff,
  0x4024ffffffffffff,
  0x4024ffffffffffff,
  0x4024ffffffffffff,
  0x4025ffffffffffff,
  0x4025ffffffffffff,
  0x4026000000000000,
  0x4026ffffffffffff,
  0x4034000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x4023ffffffffffff,
  0x4023ffffffffffff,
  0x4023ffffffffffff,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0xfc9fffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x800edcba98765433,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x8000000000000000,
  0x800edcba98765432,
  0x000123456789abcc,
  0x000123456789abcd,
  0x001123456789abcd,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0002468acf13579a,
  0x001123456789abcc,
  0x000123456789abce,
  0x000fffffffffffff,
  0x8000000000000001,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x000edcba98765432,
  0x8000000000000000,
  0x000ffffffffffffe,
  0x000fffffffffffff,
  0x001fffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x001123456789abcc,
  0x001ffffffffffffe,
  0x0010000000000000,
  0x0000000000000001,
  0x800fffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcc,
  0x800ffffffffffffe,
  0x8000000000000000,
  0x0000000000000001,
  0x0010000000000001,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abce,
  0x0010000000000000,
  0x0000000000000002,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8010000000000000,
  0x8020000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x801123456789abcd,
  0x801fffffffffffff,
  0x8010000000000001,
  0x8010000000000000,
  0x0000000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x800edcba98765433,
  0x8000000000000001,
  0x800fffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff7ffffffffffff,
  0xbff8000000000000,
  0xbff8000000000001,
  0xc000000000000000,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0x0000000000000000,
  0x3c90000000000000,
  0x3ca8000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000002,
  0x3ff0000000000000,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000001,
  0xc000000000000000,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbc90000000000000,
  0x0000000000000000,
  0x3ca0000000000000,
  0x3fdffffffffffffe,
  0x3fe0000000000000,
  0x3fe0000000000002,
  0x3ff0000000000000,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000002,
  0xc000000000000000,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbca8000000000000,
  0xbca0000000000000,
  0x0000000000000000,
  0x3fdffffffffffffc,
  0x3fdffffffffffffe,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbff7ffffffffffff,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbfffffffffffffff,
  0xc000000000000000,
  0xc000000000000000,
  0xc004000000000000,
  0xc026000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfdfffffffffffff,
  0xbfdffffffffffffe,
  0xbfdffffffffffffc,
  0x0000000000000000,
  0x3ca0000000000000,
  0x3cb8000000000000,
  0x3fe0000000000001,
  0x4022000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xc000000000000000,
  0xc000000000000000,
  0xc000000000000000,
  0xc004000000000000,
  0xc026000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfdffffffffffffe,
  0xbca0000000000000,
  0x0000000000000000,
  0x3cb0000000000000,
  0x3fe0000000000000,
  0x4022000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff8000000000001,
  0xbff8000000000001,
  0xbff8000000000002,
  0xc000000000000000,
  0xc000000000000000,
  0xc000000000000001,
  0xc004000000000000,
  0xc026000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbfe0000000000002,
  0xbfe0000000000002,
  0xbfe0000000000001,
  0xbcb8000000000000,
  0xbcb0000000000000,
  0x0000000000000000,
  0x3fdffffffffffffc,
  0x4022000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff8000000000000,
  0xbff8000000000000,
  0xc000000000000000,
  0xc000000000000000,
  0xc000000000000000,
  0xc004000000000000,
  0xc004000000000000,
  0xc004000000000000,
  0xc008000000000000,
  0xc027000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbfefffffffffffff,
  0xbfe0000000000001,
  0xbfe0000000000000,
  0xbfdffffffffffffc,
  0x0000000000000000,
  0x4021000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc025000000000000,
  0xc025000000000000,
  0xc025000000000000,
  0xc026000000000000,
  0xc026000000000000,
  0xc026000000000000,
  0xc027000000000000,
  0xc034000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc023000000000000,
  0xc023000000000000,
  0xc023000000000000,
  0xc022000000000000,
  0xc022000000000000,
  0xc022000000000000,
  0xc021000000000000,
  0x0000000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0x0000000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x800123456789abcd,
  0x801123456789abcd,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x8002468acf13579a,
  0x801123456789abcc,
  0x800123456789abce,
  0x800123456789abcd,
  0x000edcba98765433,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0000000000000000,
  0x000edcba98765432,
  0x800123456789abcc,
  0x800fffffffffffff,
  0x801fffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x801123456789abcc,
  0x801ffffffffffffe,
  0x8010000000000000,
  0x800fffffffffffff,
  0x0000000000000001,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x800edcba98765432,
  0x0000000000000000,
  0x800ffffffffffffe,
  0x8000000000000001,
  0x8010000000000001,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abce,
  0x8010000000000000,
  0x8000000000000002,
  0x8000000000000001,
  0x000fffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcc,
  0x000ffffffffffffe,
  0x0000000000000000,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0010000000000000,
  0x0000000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x000edcba98765433,
  0x0000000000000001,
  0x000fffffffffffff,
  0x0010000000000000,
  0x0020000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x001123456789abcd,
  0x001fffffffffffff,
  0x0010000000000001,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x0000000000000000,
  0xbc90000000000000,
  0xbca8000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000002,
  0xbff0000000000000,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff7ffffffffffff,
  0x3ff8000000000000,
  0x3ff8000000000001,
  0x4000000000000000,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3c90000000000000,
  0x0000000000000000,
  0xbca0000000000000,
  0xbfdffffffffffffe,
  0xbfe0000000000000,
  0xbfe0000000000002,
  0xbff0000000000000,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000001,
  0x4000000000000000,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3ca8000000000000,
  0x3ca0000000000000,
  0x0000000000000000,
  0xbfdffffffffffffc,
  0xbfdffffffffffffe,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000002,
  0x4000000000000000,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fdfffffffffffff,
  0x3fdffffffffffffe,
  0x3fdffffffffffffc,
  0x0000000000000000,
  0xbca0000000000000,
  0xbcb8000000000000,
  0xbfe0000000000001,
  0xc022000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3ff7ffffffffffff,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3fffffffffffffff,
  0x4000000000000000,
  0x4000000000000000,
  0x4004000000000000,
  0x4026000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fdffffffffffffe,
  0x3ca0000000000000,
  0x0000000000000000,
  0xbcb0000000000000,
  0xbfe0000000000000,
  0xc022000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x4000000000000000,
  0x4000000000000000,
  0x4000000000000000,
  0x4004000000000000,
  0x4026000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3fe0000000000002,
  0x3fe0000000000002,
  0x3fe0000000000001,
  0x3cb8000000000000,
  0x3cb0000000000000,
  0x0000000000000000,
  0xbfdffffffffffffc,
  0xc022000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff8000000000001,
  0x3ff8000000000001,
  0x3ff8000000000002,
  0x4000000000000000,
  0x4000000000000000,
  0x4000000000000001,
  0x4004000000000000,
  0x4026000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3fefffffffffffff,
  0x3fe0000000000001,
  0x3fe0000000000000,
  0x3fdffffffffffffc,
  0x0000000000000000,
  0xc021000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x4000000000000000,
  0x4000000000000000,
  0x4000000000000000,
  0x4004000000000000,
  0x4004000000000000,
  0x4004000000000000,
  0x4008000000000000,
  0x4027000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4023000000000000,
  0x4023000000000000,
  0x4023000000000000,
  0x4022000000000000,
  0x4022000000000000,
  0x4022000000000000,
  0x4021000000000000,
  0x0000000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4025000000000000,
  0x4025000000000000,
  0x4025000000000000,
  0x4026000000000000,
  0x4026000000000000,
  0x4026000000000000,
  0x4027000000000000,
  0x4034000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x0000000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x800edcba98765433,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0000000000000000,
  0x800edcba98765432,
  0x000123456789abcc,
  0x000123456789abcd,
  0x001123456789abcd,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0002468acf13579a,
  0x001123456789abcc,
  0x000123456789abce,
  0x000fffffffffffff,
  0x8000000000000001,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x000edcba98765432,
  0x0000000000000000,
  0x000ffffffffffffe,
  0x000fffffffffffff,
  0x001fffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x001123456789abcc,
  0x001ffffffffffffe,
  0x0010000000000000,
  0x0000000000000001,
  0x800fffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcc,
  0x800ffffffffffffe,
  0x0000000000000000,
  0x0000000000000001,
  0x0010000000000001,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abce,
  0x0010000000000000,
  0x0000000000000002,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8010000000000001,
  0x8020000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x801123456789abce,
  0x8020000000000000,
  0x8010000000000002,
  0x8010000000000001,
  0x8000000000000001,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x800edcba98765434,
  0x8000000000000002,
  0x8010000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000001,
  0xc000000000000000,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbc9fffffffffffff,
  0xbc8ffffffffffffe,
  0x3c90000000000001,
  0x3fdffffffffffffd,
  0x3fdfffffffffffff,
  0x3fe0000000000002,
  0x3ff0000000000000,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000002,
  0xc000000000000000,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbca8000000000000,
  0xbca0000000000000,
  0x0000000000000000,
  0x3fdffffffffffffc,
  0x3fdffffffffffffe,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000002,
  0xbfe0000000000002,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000002,
  0xbff8000000000001,
  0xbff8000000000001,
  0xbff8000000000002,
  0xc000000000000001,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe0000000000002,
  0xbfe0000000000002,
  0xbfe0000000000002,
  0xbfe0000000000002,
  0xbfe0000000000002,
  0xbcb4000000000000,
  0xbcb0000000000000,
  0xbca0000000000001,
  0x3fdffffffffffffa,
  0x3fdffffffffffffc,
  0x3fe0000000000000,
  0x3feffffffffffffe,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe0000000000002,
  0xbfe0000000000002,
  0xbfe0000000000002,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000001,
  0xc000000000000000,
  0xc000000000000000,
  0xc000000000000001,
  0xc004000000000000,
  0xc026000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000000,
  0xbcafffffffffffff,
  0xbc9ffffffffffffe,
  0x3ca0000000000001,
  0x3fdffffffffffffe,
  0x4022000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff8000000000001,
  0xbff8000000000001,
  0xbff8000000000002,
  0xc000000000000000,
  0xc000000000000000,
  0xc000000000000001,
  0xc004000000000000,
  0xc026000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbfe0000000000002,
  0xbfe0000000000002,
  0xbfe0000000000001,
  0xbcb8000000000000,
  0xbcb0000000000000,
  0x0000000000000000,
  0x3fdffffffffffffc,
  0x4022000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000002,
  0xbff0000000000002,
  0xbff8000000000002,
  0xbff8000000000002,
  0xbff8000000000003,
  0xc000000000000001,
  0xc000000000000001,
  0xc000000000000002,
  0xc004000000000001,
  0xc026000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbff0000000000002,
  0xbff0000000000002,
  0xbff0000000000002,
  0xbff0000000000002,
  0xbff0000000000002,
  0xbfe0000000000005,
  0xbfe0000000000004,
  0xbfe0000000000003,
  0xbcc4000000000000,
  0xbcc0000000000000,
  0xbcb0000000000001,
  0x3fdffffffffffff8,
  0x4022000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbff0000000000002,
  0xbff0000000000002,
  0xbff0000000000002,
  0xbff8000000000002,
  0xbff8000000000002,
  0xc000000000000001,
  0xc000000000000001,
  0xc000000000000001,
  0xc004000000000000,
  0xc004000000000001,
  0xc004000000000001,
  0xc008000000000001,
  0xc027000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbff8000000000002,
  0xbff8000000000002,
  0xbff8000000000002,
  0xbff8000000000002,
  0xbff8000000000001,
  0xbff0000000000002,
  0xbff0000000000002,
  0xbff0000000000001,
  0xbfe0000000000004,
  0xbfe0000000000003,
  0xbfe0000000000001,
  0xbcb8000000000000,
  0x4021000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbff8000000000001,
  0xbff8000000000001,
  0xbff8000000000001,
  0xc024000000000001,
  0xc024000000000001,
  0xc025000000000001,
  0xc025000000000001,
  0xc025000000000001,
  0xc026000000000001,
  0xc026000000000001,
  0xc026000000000001,
  0xc027000000000001,
  0xc034000000000001,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc024000000000001,
  0xc024000000000001,
  0xc024000000000001,
  0xc024000000000001,
  0xc024000000000001,
  0xc023000000000001,
  0xc023000000000001,
  0xc023000000000001,
  0xc022000000000001,
  0xc022000000000001,
  0xc022000000000001,
  0xc021000000000001,
  0xbce4000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc024000000000001,
  0xc024000000000001,
  0xc024000000000001,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfcafffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x800123456789abcd,
  0x801123456789abcd,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x8002468acf13579a,
  0x801123456789abcc,
  0x800123456789abce,
  0x800123456789abcd,
  0x000edcba98765433,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8000000000000000,
  0x000edcba98765432,
  0x800123456789abcc,
  0x8010000000000000,
  0x8020000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x801123456789abcd,
  0x801fffffffffffff,
  0x8010000000000001,
  0x8010000000000000,
  0x0000000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x800edcba98765433,
  0x8000000000000001,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8010000000000001,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abce,
  0x8010000000000000,
  0x8000000000000002,
  0x8000000000000001,
  0x000fffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcc,
  0x000ffffffffffffe,
  0x8000000000000000,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0010000000000001,
  0x0000000000000001,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x000edcba98765434,
  0x0000000000000002,
  0x0010000000000000,
  0x0010000000000001,
  0x0020000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x001123456789abce,
  0x0020000000000000,
  0x0010000000000002,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3c9fffffffffffff,
  0x3c8ffffffffffffe,
  0xbc90000000000001,
  0xbfdffffffffffffd,
  0xbfdfffffffffffff,
  0xbfe0000000000002,
  0xbff0000000000000,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000001,
  0x4000000000000000,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3ca8000000000000,
  0x3ca0000000000000,
  0x0000000000000000,
  0xbfdffffffffffffc,
  0xbfdffffffffffffe,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000002,
  0x4000000000000000,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000002,
  0x3fe0000000000002,
  0x3cb4000000000000,
  0x3cb0000000000000,
  0x3ca0000000000001,
  0xbfdffffffffffffa,
  0xbfdffffffffffffc,
  0xbfe0000000000000,
  0xbfeffffffffffffe,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe0000000000002,
  0x3fe0000000000002,
  0x3fe0000000000002,
  0x3fe0000000000002,
  0x3fe0000000000002,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000002,
  0x3ff8000000000001,
  0x3ff8000000000001,
  0x3ff8000000000002,
  0x4000000000000001,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe0000000000002,
  0x3fe0000000000002,
  0x3fe0000000000002,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000000,
  0x3cafffffffffffff,
  0x3c9ffffffffffffe,
  0xbca0000000000001,
  0xbfdffffffffffffe,
  0xc022000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000001,
  0x4000000000000000,
  0x4000000000000000,
  0x4000000000000001,
  0x4004000000000000,
  0x4026000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3fe0000000000002,
  0x3fe0000000000002,
  0x3fe0000000000001,
  0x3cb8000000000000,
  0x3cb0000000000000,
  0x0000000000000000,
  0xbfdffffffffffffc,
  0xc022000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff8000000000001,
  0x3ff8000000000001,
  0x3ff8000000000002,
  0x4000000000000000,
  0x4000000000000000,
  0x4000000000000001,
  0x4004000000000000,
  0x4026000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000002,
  0x3ff0000000000002,
  0x3fe0000000000005,
  0x3fe0000000000004,
  0x3fe0000000000003,
  0x3cc4000000000000,
  0x3cc0000000000000,
  0x3cb0000000000001,
  0xbfdffffffffffff8,
  0xc022000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3ff0000000000002,
  0x3ff0000000000002,
  0x3ff0000000000002,
  0x3ff0000000000002,
  0x3ff0000000000002,
  0x3ff8000000000002,
  0x3ff8000000000002,
  0x3ff8000000000003,
  0x4000000000000001,
  0x4000000000000001,
  0x4000000000000002,
  0x4004000000000001,
  0x4026000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3ff0000000000002,
  0x3ff0000000000002,
  0x3ff0000000000002,
  0x3ff8000000000002,
  0x3ff8000000000001,
  0x3ff0000000000002,
  0x3ff0000000000002,
  0x3ff0000000000001,
  0x3fe0000000000004,
  0x3fe0000000000003,
  0x3fe0000000000001,
  0x3cb8000000000000,
  0xc021000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3ff8000000000001,
  0x3ff8000000000001,
  0x3ff8000000000001,
  0x3ff8000000000002,
  0x3ff8000000000002,
  0x4000000000000001,
  0x4000000000000001,
  0x4000000000000001,
  0x4004000000000000,
  0x4004000000000001,
  0x4004000000000001,
  0x4008000000000001,
  0x4027000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3ff8000000000002,
  0x3ff8000000000002,
  0x3ff8000000000002,
  0x4024000000000001,
  0x4024000000000001,
  0x4023000000000001,
  0x4023000000000001,
  0x4023000000000001,
  0x4022000000000001,
  0x4022000000000001,
  0x4022000000000001,
  0x4021000000000001,
  0x3ce4000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x4024000000000001,
  0x4024000000000001,
  0x4024000000000001,
  0x4024000000000001,
  0x4024000000000001,
  0x4025000000000001,
  0x4025000000000001,
  0x4025000000000001,
  0x4026000000000001,
  0x4026000000000001,
  0x4026000000000001,
  0x4027000000000001,
  0x4034000000000001,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x4024000000000001,
  0x4024000000000001,
  0x4024000000000001,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7cafffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x800edcba98765433,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0000000000000000,
  0x800edcba98765432,
  0x000123456789abcc,
  0x000123456789abcd,
  0x001123456789abcd,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0002468acf13579a,
  0x001123456789abcc,
  0x000123456789abce,
  0x0010000000000000,
  0x8000000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x000edcba98765433,
  0x0000000000000001,
  0x000fffffffffffff,
  0x0010000000000000,
  0x0020000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x001123456789abcd,
  0x001fffffffffffff,
  0x0010000000000001,
  0x0000000000000001,
  0x800fffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcc,
  0x800ffffffffffffe,
  0x0000000000000000,
  0x0000000000000001,
  0x0010000000000001,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abce,
  0x0010000000000000,
  0x0000000000000002,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8018000000000000,
  0x8024000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x801923456789abcd,
  0x8024000000000000,
  0x8018000000000001,
  0x8018000000000000,
  0x8008000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8016dcba98765433,
  0x8008000000000001,
  0x8017ffffffffffff,
  0xbfe7ffffffffffff,
  0xbfe7ffffffffffff,
  0xbff3ffffffffffff,
  0xbff4000000000000,
  0xbff4000000000000,
  0xbffbffffffffffff,
  0xbffc000000000000,
  0xbffc000000000001,
  0xc002000000000000,
  0xc025800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe7ffffffffffff,
  0xbfe7ffffffffffff,
  0xbfe7ffffffffffff,
  0xbfe7ffffffffffff,
  0xbfe7ffffffffffff,
  0xbfcfffffffffffff,
  0xbfcffffffffffffd,
  0xbfcffffffffffff9,
  0x3fcfffffffffffff,
  0x3fd0000000000002,
  0x3fd0000000000006,
  0x3fe8000000000001,
  0x4022800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe7ffffffffffff,
  0xbfe7ffffffffffff,
  0xbfe7ffffffffffff,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbff4000000000000,
  0xbff4000000000000,
  0xbff4000000000000,
  0xbffc000000000000,
  0xbffc000000000000,
  0xbffc000000000001,
  0xc002000000000000,
  0xc025800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbfd0000000000001,
  0xbfd0000000000000,
  0xbfcffffffffffffc,
  0x3fcffffffffffffc,
  0x3fd0000000000000,
  0x3fd0000000000004,
  0x3fe8000000000000,
  0x4022800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbfe8000000000000,
  0xbfe8000000000002,
  0xbfe8000000000002,
  0xbff4000000000000,
  0xbff4000000000001,
  0xbff4000000000001,
  0xbffc000000000000,
  0xbffc000000000001,
  0xbffc000000000002,
  0xc002000000000000,
  0xc025800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfe8000000000002,
  0xbfe8000000000002,
  0xbfe8000000000002,
  0xbfe8000000000002,
  0xbfe8000000000001,
  0xbfd0000000000004,
  0xbfd0000000000003,
  0xbfd0000000000001,
  0x3fcffffffffffff6,
  0x3fcffffffffffffa,
  0x3fd0000000000001,
  0x3fe7fffffffffffe,
  0x4022800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfe8000000000001,
  0xbfe8000000000001,
  0xbfe8000000000001,
  0xbff7ffffffffffff,
  0xbff7ffffffffffff,
  0xbfffffffffffffff,
  0xbfffffffffffffff,
  0xc000000000000000,
  0xc003ffffffffffff,
  0xc004000000000000,
  0xc004000000000000,
  0xc008000000000000,
  0xc027000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbff7ffffffffffff,
  0xbff7ffffffffffff,
  0xbff7ffffffffffff,
  0xbff7ffffffffffff,
  0xbff7ffffffffffff,
  0xbfefffffffffffff,
  0xbfeffffffffffffe,
  0xbfeffffffffffffe,
  0xbfdfffffffffffff,
  0xbfdffffffffffffd,
  0xbfdffffffffffff9,
  0x3ca8000000000000,
  0x4021000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbff7ffffffffffff,
  0xbff7ffffffffffff,
  0xbff7ffffffffffff,
  0xbff8000000000000,
  0xbff8000000000000,
  0xc000000000000000,
  0xc000000000000000,
  0xc000000000000000,
  0xc004000000000000,
  0xc004000000000000,
  0xc004000000000000,
  0xc008000000000000,
  0xc027000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbfefffffffffffff,
  0xbfe0000000000001,
  0xbfe0000000000000,
  0xbfdffffffffffffc,
  0x0000000000000000,
  0x4021000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000002,
  0xbff8000000000002,
  0xc000000000000001,
  0xc000000000000001,
  0xc000000000000001,
  0xc004000000000000,
  0xc004000000000001,
  0xc004000000000001,
  0xc008000000000001,
  0xc027000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbff8000000000002,
  0xbff8000000000002,
  0xbff8000000000002,
  0xbff8000000000002,
  0xbff8000000000001,
  0xbff0000000000002,
  0xbff0000000000002,
  0xbff0000000000001,
  0xbfe0000000000004,
  0xbfe0000000000003,
  0xbfe0000000000001,
  0xbcb8000000000000,
  0x4021000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbff8000000000001,
  0xbff8000000000001,
  0xbff8000000000001,
  0xc002000000000000,
  0xc002000000000000,
  0xc006000000000000,
  0xc006000000000000,
  0xc006000000000000,
  0xc00a000000000000,
  0xc00a000000000000,
  0xc00a000000000000,
  0xc00e000000000000,
  0xc028800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc002000000000000,
  0xc002000000000000,
  0xc002000000000000,
  0xc002000000000000,
  0xc002000000000000,
  0xbffc000000000000,
  0xbffc000000000000,
  0xbffc000000000000,
  0xbff4000000000000,
  0xbff4000000000000,
  0xbff3ffffffffffff,
  0xbfe8000000000000,
  0x401f000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc002000000000000,
  0xc002000000000000,
  0xc002000000000000,
  0xc02e000000000000,
  0xc02e000000000000,
  0xc02f000000000000,
  0xc02f000000000000,
  0xc02f000000000000,
  0xc030000000000000,
  0xc030000000000000,
  0xc030000000000000,
  0xc030800000000000,
  0xc039000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc02e000000000000,
  0xc02e000000000000,
  0xc02e000000000000,
  0xc02e000000000000,
  0xc02e000000000000,
  0xc02d000000000000,
  0xc02d000000000000,
  0xc02d000000000000,
  0xc02c000000000000,
  0xc02c000000000000,
  0xc02c000000000000,
  0xc02b000000000000,
  0xc014000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc02e000000000000,
  0xc02e000000000000,
  0xc02e000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xffdfffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x8001b4e81b4e81b4,
  0x8011b4e81b4e81b4,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x8002d82d82d82d80,
  0x8011b4e81b4e81b2,
  0x8001b4e81b4e81b4,
  0x8001b4e81b4e81b4,
  0x000e4b17e4b17e4c,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x800091a2b3c4d5e6,
  0x000e4b17e4b17e4c,
  0x8001b4e81b4e81b2,
  0x8017fffffffffffe,
  0x8023ffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x801923456789abcc,
  0x8023ffffffffffff,
  0x8018000000000000,
  0x8017fffffffffffe,
  0x8007fffffffffffe,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8016dcba98765432,
  0x8008000000000000,
  0x8017fffffffffffe,
  0x8000000000000002,
  0x8010000000000002,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abce,
  0x8010000000000000,
  0x8000000000000002,
  0x8000000000000002,
  0x000ffffffffffffe,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcc,
  0x000ffffffffffffe,
  0x8000000000000000,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0018000000000000,
  0x0008000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0016dcba98765433,
  0x0008000000000001,
  0x0017ffffffffffff,
  0x0018000000000000,
  0x0024000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x001923456789abcd,
  0x0024000000000000,
  0x0018000000000001,
  0x3fe7ffffffffffff,
  0x3fe7ffffffffffff,
  0x3fcfffffffffffff,
  0x3fcffffffffffffd,
  0x3fcffffffffffff9,
  0xbfcfffffffffffff,
  0xbfd0000000000002,
  0xbfd0000000000006,
  0xbfe8000000000001,
  0xc022800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe7ffffffffffff,
  0x3fe7ffffffffffff,
  0x3fe7ffffffffffff,
  0x3fe7ffffffffffff,
  0x3fe7ffffffffffff,
  0x3ff3ffffffffffff,
  0x3ff4000000000000,
  0x3ff4000000000000,
  0x3ffbffffffffffff,
  0x3ffc000000000000,
  0x3ffc000000000001,
  0x4002000000000000,
  0x4025800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe7ffffffffffff,
  0x3fe7ffffffffffff,
  0x3fe7ffffffffffff,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3fd0000000000001,
  0x3fd0000000000000,
  0x3fcffffffffffffc,
  0xbfcffffffffffffc,
  0xbfd0000000000000,
  0xbfd0000000000004,
  0xbfe8000000000000,
  0xc022800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3ff4000000000000,
  0x3ff4000000000000,
  0x3ff4000000000000,
  0x3ffc000000000000,
  0x3ffc000000000000,
  0x3ffc000000000001,
  0x4002000000000000,
  0x4025800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3fe8000000000000,
  0x3fe8000000000002,
  0x3fe8000000000001,
  0x3fd0000000000004,
  0x3fd0000000000003,
  0x3fd0000000000001,
  0xbfcffffffffffff6,
  0xbfcffffffffffffa,
  0xbfd0000000000001,
  0xbfe7fffffffffffe,
  0xc022800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fe8000000000001,
  0x3fe8000000000001,
  0x3fe8000000000001,
  0x3fe8000000000002,
  0x3fe8000000000002,
  0x3ff4000000000000,
  0x3ff4000000000001,
  0x3ff4000000000001,
  0x3ffc000000000000,
  0x3ffc000000000001,
  0x3ffc000000000002,
  0x4002000000000000,
  0x4025800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fe8000000000002,
  0x3fe8000000000002,
  0x3fe8000000000002,
  0x3ff7ffffffffffff,
  0x3ff7ffffffffffff,
  0x3fefffffffffffff,
  0x3feffffffffffffe,
  0x3feffffffffffffe,
  0x3fdfffffffffffff,
  0x3fdffffffffffffd,
  0x3fdffffffffffff9,
  0xbca8000000000000,
  0xc021000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3ff7ffffffffffff,
  0x3ff7ffffffffffff,
  0x3ff7ffffffffffff,
  0x3ff7ffffffffffff,
  0x3ff7ffffffffffff,
  0x3fffffffffffffff,
  0x3fffffffffffffff,
  0x4000000000000000,
  0x4003ffffffffffff,
  0x4004000000000000,
  0x4004000000000000,
  0x4008000000000000,
  0x4027000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3ff7ffffffffffff,
  0x3ff7ffffffffffff,
  0x3ff7ffffffffffff,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3fefffffffffffff,
  0x3fe0000000000001,
  0x3fe0000000000000,
  0x3fdffffffffffffc,
  0x0000000000000000,
  0xc021000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x4000000000000000,
  0x4000000000000000,
  0x4000000000000000,
  0x4004000000000000,
  0x4004000000000000,
  0x4004000000000000,
  0x4008000000000000,
  0x4027000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000002,
  0x3ff8000000000001,
  0x3ff0000000000002,
  0x3ff0000000000002,
  0x3ff0000000000001,
  0x3fe0000000000004,
  0x3fe0000000000003,
  0x3fe0000000000001,
  0x3cb8000000000000,
  0xc021000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3ff8000000000001,
  0x3ff8000000000001,
  0x3ff8000000000001,
  0x3ff8000000000002,
  0x3ff8000000000002,
  0x4000000000000001,
  0x4000000000000001,
  0x4000000000000001,
  0x4004000000000000,
  0x4004000000000001,
  0x4004000000000001,
  0x4008000000000001,
  0x4027000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3ff8000000000002,
  0x3ff8000000000002,
  0x3ff8000000000002,
  0x4002000000000000,
  0x4002000000000000,
  0x3ffc000000000000,
  0x3ffc000000000000,
  0x3ffc000000000000,
  0x3ff4000000000000,
  0x3ff4000000000000,
  0x3ff3ffffffffffff,
  0x3fe8000000000000,
  0xc01f000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x4002000000000000,
  0x4002000000000000,
  0x4002000000000000,
  0x4002000000000000,
  0x4002000000000000,
  0x4006000000000000,
  0x4006000000000000,
  0x4006000000000000,
  0x400a000000000000,
  0x400a000000000000,
  0x400a000000000000,
  0x400e000000000000,
  0x4028800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x4002000000000000,
  0x4002000000000000,
  0x4002000000000000,
  0x402e000000000000,
  0x402e000000000000,
  0x402d000000000000,
  0x402d000000000000,
  0x402d000000000000,
  0x402c000000000000,
  0x402c000000000000,
  0x402c000000000000,
  0x402b000000000000,
  0x4014000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x402e000000000000,
  0x402e000000000000,
  0x402e000000000000,
  0x402e000000000000,
  0x402e000000000000,
  0x402f000000000000,
  0x402f000000000000,
  0x402f000000000000,
  0x4030000000000000,
  0x4030000000000000,
  0x4030000000000000,
  0x4030800000000000,
  0x4039000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x402e000000000000,
  0x402e000000000000,
  0x402e000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7fdfffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x0001b4e81b4e81b4,
  0x800e4b17e4b17e4c,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x000091a2b3c4d5e6,
  0x800e4b17e4b17e4c,
  0x0001b4e81b4e81b2,
  0x0001b4e81b4e81b4,
  0x0011b4e81b4e81b4,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0002d82d82d82d80,
  0x0011b4e81b4e81b2,
  0x0001b4e81b4e81b4,
  0x0017fffffffffffe,
  0x0007fffffffffffe,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0016dcba98765432,
  0x0008000000000000,
  0x0017fffffffffffe,
  0x0017fffffffffffe,
  0x0023ffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x001923456789abcc,
  0x0023ffffffffffff,
  0x0018000000000000,
  0x0000000000000002,
  0x800ffffffffffffe,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcc,
  0x800ffffffffffffe,
  0x0000000000000000,
  0x0000000000000002,
  0x0010000000000002,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abce,
  0x0010000000000000,
  0x0000000000000002,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8044000000000000,
  0x8046000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x80442468acf1357a,
  0x8046000000000000,
  0x8044000000000000,
  0x8044000000000000,
  0x8042000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8043db97530eca86,
  0x8042000000000000,
  0x8044000000000000,
  0xc013ffffffffffff,
  0xc013ffffffffffff,
  0xc015ffffffffffff,
  0xc015ffffffffffff,
  0xc016000000000000,
  0xc017ffffffffffff,
  0xc017ffffffffffff,
  0xc018000000000000,
  0xc019ffffffffffff,
  0xc02e000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc013ffffffffffff,
  0xc013ffffffffffff,
  0xc013ffffffffffff,
  0xc013ffffffffffff,
  0xc013ffffffffffff,
  0xc011ffffffffffff,
  0xc011ffffffffffff,
  0xc011ffffffffffff,
  0xc00fffffffffffff,
  0xc00fffffffffffff,
  0xc00ffffffffffffe,
  0xc00bffffffffffff,
  0x4014000000000001,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc013ffffffffffff,
  0xc013ffffffffffff,
  0xc013ffffffffffff,
  0xc014000000000000,
  0xc014000000000000,
  0xc016000000000000,
  0xc016000000000000,
  0xc016000000000000,
  0xc018000000000000,
  0xc018000000000000,
  0xc018000000000000,
  0xc01a000000000000,
  0xc02e000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc014000000000000,
  0xc014000000000000,
  0xc014000000000000,
  0xc014000000000000,
  0xc014000000000000,
  0xc012000000000000,
  0xc012000000000000,
  0xc012000000000000,
  0xc010000000000000,
  0xc010000000000000,
  0xc010000000000000,
  0xc00c000000000000,
  0x4014000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc014000000000000,
  0xc014000000000000,
  0xc014000000000000,
  0xc014000000000001,
  0xc014000000000001,
  0xc016000000000001,
  0xc016000000000001,
  0xc016000000000001,
  0xc018000000000001,
  0xc018000000000001,
  0xc018000000000002,
  0xc01a000000000001,
  0xc02e000000000001,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc014000000000001,
  0xc014000000000001,
  0xc014000000000001,
  0xc014000000000001,
  0xc014000000000001,
  0xc012000000000001,
  0xc012000000000001,
  0xc012000000000001,
  0xc010000000000001,
  0xc010000000000001,
  0xc010000000000001,
  0xc00c000000000002,
  0x4013ffffffffffff,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc014000000000001,
  0xc014000000000001,
  0xc014000000000001,
  0xc023ffffffffffff,
  0xc023ffffffffffff,
  0xc024ffffffffffff,
  0xc024ffffffffffff,
  0xc024ffffffffffff,
  0xc025ffffffffffff,
  0xc025ffffffffffff,
  0xc026000000000000,
  0xc026ffffffffffff,
  0xc034000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc023ffffffffffff,
  0xc023ffffffffffff,
  0xc023ffffffffffff,
  0xc023ffffffffffff,
  0xc023ffffffffffff,
  0xc022ffffffffffff,
  0xc022ffffffffffff,
  0xc022ffffffffffff,
  0xc021ffffffffffff,
  0xc021ffffffffffff,
  0xc021ffffffffffff,
  0xc020ffffffffffff,
  0x3cd4000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc023ffffffffffff,
  0xc023ffffffffffff,
  0xc023ffffffffffff,
  0xc024000000000000,
  0xc024000000000000,
  0xc025000000000000,
  0xc025000000000000,
  0xc025000000000000,
  0xc026000000000000,
  0xc026000000000000,
  0xc026000000000000,
  0xc027000000000000,
  0xc034000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc023000000000000,
  0xc023000000000000,
  0xc023000000000000,
  0xc022000000000000,
  0xc022000000000000,
  0xc022000000000000,
  0xc021000000000000,
  0x0000000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc024000000000001,
  0xc024000000000001,
  0xc025000000000001,
  0xc025000000000001,
  0xc025000000000001,
  0xc026000000000001,
  0xc026000000000001,
  0xc026000000000001,
  0xc027000000000001,
  0xc034000000000001,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc024000000000001,
  0xc024000000000001,
  0xc024000000000001,
  0xc024000000000001,
  0xc024000000000001,
  0xc023000000000001,
  0xc023000000000001,
  0xc023000000000001,
  0xc022000000000001,
  0xc022000000000001,
  0xc022000000000001,
  0xc021000000000001,
  0xbce4000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc024000000000001,
  0xc024000000000001,
  0xc024000000000001,
  0xc02e000000000000,
  0xc02e000000000000,
  0xc02f000000000000,
  0xc02f000000000000,
  0xc02f000000000000,
  0xc030000000000000,
  0xc030000000000000,
  0xc030000000000000,
  0xc030800000000000,
  0xc039000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc02e000000000000,
  0xc02e000000000000,
  0xc02e000000000000,
  0xc02e000000000000,
  0xc02e000000000000,
  0xc02d000000000000,
  0xc02d000000000000,
  0xc02d000000000000,
  0xc02c000000000000,
  0xc02c000000000000,
  0xc02c000000000000,
  0xc02b000000000000,
  0xc014000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc02e000000000000,
  0xc02e000000000000,
  0xc02e000000000000,
  0xc059000000000000,
  0xc059000000000000,
  0xc059200000000000,
  0xc059200000000000,
  0xc059200000000000,
  0xc059400000000000,
  0xc059400000000000,
  0xc059400000000000,
  0xc059600000000000,
  0xc05b800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc059000000000000,
  0xc059000000000000,
  0xc059000000000000,
  0xc059000000000000,
  0xc059000000000000,
  0xc058e00000000000,
  0xc058e00000000000,
  0xc058e00000000000,
  0xc058c00000000000,
  0xc058c00000000000,
  0xc058c00000000000,
  0xc058a00000000000,
  0xc056800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc059000000000000,
  0xc059000000000000,
  0xc059000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x800b60b60b60b602,
  0x801b60b60b60b602,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800c83fb72ea61cf,
  0x801b60b60b60b601,
  0x800b60b60b60b603,
  0x800b60b60b60b602,
  0x00049f49f49f49fe,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x800a3d70a3d70a35,
  0x00049f49f49f49fd,
  0x800b60b60b60b601,
  0x8043ffffffffffff,
  0x8045ffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x80442468acf13578,
  0x8045ffffffffffff,
  0x8043ffffffffffff,
  0x8043ffffffffffff,
  0x8041ffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8043db97530eca85,
  0x8041ffffffffffff,
  0x8043ffffffffffff,
  0x800000000000000a,
  0x801000000000000a,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abd7,
  0x8010000000000009,
  0x800000000000000b,
  0x800000000000000a,
  0x000ffffffffffff6,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abc3,
  0x000ffffffffffff5,
  0x8000000000000009,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0044000000000000,
  0x0042000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0043db97530eca86,
  0x0042000000000000,
  0x0044000000000000,
  0x0044000000000000,
  0x0046000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x00442468acf1357a,
  0x0046000000000000,
  0x0044000000000000,
  0x4013ffffffffffff,
  0x4013ffffffffffff,
  0x4011ffffffffffff,
  0x4011ffffffffffff,
  0x4011ffffffffffff,
  0x400fffffffffffff,
  0x400fffffffffffff,
  0x400ffffffffffffe,
  0x400bffffffffffff,
  0xc014000000000001,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x4013ffffffffffff,
  0x4013ffffffffffff,
  0x4013ffffffffffff,
  0x4013ffffffffffff,
  0x4013ffffffffffff,
  0x4015ffffffffffff,
  0x4015ffffffffffff,
  0x4016000000000000,
  0x4017ffffffffffff,
  0x4017ffffffffffff,
  0x4018000000000000,
  0x4019ffffffffffff,
  0x402e000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x4013ffffffffffff,
  0x4013ffffffffffff,
  0x4013ffffffffffff,
  0x4014000000000000,
  0x4014000000000000,
  0x4012000000000000,
  0x4012000000000000,
  0x4012000000000000,
  0x4010000000000000,
  0x4010000000000000,
  0x4010000000000000,
  0x400c000000000000,
  0xc014000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x4014000000000000,
  0x4014000000000000,
  0x4014000000000000,
  0x4014000000000000,
  0x4014000000000000,
  0x4016000000000000,
  0x4016000000000000,
  0x4016000000000000,
  0x4018000000000000,
  0x4018000000000000,
  0x4018000000000000,
  0x401a000000000000,
  0x402e000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x4014000000000000,
  0x4014000000000000,
  0x4014000000000000,
  0x4014000000000001,
  0x4014000000000001,
  0x4012000000000001,
  0x4012000000000001,
  0x4012000000000001,
  0x4010000000000001,
  0x4010000000000001,
  0x4010000000000001,
  0x400c000000000002,
  0xc013ffffffffffff,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x4014000000000001,
  0x4014000000000001,
  0x4014000000000001,
  0x4014000000000001,
  0x4014000000000001,
  0x4016000000000001,
  0x4016000000000001,
  0x4016000000000001,
  0x4018000000000001,
  0x4018000000000001,
  0x4018000000000002,
  0x401a000000000001,
  0x402e000000000001,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x4014000000000001,
  0x4014000000000001,
  0x4014000000000001,
  0x4023ffffffffffff,
  0x4023ffffffffffff,
  0x4022ffffffffffff,
  0x4022ffffffffffff,
  0x4022ffffffffffff,
  0x4021ffffffffffff,
  0x4021ffffffffffff,
  0x4021ffffffffffff,
  0x4020ffffffffffff,
  0xbcd4000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x4023ffffffffffff,
  0x4023ffffffffffff,
  0x4023ffffffffffff,
  0x4023ffffffffffff,
  0x4023ffffffffffff,
  0x4024ffffffffffff,
  0x4024ffffffffffff,
  0x4024ffffffffffff,
  0x4025ffffffffffff,
  0x4025ffffffffffff,
  0x4026000000000000,
  0x4026ffffffffffff,
  0x4034000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x4023ffffffffffff,
  0x4023ffffffffffff,
  0x4023ffffffffffff,
  0x4024000000000000,
  0x4024000000000000,
  0x4023000000000000,
  0x4023000000000000,
  0x4023000000000000,
  0x4022000000000000,
  0x4022000000000000,
  0x4022000000000000,
  0x4021000000000000,
  0x0000000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4025000000000000,
  0x4025000000000000,
  0x4025000000000000,
  0x4026000000000000,
  0x4026000000000000,
  0x4026000000000000,
  0x4027000000000000,
  0x4034000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4024000000000001,
  0x4024000000000001,
  0x4023000000000001,
  0x4023000000000001,
  0x4023000000000001,
  0x4022000000000001,
  0x4022000000000001,
  0x4022000000000001,
  0x4021000000000001,
  0x3ce4000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x4024000000000001,
  0x4024000000000001,
  0x4024000000000001,
  0x4024000000000001,
  0x4024000000000001,
  0x4025000000000001,
  0x4025000000000001,
  0x4025000000000001,
  0x4026000000000001,
  0x4026000000000001,
  0x4026000000000001,
  0x4027000000000001,
  0x4034000000000001,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x4024000000000001,
  0x4024000000000001,
  0x4024000000000001,
  0x402e000000000000,
  0x402e000000000000,
  0x402d000000000000,
  0x402d000000000000,
  0x402d000000000000,
  0x402c000000000000,
  0x402c000000000000,
  0x402c000000000000,
  0x402b000000000000,
  0x4014000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x402e000000000000,
  0x402e000000000000,
  0x402e000000000000,
  0x402e000000000000,
  0x402e000000000000,
  0x402f000000000000,
  0x402f000000000000,
  0x402f000000000000,
  0x4030000000000000,
  0x4030000000000000,
  0x4030000000000000,
  0x4030800000000000,
  0x4039000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x402e000000000000,
  0x402e000000000000,
  0x402e000000000000,
  0x4059000000000000,
  0x4059000000000000,
  0x4058e00000000000,
  0x4058e00000000000,
  0x4058e00000000000,
  0x4058c00000000000,
  0x4058c00000000000,
  0x4058c00000000000,
  0x4058a00000000000,
  0x4056800000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x4059000000000000,
  0x4059000000000000,
  0x4059000000000000,
  0x4059000000000000,
  0x4059000000000000,
  0x4059200000000000,
  0x4059200000000000,
  0x4059200000000000,
  0x4059400000000000,
  0x4059400000000000,
  0x4059400000000000,
  0x4059600000000000,
  0x405b800000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x4059000000000000,
  0x4059000000000000,
  0x4059000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x000b60b60b60b602,
  0x80049f49f49f49fe,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x000a3d70a3d70a35,
  0x80049f49f49f49fd,
  0x000b60b60b60b601,
  0x000b60b60b60b602,
  0x001b60b60b60b602,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000c83fb72ea61cf,
  0x001b60b60b60b601,
  0x000b60b60b60b603,
  0x0043ffffffffffff,
  0x0041ffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0043db97530eca85,
  0x0041ffffffffffff,
  0x0043ffffffffffff,
  0x0043ffffffffffff,
  0x0045ffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x00442468acf13578,
  0x0045ffffffffffff,
  0x0043ffffffffffff,
  0x000000000000000a,
  0x800ffffffffffff6,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abc3,
  0x800ffffffffffff5,
  0x0000000000000009,
  0x000000000000000a,
  0x001000000000000a,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abd7,
  0x0010000000000009,
  0x000000000000000b,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0xc00fffffffffffff,
  0xc00fffffffffffff,
  0xc011ffffffffffff,
  0xc012000000000000,
  0xc012000000000000,
  0xc013ffffffffffff,
  0xc014000000000000,
  0xc014000000000000,
  0xc016000000000000,
  0xc02c000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc00fffffffffffff,
  0xc00fffffffffffff,
  0xc00fffffffffffff,
  0xc00fffffffffffff,
  0xc00fffffffffffff,
  0xc00bffffffffffff,
  0xc00bffffffffffff,
  0xc00bffffffffffff,
  0xc007ffffffffffff,
  0xc007ffffffffffff,
  0xc007fffffffffffe,
  0xc003ffffffffffff,
  0x4018000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc00fffffffffffff,
  0xc00fffffffffffff,
  0xc00fffffffffffff,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0x7fe0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdffffffffffffe,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0x7fdfffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffdfffffffffffff,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0x7fdffffffffffffd,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffe0000000000000,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0x7c9fffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffeffffffffffffe,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0x0000000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfcafffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xffdfffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xbfd23456789abccf,
  0xbfd23456789abccf,
  0xbfe91a2b3c4d5e67,
  0xbfe91a2b3c4d5e68,
  0xbfe91a2b3c4d5e69,
  0xbff48d159e26af33,
  0xbff48d159e26af34,
  0xbff48d159e26af35,
  0xbffc8d159e26af34,
  0xc02491a2b3c4d5e6,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfd23456789abccf,
  0xbfd23456789abccf,
  0xbfd23456789abccf,
  0xbfd23456789abccf,
  0xbfd23456789abccf,
  0x3fcb97530eca865f,
  0x3fcb97530eca8661,
  0x3fcb97530eca8665,
  0x3fe6e5d4c3b2a197,
  0x3fe6e5d4c3b2a198,
  0x3fe6e5d4c3b2a19a,
  0x3ff372ea61d950cc,
  0x40236e5d4c3b2a1a,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfd23456789abccf,
  0xbfd23456789abccf,
  0xbfd23456789abccf,
  0xc00ffffffffffffd,
  0xc00ffffffffffffd,
  0xc011fffffffffffe,
  0xc011ffffffffffff,
  0xc011ffffffffffff,
  0xc013fffffffffffe,
  0xc013ffffffffffff,
  0xc013ffffffffffff,
  0xc015ffffffffffff,
  0xc02bffffffffffff,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc00ffffffffffffd,
  0xc00ffffffffffffd,
  0xc00ffffffffffffd,
  0xc00ffffffffffffd,
  0xc00ffffffffffffd,
  0xc00bfffffffffffd,
  0xc00bfffffffffffd,
  0xc00bfffffffffffd,
  0xc007fffffffffffd,
  0xc007fffffffffffd,
  0xc007fffffffffffd,
  0xc003fffffffffffd,
  0x4018000000000001,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc00ffffffffffffd,
  0xc00ffffffffffffd,
  0xc00ffffffffffffd,
  0xbccfffffffffffff,
  0xbccfffffffffffff,
  0xbfe0000000000007,
  0xbfe0000000000008,
  0xbfe0000000000009,
  0xbff0000000000003,
  0xbff0000000000004,
  0xbff0000000000005,
  0xbff8000000000004,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbccfffffffffffff,
  0xbccfffffffffffff,
  0xbccfffffffffffff,
  0xbccfffffffffffff,
  0xbccfffffffffffff,
  0x3fdfffffffffffef,
  0x3fdffffffffffff0,
  0x3fdffffffffffff2,
  0x3feffffffffffff7,
  0x3feffffffffffff8,
  0x3feffffffffffffa,
  0x3ff7fffffffffffc,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbccfffffffffffff,
  0xbccfffffffffffff,
  0xbccfffffffffffff,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x400fffffffffffff,
  0x400fffffffffffff,
  0x400bffffffffffff,
  0x400bffffffffffff,
  0x400bffffffffffff,
  0x4007ffffffffffff,
  0x4007ffffffffffff,
  0x4007fffffffffffe,
  0x4003ffffffffffff,
  0xc018000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x400fffffffffffff,
  0x400fffffffffffff,
  0x400fffffffffffff,
  0x400fffffffffffff,
  0x400fffffffffffff,
  0x4011ffffffffffff,
  0x4012000000000000,
  0x4012000000000000,
  0x4013ffffffffffff,
  0x4014000000000000,
  0x4014000000000000,
  0x4016000000000000,
  0x402c000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x400fffffffffffff,
  0x400fffffffffffff,
  0x400fffffffffffff,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0xffe0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdffffffffffffe,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0xffdfffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fdfffffffffffff,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0xffdffffffffffffd,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7fe0000000000000,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0xfc9fffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7feffffffffffffe,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x0000000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7cafffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7fdfffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x3fd23456789abccf,
  0x3fd23456789abccf,
  0xbfcb97530eca865f,
  0xbfcb97530eca8661,
  0xbfcb97530eca8665,
  0xbfe6e5d4c3b2a197,
  0xbfe6e5d4c3b2a198,
  0xbfe6e5d4c3b2a19a,
  0xbff372ea61d950cc,
  0xc0236e5d4c3b2a1a,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fd23456789abccf,
  0x3fd23456789abccf,
  0x3fd23456789abccf,
  0x3fd23456789abccf,
  0x3fd23456789abccf,
  0x3fe91a2b3c4d5e67,
  0x3fe91a2b3c4d5e68,
  0x3fe91a2b3c4d5e69,
  0x3ff48d159e26af33,
  0x3ff48d159e26af34,
  0x3ff48d159e26af35,
  0x3ffc8d159e26af34,
  0x402491a2b3c4d5e6,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fd23456789abccf,
  0x3fd23456789abccf,
  0x3fd23456789abccf,
  0x400ffffffffffffd,
  0x400ffffffffffffd,
  0x400bfffffffffffd,
  0x400bfffffffffffd,
  0x400bfffffffffffd,
  0x4007fffffffffffd,
  0x4007fffffffffffd,
  0x4007fffffffffffd,
  0x4003fffffffffffd,
  0xc018000000000001,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x400ffffffffffffd,
  0x400ffffffffffffd,
  0x400ffffffffffffd,
  0x400ffffffffffffd,
  0x400ffffffffffffd,
  0x4011fffffffffffe,
  0x4011ffffffffffff,
  0x4011ffffffffffff,
  0x4013fffffffffffe,
  0x4013ffffffffffff,
  0x4013ffffffffffff,
  0x4015ffffffffffff,
  0x402bffffffffffff,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x400ffffffffffffd,
  0x400ffffffffffffd,
  0x400ffffffffffffd,
  0x3ccfffffffffffff,
  0x3ccfffffffffffff,
  0xbfdfffffffffffef,
  0xbfdffffffffffff0,
  0xbfdffffffffffff2,
  0xbfeffffffffffff7,
  0xbfeffffffffffff8,
  0xbfeffffffffffffa,
  0xbff7fffffffffffc,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3ccfffffffffffff,
  0x3ccfffffffffffff,
  0x3ccfffffffffffff,
  0x3ccfffffffffffff,
  0x3ccfffffffffffff,
  0x3fe0000000000007,
  0x3fe0000000000008,
  0x3fe0000000000009,
  0x3ff0000000000003,
  0x3ff0000000000004,
  0x3ff0000000000005,
  0x3ff8000000000004,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3ccfffffffffffff,
  0x3ccfffffffffffff,
  0x3ccfffffffffffff,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x800091a2b3c4d5e6,
  0x801091a2b3c4d5e6,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x8001b4e81b4e81b3,
  0x801091a2b3c4d5e5,
  0x800091a2b3c4d5e7,
  0x800091a2b3c4d5e6,
  0x000f6e5d4c3b2a1a,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000091a2b3c4d5e7,
  0x000f6e5d4c3b2a19,
  0x800091a2b3c4d5e5,
  0x800091a2b3c4d5e6,
  0x801091a2b3c4d5e6,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x8001b4e81b4e81b4,
  0x801091a2b3c4d5e6,
  0x800091a2b3c4d5e8,
  0x800091a2b3c4d5e6,
  0x000f6e5d4c3b2a1a,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000091a2b3c4d5e6,
  0x000f6e5d4c3b2a18,
  0x800091a2b3c4d5e6,
  0x800091a2b3c4d5e7,
  0x801091a2b3c4d5e7,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x8001b4e81b4e81b4,
  0x801091a2b3c4d5e6,
  0x800091a2b3c4d5e8,
  0x800091a2b3c4d5e7,
  0x000f6e5d4c3b2a19,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000091a2b3c4d5e6,
  0x000f6e5d4c3b2a18,
  0x800091a2b3c4d5e6,
  0x800123456789abcd,
  0x801123456789abcd,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x8002468acf13579a,
  0x801123456789abcc,
  0x800123456789abce,
  0x800123456789abcd,
  0x000edcba98765433,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0000000000000000,
  0x000edcba98765432,
  0x800123456789abcc,
  0x800123456789abcd,
  0x801123456789abcd,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x8002468acf13579a,
  0x801123456789abcc,
  0x800123456789abce,
  0x800123456789abcd,
  0x000edcba98765433,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0000000000000000,
  0x000edcba98765432,
  0x800123456789abcc,
  0x800123456789abcd,
  0x801123456789abcd,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x8002468acf13579a,
  0x801123456789abcc,
  0x800123456789abce,
  0x800123456789abcd,
  0x000edcba98765433,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8000000000000000,
  0x000edcba98765432,
  0x800123456789abcc,
  0x8001b4e81b4e81b4,
  0x8011b4e81b4e81b4,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x8002d82d82d82d80,
  0x8011b4e81b4e81b2,
  0x8001b4e81b4e81b4,
  0x8001b4e81b4e81b4,
  0x000e4b17e4b17e4c,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x800091a2b3c4d5e6,
  0x000e4b17e4b17e4c,
  0x8001b4e81b4e81b2,
  0x800b60b60b60b602,
  0x801b60b60b60b602,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800c83fb72ea61cf,
  0x801b60b60b60b601,
  0x800b60b60b60b603,
  0x800b60b60b60b602,
  0x00049f49f49f49fe,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x800a3d70a3d70a35,
  0x00049f49f49f49fd,
  0x800b60b60b60b601,
  0xbfd23456789abccf,
  0xbfd23456789abccf,
  0xbfe91a2b3c4d5e67,
  0xbfe91a2b3c4d5e68,
  0xbfe91a2b3c4d5e69,
  0xbff48d159e26af33,
  0xbff48d159e26af34,
  0xbff48d159e26af35,
  0xbffc8d159e26af34,
  0xc02491a2b3c4d5e6,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbfd23456789abccf,
  0xbfd23456789abccf,
  0xbfd23456789abccf,
  0xbfd23456789abccf,
  0xbfd23456789abccf,
  0x3fcb97530eca865f,
  0x3fcb97530eca8661,
  0x3fcb97530eca8665,
  0x3fe6e5d4c3b2a197,
  0x3fe6e5d4c3b2a198,
  0x3fe6e5d4c3b2a19a,
  0x3ff372ea61d950cc,
  0x40236e5d4c3b2a1a,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbfd23456789abccf,
  0xbfd23456789abccf,
  0xbfd23456789abccf,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x000091a2b3c4d5e6,
  0x800f6e5d4c3b2a1a,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800091a2b3c4d5e7,
  0x800f6e5d4c3b2a19,
  0x000091a2b3c4d5e5,
  0x000091a2b3c4d5e6,
  0x001091a2b3c4d5e6,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0001b4e81b4e81b3,
  0x001091a2b3c4d5e5,
  0x000091a2b3c4d5e7,
  0x000091a2b3c4d5e6,
  0x800f6e5d4c3b2a1a,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800091a2b3c4d5e6,
  0x800f6e5d4c3b2a18,
  0x000091a2b3c4d5e6,
  0x000091a2b3c4d5e6,
  0x001091a2b3c4d5e6,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0001b4e81b4e81b4,
  0x001091a2b3c4d5e6,
  0x000091a2b3c4d5e8,
  0x000091a2b3c4d5e7,
  0x800f6e5d4c3b2a19,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800091a2b3c4d5e6,
  0x800f6e5d4c3b2a18,
  0x000091a2b3c4d5e6,
  0x000091a2b3c4d5e7,
  0x001091a2b3c4d5e7,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0001b4e81b4e81b4,
  0x001091a2b3c4d5e6,
  0x000091a2b3c4d5e8,
  0x000123456789abcd,
  0x800edcba98765433,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x8000000000000000,
  0x800edcba98765432,
  0x000123456789abcc,
  0x000123456789abcd,
  0x001123456789abcd,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0002468acf13579a,
  0x001123456789abcc,
  0x000123456789abce,
  0x000123456789abcd,
  0x800edcba98765433,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0000000000000000,
  0x800edcba98765432,
  0x000123456789abcc,
  0x000123456789abcd,
  0x001123456789abcd,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0002468acf13579a,
  0x001123456789abcc,
  0x000123456789abce,
  0x000123456789abcd,
  0x800edcba98765433,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0000000000000000,
  0x800edcba98765432,
  0x000123456789abcc,
  0x000123456789abcd,
  0x001123456789abcd,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0002468acf13579a,
  0x001123456789abcc,
  0x000123456789abce,
  0x0001b4e81b4e81b4,
  0x800e4b17e4b17e4c,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x000091a2b3c4d5e6,
  0x800e4b17e4b17e4c,
  0x0001b4e81b4e81b2,
  0x0001b4e81b4e81b4,
  0x0011b4e81b4e81b4,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0002d82d82d82d80,
  0x0011b4e81b4e81b2,
  0x0001b4e81b4e81b4,
  0x000b60b60b60b602,
  0x80049f49f49f49fe,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x000a3d70a3d70a35,
  0x80049f49f49f49fd,
  0x000b60b60b60b601,
  0x000b60b60b60b602,
  0x001b60b60b60b602,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000c83fb72ea61cf,
  0x001b60b60b60b601,
  0x000b60b60b60b603,
  0x3fd23456789abccf,
  0x3fd23456789abccf,
  0xbfcb97530eca865f,
  0xbfcb97530eca8661,
  0xbfcb97530eca8665,
  0xbfe6e5d4c3b2a197,
  0xbfe6e5d4c3b2a198,
  0xbfe6e5d4c3b2a19a,
  0xbff372ea61d950cc,
  0xc0236e5d4c3b2a1a,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3fd23456789abccf,
  0x3fd23456789abccf,
  0x3fd23456789abccf,
  0x3fd23456789abccf,
  0x3fd23456789abccf,
  0x3fe91a2b3c4d5e67,
  0x3fe91a2b3c4d5e68,
  0x3fe91a2b3c4d5e69,
  0x3ff48d159e26af33,
  0x3ff48d159e26af34,
  0x3ff48d159e26af35,
  0x3ffc8d159e26af34,
  0x402491a2b3c4d5e6,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3fd23456789abccf,
  0x3fd23456789abccf,
  0x3fd23456789abccf,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8007ffffffffffff,
  0x8017ffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800923456789abcc,
  0x8017fffffffffffe,
  0x8008000000000000,
  0x8007ffffffffffff,
  0x0008000000000001,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8006dcba98765432,
  0x0008000000000000,
  0x8007fffffffffffe,
  0x8008000000000000,
  0x8018000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800923456789abcc,
  0x8017fffffffffffe,
  0x8008000000000000,
  0x8008000000000000,
  0x0008000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8006dcba98765432,
  0x0008000000000000,
  0x8007fffffffffffe,
  0x8008000000000000,
  0x8018000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800923456789abcd,
  0x8017ffffffffffff,
  0x8008000000000001,
  0x8008000000000000,
  0x0008000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8006dcba98765433,
  0x0007ffffffffffff,
  0x8007ffffffffffff,
  0x800fffffffffffff,
  0x801fffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x801123456789abcc,
  0x801ffffffffffffe,
  0x8010000000000000,
  0x800fffffffffffff,
  0x0000000000000001,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x800edcba98765432,
  0x0000000000000000,
  0x800ffffffffffffe,
  0x800fffffffffffff,
  0x801fffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x801123456789abcc,
  0x801ffffffffffffe,
  0x8010000000000000,
  0x800fffffffffffff,
  0x0000000000000001,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x800edcba98765432,
  0x0000000000000000,
  0x800ffffffffffffe,
  0x8010000000000000,
  0x8020000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x801123456789abcd,
  0x801fffffffffffff,
  0x8010000000000001,
  0x8010000000000000,
  0x0000000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x800edcba98765433,
  0x8000000000000001,
  0x800fffffffffffff,
  0x8017fffffffffffe,
  0x8023ffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x801923456789abcc,
  0x8023ffffffffffff,
  0x8018000000000000,
  0x8017fffffffffffe,
  0x8007fffffffffffe,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8016dcba98765432,
  0x8008000000000000,
  0x8017fffffffffffe,
  0x8043ffffffffffff,
  0x8045ffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x80442468acf13578,
  0x8045ffffffffffff,
  0x8043ffffffffffff,
  0x8043ffffffffffff,
  0x8041ffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x8043db97530eca85,
  0x8041ffffffffffff,
  0x8043ffffffffffff,
  0xc00ffffffffffffd,
  0xc00ffffffffffffd,
  0xc011fffffffffffe,
  0xc011ffffffffffff,
  0xc011ffffffffffff,
  0xc013fffffffffffe,
  0xc013ffffffffffff,
  0xc013ffffffffffff,
  0xc015ffffffffffff,
  0xc02bffffffffffff,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xc00ffffffffffffd,
  0xc00ffffffffffffd,
  0xc00ffffffffffffd,
  0xc00ffffffffffffd,
  0xc00ffffffffffffd,
  0xc00bfffffffffffd,
  0xc00bfffffffffffd,
  0xc00bfffffffffffd,
  0xc007fffffffffffd,
  0xc007fffffffffffd,
  0xc007fffffffffffd,
  0xc003fffffffffffd,
  0x4018000000000001,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xc00ffffffffffffd,
  0xc00ffffffffffffd,
  0xc00ffffffffffffd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0007ffffffffffff,
  0x8008000000000001,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0006dcba98765432,
  0x8008000000000000,
  0x0007fffffffffffe,
  0x0007ffffffffffff,
  0x0017ffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000923456789abcc,
  0x0017fffffffffffe,
  0x0008000000000000,
  0x0008000000000000,
  0x8008000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0006dcba98765432,
  0x8008000000000000,
  0x0007fffffffffffe,
  0x0008000000000000,
  0x0018000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000923456789abcc,
  0x0017fffffffffffe,
  0x0008000000000000,
  0x0008000000000000,
  0x8008000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0006dcba98765433,
  0x8007ffffffffffff,
  0x0007ffffffffffff,
  0x0008000000000000,
  0x0018000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000923456789abcd,
  0x0017ffffffffffff,
  0x0008000000000001,
  0x000fffffffffffff,
  0x8000000000000001,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x000edcba98765432,
  0x8000000000000000,
  0x000ffffffffffffe,
  0x000fffffffffffff,
  0x001fffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x001123456789abcc,
  0x001ffffffffffffe,
  0x0010000000000000,
  0x000fffffffffffff,
  0x8000000000000001,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x000edcba98765432,
  0x0000000000000000,
  0x000ffffffffffffe,
  0x000fffffffffffff,
  0x001fffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x001123456789abcc,
  0x001ffffffffffffe,
  0x0010000000000000,
  0x0010000000000000,
  0x8000000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x000edcba98765433,
  0x0000000000000001,
  0x000fffffffffffff,
  0x0010000000000000,
  0x0020000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x001123456789abcd,
  0x001fffffffffffff,
  0x0010000000000001,
  0x0017fffffffffffe,
  0x0007fffffffffffe,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0016dcba98765432,
  0x0008000000000000,
  0x0017fffffffffffe,
  0x0017fffffffffffe,
  0x0023ffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x001923456789abcc,
  0x0023ffffffffffff,
  0x0018000000000000,
  0x0043ffffffffffff,
  0x0041ffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x0043db97530eca85,
  0x0041ffffffffffff,
  0x0043ffffffffffff,
  0x0043ffffffffffff,
  0x0045ffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x00442468acf13578,
  0x0045ffffffffffff,
  0x0043ffffffffffff,
  0x400ffffffffffffd,
  0x400ffffffffffffd,
  0x400bfffffffffffd,
  0x400bfffffffffffd,
  0x400bfffffffffffd,
  0x4007fffffffffffd,
  0x4007fffffffffffd,
  0x4007fffffffffffd,
  0x4003fffffffffffd,
  0xc018000000000001,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x400ffffffffffffd,
  0x400ffffffffffffd,
  0x400ffffffffffffd,
  0x400ffffffffffffd,
  0x400ffffffffffffd,
  0x4011fffffffffffe,
  0x4011ffffffffffff,
  0x4011ffffffffffff,
  0x4013fffffffffffe,
  0x4013ffffffffffff,
  0x4013ffffffffffff,
  0x4015ffffffffffff,
  0x402bffffffffffff,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x400ffffffffffffd,
  0x400ffffffffffffd,
  0x400ffffffffffffd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abce,
  0x8010000000000000,
  0x8000000000000002,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcc,
  0x000ffffffffffffe,
  0x0000000000000000,
  0x8000000000000001,
  0x8010000000000001,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abce,
  0x8010000000000000,
  0x8000000000000002,
  0x8000000000000001,
  0x000fffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcc,
  0x000ffffffffffffe,
  0x0000000000000000,
  0x8000000000000001,
  0x8010000000000001,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abce,
  0x8010000000000000,
  0x8000000000000002,
  0x8000000000000001,
  0x000fffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcc,
  0x000ffffffffffffe,
  0x0000000000000000,
  0x8000000000000001,
  0x8010000000000001,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abce,
  0x8010000000000000,
  0x8000000000000002,
  0x8000000000000001,
  0x000fffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcc,
  0x000ffffffffffffe,
  0x0000000000000000,
  0x8000000000000001,
  0x8010000000000001,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abce,
  0x8010000000000000,
  0x8000000000000002,
  0x8000000000000001,
  0x000fffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcc,
  0x000ffffffffffffe,
  0x8000000000000000,
  0x8000000000000002,
  0x8010000000000002,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abce,
  0x8010000000000000,
  0x8000000000000002,
  0x8000000000000002,
  0x000ffffffffffffe,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcc,
  0x000ffffffffffffe,
  0x8000000000000000,
  0x800000000000000a,
  0x801000000000000a,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abd7,
  0x8010000000000009,
  0x800000000000000b,
  0x800000000000000a,
  0x000ffffffffffff6,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abc3,
  0x000ffffffffffff5,
  0x8000000000000009,
  0xbccfffffffffffff,
  0xbccfffffffffffff,
  0xbfe0000000000007,
  0xbfe0000000000008,
  0xbfe0000000000009,
  0xbff0000000000003,
  0xbff0000000000004,
  0xbff0000000000005,
  0xbff8000000000004,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xbccfffffffffffff,
  0xbccfffffffffffff,
  0xbccfffffffffffff,
  0xbccfffffffffffff,
  0xbccfffffffffffff,
  0x3fdfffffffffffef,
  0x3fdffffffffffff0,
  0x3fdffffffffffff2,
  0x3feffffffffffff7,
  0x3feffffffffffff8,
  0x3feffffffffffffa,
  0x3ff7fffffffffffc,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0xbccfffffffffffff,
  0xbccfffffffffffff,
  0xbccfffffffffffff,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x8000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcc,
  0x800ffffffffffffe,
  0x8000000000000000,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abce,
  0x0010000000000000,
  0x0000000000000002,
  0x0000000000000001,
  0x800fffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcc,
  0x800ffffffffffffe,
  0x8000000000000000,
  0x0000000000000001,
  0x0010000000000001,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abce,
  0x0010000000000000,
  0x0000000000000002,
  0x0000000000000001,
  0x800fffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcc,
  0x800ffffffffffffe,
  0x8000000000000000,
  0x0000000000000001,
  0x0010000000000001,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abce,
  0x0010000000000000,
  0x0000000000000002,
  0x0000000000000001,
  0x800fffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcc,
  0x800ffffffffffffe,
  0x0000000000000000,
  0x0000000000000001,
  0x0010000000000001,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abce,
  0x0010000000000000,
  0x0000000000000002,
  0x0000000000000001,
  0x800fffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcc,
  0x800ffffffffffffe,
  0x0000000000000000,
  0x0000000000000001,
  0x0010000000000001,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abce,
  0x0010000000000000,
  0x0000000000000002,
  0x0000000000000002,
  0x800ffffffffffffe,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcc,
  0x800ffffffffffffe,
  0x0000000000000000,
  0x0000000000000002,
  0x0010000000000002,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abce,
  0x0010000000000000,
  0x0000000000000002,
  0x000000000000000a,
  0x800ffffffffffff6,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abc3,
  0x800ffffffffffff5,
  0x0000000000000009,
  0x000000000000000a,
  0x001000000000000a,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abd7,
  0x0010000000000009,
  0x000000000000000b,
  0x3ccfffffffffffff,
  0x3ccfffffffffffff,
  0xbfdfffffffffffef,
  0xbfdffffffffffff0,
  0xbfdffffffffffff2,
  0xbfeffffffffffff7,
  0xbfeffffffffffff8,
  0xbfeffffffffffffa,
  0xbff7fffffffffffc,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x3ccfffffffffffff,
  0x3ccfffffffffffff,
  0x3ccfffffffffffff,
  0x3ccfffffffffffff,
  0x3ccfffffffffffff,
  0x3fe0000000000007,
  0x3fe0000000000008,
  0x3fe0000000000009,
  0x3ff0000000000003,
  0x3ff0000000000004,
  0x3ff0000000000005,
  0x3ff8000000000004,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x3ccfffffffffffff,
  0x3ccfffffffffffff,
  0x3ccfffffffffffff,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
};
const unsigned kExpectedCount_fnmsub_d = 54872;

const uint32_t kExpected_fnmsub_s[] = {
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00400000,
  0x80400000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x002dcbaa,
  0x803fffff,
  0x003fffff,
  0x00400000,
  0x00c00000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00523456,
  0x00bfffff,
  0x00400001,
  0x00400000,
  0x80400000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x002dcbaa,
  0x803fffff,
  0x003fffff,
  0x00400000,
  0x00c00000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00523456,
  0x00bfffff,
  0x00400001,
  0x00400000,
  0x80400000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x002dcbaa,
  0x803ffffe,
  0x00400000,
  0x00400000,
  0x00c00000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00523456,
  0x00c00000,
  0x00400002,
  0x00800000,
  0x80000000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x006dcbaa,
  0x00000000,
  0x007ffffe,
  0x00800000,
  0x01000000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00923456,
  0x00fffffe,
  0x00800000,
  0x00800000,
  0x00000000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x006dcbaa,
  0x00000001,
  0x007fffff,
  0x00800000,
  0x01000000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00923456,
  0x00ffffff,
  0x00800001,
  0x00800001,
  0x00000001,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x006dcbab,
  0x00000002,
  0x00800000,
  0x00800001,
  0x01000000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00923457,
  0x01000000,
  0x00800002,
  0x00c00000,
  0x00400000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x00adcbaa,
  0x00400001,
  0x00bfffff,
  0x00c00000,
  0x01200000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00d23456,
  0x01200000,
  0x00c00001,
  0x02200000,
  0x02100000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x021db975,
  0x02100000,
  0x02200000,
  0x02200000,
  0x02300000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x0222468b,
  0x02300000,
  0x02200000,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80400000,
  0x80c00000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80523456,
  0x80bfffff,
  0x80400001,
  0x80400000,
  0x00400000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x802dcbaa,
  0x003fffff,
  0x803fffff,
  0x80400000,
  0x80c00000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80523456,
  0x80bfffff,
  0x80400001,
  0x80400000,
  0x00400000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x802dcbaa,
  0x003fffff,
  0x803fffff,
  0x80400000,
  0x80c00000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80523456,
  0x80c00000,
  0x80400002,
  0x80400000,
  0x00400000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x802dcbaa,
  0x003ffffe,
  0x80400000,
  0x80800000,
  0x81000000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80923456,
  0x80fffffe,
  0x80800000,
  0x80800000,
  0x00000000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x806dcbaa,
  0x80000000,
  0x807ffffe,
  0x80800000,
  0x81000000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80923456,
  0x80ffffff,
  0x80800001,
  0x80800000,
  0x00000000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x806dcbaa,
  0x80000001,
  0x807fffff,
  0x80800001,
  0x81000000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80923457,
  0x81000000,
  0x80800002,
  0x80800001,
  0x80000001,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x806dcbab,
  0x80000002,
  0x80800000,
  0x80c00000,
  0x81200000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80d23456,
  0x81200000,
  0x80c00001,
  0x80c00000,
  0x80400000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x80adcbaa,
  0x80400001,
  0x80bfffff,
  0x82200000,
  0x82300000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x8222468b,
  0x82300000,
  0x82200000,
  0x82200000,
  0x82100000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x821db975,
  0x82100000,
  0x82200000,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00400000,
  0x80400000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x002dcbaa,
  0x803fffff,
  0x003fffff,
  0x00400000,
  0x00c00000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00523456,
  0x00bfffff,
  0x00400001,
  0x3e7ffffe,
  0x3e7ffffe,
  0xbe800000,
  0xbe800001,
  0xbe800003,
  0xbf3fffff,
  0xbf400000,
  0xbf400002,
  0xbfa00000,
  0xc11c0000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3e7ffffe,
  0x3e7ffffe,
  0x3e7ffffe,
  0x3e7ffffe,
  0x3e7ffffe,
  0x3f3fffff,
  0x3f400000,
  0x3f400001,
  0x3f9fffff,
  0x3fa00000,
  0x3fa00001,
  0x3fe00000,
  0x41240000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3e7ffffe,
  0x3e7ffffe,
  0x3e7ffffe,
  0x3e7fffff,
  0x3e7fffff,
  0xbe7fffff,
  0xbe800000,
  0xbe800002,
  0xbf3fffff,
  0xbf400000,
  0xbf400002,
  0xbfa00000,
  0xc11c0000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3e7fffff,
  0x3e7fffff,
  0x3e7fffff,
  0x3e7fffff,
  0x3e7fffff,
  0x3f3fffff,
  0x3f400000,
  0x3f400001,
  0x3f9fffff,
  0x3fa00000,
  0x3fa00001,
  0x3fe00000,
  0x41240000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3e7fffff,
  0x3e7fffff,
  0x3e7fffff,
  0x3e800000,
  0x3e800000,
  0xbe7ffffd,
  0xbe7fffff,
  0xbe800002,
  0xbf3fffff,
  0xbf400000,
  0xbf400002,
  0xbfa00000,
  0xc11c0000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3e800000,
  0x3e800000,
  0x3e800000,
  0x3e800000,
  0x3e800000,
  0x3f400000,
  0x3f400000,
  0x3f400001,
  0x3fa00000,
  0x3fa00000,
  0x3fa00001,
  0x3fe00000,
  0x41240000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3e800000,
  0x3e800000,
  0x3e800000,
  0x3efffffe,
  0x3efffffe,
  0xb2ffffff,
  0xb3800000,
  0xb4000000,
  0xbf000000,
  0xbf000001,
  0xbf000003,
  0xbf800000,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3efffffe,
  0x3efffffe,
  0x3efffffe,
  0x3efffffe,
  0x3efffffe,
  0x3f7fffff,
  0x3f7fffff,
  0x3f800000,
  0x3fbfffff,
  0x3fc00000,
  0x3fc00001,
  0x40000000,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3efffffe,
  0x3efffffe,
  0x3efffffe,
  0x3effffff,
  0x3effffff,
  0x00000000,
  0xb3000000,
  0xb3c00000,
  0xbeffffff,
  0xbf000000,
  0xbf000002,
  0xbf800000,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3f7fffff,
  0x3f800000,
  0x3f800000,
  0x3fbfffff,
  0x3fc00000,
  0x3fc00001,
  0x40000000,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3f000000,
  0x3f000000,
  0x337fffff,
  0x32fffffe,
  0xb3000001,
  0xbefffffd,
  0xbeffffff,
  0xbf000002,
  0xbf800000,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f800000,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x3fc00000,
  0x3fc00001,
  0x40000000,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f3fffff,
  0x3f3fffff,
  0x3e7fffff,
  0x3e7ffffd,
  0x3e7ffff9,
  0xbe7fffff,
  0xbe800002,
  0xbe800006,
  0xbf400001,
  0xc1140000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f3fffff,
  0x3f3fffff,
  0x3f3fffff,
  0x3f3fffff,
  0x3f3fffff,
  0x3f9fffff,
  0x3fa00000,
  0x3fa00000,
  0x3fdfffff,
  0x3fe00000,
  0x3fe00001,
  0x40100000,
  0x412c0000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f3fffff,
  0x3f3fffff,
  0x3f3fffff,
  0x409fffff,
  0x409fffff,
  0x408fffff,
  0x408fffff,
  0x408fffff,
  0x407fffff,
  0x407fffff,
  0x407ffffe,
  0x405fffff,
  0xc0a00001,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x409fffff,
  0x409fffff,
  0x409fffff,
  0x409fffff,
  0x409fffff,
  0x40afffff,
  0x40afffff,
  0x40b00000,
  0x40bfffff,
  0x40bfffff,
  0x40c00000,
  0x40cfffff,
  0x41700000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x409fffff,
  0x409fffff,
  0x409fffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x00091a2b,
  0x8076e5d5,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80091a2b,
  0x8076e5d4,
  0x00091a2a,
  0x00091a2b,
  0x00891a2b,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x001b4e81,
  0x00891a2a,
  0x00091a2c,
  0x003fffff,
  0x80400001,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x002dcba9,
  0x80400000,
  0x003ffffe,
  0x003fffff,
  0x00bfffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00523455,
  0x00bffffe,
  0x00400000,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80400000,
  0x80c00000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80523456,
  0x80bfffff,
  0x80400001,
  0x80400000,
  0x00400000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x802dcbaa,
  0x003fffff,
  0x803fffff,
  0xbe7ffffe,
  0xbe7ffffe,
  0xbf3fffff,
  0xbf400000,
  0xbf400001,
  0xbf9fffff,
  0xbfa00000,
  0xbfa00001,
  0xbfe00000,
  0xc1240000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbe7ffffe,
  0xbe7ffffe,
  0xbe7ffffe,
  0xbe7ffffe,
  0xbe7ffffe,
  0x3e800000,
  0x3e800001,
  0x3e800003,
  0x3f3fffff,
  0x3f400000,
  0x3f400002,
  0x3fa00000,
  0x411c0000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbe7ffffe,
  0xbe7ffffe,
  0xbe7ffffe,
  0xbe7fffff,
  0xbe7fffff,
  0xbf3fffff,
  0xbf400000,
  0xbf400001,
  0xbf9fffff,
  0xbfa00000,
  0xbfa00001,
  0xbfe00000,
  0xc1240000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbe7fffff,
  0xbe7fffff,
  0xbe7fffff,
  0xbe7fffff,
  0xbe7fffff,
  0x3e7fffff,
  0x3e800000,
  0x3e800002,
  0x3f3fffff,
  0x3f400000,
  0x3f400002,
  0x3fa00000,
  0x411c0000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbe7fffff,
  0xbe7fffff,
  0xbe7fffff,
  0xbe800000,
  0xbe800000,
  0xbf400000,
  0xbf400000,
  0xbf400001,
  0xbfa00000,
  0xbfa00000,
  0xbfa00001,
  0xbfe00000,
  0xc1240000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbe800000,
  0xbe800000,
  0xbe800000,
  0xbe800000,
  0xbe800000,
  0x3e7ffffd,
  0x3e7fffff,
  0x3e800002,
  0x3f3fffff,
  0x3f400000,
  0x3f400002,
  0x3fa00000,
  0x411c0000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbe800000,
  0xbe800000,
  0xbe800000,
  0xbefffffe,
  0xbefffffe,
  0xbf7fffff,
  0xbf7fffff,
  0xbf800000,
  0xbfbfffff,
  0xbfc00000,
  0xbfc00001,
  0xc0000000,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbefffffe,
  0xbefffffe,
  0xbefffffe,
  0xbefffffe,
  0xbefffffe,
  0x32ffffff,
  0x33800000,
  0x34000000,
  0x3f000000,
  0x3f000001,
  0x3f000003,
  0x3f800000,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbefffffe,
  0xbefffffe,
  0xbefffffe,
  0xbeffffff,
  0xbeffffff,
  0xbf7fffff,
  0xbf800000,
  0xbf800000,
  0xbfbfffff,
  0xbfc00000,
  0xbfc00001,
  0xc0000000,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0x00000000,
  0x33000000,
  0x33c00000,
  0x3effffff,
  0x3f000000,
  0x3f000002,
  0x3f800000,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbf000000,
  0xbf000000,
  0xbf800000,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xbfc00000,
  0xbfc00001,
  0xc0000000,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xb37fffff,
  0xb2fffffe,
  0x33000001,
  0x3efffffd,
  0x3effffff,
  0x3f000002,
  0x3f800000,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf3fffff,
  0xbf3fffff,
  0xbf9fffff,
  0xbfa00000,
  0xbfa00000,
  0xbfdfffff,
  0xbfe00000,
  0xbfe00001,
  0xc0100000,
  0xc12c0000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf3fffff,
  0xbf3fffff,
  0xbf3fffff,
  0xbf3fffff,
  0xbf3fffff,
  0xbe7fffff,
  0xbe7ffffd,
  0xbe7ffff9,
  0x3e7fffff,
  0x3e800002,
  0x3e800006,
  0x3f400001,
  0x41140000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf3fffff,
  0xbf3fffff,
  0xbf3fffff,
  0xc09fffff,
  0xc09fffff,
  0xc0afffff,
  0xc0afffff,
  0xc0b00000,
  0xc0bfffff,
  0xc0bfffff,
  0xc0c00000,
  0xc0cfffff,
  0xc1700000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xc09fffff,
  0xc09fffff,
  0xc09fffff,
  0xc09fffff,
  0xc09fffff,
  0xc08fffff,
  0xc08fffff,
  0xc08fffff,
  0xc07fffff,
  0xc07fffff,
  0xc07ffffe,
  0xc05fffff,
  0x40a00001,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xc09fffff,
  0xc09fffff,
  0xc09fffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x80091a2b,
  0x80891a2b,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x801b4e81,
  0x80891a2a,
  0x80091a2c,
  0x80091a2b,
  0x0076e5d5,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00091a2b,
  0x0076e5d4,
  0x80091a2a,
  0x803fffff,
  0x80bfffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80523455,
  0x80bffffe,
  0x80400000,
  0x803fffff,
  0x00400001,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x802dcba9,
  0x00400000,
  0x803ffffe,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00400000,
  0x80400000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x002dcbaa,
  0x803fffff,
  0x003fffff,
  0x00400000,
  0x00c00000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00523456,
  0x00bfffff,
  0x00400001,
  0x3e7fffff,
  0x3e7fffff,
  0xbe7fffff,
  0xbe800000,
  0xbe800002,
  0xbf3fffff,
  0xbf400000,
  0xbf400002,
  0xbfa00000,
  0xc11c0000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3e7fffff,
  0x3e7fffff,
  0x3e7fffff,
  0x3e7fffff,
  0x3e7fffff,
  0x3f3fffff,
  0x3f400000,
  0x3f400001,
  0x3f9fffff,
  0x3fa00000,
  0x3fa00001,
  0x3fe00000,
  0x41240000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3e7fffff,
  0x3e7fffff,
  0x3e7fffff,
  0x3e800000,
  0x3e800000,
  0xbe7ffffe,
  0xbe800000,
  0xbe800002,
  0xbf3fffff,
  0xbf400000,
  0xbf400002,
  0xbfa00000,
  0xc11c0000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3e800000,
  0x3e800000,
  0x3e800000,
  0x3e800000,
  0x3e800000,
  0x3f400000,
  0x3f400000,
  0x3f400001,
  0x3fa00000,
  0x3fa00000,
  0x3fa00001,
  0x3fe00000,
  0x41240000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3e800000,
  0x3e800000,
  0x3e800000,
  0x3e800001,
  0x3e800001,
  0xbe7ffffc,
  0xbe7ffffe,
  0xbe800001,
  0xbf3ffffe,
  0xbf400000,
  0xbf400002,
  0xbfa00000,
  0xc11c0000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3e800001,
  0x3e800001,
  0x3e800001,
  0x3e800001,
  0x3e800001,
  0x3f400000,
  0x3f400000,
  0x3f400002,
  0x3fa00000,
  0x3fa00000,
  0x3fa00001,
  0x3fe00000,
  0x41240000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3e800001,
  0x3e800001,
  0x3e800001,
  0x3effffff,
  0x3effffff,
  0x00000000,
  0xb3000000,
  0xb3c00000,
  0xbeffffff,
  0xbf000000,
  0xbf000002,
  0xbf800000,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3f7fffff,
  0x3f800000,
  0x3f800000,
  0x3fbfffff,
  0x3fc00000,
  0x3fc00001,
  0x40000000,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3f000000,
  0x3f000000,
  0x33000000,
  0x00000000,
  0xb3800000,
  0xbefffffe,
  0xbf000000,
  0xbf000002,
  0xbf800000,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3fc00000,
  0x3fc00000,
  0x3fc00001,
  0x40000000,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000001,
  0x3f000001,
  0x33c00000,
  0x33800000,
  0x00000000,
  0xbefffffc,
  0xbefffffe,
  0xbf000001,
  0xbf7fffff,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f800000,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x3fc00000,
  0x3fc00002,
  0x40000000,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f400000,
  0x3f400000,
  0x3e800001,
  0x3e800000,
  0x3e7ffffc,
  0xbe7ffffc,
  0xbe800000,
  0xbe800004,
  0xbf400000,
  0xc1140000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f400000,
  0x3f400000,
  0x3f400000,
  0x3f400000,
  0x3f400000,
  0x3fa00000,
  0x3fa00000,
  0x3fa00000,
  0x3fe00000,
  0x3fe00000,
  0x3fe00001,
  0x40100000,
  0x412c0000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f400000,
  0x3f400000,
  0x3f400000,
  0x40a00000,
  0x40a00000,
  0x40900000,
  0x40900000,
  0x40900000,
  0x40800000,
  0x40800000,
  0x40800000,
  0x40600000,
  0xc0a00000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x40a00000,
  0x40a00000,
  0x40a00000,
  0x40a00000,
  0x40a00000,
  0x40b00000,
  0x40b00000,
  0x40b00000,
  0x40c00000,
  0x40c00000,
  0x40c00000,
  0x40d00000,
  0x41700000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x40a00000,
  0x40a00000,
  0x40a00000,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x00091a2b,
  0x8076e5d5,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80091a2b,
  0x8076e5d4,
  0x00091a2a,
  0x00091a2b,
  0x00891a2b,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x001b4e81,
  0x00891a2a,
  0x00091a2c,
  0x00400000,
  0x80400000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x002dcbaa,
  0x80400000,
  0x003ffffe,
  0x00400000,
  0x00c00000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00523456,
  0x00bffffe,
  0x00400000,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807ffffe,
  0x80000000,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x00800000,
  0x00000002,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80400000,
  0x80c00000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80523456,
  0x80bfffff,
  0x80400001,
  0x80400000,
  0x00400000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x802dcbaa,
  0x003fffff,
  0x803fffff,
  0xbe7fffff,
  0xbe7fffff,
  0xbf3fffff,
  0xbf400000,
  0xbf400001,
  0xbf9fffff,
  0xbfa00000,
  0xbfa00001,
  0xbfe00000,
  0xc1240000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbe7fffff,
  0xbe7fffff,
  0xbe7fffff,
  0xbe7fffff,
  0xbe7fffff,
  0x3e7fffff,
  0x3e800000,
  0x3e800002,
  0x3f3fffff,
  0x3f400000,
  0x3f400002,
  0x3fa00000,
  0x411c0000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbe7fffff,
  0xbe7fffff,
  0xbe7fffff,
  0xbe800000,
  0xbe800000,
  0xbf400000,
  0xbf400000,
  0xbf400001,
  0xbfa00000,
  0xbfa00000,
  0xbfa00001,
  0xbfe00000,
  0xc1240000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbe800000,
  0xbe800000,
  0xbe800000,
  0xbe800000,
  0xbe800000,
  0x3e7ffffe,
  0x3e800000,
  0x3e800002,
  0x3f3fffff,
  0x3f400000,
  0x3f400002,
  0x3fa00000,
  0x411c0000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbe800000,
  0xbe800000,
  0xbe800000,
  0xbe800001,
  0xbe800001,
  0xbf400000,
  0xbf400000,
  0xbf400002,
  0xbfa00000,
  0xbfa00000,
  0xbfa00001,
  0xbfe00000,
  0xc1240000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbe800001,
  0xbe800001,
  0xbe800001,
  0xbe800001,
  0xbe800001,
  0x3e7ffffc,
  0x3e7ffffe,
  0x3e800001,
  0x3f3ffffe,
  0x3f400000,
  0x3f400002,
  0x3fa00000,
  0x411c0000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbe800001,
  0xbe800001,
  0xbe800001,
  0xbeffffff,
  0xbeffffff,
  0xbf7fffff,
  0xbf800000,
  0xbf800000,
  0xbfbfffff,
  0xbfc00000,
  0xbfc00001,
  0xc0000000,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0x00000000,
  0x33000000,
  0x33c00000,
  0x3effffff,
  0x3f000000,
  0x3f000002,
  0x3f800000,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbf000000,
  0xbf000000,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbfc00000,
  0xbfc00000,
  0xbfc00001,
  0xc0000000,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xb3000000,
  0x00000000,
  0x33800000,
  0x3efffffe,
  0x3f000000,
  0x3f000002,
  0x3f800000,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000001,
  0xbf000001,
  0xbf800000,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xbfc00000,
  0xbfc00002,
  0xc0000000,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xb3c00000,
  0xb3800000,
  0x00000000,
  0x3efffffc,
  0x3efffffe,
  0x3f000001,
  0x3f7fffff,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf400000,
  0xbf400000,
  0xbfa00000,
  0xbfa00000,
  0xbfa00000,
  0xbfe00000,
  0xbfe00000,
  0xbfe00001,
  0xc0100000,
  0xc12c0000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf400000,
  0xbf400000,
  0xbf400000,
  0xbf400000,
  0xbf400000,
  0xbe800001,
  0xbe800000,
  0xbe7ffffc,
  0x3e7ffffc,
  0x3e800000,
  0x3e800004,
  0x3f400000,
  0x41140000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf400000,
  0xbf400000,
  0xbf400000,
  0xc0a00000,
  0xc0a00000,
  0xc0b00000,
  0xc0b00000,
  0xc0b00000,
  0xc0c00000,
  0xc0c00000,
  0xc0c00000,
  0xc0d00000,
  0xc1700000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xc0a00000,
  0xc0a00000,
  0xc0a00000,
  0xc0a00000,
  0xc0a00000,
  0xc0900000,
  0xc0900000,
  0xc0900000,
  0xc0800000,
  0xc0800000,
  0xc0800000,
  0xc0600000,
  0x40a00000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xc0a00000,
  0xc0a00000,
  0xc0a00000,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x80091a2b,
  0x80891a2b,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x801b4e81,
  0x80891a2a,
  0x80091a2c,
  0x80091a2b,
  0x0076e5d5,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00091a2b,
  0x0076e5d4,
  0x80091a2a,
  0x80400000,
  0x80c00000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80523456,
  0x80bffffe,
  0x80400000,
  0x80400000,
  0x00400000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x802dcbaa,
  0x00400000,
  0x803ffffe,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x80800000,
  0x80000002,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007ffffe,
  0x00000000,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00400000,
  0x80400000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x002dcbaa,
  0x803ffffe,
  0x00400000,
  0x00400000,
  0x00c00000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00523456,
  0x00c00000,
  0x00400002,
  0x3e800000,
  0x3e800000,
  0xbe7ffffd,
  0xbe7fffff,
  0xbe800002,
  0xbf3fffff,
  0xbf400000,
  0xbf400002,
  0xbfa00000,
  0xc11c0000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3e800000,
  0x3e800000,
  0x3e800000,
  0x3e800000,
  0x3e800000,
  0x3f400000,
  0x3f400000,
  0x3f400001,
  0x3fa00000,
  0x3fa00000,
  0x3fa00001,
  0x3fe00000,
  0x41240000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3e800000,
  0x3e800000,
  0x3e800000,
  0x3e800001,
  0x3e800001,
  0xbe7ffffc,
  0xbe7ffffe,
  0xbe800001,
  0xbf3ffffe,
  0xbf400000,
  0xbf400002,
  0xbfa00000,
  0xc11c0000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3e800001,
  0x3e800001,
  0x3e800001,
  0x3e800001,
  0x3e800001,
  0x3f400000,
  0x3f400000,
  0x3f400002,
  0x3fa00000,
  0x3fa00000,
  0x3fa00001,
  0x3fe00000,
  0x41240000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3e800001,
  0x3e800001,
  0x3e800001,
  0x3e800002,
  0x3e800002,
  0xbe7ffffa,
  0xbe7ffffc,
  0xbe800000,
  0xbf3ffffe,
  0xbf3fffff,
  0xbf400001,
  0xbf9fffff,
  0xc11c0000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3e800002,
  0x3e800002,
  0x3e800002,
  0x3e800002,
  0x3e800002,
  0x3f400001,
  0x3f400001,
  0x3f400002,
  0x3fa00000,
  0x3fa00001,
  0x3fa00002,
  0x3fe00001,
  0x41240000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3e800002,
  0x3e800002,
  0x3e800002,
  0x3f000000,
  0x3f000000,
  0x337fffff,
  0x32fffffe,
  0xb3000001,
  0xbefffffd,
  0xbeffffff,
  0xbf000002,
  0xbf800000,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f800000,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x3fc00000,
  0x3fc00001,
  0x40000000,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000001,
  0x3f000001,
  0x33c00000,
  0x33800000,
  0x00000000,
  0xbefffffc,
  0xbefffffe,
  0xbf000001,
  0xbf7fffff,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f800000,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x3fc00000,
  0x3fc00002,
  0x40000000,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f000002,
  0x3f000002,
  0x34200000,
  0x34000000,
  0x33800001,
  0xbefffffa,
  0xbefffffc,
  0xbf000000,
  0xbf7ffffe,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f000002,
  0x3f000002,
  0x3f000002,
  0x3f000002,
  0x3f000002,
  0x3f800001,
  0x3f800001,
  0x3f800002,
  0x3fc00001,
  0x3fc00001,
  0x3fc00002,
  0x40000001,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f000002,
  0x3f000002,
  0x3f000002,
  0x3f400002,
  0x3f400001,
  0x3e800004,
  0x3e800003,
  0x3e800001,
  0xbe7ffff6,
  0xbe7ffffa,
  0xbe800001,
  0xbf3ffffe,
  0xc1140000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f400001,
  0x3f400001,
  0x3f400001,
  0x3f400002,
  0x3f400002,
  0x3fa00000,
  0x3fa00001,
  0x3fa00001,
  0x3fe00000,
  0x3fe00001,
  0x3fe00002,
  0x40100000,
  0x412c0000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f400002,
  0x3f400002,
  0x3f400002,
  0x40a00001,
  0x40a00001,
  0x40900001,
  0x40900001,
  0x40900001,
  0x40800001,
  0x40800001,
  0x40800001,
  0x40600002,
  0xc09fffff,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x40a00001,
  0x40a00001,
  0x40a00001,
  0x40a00001,
  0x40a00001,
  0x40b00001,
  0x40b00001,
  0x40b00001,
  0x40c00001,
  0x40c00001,
  0x40c00002,
  0x40d00001,
  0x41700001,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x40a00001,
  0x40a00001,
  0x40a00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x00091a2b,
  0x8076e5d5,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80091a2b,
  0x8076e5d4,
  0x00091a2a,
  0x00091a2b,
  0x00891a2b,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x001b4e81,
  0x00891a2a,
  0x00091a2c,
  0x00400000,
  0x80400000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x002dcbaa,
  0x803fffff,
  0x003fffff,
  0x00400000,
  0x00c00000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00523456,
  0x00bfffff,
  0x00400001,
  0x00000001,
  0x807fffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123455,
  0x807ffffe,
  0x80000000,
  0x00000001,
  0x00800001,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123457,
  0x00800000,
  0x00000002,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80400000,
  0x80c00000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80523456,
  0x80c00000,
  0x80400002,
  0x80400000,
  0x00400000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x802dcbaa,
  0x003ffffe,
  0x80400000,
  0xbe800000,
  0xbe800000,
  0xbf400000,
  0xbf400000,
  0xbf400001,
  0xbfa00000,
  0xbfa00000,
  0xbfa00001,
  0xbfe00000,
  0xc1240000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbe800000,
  0xbe800000,
  0xbe800000,
  0xbe800000,
  0xbe800000,
  0x3e7ffffd,
  0x3e7fffff,
  0x3e800002,
  0x3f3fffff,
  0x3f400000,
  0x3f400002,
  0x3fa00000,
  0x411c0000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbe800000,
  0xbe800000,
  0xbe800000,
  0xbe800001,
  0xbe800001,
  0xbf400000,
  0xbf400000,
  0xbf400002,
  0xbfa00000,
  0xbfa00000,
  0xbfa00001,
  0xbfe00000,
  0xc1240000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbe800001,
  0xbe800001,
  0xbe800001,
  0xbe800001,
  0xbe800001,
  0x3e7ffffc,
  0x3e7ffffe,
  0x3e800001,
  0x3f3ffffe,
  0x3f400000,
  0x3f400002,
  0x3fa00000,
  0x411c0000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbe800001,
  0xbe800001,
  0xbe800001,
  0xbe800002,
  0xbe800002,
  0xbf400001,
  0xbf400001,
  0xbf400002,
  0xbfa00000,
  0xbfa00001,
  0xbfa00002,
  0xbfe00001,
  0xc1240000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbe800002,
  0xbe800002,
  0xbe800002,
  0xbe800002,
  0xbe800002,
  0x3e7ffffa,
  0x3e7ffffc,
  0x3e800000,
  0x3f3ffffe,
  0x3f3fffff,
  0x3f400001,
  0x3f9fffff,
  0x411c0000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbe800002,
  0xbe800002,
  0xbe800002,
  0xbf000000,
  0xbf000000,
  0xbf800000,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xbfc00000,
  0xbfc00001,
  0xc0000000,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xb37fffff,
  0xb2fffffe,
  0x33000001,
  0x3efffffd,
  0x3effffff,
  0x3f000002,
  0x3f800000,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000001,
  0xbf000001,
  0xbf800000,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xbfc00000,
  0xbfc00002,
  0xc0000000,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xb3c00000,
  0xb3800000,
  0x00000000,
  0x3efffffc,
  0x3efffffe,
  0x3f000001,
  0x3f7fffff,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf000002,
  0xbf000002,
  0xbf800001,
  0xbf800001,
  0xbf800002,
  0xbfc00001,
  0xbfc00001,
  0xbfc00002,
  0xc0000001,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf000002,
  0xbf000002,
  0xbf000002,
  0xbf000002,
  0xbf000002,
  0xb4200000,
  0xb4000000,
  0xb3800001,
  0x3efffffa,
  0x3efffffc,
  0x3f000000,
  0x3f7ffffe,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf000002,
  0xbf000002,
  0xbf000002,
  0xbf400002,
  0xbf400002,
  0xbfa00000,
  0xbfa00001,
  0xbfa00001,
  0xbfe00000,
  0xbfe00001,
  0xbfe00002,
  0xc0100000,
  0xc12c0000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf400002,
  0xbf400002,
  0xbf400002,
  0xbf400002,
  0xbf400001,
  0xbe800004,
  0xbe800003,
  0xbe800001,
  0x3e7ffff6,
  0x3e7ffffa,
  0x3e800001,
  0x3f3ffffe,
  0x41140000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf400001,
  0xbf400001,
  0xbf400001,
  0xc0a00001,
  0xc0a00001,
  0xc0b00001,
  0xc0b00001,
  0xc0b00001,
  0xc0c00001,
  0xc0c00001,
  0xc0c00002,
  0xc0d00001,
  0xc1700001,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xc0a00001,
  0xc0a00001,
  0xc0a00001,
  0xc0a00001,
  0xc0a00001,
  0xc0900001,
  0xc0900001,
  0xc0900001,
  0xc0800001,
  0xc0800001,
  0xc0800001,
  0xc0600002,
  0x409fffff,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xc0a00001,
  0xc0a00001,
  0xc0a00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x80091a2b,
  0x80891a2b,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x801b4e81,
  0x80891a2a,
  0x80091a2c,
  0x80091a2b,
  0x0076e5d5,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00091a2b,
  0x0076e5d4,
  0x80091a2a,
  0x80400000,
  0x80c00000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80523456,
  0x80bfffff,
  0x80400001,
  0x80400000,
  0x00400000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x802dcbaa,
  0x003fffff,
  0x803fffff,
  0x80000001,
  0x80800001,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123457,
  0x80800000,
  0x80000002,
  0x80000001,
  0x007fffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123455,
  0x007ffffe,
  0x00000000,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00800000,
  0x80000000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x006dcbaa,
  0x00000000,
  0x007ffffe,
  0x00800000,
  0x01000000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00923456,
  0x00fffffe,
  0x00800000,
  0x3efffffe,
  0x3efffffe,
  0xb2ffffff,
  0xb3800000,
  0xb4000000,
  0xbf000000,
  0xbf000001,
  0xbf000003,
  0xbf800000,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3efffffe,
  0x3efffffe,
  0x3efffffe,
  0x3efffffe,
  0x3efffffe,
  0x3f7fffff,
  0x3f7fffff,
  0x3f800000,
  0x3fbfffff,
  0x3fc00000,
  0x3fc00001,
  0x40000000,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3efffffe,
  0x3efffffe,
  0x3efffffe,
  0x3effffff,
  0x3effffff,
  0x00000000,
  0xb3000000,
  0xb3c00000,
  0xbeffffff,
  0xbf000000,
  0xbf000002,
  0xbf800000,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3f7fffff,
  0x3f800000,
  0x3f800000,
  0x3fbfffff,
  0x3fc00000,
  0x3fc00001,
  0x40000000,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3f000000,
  0x3f000000,
  0x337fffff,
  0x32fffffe,
  0xb3000001,
  0xbefffffd,
  0xbeffffff,
  0xbf000002,
  0xbf800000,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f800000,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x3fc00000,
  0x3fc00001,
  0x40000000,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f7ffffe,
  0x3f7ffffe,
  0x3efffffd,
  0x3efffffc,
  0x3efffffa,
  0xb37fffff,
  0xb4000000,
  0xb4800000,
  0xbf000002,
  0xc1100000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f7ffffe,
  0x3f7ffffe,
  0x3f7ffffe,
  0x3f7ffffe,
  0x3f7ffffe,
  0x3fbfffff,
  0x3fbfffff,
  0x3fc00000,
  0x3fffffff,
  0x3fffffff,
  0x40000000,
  0x40200000,
  0x41300000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f7ffffe,
  0x3f7ffffe,
  0x3f7ffffe,
  0x3f7fffff,
  0x3f7fffff,
  0x3effffff,
  0x3efffffe,
  0x3efffffc,
  0x00000000,
  0xb3800000,
  0xb4400000,
  0xbf000001,
  0xc1100000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f7fffff,
  0x3f7fffff,
  0x3f7fffff,
  0x3f7fffff,
  0x3f7fffff,
  0x3fbfffff,
  0x3fc00000,
  0x3fc00000,
  0x3fffffff,
  0x40000000,
  0x40000000,
  0x40200000,
  0x41300000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f7fffff,
  0x3f7fffff,
  0x3f7fffff,
  0x3f800000,
  0x3f800000,
  0x3f000001,
  0x3f000001,
  0x3f000000,
  0x33ffffff,
  0x337ffffe,
  0xb3800001,
  0xbefffffe,
  0xc1100000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3fc00000,
  0x3fc00000,
  0x3fc00001,
  0x40000000,
  0x40000000,
  0x40000001,
  0x40200000,
  0x41300000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3fbfffff,
  0x3fbfffff,
  0x3f7fffff,
  0x3f7ffffe,
  0x3f7ffffe,
  0x3effffff,
  0x3efffffd,
  0x3efffff9,
  0xb3c00000,
  0xc1080000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3fbfffff,
  0x3fbfffff,
  0x3fbfffff,
  0x3fbfffff,
  0x3fbfffff,
  0x3fffffff,
  0x3fffffff,
  0x40000000,
  0x401fffff,
  0x40200000,
  0x40200000,
  0x40400000,
  0x41380000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3fbfffff,
  0x3fbfffff,
  0x3fbfffff,
  0x411fffff,
  0x411fffff,
  0x4117ffff,
  0x4117ffff,
  0x4117ffff,
  0x410fffff,
  0x410fffff,
  0x410fffff,
  0x4107ffff,
  0xb5200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x411fffff,
  0x411fffff,
  0x411fffff,
  0x411fffff,
  0x411fffff,
  0x4127ffff,
  0x4127ffff,
  0x4127ffff,
  0x412fffff,
  0x412fffff,
  0x41300000,
  0x4137ffff,
  0x41a00000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x411fffff,
  0x411fffff,
  0x411fffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x00123456,
  0x806dcbaa,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80000000,
  0x806dcba9,
  0x00123455,
  0x00123456,
  0x00923456,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x002468ac,
  0x00923455,
  0x00123457,
  0x007fffff,
  0x80000001,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x006dcba9,
  0x80000000,
  0x007ffffe,
  0x007fffff,
  0x00ffffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00923455,
  0x00fffffe,
  0x00800000,
  0x00000001,
  0x807fffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123455,
  0x807ffffe,
  0x80000000,
  0x00000001,
  0x00800001,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123457,
  0x00800000,
  0x00000002,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80800000,
  0x81000000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80923456,
  0x80fffffe,
  0x80800000,
  0x80800000,
  0x00000000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x806dcbaa,
  0x80000000,
  0x807ffffe,
  0xbefffffe,
  0xbefffffe,
  0xbf7fffff,
  0xbf7fffff,
  0xbf800000,
  0xbfbfffff,
  0xbfc00000,
  0xbfc00001,
  0xc0000000,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbefffffe,
  0xbefffffe,
  0xbefffffe,
  0xbefffffe,
  0xbefffffe,
  0x32ffffff,
  0x33800000,
  0x34000000,
  0x3f000000,
  0x3f000001,
  0x3f000003,
  0x3f800000,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbefffffe,
  0xbefffffe,
  0xbefffffe,
  0xbeffffff,
  0xbeffffff,
  0xbf7fffff,
  0xbf800000,
  0xbf800000,
  0xbfbfffff,
  0xbfc00000,
  0xbfc00001,
  0xc0000000,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0x00000000,
  0x33000000,
  0x33c00000,
  0x3effffff,
  0x3f000000,
  0x3f000002,
  0x3f800000,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbf000000,
  0xbf000000,
  0xbf800000,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xbfc00000,
  0xbfc00001,
  0xc0000000,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xb37fffff,
  0xb2fffffe,
  0x33000001,
  0x3efffffd,
  0x3effffff,
  0x3f000002,
  0x3f800000,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf7ffffe,
  0xbf7ffffe,
  0xbfbfffff,
  0xbfbfffff,
  0xbfc00000,
  0xbfffffff,
  0xbfffffff,
  0xc0000000,
  0xc0200000,
  0xc1300000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf7ffffe,
  0xbf7ffffe,
  0xbf7ffffe,
  0xbf7ffffe,
  0xbf7ffffe,
  0xbefffffd,
  0xbefffffc,
  0xbefffffa,
  0x337fffff,
  0x34000000,
  0x34800000,
  0x3f000002,
  0x41100000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf7ffffe,
  0xbf7ffffe,
  0xbf7ffffe,
  0xbf7fffff,
  0xbf7fffff,
  0xbfbfffff,
  0xbfc00000,
  0xbfc00000,
  0xbfffffff,
  0xc0000000,
  0xc0000000,
  0xc0200000,
  0xc1300000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf7fffff,
  0xbf7fffff,
  0xbf7fffff,
  0xbf7fffff,
  0xbf7fffff,
  0xbeffffff,
  0xbefffffe,
  0xbefffffc,
  0x00000000,
  0x33800000,
  0x34400000,
  0x3f000001,
  0x41100000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf7fffff,
  0xbf7fffff,
  0xbf7fffff,
  0xbf800000,
  0xbf800000,
  0xbfc00000,
  0xbfc00000,
  0xbfc00001,
  0xc0000000,
  0xc0000000,
  0xc0000001,
  0xc0200000,
  0xc1300000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbf000001,
  0xbf000001,
  0xbf000000,
  0xb3ffffff,
  0xb37ffffe,
  0x33800001,
  0x3efffffe,
  0x41100000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbfbfffff,
  0xbfbfffff,
  0xbfffffff,
  0xbfffffff,
  0xc0000000,
  0xc01fffff,
  0xc0200000,
  0xc0200000,
  0xc0400000,
  0xc1380000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbfbfffff,
  0xbfbfffff,
  0xbfbfffff,
  0xbfbfffff,
  0xbfbfffff,
  0xbf7fffff,
  0xbf7ffffe,
  0xbf7ffffe,
  0xbeffffff,
  0xbefffffd,
  0xbefffff9,
  0x33c00000,
  0x41080000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbfbfffff,
  0xbfbfffff,
  0xbfbfffff,
  0xc11fffff,
  0xc11fffff,
  0xc127ffff,
  0xc127ffff,
  0xc127ffff,
  0xc12fffff,
  0xc12fffff,
  0xc1300000,
  0xc137ffff,
  0xc1a00000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xc11fffff,
  0xc11fffff,
  0xc11fffff,
  0xc11fffff,
  0xc11fffff,
  0xc117ffff,
  0xc117ffff,
  0xc117ffff,
  0xc10fffff,
  0xc10fffff,
  0xc10fffff,
  0xc107ffff,
  0x35200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xc11fffff,
  0xc11fffff,
  0xc11fffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x80123456,
  0x80923456,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x802468ac,
  0x80923455,
  0x80123457,
  0x80123456,
  0x006dcbaa,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00000000,
  0x006dcba9,
  0x80123455,
  0x807fffff,
  0x80ffffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80923455,
  0x80fffffe,
  0x80800000,
  0x807fffff,
  0x00000001,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x806dcba9,
  0x00000000,
  0x807ffffe,
  0x80000001,
  0x80800001,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123457,
  0x80800000,
  0x80000002,
  0x80000001,
  0x007fffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123455,
  0x007ffffe,
  0x00000000,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00800000,
  0x00000000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x006dcbaa,
  0x00000001,
  0x007fffff,
  0x00800000,
  0x01000000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00923456,
  0x00ffffff,
  0x00800001,
  0x3effffff,
  0x3effffff,
  0x00000000,
  0xb3000000,
  0xb3c00000,
  0xbeffffff,
  0xbf000000,
  0xbf000002,
  0xbf800000,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3f7fffff,
  0x3f800000,
  0x3f800000,
  0x3fbfffff,
  0x3fc00000,
  0x3fc00001,
  0x40000000,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3f000000,
  0x3f000000,
  0x33000000,
  0x00000000,
  0xb3800000,
  0xbefffffe,
  0xbf000000,
  0xbf000002,
  0xbf800000,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3fc00000,
  0x3fc00000,
  0x3fc00001,
  0x40000000,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000001,
  0x3f000001,
  0x33c00000,
  0x33800000,
  0x00000000,
  0xbefffffc,
  0xbefffffe,
  0xbf000001,
  0xbf7fffff,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f800000,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x3fc00000,
  0x3fc00002,
  0x40000000,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f7fffff,
  0x3f7fffff,
  0x3effffff,
  0x3efffffe,
  0x3efffffc,
  0x00000000,
  0xb3800000,
  0xb4400000,
  0xbf000001,
  0xc1100000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f7fffff,
  0x3f7fffff,
  0x3f7fffff,
  0x3f7fffff,
  0x3f7fffff,
  0x3fbfffff,
  0x3fc00000,
  0x3fc00000,
  0x3fffffff,
  0x40000000,
  0x40000000,
  0x40200000,
  0x41300000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f7fffff,
  0x3f7fffff,
  0x3f7fffff,
  0x3f800000,
  0x3f800000,
  0x3f000000,
  0x3f000000,
  0x3efffffe,
  0x33800000,
  0x00000000,
  0xb4000000,
  0xbf000000,
  0xc1100000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3fc00000,
  0x3fc00000,
  0x3fc00000,
  0x40000000,
  0x40000000,
  0x40000000,
  0x40200000,
  0x41300000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3f800001,
  0x3f800001,
  0x3f000002,
  0x3f000002,
  0x3f000001,
  0x34400000,
  0x34000000,
  0x00000000,
  0xbefffffc,
  0xc1100000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f800001,
  0x3f800001,
  0x3f800001,
  0x3f800001,
  0x3f800001,
  0x3fc00001,
  0x3fc00001,
  0x3fc00002,
  0x40000000,
  0x40000000,
  0x40000001,
  0x40200000,
  0x41300000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f800001,
  0x3f800001,
  0x3f800001,
  0x3fc00000,
  0x3fc00000,
  0x3f800000,
  0x3f800000,
  0x3f7fffff,
  0x3f000001,
  0x3f000000,
  0x3efffffc,
  0x00000000,
  0xc1080000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3fc00000,
  0x3fc00000,
  0x3fc00000,
  0x3fc00000,
  0x3fc00000,
  0x40000000,
  0x40000000,
  0x40000000,
  0x40200000,
  0x40200000,
  0x40200000,
  0x40400000,
  0x41380000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3fc00000,
  0x3fc00000,
  0x3fc00000,
  0x41200000,
  0x41200000,
  0x41180000,
  0x41180000,
  0x41180000,
  0x41100000,
  0x41100000,
  0x41100000,
  0x41080000,
  0x00000000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x41200000,
  0x41200000,
  0x41200000,
  0x41200000,
  0x41200000,
  0x41280000,
  0x41280000,
  0x41280000,
  0x41300000,
  0x41300000,
  0x41300000,
  0x41380000,
  0x41a00000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x41200000,
  0x41200000,
  0x41200000,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x00123456,
  0x806dcbaa,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x00000000,
  0x806dcba9,
  0x00123455,
  0x00123456,
  0x00923456,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x002468ac,
  0x00923455,
  0x00123457,
  0x007fffff,
  0x80000001,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x006dcba9,
  0x00000000,
  0x007ffffe,
  0x007fffff,
  0x00ffffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00923455,
  0x00fffffe,
  0x00800000,
  0x00000001,
  0x807fffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123455,
  0x807ffffe,
  0x00000000,
  0x00000001,
  0x00800001,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123457,
  0x00800000,
  0x00000002,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80800000,
  0x81000000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80923456,
  0x80ffffff,
  0x80800001,
  0x80800000,
  0x00000000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x806dcbaa,
  0x80000001,
  0x807fffff,
  0xbeffffff,
  0xbeffffff,
  0xbf7fffff,
  0xbf800000,
  0xbf800000,
  0xbfbfffff,
  0xbfc00000,
  0xbfc00001,
  0xc0000000,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0x00000000,
  0x33000000,
  0x33c00000,
  0x3effffff,
  0x3f000000,
  0x3f000002,
  0x3f800000,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbf000000,
  0xbf000000,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbfc00000,
  0xbfc00000,
  0xbfc00001,
  0xc0000000,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xb3000000,
  0x00000000,
  0x33800000,
  0x3efffffe,
  0x3f000000,
  0x3f000002,
  0x3f800000,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000001,
  0xbf000001,
  0xbf800000,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xbfc00000,
  0xbfc00002,
  0xc0000000,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xb3c00000,
  0xb3800000,
  0x00000000,
  0x3efffffc,
  0x3efffffe,
  0x3f000001,
  0x3f7fffff,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf7fffff,
  0xbf7fffff,
  0xbfbfffff,
  0xbfc00000,
  0xbfc00000,
  0xbfffffff,
  0xc0000000,
  0xc0000000,
  0xc0200000,
  0xc1300000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf7fffff,
  0xbf7fffff,
  0xbf7fffff,
  0xbf7fffff,
  0xbf7fffff,
  0xbeffffff,
  0xbefffffe,
  0xbefffffc,
  0x00000000,
  0x33800000,
  0x34400000,
  0x3f000001,
  0x41100000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf7fffff,
  0xbf7fffff,
  0xbf7fffff,
  0xbf800000,
  0xbf800000,
  0xbfc00000,
  0xbfc00000,
  0xbfc00000,
  0xc0000000,
  0xc0000000,
  0xc0000000,
  0xc0200000,
  0xc1300000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbf000000,
  0xbf000000,
  0xbefffffe,
  0xb3800000,
  0x00000000,
  0x34000000,
  0x3f000000,
  0x41100000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbf800001,
  0xbf800001,
  0xbfc00001,
  0xbfc00001,
  0xbfc00002,
  0xc0000000,
  0xc0000000,
  0xc0000001,
  0xc0200000,
  0xc1300000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf800001,
  0xbf800001,
  0xbf800001,
  0xbf800001,
  0xbf800001,
  0xbf000002,
  0xbf000002,
  0xbf000001,
  0xb4400000,
  0xb4000000,
  0x00000000,
  0x3efffffc,
  0x41100000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf800001,
  0xbf800001,
  0xbf800001,
  0xbfc00000,
  0xbfc00000,
  0xc0000000,
  0xc0000000,
  0xc0000000,
  0xc0200000,
  0xc0200000,
  0xc0200000,
  0xc0400000,
  0xc1380000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbfc00000,
  0xbfc00000,
  0xbfc00000,
  0xbfc00000,
  0xbfc00000,
  0xbf800000,
  0xbf800000,
  0xbf7fffff,
  0xbf000001,
  0xbf000000,
  0xbefffffc,
  0x00000000,
  0x41080000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbfc00000,
  0xbfc00000,
  0xbfc00000,
  0xc1200000,
  0xc1200000,
  0xc1280000,
  0xc1280000,
  0xc1280000,
  0xc1300000,
  0xc1300000,
  0xc1300000,
  0xc1380000,
  0xc1a00000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xc1200000,
  0xc1200000,
  0xc1200000,
  0xc1200000,
  0xc1200000,
  0xc1180000,
  0xc1180000,
  0xc1180000,
  0xc1100000,
  0xc1100000,
  0xc1100000,
  0xc1080000,
  0x00000000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xc1200000,
  0xc1200000,
  0xc1200000,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x80123456,
  0x80923456,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x802468ac,
  0x80923455,
  0x80123457,
  0x80123456,
  0x006dcbaa,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00000000,
  0x006dcba9,
  0x80123455,
  0x807fffff,
  0x80ffffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80923455,
  0x80fffffe,
  0x80800000,
  0x807fffff,
  0x00000001,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x806dcba9,
  0x00000000,
  0x807ffffe,
  0x80000001,
  0x80800001,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123457,
  0x80800000,
  0x80000002,
  0x80000001,
  0x007fffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123455,
  0x007ffffe,
  0x00000000,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00800001,
  0x00000001,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x006dcbab,
  0x00000002,
  0x00800000,
  0x00800001,
  0x01000000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00923457,
  0x01000000,
  0x00800002,
  0x3f000000,
  0x3f000000,
  0x337fffff,
  0x32fffffe,
  0xb3000001,
  0xbefffffd,
  0xbeffffff,
  0xbf000002,
  0xbf800000,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f800000,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x3fc00000,
  0x3fc00001,
  0x40000000,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000001,
  0x3f000001,
  0x33c00000,
  0x33800000,
  0x00000000,
  0xbefffffc,
  0xbefffffe,
  0xbf000001,
  0xbf7fffff,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f800000,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x3fc00000,
  0x3fc00002,
  0x40000000,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f000002,
  0x3f000002,
  0x34200000,
  0x34000000,
  0x33800001,
  0xbefffffa,
  0xbefffffc,
  0xbf000000,
  0xbf7ffffe,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f000002,
  0x3f000002,
  0x3f000002,
  0x3f000002,
  0x3f000002,
  0x3f800001,
  0x3f800001,
  0x3f800002,
  0x3fc00001,
  0x3fc00001,
  0x3fc00002,
  0x40000001,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f000002,
  0x3f000002,
  0x3f000002,
  0x3f800000,
  0x3f800000,
  0x3f000001,
  0x3f000001,
  0x3f000000,
  0x33ffffff,
  0x337ffffe,
  0xb3800001,
  0xbefffffe,
  0xc1100000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3fc00000,
  0x3fc00000,
  0x3fc00001,
  0x40000000,
  0x40000000,
  0x40000001,
  0x40200000,
  0x41300000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3f800001,
  0x3f800001,
  0x3f000002,
  0x3f000002,
  0x3f000001,
  0x34400000,
  0x34000000,
  0x00000000,
  0xbefffffc,
  0xc1100000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f800001,
  0x3f800001,
  0x3f800001,
  0x3f800001,
  0x3f800001,
  0x3fc00001,
  0x3fc00001,
  0x3fc00002,
  0x40000000,
  0x40000000,
  0x40000001,
  0x40200000,
  0x41300000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f800001,
  0x3f800001,
  0x3f800001,
  0x3f800002,
  0x3f800002,
  0x3f000005,
  0x3f000004,
  0x3f000003,
  0x34a00000,
  0x34800000,
  0x34000001,
  0xbefffff8,
  0xc1100000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f800002,
  0x3f800002,
  0x3f800002,
  0x3f800002,
  0x3f800002,
  0x3fc00002,
  0x3fc00002,
  0x3fc00003,
  0x40000001,
  0x40000001,
  0x40000002,
  0x40200001,
  0x41300000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f800002,
  0x3f800002,
  0x3f800002,
  0x3fc00002,
  0x3fc00001,
  0x3f800002,
  0x3f800002,
  0x3f800001,
  0x3f000004,
  0x3f000003,
  0x3f000001,
  0x34400000,
  0xc1080000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3fc00001,
  0x3fc00001,
  0x3fc00001,
  0x3fc00002,
  0x3fc00002,
  0x40000001,
  0x40000001,
  0x40000001,
  0x40200000,
  0x40200001,
  0x40200001,
  0x40400001,
  0x41380000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3fc00002,
  0x3fc00002,
  0x3fc00002,
  0x41200001,
  0x41200001,
  0x41180001,
  0x41180001,
  0x41180001,
  0x41100001,
  0x41100001,
  0x41100001,
  0x41080001,
  0x35a00000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x41200001,
  0x41200001,
  0x41200001,
  0x41200001,
  0x41200001,
  0x41280001,
  0x41280001,
  0x41280001,
  0x41300001,
  0x41300001,
  0x41300001,
  0x41380001,
  0x41a00001,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x41200001,
  0x41200001,
  0x41200001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x00123456,
  0x806dcbaa,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x00000000,
  0x806dcba9,
  0x00123455,
  0x00123456,
  0x00923456,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x002468ac,
  0x00923455,
  0x00123457,
  0x00800000,
  0x80000000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x006dcbaa,
  0x00000001,
  0x007fffff,
  0x00800000,
  0x01000000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00923456,
  0x00ffffff,
  0x00800001,
  0x00000001,
  0x807fffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123455,
  0x807ffffe,
  0x00000000,
  0x00000001,
  0x00800001,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123457,
  0x00800000,
  0x00000002,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80800001,
  0x81000000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80923457,
  0x81000000,
  0x80800002,
  0x80800001,
  0x80000001,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x806dcbab,
  0x80000002,
  0x80800000,
  0xbf000000,
  0xbf000000,
  0xbf800000,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xbfc00000,
  0xbfc00001,
  0xc0000000,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xb37fffff,
  0xb2fffffe,
  0x33000001,
  0x3efffffd,
  0x3effffff,
  0x3f000002,
  0x3f800000,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000001,
  0xbf000001,
  0xbf800000,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xbfc00000,
  0xbfc00002,
  0xc0000000,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xb3c00000,
  0xb3800000,
  0x00000000,
  0x3efffffc,
  0x3efffffe,
  0x3f000001,
  0x3f7fffff,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf000002,
  0xbf000002,
  0xbf800001,
  0xbf800001,
  0xbf800002,
  0xbfc00001,
  0xbfc00001,
  0xbfc00002,
  0xc0000001,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf000002,
  0xbf000002,
  0xbf000002,
  0xbf000002,
  0xbf000002,
  0xb4200000,
  0xb4000000,
  0xb3800001,
  0x3efffffa,
  0x3efffffc,
  0x3f000000,
  0x3f7ffffe,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf000002,
  0xbf000002,
  0xbf000002,
  0xbf800000,
  0xbf800000,
  0xbfc00000,
  0xbfc00000,
  0xbfc00001,
  0xc0000000,
  0xc0000000,
  0xc0000001,
  0xc0200000,
  0xc1300000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbf000001,
  0xbf000001,
  0xbf000000,
  0xb3ffffff,
  0xb37ffffe,
  0x33800001,
  0x3efffffe,
  0x41100000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbf800001,
  0xbf800001,
  0xbfc00001,
  0xbfc00001,
  0xbfc00002,
  0xc0000000,
  0xc0000000,
  0xc0000001,
  0xc0200000,
  0xc1300000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf800001,
  0xbf800001,
  0xbf800001,
  0xbf800001,
  0xbf800001,
  0xbf000002,
  0xbf000002,
  0xbf000001,
  0xb4400000,
  0xb4000000,
  0x00000000,
  0x3efffffc,
  0x41100000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf800001,
  0xbf800001,
  0xbf800001,
  0xbf800002,
  0xbf800002,
  0xbfc00002,
  0xbfc00002,
  0xbfc00003,
  0xc0000001,
  0xc0000001,
  0xc0000002,
  0xc0200001,
  0xc1300000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf800002,
  0xbf800002,
  0xbf800002,
  0xbf800002,
  0xbf800002,
  0xbf000005,
  0xbf000004,
  0xbf000003,
  0xb4a00000,
  0xb4800000,
  0xb4000001,
  0x3efffff8,
  0x41100000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf800002,
  0xbf800002,
  0xbf800002,
  0xbfc00002,
  0xbfc00002,
  0xc0000001,
  0xc0000001,
  0xc0000001,
  0xc0200000,
  0xc0200001,
  0xc0200001,
  0xc0400001,
  0xc1380000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbfc00002,
  0xbfc00002,
  0xbfc00002,
  0xbfc00002,
  0xbfc00001,
  0xbf800002,
  0xbf800002,
  0xbf800001,
  0xbf000004,
  0xbf000003,
  0xbf000001,
  0xb4400000,
  0x41080000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbfc00001,
  0xbfc00001,
  0xbfc00001,
  0xc1200001,
  0xc1200001,
  0xc1280001,
  0xc1280001,
  0xc1280001,
  0xc1300001,
  0xc1300001,
  0xc1300001,
  0xc1380001,
  0xc1a00001,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xc1200001,
  0xc1200001,
  0xc1200001,
  0xc1200001,
  0xc1200001,
  0xc1180001,
  0xc1180001,
  0xc1180001,
  0xc1100001,
  0xc1100001,
  0xc1100001,
  0xc1080001,
  0xb5a00000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xc1200001,
  0xc1200001,
  0xc1200001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x80123456,
  0x80923456,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x802468ac,
  0x80923455,
  0x80123457,
  0x80123456,
  0x006dcbaa,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x80000000,
  0x006dcba9,
  0x80123455,
  0x80800000,
  0x81000000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80923456,
  0x80ffffff,
  0x80800001,
  0x80800000,
  0x00000000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x806dcbaa,
  0x80000001,
  0x807fffff,
  0x80000001,
  0x80800001,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123457,
  0x80800000,
  0x80000002,
  0x80000001,
  0x007fffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123455,
  0x007ffffe,
  0x80000000,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00c00000,
  0x00400000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x00adcbaa,
  0x00400001,
  0x00bfffff,
  0x00c00000,
  0x01200000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00d23456,
  0x01200000,
  0x00c00001,
  0x3f3fffff,
  0x3f3fffff,
  0x3e7fffff,
  0x3e7ffffd,
  0x3e7ffff9,
  0xbe7fffff,
  0xbe800002,
  0xbe800006,
  0xbf400001,
  0xc1140000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f3fffff,
  0x3f3fffff,
  0x3f3fffff,
  0x3f3fffff,
  0x3f3fffff,
  0x3f9fffff,
  0x3fa00000,
  0x3fa00000,
  0x3fdfffff,
  0x3fe00000,
  0x3fe00001,
  0x40100000,
  0x412c0000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f3fffff,
  0x3f3fffff,
  0x3f3fffff,
  0x3f400000,
  0x3f400000,
  0x3e800001,
  0x3e800000,
  0x3e7ffffc,
  0xbe7ffffc,
  0xbe800000,
  0xbe800004,
  0xbf400000,
  0xc1140000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f400000,
  0x3f400000,
  0x3f400000,
  0x3f400000,
  0x3f400000,
  0x3fa00000,
  0x3fa00000,
  0x3fa00000,
  0x3fe00000,
  0x3fe00000,
  0x3fe00001,
  0x40100000,
  0x412c0000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f400000,
  0x3f400000,
  0x3f400000,
  0x3f400002,
  0x3f400001,
  0x3e800004,
  0x3e800003,
  0x3e800001,
  0xbe7ffff6,
  0xbe7ffffa,
  0xbe800001,
  0xbf3ffffe,
  0xc1140000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f400001,
  0x3f400001,
  0x3f400001,
  0x3f400002,
  0x3f400002,
  0x3fa00000,
  0x3fa00001,
  0x3fa00001,
  0x3fe00000,
  0x3fe00001,
  0x3fe00002,
  0x40100000,
  0x412c0000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f400002,
  0x3f400002,
  0x3f400002,
  0x3fbfffff,
  0x3fbfffff,
  0x3f7fffff,
  0x3f7ffffe,
  0x3f7ffffe,
  0x3effffff,
  0x3efffffd,
  0x3efffff9,
  0xb3c00000,
  0xc1080000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3fbfffff,
  0x3fbfffff,
  0x3fbfffff,
  0x3fbfffff,
  0x3fbfffff,
  0x3fffffff,
  0x3fffffff,
  0x40000000,
  0x401fffff,
  0x40200000,
  0x40200000,
  0x40400000,
  0x41380000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3fbfffff,
  0x3fbfffff,
  0x3fbfffff,
  0x3fc00000,
  0x3fc00000,
  0x3f800000,
  0x3f800000,
  0x3f7fffff,
  0x3f000001,
  0x3f000000,
  0x3efffffc,
  0x00000000,
  0xc1080000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3fc00000,
  0x3fc00000,
  0x3fc00000,
  0x3fc00000,
  0x3fc00000,
  0x40000000,
  0x40000000,
  0x40000000,
  0x40200000,
  0x40200000,
  0x40200000,
  0x40400000,
  0x41380000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3fc00000,
  0x3fc00000,
  0x3fc00000,
  0x3fc00002,
  0x3fc00001,
  0x3f800002,
  0x3f800002,
  0x3f800001,
  0x3f000004,
  0x3f000003,
  0x3f000001,
  0x34400000,
  0xc1080000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3fc00001,
  0x3fc00001,
  0x3fc00001,
  0x3fc00002,
  0x3fc00002,
  0x40000001,
  0x40000001,
  0x40000001,
  0x40200000,
  0x40200001,
  0x40200001,
  0x40400001,
  0x41380000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3fc00002,
  0x3fc00002,
  0x3fc00002,
  0x40100000,
  0x40100000,
  0x3fe00000,
  0x3fe00000,
  0x3fe00000,
  0x3fa00000,
  0x3fa00000,
  0x3f9fffff,
  0x3f400000,
  0xc0f80000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x40100000,
  0x40100000,
  0x40100000,
  0x40100000,
  0x40100000,
  0x40300000,
  0x40300000,
  0x40300000,
  0x40500000,
  0x40500000,
  0x40500000,
  0x40700000,
  0x41440000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x40100000,
  0x40100000,
  0x40100000,
  0x41700000,
  0x41700000,
  0x41680000,
  0x41680000,
  0x41680000,
  0x41600000,
  0x41600000,
  0x41600000,
  0x41580000,
  0x40a00000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x41700000,
  0x41700000,
  0x41700000,
  0x41700000,
  0x41700000,
  0x41780000,
  0x41780000,
  0x41780000,
  0x41800000,
  0x41800000,
  0x41800000,
  0x41840000,
  0x41c80000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x41700000,
  0x41700000,
  0x41700000,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x001b4e81,
  0x8064b17f,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x00091a2b,
  0x8064b17e,
  0x001b4e80,
  0x001b4e81,
  0x009b4e81,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x002d82d7,
  0x009b4e80,
  0x001b4e82,
  0x00bffffe,
  0x003ffffe,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x00adcba8,
  0x00400000,
  0x00bffffe,
  0x00bffffe,
  0x011fffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00d23454,
  0x011fffff,
  0x00c00000,
  0x00000002,
  0x807ffffe,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123454,
  0x807ffffe,
  0x00000000,
  0x00000002,
  0x00800002,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123458,
  0x00800000,
  0x00000002,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80c00000,
  0x81200000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80d23456,
  0x81200000,
  0x80c00001,
  0x80c00000,
  0x80400000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x80adcbaa,
  0x80400001,
  0x80bfffff,
  0xbf3fffff,
  0xbf3fffff,
  0xbf9fffff,
  0xbfa00000,
  0xbfa00000,
  0xbfdfffff,
  0xbfe00000,
  0xbfe00001,
  0xc0100000,
  0xc12c0000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf3fffff,
  0xbf3fffff,
  0xbf3fffff,
  0xbf3fffff,
  0xbf3fffff,
  0xbe7fffff,
  0xbe7ffffd,
  0xbe7ffff9,
  0x3e7fffff,
  0x3e800002,
  0x3e800006,
  0x3f400001,
  0x41140000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf3fffff,
  0xbf3fffff,
  0xbf3fffff,
  0xbf400000,
  0xbf400000,
  0xbfa00000,
  0xbfa00000,
  0xbfa00000,
  0xbfe00000,
  0xbfe00000,
  0xbfe00001,
  0xc0100000,
  0xc12c0000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf400000,
  0xbf400000,
  0xbf400000,
  0xbf400000,
  0xbf400000,
  0xbe800001,
  0xbe800000,
  0xbe7ffffc,
  0x3e7ffffc,
  0x3e800000,
  0x3e800004,
  0x3f400000,
  0x41140000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf400000,
  0xbf400000,
  0xbf400000,
  0xbf400002,
  0xbf400002,
  0xbfa00000,
  0xbfa00001,
  0xbfa00001,
  0xbfe00000,
  0xbfe00001,
  0xbfe00002,
  0xc0100000,
  0xc12c0000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf400002,
  0xbf400002,
  0xbf400002,
  0xbf400002,
  0xbf400001,
  0xbe800004,
  0xbe800003,
  0xbe800001,
  0x3e7ffff6,
  0x3e7ffffa,
  0x3e800001,
  0x3f3ffffe,
  0x41140000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf400001,
  0xbf400001,
  0xbf400001,
  0xbfbfffff,
  0xbfbfffff,
  0xbfffffff,
  0xbfffffff,
  0xc0000000,
  0xc01fffff,
  0xc0200000,
  0xc0200000,
  0xc0400000,
  0xc1380000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbfbfffff,
  0xbfbfffff,
  0xbfbfffff,
  0xbfbfffff,
  0xbfbfffff,
  0xbf7fffff,
  0xbf7ffffe,
  0xbf7ffffe,
  0xbeffffff,
  0xbefffffd,
  0xbefffff9,
  0x33c00000,
  0x41080000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbfbfffff,
  0xbfbfffff,
  0xbfbfffff,
  0xbfc00000,
  0xbfc00000,
  0xc0000000,
  0xc0000000,
  0xc0000000,
  0xc0200000,
  0xc0200000,
  0xc0200000,
  0xc0400000,
  0xc1380000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbfc00000,
  0xbfc00000,
  0xbfc00000,
  0xbfc00000,
  0xbfc00000,
  0xbf800000,
  0xbf800000,
  0xbf7fffff,
  0xbf000001,
  0xbf000000,
  0xbefffffc,
  0x00000000,
  0x41080000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbfc00000,
  0xbfc00000,
  0xbfc00000,
  0xbfc00002,
  0xbfc00002,
  0xc0000001,
  0xc0000001,
  0xc0000001,
  0xc0200000,
  0xc0200001,
  0xc0200001,
  0xc0400001,
  0xc1380000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbfc00002,
  0xbfc00002,
  0xbfc00002,
  0xbfc00002,
  0xbfc00001,
  0xbf800002,
  0xbf800002,
  0xbf800001,
  0xbf000004,
  0xbf000003,
  0xbf000001,
  0xb4400000,
  0x41080000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbfc00001,
  0xbfc00001,
  0xbfc00001,
  0xc0100000,
  0xc0100000,
  0xc0300000,
  0xc0300000,
  0xc0300000,
  0xc0500000,
  0xc0500000,
  0xc0500000,
  0xc0700000,
  0xc1440000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xc0100000,
  0xc0100000,
  0xc0100000,
  0xc0100000,
  0xc0100000,
  0xbfe00000,
  0xbfe00000,
  0xbfe00000,
  0xbfa00000,
  0xbfa00000,
  0xbf9fffff,
  0xbf400000,
  0x40f80000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xc0100000,
  0xc0100000,
  0xc0100000,
  0xc1700000,
  0xc1700000,
  0xc1780000,
  0xc1780000,
  0xc1780000,
  0xc1800000,
  0xc1800000,
  0xc1800000,
  0xc1840000,
  0xc1c80000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xc1700000,
  0xc1700000,
  0xc1700000,
  0xc1700000,
  0xc1700000,
  0xc1680000,
  0xc1680000,
  0xc1680000,
  0xc1600000,
  0xc1600000,
  0xc1600000,
  0xc1580000,
  0xc0a00000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xc1700000,
  0xc1700000,
  0xc1700000,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x801b4e81,
  0x809b4e81,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x802d82d7,
  0x809b4e80,
  0x801b4e82,
  0x801b4e81,
  0x0064b17f,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x80091a2b,
  0x0064b17e,
  0x801b4e80,
  0x80bffffe,
  0x811fffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80d23454,
  0x811fffff,
  0x80c00000,
  0x80bffffe,
  0x803ffffe,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x80adcba8,
  0x80400000,
  0x80bffffe,
  0x80000002,
  0x80800002,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123458,
  0x80800000,
  0x80000002,
  0x80000002,
  0x007ffffe,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123454,
  0x007ffffe,
  0x80000000,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x02200000,
  0x02100000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x021db975,
  0x02100000,
  0x02200000,
  0x02200000,
  0x02300000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x0222468b,
  0x02300000,
  0x02200000,
  0x409fffff,
  0x409fffff,
  0x408fffff,
  0x408fffff,
  0x408fffff,
  0x407fffff,
  0x407fffff,
  0x407ffffe,
  0x405fffff,
  0xc0a00001,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x409fffff,
  0x409fffff,
  0x409fffff,
  0x409fffff,
  0x409fffff,
  0x40afffff,
  0x40afffff,
  0x40b00000,
  0x40bfffff,
  0x40bfffff,
  0x40c00000,
  0x40cfffff,
  0x41700000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x409fffff,
  0x409fffff,
  0x409fffff,
  0x40a00000,
  0x40a00000,
  0x40900000,
  0x40900000,
  0x40900000,
  0x40800000,
  0x40800000,
  0x40800000,
  0x40600000,
  0xc0a00000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x40a00000,
  0x40a00000,
  0x40a00000,
  0x40a00000,
  0x40a00000,
  0x40b00000,
  0x40b00000,
  0x40b00000,
  0x40c00000,
  0x40c00000,
  0x40c00000,
  0x40d00000,
  0x41700000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x40a00000,
  0x40a00000,
  0x40a00000,
  0x40a00001,
  0x40a00001,
  0x40900001,
  0x40900001,
  0x40900001,
  0x40800001,
  0x40800001,
  0x40800001,
  0x40600002,
  0xc09fffff,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x40a00001,
  0x40a00001,
  0x40a00001,
  0x40a00001,
  0x40a00001,
  0x40b00001,
  0x40b00001,
  0x40b00001,
  0x40c00001,
  0x40c00001,
  0x40c00002,
  0x40d00001,
  0x41700001,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x40a00001,
  0x40a00001,
  0x40a00001,
  0x411fffff,
  0x411fffff,
  0x4117ffff,
  0x4117ffff,
  0x4117ffff,
  0x410fffff,
  0x410fffff,
  0x410fffff,
  0x4107ffff,
  0xb5200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x411fffff,
  0x411fffff,
  0x411fffff,
  0x411fffff,
  0x411fffff,
  0x4127ffff,
  0x4127ffff,
  0x4127ffff,
  0x412fffff,
  0x412fffff,
  0x41300000,
  0x4137ffff,
  0x41a00000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x411fffff,
  0x411fffff,
  0x411fffff,
  0x41200000,
  0x41200000,
  0x41180000,
  0x41180000,
  0x41180000,
  0x41100000,
  0x41100000,
  0x41100000,
  0x41080000,
  0x00000000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x41200000,
  0x41200000,
  0x41200000,
  0x41200000,
  0x41200000,
  0x41280000,
  0x41280000,
  0x41280000,
  0x41300000,
  0x41300000,
  0x41300000,
  0x41380000,
  0x41a00000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x41200000,
  0x41200000,
  0x41200000,
  0x41200001,
  0x41200001,
  0x41180001,
  0x41180001,
  0x41180001,
  0x41100001,
  0x41100001,
  0x41100001,
  0x41080001,
  0x35a00000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x41200001,
  0x41200001,
  0x41200001,
  0x41200001,
  0x41200001,
  0x41280001,
  0x41280001,
  0x41280001,
  0x41300001,
  0x41300001,
  0x41300001,
  0x41380001,
  0x41a00001,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x41200001,
  0x41200001,
  0x41200001,
  0x41700000,
  0x41700000,
  0x41680000,
  0x41680000,
  0x41680000,
  0x41600000,
  0x41600000,
  0x41600000,
  0x41580000,
  0x40a00000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x41700000,
  0x41700000,
  0x41700000,
  0x41700000,
  0x41700000,
  0x41780000,
  0x41780000,
  0x41780000,
  0x41800000,
  0x41800000,
  0x41800000,
  0x41840000,
  0x41c80000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x41700000,
  0x41700000,
  0x41700000,
  0x42c80000,
  0x42c80000,
  0x42c70000,
  0x42c70000,
  0x42c70000,
  0x42c60000,
  0x42c60000,
  0x42c60000,
  0x42c50000,
  0x42b40000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x42c80000,
  0x42c80000,
  0x42c80000,
  0x42c80000,
  0x42c80000,
  0x42c90000,
  0x42c90000,
  0x42c90000,
  0x42ca0000,
  0x42ca0000,
  0x42ca0000,
  0x42cb0000,
  0x42dc0000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x42c80000,
  0x42c80000,
  0x42c80000,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x00b60b5c,
  0x00360b5c,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x00a3d706,
  0x00360b5d,
  0x00b60b5b,
  0x00b60b5c,
  0x011b05ae,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00c83fb2,
  0x011b05ae,
  0x00b60b5d,
  0x021fffff,
  0x020fffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x021db974,
  0x020fffff,
  0x021fffff,
  0x021fffff,
  0x022fffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x0222468a,
  0x022fffff,
  0x021fffff,
  0x0000000a,
  0x807ffff6,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x8012344c,
  0x807ffff5,
  0x00000009,
  0x0000000a,
  0x0080000a,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123460,
  0x00800009,
  0x0000000b,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x82200000,
  0x82300000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x8222468b,
  0x82300000,
  0x82200000,
  0x82200000,
  0x82100000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x821db975,
  0x82100000,
  0x82200000,
  0xc09fffff,
  0xc09fffff,
  0xc0afffff,
  0xc0afffff,
  0xc0b00000,
  0xc0bfffff,
  0xc0bfffff,
  0xc0c00000,
  0xc0cfffff,
  0xc1700000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xc09fffff,
  0xc09fffff,
  0xc09fffff,
  0xc09fffff,
  0xc09fffff,
  0xc08fffff,
  0xc08fffff,
  0xc08fffff,
  0xc07fffff,
  0xc07fffff,
  0xc07ffffe,
  0xc05fffff,
  0x40a00001,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xc09fffff,
  0xc09fffff,
  0xc09fffff,
  0xc0a00000,
  0xc0a00000,
  0xc0b00000,
  0xc0b00000,
  0xc0b00000,
  0xc0c00000,
  0xc0c00000,
  0xc0c00000,
  0xc0d00000,
  0xc1700000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xc0a00000,
  0xc0a00000,
  0xc0a00000,
  0xc0a00000,
  0xc0a00000,
  0xc0900000,
  0xc0900000,
  0xc0900000,
  0xc0800000,
  0xc0800000,
  0xc0800000,
  0xc0600000,
  0x40a00000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xc0a00000,
  0xc0a00000,
  0xc0a00000,
  0xc0a00001,
  0xc0a00001,
  0xc0b00001,
  0xc0b00001,
  0xc0b00001,
  0xc0c00001,
  0xc0c00001,
  0xc0c00002,
  0xc0d00001,
  0xc1700001,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xc0a00001,
  0xc0a00001,
  0xc0a00001,
  0xc0a00001,
  0xc0a00001,
  0xc0900001,
  0xc0900001,
  0xc0900001,
  0xc0800001,
  0xc0800001,
  0xc0800001,
  0xc0600002,
  0x409fffff,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xc0a00001,
  0xc0a00001,
  0xc0a00001,
  0xc11fffff,
  0xc11fffff,
  0xc127ffff,
  0xc127ffff,
  0xc127ffff,
  0xc12fffff,
  0xc12fffff,
  0xc1300000,
  0xc137ffff,
  0xc1a00000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xc11fffff,
  0xc11fffff,
  0xc11fffff,
  0xc11fffff,
  0xc11fffff,
  0xc117ffff,
  0xc117ffff,
  0xc117ffff,
  0xc10fffff,
  0xc10fffff,
  0xc10fffff,
  0xc107ffff,
  0x35200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xc11fffff,
  0xc11fffff,
  0xc11fffff,
  0xc1200000,
  0xc1200000,
  0xc1280000,
  0xc1280000,
  0xc1280000,
  0xc1300000,
  0xc1300000,
  0xc1300000,
  0xc1380000,
  0xc1a00000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xc1200000,
  0xc1200000,
  0xc1200000,
  0xc1200000,
  0xc1200000,
  0xc1180000,
  0xc1180000,
  0xc1180000,
  0xc1100000,
  0xc1100000,
  0xc1100000,
  0xc1080000,
  0x00000000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xc1200000,
  0xc1200000,
  0xc1200000,
  0xc1200001,
  0xc1200001,
  0xc1280001,
  0xc1280001,
  0xc1280001,
  0xc1300001,
  0xc1300001,
  0xc1300001,
  0xc1380001,
  0xc1a00001,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xc1200001,
  0xc1200001,
  0xc1200001,
  0xc1200001,
  0xc1200001,
  0xc1180001,
  0xc1180001,
  0xc1180001,
  0xc1100001,
  0xc1100001,
  0xc1100001,
  0xc1080001,
  0xb5a00000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xc1200001,
  0xc1200001,
  0xc1200001,
  0xc1700000,
  0xc1700000,
  0xc1780000,
  0xc1780000,
  0xc1780000,
  0xc1800000,
  0xc1800000,
  0xc1800000,
  0xc1840000,
  0xc1c80000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xc1700000,
  0xc1700000,
  0xc1700000,
  0xc1700000,
  0xc1700000,
  0xc1680000,
  0xc1680000,
  0xc1680000,
  0xc1600000,
  0xc1600000,
  0xc1600000,
  0xc1580000,
  0xc0a00000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xc1700000,
  0xc1700000,
  0xc1700000,
  0xc2c80000,
  0xc2c80000,
  0xc2c90000,
  0xc2c90000,
  0xc2c90000,
  0xc2ca0000,
  0xc2ca0000,
  0xc2ca0000,
  0xc2cb0000,
  0xc2dc0000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xc2c80000,
  0xc2c80000,
  0xc2c80000,
  0xc2c80000,
  0xc2c80000,
  0xc2c70000,
  0xc2c70000,
  0xc2c70000,
  0xc2c60000,
  0xc2c60000,
  0xc2c60000,
  0xc2c50000,
  0xc2b40000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xc2c80000,
  0xc2c80000,
  0xc2c80000,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x80b60b5c,
  0x811b05ae,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80c83fb2,
  0x811b05ae,
  0x80b60b5d,
  0x80b60b5c,
  0x80360b5c,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x80a3d706,
  0x80360b5d,
  0x80b60b5b,
  0x821fffff,
  0x822fffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x8222468a,
  0x822fffff,
  0x821fffff,
  0x821fffff,
  0x820fffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x821db974,
  0x820fffff,
  0x821fffff,
  0x8000000a,
  0x8080000a,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123460,
  0x80800009,
  0x8000000b,
  0x8000000a,
  0x007ffff6,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x0012344c,
  0x007ffff5,
  0x80000009,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00091a2b,
  0x8076e5d5,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80091a2b,
  0x8076e5d4,
  0x00091a2a,
  0x00091a2b,
  0x00891a2b,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x001b4e81,
  0x00891a2a,
  0x00091a2c,
  0x00091a2b,
  0x8076e5d5,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80091a2b,
  0x8076e5d4,
  0x00091a2a,
  0x00091a2b,
  0x00891a2b,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x001b4e81,
  0x00891a2a,
  0x00091a2c,
  0x00091a2b,
  0x8076e5d5,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80091a2b,
  0x8076e5d4,
  0x00091a2a,
  0x00091a2b,
  0x00891a2b,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x001b4e81,
  0x00891a2a,
  0x00091a2c,
  0x00123456,
  0x806dcbaa,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80000000,
  0x806dcba9,
  0x00123455,
  0x00123456,
  0x00923456,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x002468ac,
  0x00923455,
  0x00123457,
  0x00123456,
  0x806dcbaa,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x00000000,
  0x806dcba9,
  0x00123455,
  0x00123456,
  0x00923456,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x002468ac,
  0x00923455,
  0x00123457,
  0x00123456,
  0x806dcbaa,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x00000000,
  0x806dcba9,
  0x00123455,
  0x00123456,
  0x00923456,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x002468ac,
  0x00923455,
  0x00123457,
  0x001b4e81,
  0x8064b17f,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x00091a2b,
  0x8064b17e,
  0x001b4e80,
  0x001b4e81,
  0x009b4e81,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x002d82d7,
  0x009b4e80,
  0x001b4e82,
  0x00b60b5c,
  0x00360b5c,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x00a3d706,
  0x00360b5d,
  0x00b60b5b,
  0x00b60b5c,
  0x011b05ae,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00c83fb2,
  0x011b05ae,
  0x00b60b5d,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80091a2b,
  0x80891a2b,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x801b4e81,
  0x80891a2a,
  0x80091a2c,
  0x80091a2b,
  0x0076e5d5,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00091a2b,
  0x0076e5d4,
  0x80091a2a,
  0x80091a2b,
  0x80891a2b,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x801b4e81,
  0x80891a2a,
  0x80091a2c,
  0x80091a2b,
  0x0076e5d5,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00091a2b,
  0x0076e5d4,
  0x80091a2a,
  0x80091a2b,
  0x80891a2b,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x801b4e81,
  0x80891a2a,
  0x80091a2c,
  0x80091a2b,
  0x0076e5d5,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00091a2b,
  0x0076e5d4,
  0x80091a2a,
  0x80123456,
  0x80923456,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x802468ac,
  0x80923455,
  0x80123457,
  0x80123456,
  0x006dcbaa,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00000000,
  0x006dcba9,
  0x80123455,
  0x80123456,
  0x80923456,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x802468ac,
  0x80923455,
  0x80123457,
  0x80123456,
  0x006dcbaa,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00000000,
  0x006dcba9,
  0x80123455,
  0x80123456,
  0x80923456,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x802468ac,
  0x80923455,
  0x80123457,
  0x80123456,
  0x006dcbaa,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x80000000,
  0x006dcba9,
  0x80123455,
  0x801b4e81,
  0x809b4e81,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x802d82d7,
  0x809b4e80,
  0x801b4e82,
  0x801b4e81,
  0x0064b17f,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x80091a2b,
  0x0064b17e,
  0x801b4e80,
  0x80b60b5c,
  0x811b05ae,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80c83fb2,
  0x811b05ae,
  0x80b60b5d,
  0x80b60b5c,
  0x80360b5c,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x80a3d706,
  0x80360b5d,
  0x80b60b5b,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x003fffff,
  0x80400001,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x002dcba9,
  0x80400000,
  0x003ffffe,
  0x003fffff,
  0x00bfffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00523455,
  0x00bffffe,
  0x00400000,
  0x00400000,
  0x80400000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x002dcbaa,
  0x80400000,
  0x003ffffe,
  0x00400000,
  0x00c00000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00523456,
  0x00bffffe,
  0x00400000,
  0x00400000,
  0x80400000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x002dcbaa,
  0x803fffff,
  0x003fffff,
  0x00400000,
  0x00c00000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00523456,
  0x00bfffff,
  0x00400001,
  0x007fffff,
  0x80000001,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x006dcba9,
  0x80000000,
  0x007ffffe,
  0x007fffff,
  0x00ffffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00923455,
  0x00fffffe,
  0x00800000,
  0x007fffff,
  0x80000001,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x006dcba9,
  0x00000000,
  0x007ffffe,
  0x007fffff,
  0x00ffffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00923455,
  0x00fffffe,
  0x00800000,
  0x00800000,
  0x80000000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x006dcbaa,
  0x00000001,
  0x007fffff,
  0x00800000,
  0x01000000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00923456,
  0x00ffffff,
  0x00800001,
  0x00bffffe,
  0x003ffffe,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x00adcba8,
  0x00400000,
  0x00bffffe,
  0x00bffffe,
  0x011fffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00d23454,
  0x011fffff,
  0x00c00000,
  0x021fffff,
  0x020fffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x021db974,
  0x020fffff,
  0x021fffff,
  0x021fffff,
  0x022fffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x0222468a,
  0x022fffff,
  0x021fffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x803fffff,
  0x80bfffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80523455,
  0x80bffffe,
  0x80400000,
  0x803fffff,
  0x00400001,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x802dcba9,
  0x00400000,
  0x803ffffe,
  0x80400000,
  0x80c00000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80523456,
  0x80bffffe,
  0x80400000,
  0x80400000,
  0x00400000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x802dcbaa,
  0x00400000,
  0x803ffffe,
  0x80400000,
  0x80c00000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80523456,
  0x80bfffff,
  0x80400001,
  0x80400000,
  0x00400000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x802dcbaa,
  0x003fffff,
  0x803fffff,
  0x807fffff,
  0x80ffffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80923455,
  0x80fffffe,
  0x80800000,
  0x807fffff,
  0x00000001,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x806dcba9,
  0x00000000,
  0x807ffffe,
  0x807fffff,
  0x80ffffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80923455,
  0x80fffffe,
  0x80800000,
  0x807fffff,
  0x00000001,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x806dcba9,
  0x00000000,
  0x807ffffe,
  0x80800000,
  0x81000000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80923456,
  0x80ffffff,
  0x80800001,
  0x80800000,
  0x00000000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x806dcbaa,
  0x80000001,
  0x807fffff,
  0x80bffffe,
  0x811fffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80d23454,
  0x811fffff,
  0x80c00000,
  0x80bffffe,
  0x803ffffe,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x80adcba8,
  0x80400000,
  0x80bffffe,
  0x821fffff,
  0x822fffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x8222468a,
  0x822fffff,
  0x821fffff,
  0x821fffff,
  0x820fffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x821db974,
  0x820fffff,
  0x821fffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807ffffe,
  0x80000000,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x00800000,
  0x00000002,
  0x00000001,
  0x807fffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123455,
  0x807ffffe,
  0x80000000,
  0x00000001,
  0x00800001,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123457,
  0x00800000,
  0x00000002,
  0x00000001,
  0x807fffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123455,
  0x807ffffe,
  0x80000000,
  0x00000001,
  0x00800001,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123457,
  0x00800000,
  0x00000002,
  0x00000001,
  0x807fffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123455,
  0x807ffffe,
  0x00000000,
  0x00000001,
  0x00800001,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123457,
  0x00800000,
  0x00000002,
  0x00000001,
  0x807fffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123455,
  0x807ffffe,
  0x00000000,
  0x00000001,
  0x00800001,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123457,
  0x00800000,
  0x00000002,
  0x00000002,
  0x807ffffe,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123454,
  0x807ffffe,
  0x00000000,
  0x00000002,
  0x00800002,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123458,
  0x00800000,
  0x00000002,
  0x0000000a,
  0x807ffff6,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x8012344c,
  0x807ffff5,
  0x00000009,
  0x0000000a,
  0x0080000a,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123460,
  0x00800009,
  0x0000000b,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x80800000,
  0x80000002,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007ffffe,
  0x00000000,
  0x80000001,
  0x80800001,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123457,
  0x80800000,
  0x80000002,
  0x80000001,
  0x007fffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123455,
  0x007ffffe,
  0x00000000,
  0x80000001,
  0x80800001,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123457,
  0x80800000,
  0x80000002,
  0x80000001,
  0x007fffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123455,
  0x007ffffe,
  0x00000000,
  0x80000001,
  0x80800001,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123457,
  0x80800000,
  0x80000002,
  0x80000001,
  0x007fffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123455,
  0x007ffffe,
  0x00000000,
  0x80000001,
  0x80800001,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123457,
  0x80800000,
  0x80000002,
  0x80000001,
  0x007fffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123455,
  0x007ffffe,
  0x80000000,
  0x80000002,
  0x80800002,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123458,
  0x80800000,
  0x80000002,
  0x80000002,
  0x007ffffe,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123454,
  0x007ffffe,
  0x80000000,
  0x8000000a,
  0x8080000a,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123460,
  0x80800009,
  0x8000000b,
  0x8000000a,
  0x007ffff6,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x0012344c,
  0x007ffff5,
  0x80000009,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80400000,
  0x80c00000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80523456,
  0x80bfffff,
  0x80400001,
  0x80400000,
  0x00400000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x802dcbaa,
  0x003fffff,
  0x803fffff,
  0x80400000,
  0x80c00000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80523456,
  0x80bfffff,
  0x80400001,
  0x80400000,
  0x00400000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x802dcbaa,
  0x003fffff,
  0x803fffff,
  0x80400000,
  0x80c00000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80523456,
  0x80c00000,
  0x80400002,
  0x80400000,
  0x00400000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x802dcbaa,
  0x003ffffe,
  0x80400000,
  0x80800000,
  0x81000000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80923456,
  0x80fffffe,
  0x80800000,
  0x80800000,
  0x00000000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x806dcbaa,
  0x80000000,
  0x807ffffe,
  0x80800000,
  0x81000000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80923456,
  0x80ffffff,
  0x80800001,
  0x80800000,
  0x00000000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x806dcbaa,
  0x80000001,
  0x807fffff,
  0x80800001,
  0x81000000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80923457,
  0x81000000,
  0x80800002,
  0x80800001,
  0x80000001,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x806dcbab,
  0x80000002,
  0x80800000,
  0x80c00000,
  0x81200000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80d23456,
  0x81200000,
  0x80c00001,
  0x80c00000,
  0x80400000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x80adcbaa,
  0x80400001,
  0x80bfffff,
  0x82200000,
  0x82300000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x8222468b,
  0x82300000,
  0x82200000,
  0x82200000,
  0x82100000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x821db975,
  0x82100000,
  0x82200000,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00400000,
  0x80400000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x002dcbaa,
  0x803fffff,
  0x003fffff,
  0x00400000,
  0x00c00000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00523456,
  0x00bfffff,
  0x00400001,
  0x00400000,
  0x80400000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x002dcbaa,
  0x803fffff,
  0x003fffff,
  0x00400000,
  0x00c00000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00523456,
  0x00bfffff,
  0x00400001,
  0x00400000,
  0x80400000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x002dcbaa,
  0x803ffffe,
  0x00400000,
  0x00400000,
  0x00c00000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00523456,
  0x00c00000,
  0x00400002,
  0x00800000,
  0x80000000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x006dcbaa,
  0x00000000,
  0x007ffffe,
  0x00800000,
  0x01000000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00923456,
  0x00fffffe,
  0x00800000,
  0x00800000,
  0x00000000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x006dcbaa,
  0x00000001,
  0x007fffff,
  0x00800000,
  0x01000000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00923456,
  0x00ffffff,
  0x00800001,
  0x00800001,
  0x00000001,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x006dcbab,
  0x00000002,
  0x00800000,
  0x00800001,
  0x01000000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00923457,
  0x01000000,
  0x00800002,
  0x00c00000,
  0x00400000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x00adcbaa,
  0x00400001,
  0x00bfffff,
  0x00c00000,
  0x01200000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00d23456,
  0x01200000,
  0x00c00001,
  0x02200000,
  0x02100000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x021db975,
  0x02100000,
  0x02200000,
  0x02200000,
  0x02300000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x0222468b,
  0x02300000,
  0x02200000,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80400000,
  0x80c00000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80523456,
  0x80bfffff,
  0x80400001,
  0x80400000,
  0x00400000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x802dcbaa,
  0x003fffff,
  0x803fffff,
  0xbe7ffffe,
  0xbe7ffffe,
  0xbf3fffff,
  0xbf400000,
  0xbf400001,
  0xbf9fffff,
  0xbfa00000,
  0xbfa00001,
  0xbfe00000,
  0xc1240000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbe7ffffe,
  0xbe7ffffe,
  0xbe7ffffe,
  0xbe7ffffe,
  0xbe7ffffe,
  0x3e800000,
  0x3e800001,
  0x3e800003,
  0x3f3fffff,
  0x3f400000,
  0x3f400002,
  0x3fa00000,
  0x411c0000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbe7ffffe,
  0xbe7ffffe,
  0xbe7ffffe,
  0xbe7fffff,
  0xbe7fffff,
  0xbf3fffff,
  0xbf400000,
  0xbf400001,
  0xbf9fffff,
  0xbfa00000,
  0xbfa00001,
  0xbfe00000,
  0xc1240000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbe7fffff,
  0xbe7fffff,
  0xbe7fffff,
  0xbe7fffff,
  0xbe7fffff,
  0x3e7fffff,
  0x3e800000,
  0x3e800002,
  0x3f3fffff,
  0x3f400000,
  0x3f400002,
  0x3fa00000,
  0x411c0000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbe7fffff,
  0xbe7fffff,
  0xbe7fffff,
  0xbe800000,
  0xbe800000,
  0xbf400000,
  0xbf400000,
  0xbf400001,
  0xbfa00000,
  0xbfa00000,
  0xbfa00001,
  0xbfe00000,
  0xc1240000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbe800000,
  0xbe800000,
  0xbe800000,
  0xbe800000,
  0xbe800000,
  0x3e7ffffd,
  0x3e7fffff,
  0x3e800002,
  0x3f3fffff,
  0x3f400000,
  0x3f400002,
  0x3fa00000,
  0x411c0000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbe800000,
  0xbe800000,
  0xbe800000,
  0xbefffffe,
  0xbefffffe,
  0xbf7fffff,
  0xbf7fffff,
  0xbf800000,
  0xbfbfffff,
  0xbfc00000,
  0xbfc00001,
  0xc0000000,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbefffffe,
  0xbefffffe,
  0xbefffffe,
  0xbefffffe,
  0xbefffffe,
  0x32ffffff,
  0x33800000,
  0x34000000,
  0x3f000000,
  0x3f000001,
  0x3f000003,
  0x3f800000,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbefffffe,
  0xbefffffe,
  0xbefffffe,
  0xbeffffff,
  0xbeffffff,
  0xbf7fffff,
  0xbf800000,
  0xbf800000,
  0xbfbfffff,
  0xbfc00000,
  0xbfc00001,
  0xc0000000,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0x00000000,
  0x33000000,
  0x33c00000,
  0x3effffff,
  0x3f000000,
  0x3f000002,
  0x3f800000,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbf000000,
  0xbf000000,
  0xbf800000,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xbfc00000,
  0xbfc00001,
  0xc0000000,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xb37fffff,
  0xb2fffffe,
  0x33000001,
  0x3efffffd,
  0x3effffff,
  0x3f000002,
  0x3f800000,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf3fffff,
  0xbf3fffff,
  0xbf9fffff,
  0xbfa00000,
  0xbfa00000,
  0xbfdfffff,
  0xbfe00000,
  0xbfe00001,
  0xc0100000,
  0xc12c0000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf3fffff,
  0xbf3fffff,
  0xbf3fffff,
  0xbf3fffff,
  0xbf3fffff,
  0xbe7fffff,
  0xbe7ffffd,
  0xbe7ffff9,
  0x3e7fffff,
  0x3e800002,
  0x3e800006,
  0x3f400001,
  0x41140000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf3fffff,
  0xbf3fffff,
  0xbf3fffff,
  0xc09fffff,
  0xc09fffff,
  0xc0afffff,
  0xc0afffff,
  0xc0b00000,
  0xc0bfffff,
  0xc0bfffff,
  0xc0c00000,
  0xc0cfffff,
  0xc1700000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xc09fffff,
  0xc09fffff,
  0xc09fffff,
  0xc09fffff,
  0xc09fffff,
  0xc08fffff,
  0xc08fffff,
  0xc08fffff,
  0xc07fffff,
  0xc07fffff,
  0xc07ffffe,
  0xc05fffff,
  0x40a00001,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xc09fffff,
  0xc09fffff,
  0xc09fffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x80091a2b,
  0x80891a2b,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x801b4e81,
  0x80891a2a,
  0x80091a2c,
  0x80091a2b,
  0x0076e5d5,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00091a2b,
  0x0076e5d4,
  0x80091a2a,
  0x803fffff,
  0x80bfffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80523455,
  0x80bffffe,
  0x80400000,
  0x803fffff,
  0x00400001,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x802dcba9,
  0x00400000,
  0x803ffffe,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00400000,
  0x80400000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x002dcbaa,
  0x803fffff,
  0x003fffff,
  0x00400000,
  0x00c00000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00523456,
  0x00bfffff,
  0x00400001,
  0x3e7ffffe,
  0x3e7ffffe,
  0xbe800000,
  0xbe800001,
  0xbe800003,
  0xbf3fffff,
  0xbf400000,
  0xbf400002,
  0xbfa00000,
  0xc11c0000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3e7ffffe,
  0x3e7ffffe,
  0x3e7ffffe,
  0x3e7ffffe,
  0x3e7ffffe,
  0x3f3fffff,
  0x3f400000,
  0x3f400001,
  0x3f9fffff,
  0x3fa00000,
  0x3fa00001,
  0x3fe00000,
  0x41240000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3e7ffffe,
  0x3e7ffffe,
  0x3e7ffffe,
  0x3e7fffff,
  0x3e7fffff,
  0xbe7fffff,
  0xbe800000,
  0xbe800002,
  0xbf3fffff,
  0xbf400000,
  0xbf400002,
  0xbfa00000,
  0xc11c0000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3e7fffff,
  0x3e7fffff,
  0x3e7fffff,
  0x3e7fffff,
  0x3e7fffff,
  0x3f3fffff,
  0x3f400000,
  0x3f400001,
  0x3f9fffff,
  0x3fa00000,
  0x3fa00001,
  0x3fe00000,
  0x41240000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3e7fffff,
  0x3e7fffff,
  0x3e7fffff,
  0x3e800000,
  0x3e800000,
  0xbe7ffffd,
  0xbe7fffff,
  0xbe800002,
  0xbf3fffff,
  0xbf400000,
  0xbf400002,
  0xbfa00000,
  0xc11c0000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3e800000,
  0x3e800000,
  0x3e800000,
  0x3e800000,
  0x3e800000,
  0x3f400000,
  0x3f400000,
  0x3f400001,
  0x3fa00000,
  0x3fa00000,
  0x3fa00001,
  0x3fe00000,
  0x41240000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3e800000,
  0x3e800000,
  0x3e800000,
  0x3efffffe,
  0x3efffffe,
  0xb2ffffff,
  0xb3800000,
  0xb4000000,
  0xbf000000,
  0xbf000001,
  0xbf000003,
  0xbf800000,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3efffffe,
  0x3efffffe,
  0x3efffffe,
  0x3efffffe,
  0x3efffffe,
  0x3f7fffff,
  0x3f7fffff,
  0x3f800000,
  0x3fbfffff,
  0x3fc00000,
  0x3fc00001,
  0x40000000,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3efffffe,
  0x3efffffe,
  0x3efffffe,
  0x3effffff,
  0x3effffff,
  0x00000000,
  0xb3000000,
  0xb3c00000,
  0xbeffffff,
  0xbf000000,
  0xbf000002,
  0xbf800000,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3f7fffff,
  0x3f800000,
  0x3f800000,
  0x3fbfffff,
  0x3fc00000,
  0x3fc00001,
  0x40000000,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3f000000,
  0x3f000000,
  0x337fffff,
  0x32fffffe,
  0xb3000001,
  0xbefffffd,
  0xbeffffff,
  0xbf000002,
  0xbf800000,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f800000,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x3fc00000,
  0x3fc00001,
  0x40000000,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f3fffff,
  0x3f3fffff,
  0x3e7fffff,
  0x3e7ffffd,
  0x3e7ffff9,
  0xbe7fffff,
  0xbe800002,
  0xbe800006,
  0xbf400001,
  0xc1140000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f3fffff,
  0x3f3fffff,
  0x3f3fffff,
  0x3f3fffff,
  0x3f3fffff,
  0x3f9fffff,
  0x3fa00000,
  0x3fa00000,
  0x3fdfffff,
  0x3fe00000,
  0x3fe00001,
  0x40100000,
  0x412c0000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f3fffff,
  0x3f3fffff,
  0x3f3fffff,
  0x409fffff,
  0x409fffff,
  0x408fffff,
  0x408fffff,
  0x408fffff,
  0x407fffff,
  0x407fffff,
  0x407ffffe,
  0x405fffff,
  0xc0a00001,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x409fffff,
  0x409fffff,
  0x409fffff,
  0x409fffff,
  0x409fffff,
  0x40afffff,
  0x40afffff,
  0x40b00000,
  0x40bfffff,
  0x40bfffff,
  0x40c00000,
  0x40cfffff,
  0x41700000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x409fffff,
  0x409fffff,
  0x409fffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x00091a2b,
  0x8076e5d5,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80091a2b,
  0x8076e5d4,
  0x00091a2a,
  0x00091a2b,
  0x00891a2b,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x001b4e81,
  0x00891a2a,
  0x00091a2c,
  0x003fffff,
  0x80400001,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x002dcba9,
  0x80400000,
  0x003ffffe,
  0x003fffff,
  0x00bfffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00523455,
  0x00bffffe,
  0x00400000,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80400000,
  0x80c00000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80523456,
  0x80bfffff,
  0x80400001,
  0x80400000,
  0x00400000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x802dcbaa,
  0x003fffff,
  0x803fffff,
  0xbe7fffff,
  0xbe7fffff,
  0xbf3fffff,
  0xbf400000,
  0xbf400001,
  0xbf9fffff,
  0xbfa00000,
  0xbfa00001,
  0xbfe00000,
  0xc1240000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbe7fffff,
  0xbe7fffff,
  0xbe7fffff,
  0xbe7fffff,
  0xbe7fffff,
  0x3e7fffff,
  0x3e800000,
  0x3e800002,
  0x3f3fffff,
  0x3f400000,
  0x3f400002,
  0x3fa00000,
  0x411c0000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbe7fffff,
  0xbe7fffff,
  0xbe7fffff,
  0xbe800000,
  0xbe800000,
  0xbf400000,
  0xbf400000,
  0xbf400001,
  0xbfa00000,
  0xbfa00000,
  0xbfa00001,
  0xbfe00000,
  0xc1240000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbe800000,
  0xbe800000,
  0xbe800000,
  0xbe800000,
  0xbe800000,
  0x3e7ffffe,
  0x3e800000,
  0x3e800002,
  0x3f3fffff,
  0x3f400000,
  0x3f400002,
  0x3fa00000,
  0x411c0000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbe800000,
  0xbe800000,
  0xbe800000,
  0xbe800001,
  0xbe800001,
  0xbf400000,
  0xbf400000,
  0xbf400002,
  0xbfa00000,
  0xbfa00000,
  0xbfa00001,
  0xbfe00000,
  0xc1240000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbe800001,
  0xbe800001,
  0xbe800001,
  0xbe800001,
  0xbe800001,
  0x3e7ffffc,
  0x3e7ffffe,
  0x3e800001,
  0x3f3ffffe,
  0x3f400000,
  0x3f400002,
  0x3fa00000,
  0x411c0000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbe800001,
  0xbe800001,
  0xbe800001,
  0xbeffffff,
  0xbeffffff,
  0xbf7fffff,
  0xbf800000,
  0xbf800000,
  0xbfbfffff,
  0xbfc00000,
  0xbfc00001,
  0xc0000000,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0x00000000,
  0x33000000,
  0x33c00000,
  0x3effffff,
  0x3f000000,
  0x3f000002,
  0x3f800000,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbf000000,
  0xbf000000,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbfc00000,
  0xbfc00000,
  0xbfc00001,
  0xc0000000,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xb3000000,
  0x00000000,
  0x33800000,
  0x3efffffe,
  0x3f000000,
  0x3f000002,
  0x3f800000,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000001,
  0xbf000001,
  0xbf800000,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xbfc00000,
  0xbfc00002,
  0xc0000000,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xb3c00000,
  0xb3800000,
  0x00000000,
  0x3efffffc,
  0x3efffffe,
  0x3f000001,
  0x3f7fffff,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf400000,
  0xbf400000,
  0xbfa00000,
  0xbfa00000,
  0xbfa00000,
  0xbfe00000,
  0xbfe00000,
  0xbfe00001,
  0xc0100000,
  0xc12c0000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf400000,
  0xbf400000,
  0xbf400000,
  0xbf400000,
  0xbf400000,
  0xbe800001,
  0xbe800000,
  0xbe7ffffc,
  0x3e7ffffc,
  0x3e800000,
  0x3e800004,
  0x3f400000,
  0x41140000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf400000,
  0xbf400000,
  0xbf400000,
  0xc0a00000,
  0xc0a00000,
  0xc0b00000,
  0xc0b00000,
  0xc0b00000,
  0xc0c00000,
  0xc0c00000,
  0xc0c00000,
  0xc0d00000,
  0xc1700000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xc0a00000,
  0xc0a00000,
  0xc0a00000,
  0xc0a00000,
  0xc0a00000,
  0xc0900000,
  0xc0900000,
  0xc0900000,
  0xc0800000,
  0xc0800000,
  0xc0800000,
  0xc0600000,
  0x40a00000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xc0a00000,
  0xc0a00000,
  0xc0a00000,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x80091a2b,
  0x80891a2b,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x801b4e81,
  0x80891a2a,
  0x80091a2c,
  0x80091a2b,
  0x0076e5d5,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00091a2b,
  0x0076e5d4,
  0x80091a2a,
  0x80400000,
  0x80c00000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80523456,
  0x80bffffe,
  0x80400000,
  0x80400000,
  0x00400000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x802dcbaa,
  0x00400000,
  0x803ffffe,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x80800000,
  0x80000002,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007ffffe,
  0x00000000,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00400000,
  0x80400000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x002dcbaa,
  0x803fffff,
  0x003fffff,
  0x00400000,
  0x00c00000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00523456,
  0x00bfffff,
  0x00400001,
  0x3e7fffff,
  0x3e7fffff,
  0xbe7fffff,
  0xbe800000,
  0xbe800002,
  0xbf3fffff,
  0xbf400000,
  0xbf400002,
  0xbfa00000,
  0xc11c0000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3e7fffff,
  0x3e7fffff,
  0x3e7fffff,
  0x3e7fffff,
  0x3e7fffff,
  0x3f3fffff,
  0x3f400000,
  0x3f400001,
  0x3f9fffff,
  0x3fa00000,
  0x3fa00001,
  0x3fe00000,
  0x41240000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3e7fffff,
  0x3e7fffff,
  0x3e7fffff,
  0x3e800000,
  0x3e800000,
  0xbe7ffffe,
  0xbe800000,
  0xbe800002,
  0xbf3fffff,
  0xbf400000,
  0xbf400002,
  0xbfa00000,
  0xc11c0000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3e800000,
  0x3e800000,
  0x3e800000,
  0x3e800000,
  0x3e800000,
  0x3f400000,
  0x3f400000,
  0x3f400001,
  0x3fa00000,
  0x3fa00000,
  0x3fa00001,
  0x3fe00000,
  0x41240000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3e800000,
  0x3e800000,
  0x3e800000,
  0x3e800001,
  0x3e800001,
  0xbe7ffffc,
  0xbe7ffffe,
  0xbe800001,
  0xbf3ffffe,
  0xbf400000,
  0xbf400002,
  0xbfa00000,
  0xc11c0000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3e800001,
  0x3e800001,
  0x3e800001,
  0x3e800001,
  0x3e800001,
  0x3f400000,
  0x3f400000,
  0x3f400002,
  0x3fa00000,
  0x3fa00000,
  0x3fa00001,
  0x3fe00000,
  0x41240000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3e800001,
  0x3e800001,
  0x3e800001,
  0x3effffff,
  0x3effffff,
  0x00000000,
  0xb3000000,
  0xb3c00000,
  0xbeffffff,
  0xbf000000,
  0xbf000002,
  0xbf800000,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3f7fffff,
  0x3f800000,
  0x3f800000,
  0x3fbfffff,
  0x3fc00000,
  0x3fc00001,
  0x40000000,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3f000000,
  0x3f000000,
  0x33000000,
  0x00000000,
  0xb3800000,
  0xbefffffe,
  0xbf000000,
  0xbf000002,
  0xbf800000,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3fc00000,
  0x3fc00000,
  0x3fc00001,
  0x40000000,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000001,
  0x3f000001,
  0x33c00000,
  0x33800000,
  0x00000000,
  0xbefffffc,
  0xbefffffe,
  0xbf000001,
  0xbf7fffff,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f800000,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x3fc00000,
  0x3fc00002,
  0x40000000,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f400000,
  0x3f400000,
  0x3e800001,
  0x3e800000,
  0x3e7ffffc,
  0xbe7ffffc,
  0xbe800000,
  0xbe800004,
  0xbf400000,
  0xc1140000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f400000,
  0x3f400000,
  0x3f400000,
  0x3f400000,
  0x3f400000,
  0x3fa00000,
  0x3fa00000,
  0x3fa00000,
  0x3fe00000,
  0x3fe00000,
  0x3fe00001,
  0x40100000,
  0x412c0000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f400000,
  0x3f400000,
  0x3f400000,
  0x40a00000,
  0x40a00000,
  0x40900000,
  0x40900000,
  0x40900000,
  0x40800000,
  0x40800000,
  0x40800000,
  0x40600000,
  0xc0a00000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x40a00000,
  0x40a00000,
  0x40a00000,
  0x40a00000,
  0x40a00000,
  0x40b00000,
  0x40b00000,
  0x40b00000,
  0x40c00000,
  0x40c00000,
  0x40c00000,
  0x40d00000,
  0x41700000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x40a00000,
  0x40a00000,
  0x40a00000,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x00091a2b,
  0x8076e5d5,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80091a2b,
  0x8076e5d4,
  0x00091a2a,
  0x00091a2b,
  0x00891a2b,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x001b4e81,
  0x00891a2a,
  0x00091a2c,
  0x00400000,
  0x80400000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x002dcbaa,
  0x80400000,
  0x003ffffe,
  0x00400000,
  0x00c00000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00523456,
  0x00bffffe,
  0x00400000,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807ffffe,
  0x80000000,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x00800000,
  0x00000002,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80400000,
  0x80c00000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80523456,
  0x80c00000,
  0x80400002,
  0x80400000,
  0x00400000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x802dcbaa,
  0x003ffffe,
  0x80400000,
  0xbe800000,
  0xbe800000,
  0xbf400000,
  0xbf400000,
  0xbf400001,
  0xbfa00000,
  0xbfa00000,
  0xbfa00001,
  0xbfe00000,
  0xc1240000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbe800000,
  0xbe800000,
  0xbe800000,
  0xbe800000,
  0xbe800000,
  0x3e7ffffd,
  0x3e7fffff,
  0x3e800002,
  0x3f3fffff,
  0x3f400000,
  0x3f400002,
  0x3fa00000,
  0x411c0000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbe800000,
  0xbe800000,
  0xbe800000,
  0xbe800001,
  0xbe800001,
  0xbf400000,
  0xbf400000,
  0xbf400002,
  0xbfa00000,
  0xbfa00000,
  0xbfa00001,
  0xbfe00000,
  0xc1240000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbe800001,
  0xbe800001,
  0xbe800001,
  0xbe800001,
  0xbe800001,
  0x3e7ffffc,
  0x3e7ffffe,
  0x3e800001,
  0x3f3ffffe,
  0x3f400000,
  0x3f400002,
  0x3fa00000,
  0x411c0000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbe800001,
  0xbe800001,
  0xbe800001,
  0xbe800002,
  0xbe800002,
  0xbf400001,
  0xbf400001,
  0xbf400002,
  0xbfa00000,
  0xbfa00001,
  0xbfa00002,
  0xbfe00001,
  0xc1240000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbe800002,
  0xbe800002,
  0xbe800002,
  0xbe800002,
  0xbe800002,
  0x3e7ffffa,
  0x3e7ffffc,
  0x3e800000,
  0x3f3ffffe,
  0x3f3fffff,
  0x3f400001,
  0x3f9fffff,
  0x411c0000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbe800002,
  0xbe800002,
  0xbe800002,
  0xbf000000,
  0xbf000000,
  0xbf800000,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xbfc00000,
  0xbfc00001,
  0xc0000000,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xb37fffff,
  0xb2fffffe,
  0x33000001,
  0x3efffffd,
  0x3effffff,
  0x3f000002,
  0x3f800000,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000001,
  0xbf000001,
  0xbf800000,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xbfc00000,
  0xbfc00002,
  0xc0000000,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xb3c00000,
  0xb3800000,
  0x00000000,
  0x3efffffc,
  0x3efffffe,
  0x3f000001,
  0x3f7fffff,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf000002,
  0xbf000002,
  0xbf800001,
  0xbf800001,
  0xbf800002,
  0xbfc00001,
  0xbfc00001,
  0xbfc00002,
  0xc0000001,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf000002,
  0xbf000002,
  0xbf000002,
  0xbf000002,
  0xbf000002,
  0xb4200000,
  0xb4000000,
  0xb3800001,
  0x3efffffa,
  0x3efffffc,
  0x3f000000,
  0x3f7ffffe,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf000002,
  0xbf000002,
  0xbf000002,
  0xbf400002,
  0xbf400002,
  0xbfa00000,
  0xbfa00001,
  0xbfa00001,
  0xbfe00000,
  0xbfe00001,
  0xbfe00002,
  0xc0100000,
  0xc12c0000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf400002,
  0xbf400002,
  0xbf400002,
  0xbf400002,
  0xbf400001,
  0xbe800004,
  0xbe800003,
  0xbe800001,
  0x3e7ffff6,
  0x3e7ffffa,
  0x3e800001,
  0x3f3ffffe,
  0x41140000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf400001,
  0xbf400001,
  0xbf400001,
  0xc0a00001,
  0xc0a00001,
  0xc0b00001,
  0xc0b00001,
  0xc0b00001,
  0xc0c00001,
  0xc0c00001,
  0xc0c00002,
  0xc0d00001,
  0xc1700001,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xc0a00001,
  0xc0a00001,
  0xc0a00001,
  0xc0a00001,
  0xc0a00001,
  0xc0900001,
  0xc0900001,
  0xc0900001,
  0xc0800001,
  0xc0800001,
  0xc0800001,
  0xc0600002,
  0x409fffff,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xc0a00001,
  0xc0a00001,
  0xc0a00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x80091a2b,
  0x80891a2b,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x801b4e81,
  0x80891a2a,
  0x80091a2c,
  0x80091a2b,
  0x0076e5d5,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00091a2b,
  0x0076e5d4,
  0x80091a2a,
  0x80400000,
  0x80c00000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80523456,
  0x80bfffff,
  0x80400001,
  0x80400000,
  0x00400000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x802dcbaa,
  0x003fffff,
  0x803fffff,
  0x80000001,
  0x80800001,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123457,
  0x80800000,
  0x80000002,
  0x80000001,
  0x007fffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123455,
  0x007ffffe,
  0x00000000,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00400000,
  0x80400000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x002dcbaa,
  0x803ffffe,
  0x00400000,
  0x00400000,
  0x00c00000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00523456,
  0x00c00000,
  0x00400002,
  0x3e800000,
  0x3e800000,
  0xbe7ffffd,
  0xbe7fffff,
  0xbe800002,
  0xbf3fffff,
  0xbf400000,
  0xbf400002,
  0xbfa00000,
  0xc11c0000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3e800000,
  0x3e800000,
  0x3e800000,
  0x3e800000,
  0x3e800000,
  0x3f400000,
  0x3f400000,
  0x3f400001,
  0x3fa00000,
  0x3fa00000,
  0x3fa00001,
  0x3fe00000,
  0x41240000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3e800000,
  0x3e800000,
  0x3e800000,
  0x3e800001,
  0x3e800001,
  0xbe7ffffc,
  0xbe7ffffe,
  0xbe800001,
  0xbf3ffffe,
  0xbf400000,
  0xbf400002,
  0xbfa00000,
  0xc11c0000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3e800001,
  0x3e800001,
  0x3e800001,
  0x3e800001,
  0x3e800001,
  0x3f400000,
  0x3f400000,
  0x3f400002,
  0x3fa00000,
  0x3fa00000,
  0x3fa00001,
  0x3fe00000,
  0x41240000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3e800001,
  0x3e800001,
  0x3e800001,
  0x3e800002,
  0x3e800002,
  0xbe7ffffa,
  0xbe7ffffc,
  0xbe800000,
  0xbf3ffffe,
  0xbf3fffff,
  0xbf400001,
  0xbf9fffff,
  0xc11c0000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3e800002,
  0x3e800002,
  0x3e800002,
  0x3e800002,
  0x3e800002,
  0x3f400001,
  0x3f400001,
  0x3f400002,
  0x3fa00000,
  0x3fa00001,
  0x3fa00002,
  0x3fe00001,
  0x41240000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3e800002,
  0x3e800002,
  0x3e800002,
  0x3f000000,
  0x3f000000,
  0x337fffff,
  0x32fffffe,
  0xb3000001,
  0xbefffffd,
  0xbeffffff,
  0xbf000002,
  0xbf800000,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f800000,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x3fc00000,
  0x3fc00001,
  0x40000000,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000001,
  0x3f000001,
  0x33c00000,
  0x33800000,
  0x00000000,
  0xbefffffc,
  0xbefffffe,
  0xbf000001,
  0xbf7fffff,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f800000,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x3fc00000,
  0x3fc00002,
  0x40000000,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f000002,
  0x3f000002,
  0x34200000,
  0x34000000,
  0x33800001,
  0xbefffffa,
  0xbefffffc,
  0xbf000000,
  0xbf7ffffe,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f000002,
  0x3f000002,
  0x3f000002,
  0x3f000002,
  0x3f000002,
  0x3f800001,
  0x3f800001,
  0x3f800002,
  0x3fc00001,
  0x3fc00001,
  0x3fc00002,
  0x40000001,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f000002,
  0x3f000002,
  0x3f000002,
  0x3f400002,
  0x3f400001,
  0x3e800004,
  0x3e800003,
  0x3e800001,
  0xbe7ffff6,
  0xbe7ffffa,
  0xbe800001,
  0xbf3ffffe,
  0xc1140000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f400001,
  0x3f400001,
  0x3f400001,
  0x3f400002,
  0x3f400002,
  0x3fa00000,
  0x3fa00001,
  0x3fa00001,
  0x3fe00000,
  0x3fe00001,
  0x3fe00002,
  0x40100000,
  0x412c0000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f400002,
  0x3f400002,
  0x3f400002,
  0x40a00001,
  0x40a00001,
  0x40900001,
  0x40900001,
  0x40900001,
  0x40800001,
  0x40800001,
  0x40800001,
  0x40600002,
  0xc09fffff,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x40a00001,
  0x40a00001,
  0x40a00001,
  0x40a00001,
  0x40a00001,
  0x40b00001,
  0x40b00001,
  0x40b00001,
  0x40c00001,
  0x40c00001,
  0x40c00002,
  0x40d00001,
  0x41700001,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x40a00001,
  0x40a00001,
  0x40a00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x00091a2b,
  0x8076e5d5,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80091a2b,
  0x8076e5d4,
  0x00091a2a,
  0x00091a2b,
  0x00891a2b,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x001b4e81,
  0x00891a2a,
  0x00091a2c,
  0x00400000,
  0x80400000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x002dcbaa,
  0x803fffff,
  0x003fffff,
  0x00400000,
  0x00c00000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00523456,
  0x00bfffff,
  0x00400001,
  0x00000001,
  0x807fffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123455,
  0x807ffffe,
  0x80000000,
  0x00000001,
  0x00800001,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123457,
  0x00800000,
  0x00000002,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80800000,
  0x81000000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80923456,
  0x80fffffe,
  0x80800000,
  0x80800000,
  0x00000000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x806dcbaa,
  0x80000000,
  0x807ffffe,
  0xbefffffe,
  0xbefffffe,
  0xbf7fffff,
  0xbf7fffff,
  0xbf800000,
  0xbfbfffff,
  0xbfc00000,
  0xbfc00001,
  0xc0000000,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbefffffe,
  0xbefffffe,
  0xbefffffe,
  0xbefffffe,
  0xbefffffe,
  0x32ffffff,
  0x33800000,
  0x34000000,
  0x3f000000,
  0x3f000001,
  0x3f000003,
  0x3f800000,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbefffffe,
  0xbefffffe,
  0xbefffffe,
  0xbeffffff,
  0xbeffffff,
  0xbf7fffff,
  0xbf800000,
  0xbf800000,
  0xbfbfffff,
  0xbfc00000,
  0xbfc00001,
  0xc0000000,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0x00000000,
  0x33000000,
  0x33c00000,
  0x3effffff,
  0x3f000000,
  0x3f000002,
  0x3f800000,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbf000000,
  0xbf000000,
  0xbf800000,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xbfc00000,
  0xbfc00001,
  0xc0000000,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xb37fffff,
  0xb2fffffe,
  0x33000001,
  0x3efffffd,
  0x3effffff,
  0x3f000002,
  0x3f800000,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf7ffffe,
  0xbf7ffffe,
  0xbfbfffff,
  0xbfbfffff,
  0xbfc00000,
  0xbfffffff,
  0xbfffffff,
  0xc0000000,
  0xc0200000,
  0xc1300000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf7ffffe,
  0xbf7ffffe,
  0xbf7ffffe,
  0xbf7ffffe,
  0xbf7ffffe,
  0xbefffffd,
  0xbefffffc,
  0xbefffffa,
  0x337fffff,
  0x34000000,
  0x34800000,
  0x3f000002,
  0x41100000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf7ffffe,
  0xbf7ffffe,
  0xbf7ffffe,
  0xbf7fffff,
  0xbf7fffff,
  0xbfbfffff,
  0xbfc00000,
  0xbfc00000,
  0xbfffffff,
  0xc0000000,
  0xc0000000,
  0xc0200000,
  0xc1300000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf7fffff,
  0xbf7fffff,
  0xbf7fffff,
  0xbf7fffff,
  0xbf7fffff,
  0xbeffffff,
  0xbefffffe,
  0xbefffffc,
  0x00000000,
  0x33800000,
  0x34400000,
  0x3f000001,
  0x41100000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf7fffff,
  0xbf7fffff,
  0xbf7fffff,
  0xbf800000,
  0xbf800000,
  0xbfc00000,
  0xbfc00000,
  0xbfc00001,
  0xc0000000,
  0xc0000000,
  0xc0000001,
  0xc0200000,
  0xc1300000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbf000001,
  0xbf000001,
  0xbf000000,
  0xb3ffffff,
  0xb37ffffe,
  0x33800001,
  0x3efffffe,
  0x41100000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbfbfffff,
  0xbfbfffff,
  0xbfffffff,
  0xbfffffff,
  0xc0000000,
  0xc01fffff,
  0xc0200000,
  0xc0200000,
  0xc0400000,
  0xc1380000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbfbfffff,
  0xbfbfffff,
  0xbfbfffff,
  0xbfbfffff,
  0xbfbfffff,
  0xbf7fffff,
  0xbf7ffffe,
  0xbf7ffffe,
  0xbeffffff,
  0xbefffffd,
  0xbefffff9,
  0x33c00000,
  0x41080000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbfbfffff,
  0xbfbfffff,
  0xbfbfffff,
  0xc11fffff,
  0xc11fffff,
  0xc127ffff,
  0xc127ffff,
  0xc127ffff,
  0xc12fffff,
  0xc12fffff,
  0xc1300000,
  0xc137ffff,
  0xc1a00000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xc11fffff,
  0xc11fffff,
  0xc11fffff,
  0xc11fffff,
  0xc11fffff,
  0xc117ffff,
  0xc117ffff,
  0xc117ffff,
  0xc10fffff,
  0xc10fffff,
  0xc10fffff,
  0xc107ffff,
  0x35200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xc11fffff,
  0xc11fffff,
  0xc11fffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x80123456,
  0x80923456,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x802468ac,
  0x80923455,
  0x80123457,
  0x80123456,
  0x006dcbaa,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00000000,
  0x006dcba9,
  0x80123455,
  0x807fffff,
  0x80ffffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80923455,
  0x80fffffe,
  0x80800000,
  0x807fffff,
  0x00000001,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x806dcba9,
  0x00000000,
  0x807ffffe,
  0x80000001,
  0x80800001,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123457,
  0x80800000,
  0x80000002,
  0x80000001,
  0x007fffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123455,
  0x007ffffe,
  0x00000000,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00800000,
  0x80000000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x006dcbaa,
  0x00000000,
  0x007ffffe,
  0x00800000,
  0x01000000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00923456,
  0x00fffffe,
  0x00800000,
  0x3efffffe,
  0x3efffffe,
  0xb2ffffff,
  0xb3800000,
  0xb4000000,
  0xbf000000,
  0xbf000001,
  0xbf000003,
  0xbf800000,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3efffffe,
  0x3efffffe,
  0x3efffffe,
  0x3efffffe,
  0x3efffffe,
  0x3f7fffff,
  0x3f7fffff,
  0x3f800000,
  0x3fbfffff,
  0x3fc00000,
  0x3fc00001,
  0x40000000,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3efffffe,
  0x3efffffe,
  0x3efffffe,
  0x3effffff,
  0x3effffff,
  0x00000000,
  0xb3000000,
  0xb3c00000,
  0xbeffffff,
  0xbf000000,
  0xbf000002,
  0xbf800000,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3f7fffff,
  0x3f800000,
  0x3f800000,
  0x3fbfffff,
  0x3fc00000,
  0x3fc00001,
  0x40000000,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3f000000,
  0x3f000000,
  0x337fffff,
  0x32fffffe,
  0xb3000001,
  0xbefffffd,
  0xbeffffff,
  0xbf000002,
  0xbf800000,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f800000,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x3fc00000,
  0x3fc00001,
  0x40000000,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f7ffffe,
  0x3f7ffffe,
  0x3efffffd,
  0x3efffffc,
  0x3efffffa,
  0xb37fffff,
  0xb4000000,
  0xb4800000,
  0xbf000002,
  0xc1100000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f7ffffe,
  0x3f7ffffe,
  0x3f7ffffe,
  0x3f7ffffe,
  0x3f7ffffe,
  0x3fbfffff,
  0x3fbfffff,
  0x3fc00000,
  0x3fffffff,
  0x3fffffff,
  0x40000000,
  0x40200000,
  0x41300000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f7ffffe,
  0x3f7ffffe,
  0x3f7ffffe,
  0x3f7fffff,
  0x3f7fffff,
  0x3effffff,
  0x3efffffe,
  0x3efffffc,
  0x00000000,
  0xb3800000,
  0xb4400000,
  0xbf000001,
  0xc1100000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f7fffff,
  0x3f7fffff,
  0x3f7fffff,
  0x3f7fffff,
  0x3f7fffff,
  0x3fbfffff,
  0x3fc00000,
  0x3fc00000,
  0x3fffffff,
  0x40000000,
  0x40000000,
  0x40200000,
  0x41300000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f7fffff,
  0x3f7fffff,
  0x3f7fffff,
  0x3f800000,
  0x3f800000,
  0x3f000001,
  0x3f000001,
  0x3f000000,
  0x33ffffff,
  0x337ffffe,
  0xb3800001,
  0xbefffffe,
  0xc1100000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3fc00000,
  0x3fc00000,
  0x3fc00001,
  0x40000000,
  0x40000000,
  0x40000001,
  0x40200000,
  0x41300000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3fbfffff,
  0x3fbfffff,
  0x3f7fffff,
  0x3f7ffffe,
  0x3f7ffffe,
  0x3effffff,
  0x3efffffd,
  0x3efffff9,
  0xb3c00000,
  0xc1080000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3fbfffff,
  0x3fbfffff,
  0x3fbfffff,
  0x3fbfffff,
  0x3fbfffff,
  0x3fffffff,
  0x3fffffff,
  0x40000000,
  0x401fffff,
  0x40200000,
  0x40200000,
  0x40400000,
  0x41380000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3fbfffff,
  0x3fbfffff,
  0x3fbfffff,
  0x411fffff,
  0x411fffff,
  0x4117ffff,
  0x4117ffff,
  0x4117ffff,
  0x410fffff,
  0x410fffff,
  0x410fffff,
  0x4107ffff,
  0xb5200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x411fffff,
  0x411fffff,
  0x411fffff,
  0x411fffff,
  0x411fffff,
  0x4127ffff,
  0x4127ffff,
  0x4127ffff,
  0x412fffff,
  0x412fffff,
  0x41300000,
  0x4137ffff,
  0x41a00000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x411fffff,
  0x411fffff,
  0x411fffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x00123456,
  0x806dcbaa,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80000000,
  0x806dcba9,
  0x00123455,
  0x00123456,
  0x00923456,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x002468ac,
  0x00923455,
  0x00123457,
  0x007fffff,
  0x80000001,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x006dcba9,
  0x80000000,
  0x007ffffe,
  0x007fffff,
  0x00ffffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00923455,
  0x00fffffe,
  0x00800000,
  0x00000001,
  0x807fffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123455,
  0x807ffffe,
  0x80000000,
  0x00000001,
  0x00800001,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123457,
  0x00800000,
  0x00000002,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80800000,
  0x81000000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80923456,
  0x80ffffff,
  0x80800001,
  0x80800000,
  0x00000000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x806dcbaa,
  0x80000001,
  0x807fffff,
  0xbeffffff,
  0xbeffffff,
  0xbf7fffff,
  0xbf800000,
  0xbf800000,
  0xbfbfffff,
  0xbfc00000,
  0xbfc00001,
  0xc0000000,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0x00000000,
  0x33000000,
  0x33c00000,
  0x3effffff,
  0x3f000000,
  0x3f000002,
  0x3f800000,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbf000000,
  0xbf000000,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbfc00000,
  0xbfc00000,
  0xbfc00001,
  0xc0000000,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xb3000000,
  0x00000000,
  0x33800000,
  0x3efffffe,
  0x3f000000,
  0x3f000002,
  0x3f800000,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000001,
  0xbf000001,
  0xbf800000,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xbfc00000,
  0xbfc00002,
  0xc0000000,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xb3c00000,
  0xb3800000,
  0x00000000,
  0x3efffffc,
  0x3efffffe,
  0x3f000001,
  0x3f7fffff,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf7fffff,
  0xbf7fffff,
  0xbfbfffff,
  0xbfc00000,
  0xbfc00000,
  0xbfffffff,
  0xc0000000,
  0xc0000000,
  0xc0200000,
  0xc1300000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf7fffff,
  0xbf7fffff,
  0xbf7fffff,
  0xbf7fffff,
  0xbf7fffff,
  0xbeffffff,
  0xbefffffe,
  0xbefffffc,
  0x00000000,
  0x33800000,
  0x34400000,
  0x3f000001,
  0x41100000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf7fffff,
  0xbf7fffff,
  0xbf7fffff,
  0xbf800000,
  0xbf800000,
  0xbfc00000,
  0xbfc00000,
  0xbfc00000,
  0xc0000000,
  0xc0000000,
  0xc0000000,
  0xc0200000,
  0xc1300000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbf000000,
  0xbf000000,
  0xbefffffe,
  0xb3800000,
  0x00000000,
  0x34000000,
  0x3f000000,
  0x41100000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbf800001,
  0xbf800001,
  0xbfc00001,
  0xbfc00001,
  0xbfc00002,
  0xc0000000,
  0xc0000000,
  0xc0000001,
  0xc0200000,
  0xc1300000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf800001,
  0xbf800001,
  0xbf800001,
  0xbf800001,
  0xbf800001,
  0xbf000002,
  0xbf000002,
  0xbf000001,
  0xb4400000,
  0xb4000000,
  0x00000000,
  0x3efffffc,
  0x41100000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf800001,
  0xbf800001,
  0xbf800001,
  0xbfc00000,
  0xbfc00000,
  0xc0000000,
  0xc0000000,
  0xc0000000,
  0xc0200000,
  0xc0200000,
  0xc0200000,
  0xc0400000,
  0xc1380000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbfc00000,
  0xbfc00000,
  0xbfc00000,
  0xbfc00000,
  0xbfc00000,
  0xbf800000,
  0xbf800000,
  0xbf7fffff,
  0xbf000001,
  0xbf000000,
  0xbefffffc,
  0x00000000,
  0x41080000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbfc00000,
  0xbfc00000,
  0xbfc00000,
  0xc1200000,
  0xc1200000,
  0xc1280000,
  0xc1280000,
  0xc1280000,
  0xc1300000,
  0xc1300000,
  0xc1300000,
  0xc1380000,
  0xc1a00000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xc1200000,
  0xc1200000,
  0xc1200000,
  0xc1200000,
  0xc1200000,
  0xc1180000,
  0xc1180000,
  0xc1180000,
  0xc1100000,
  0xc1100000,
  0xc1100000,
  0xc1080000,
  0x00000000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xc1200000,
  0xc1200000,
  0xc1200000,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x80123456,
  0x80923456,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x802468ac,
  0x80923455,
  0x80123457,
  0x80123456,
  0x006dcbaa,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00000000,
  0x006dcba9,
  0x80123455,
  0x807fffff,
  0x80ffffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80923455,
  0x80fffffe,
  0x80800000,
  0x807fffff,
  0x00000001,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x806dcba9,
  0x00000000,
  0x807ffffe,
  0x80000001,
  0x80800001,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123457,
  0x80800000,
  0x80000002,
  0x80000001,
  0x007fffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123455,
  0x007ffffe,
  0x00000000,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00800000,
  0x00000000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x006dcbaa,
  0x00000001,
  0x007fffff,
  0x00800000,
  0x01000000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00923456,
  0x00ffffff,
  0x00800001,
  0x3effffff,
  0x3effffff,
  0x00000000,
  0xb3000000,
  0xb3c00000,
  0xbeffffff,
  0xbf000000,
  0xbf000002,
  0xbf800000,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3f7fffff,
  0x3f800000,
  0x3f800000,
  0x3fbfffff,
  0x3fc00000,
  0x3fc00001,
  0x40000000,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3f000000,
  0x3f000000,
  0x33000000,
  0x00000000,
  0xb3800000,
  0xbefffffe,
  0xbf000000,
  0xbf000002,
  0xbf800000,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3fc00000,
  0x3fc00000,
  0x3fc00001,
  0x40000000,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000001,
  0x3f000001,
  0x33c00000,
  0x33800000,
  0x00000000,
  0xbefffffc,
  0xbefffffe,
  0xbf000001,
  0xbf7fffff,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f800000,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x3fc00000,
  0x3fc00002,
  0x40000000,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f7fffff,
  0x3f7fffff,
  0x3effffff,
  0x3efffffe,
  0x3efffffc,
  0x00000000,
  0xb3800000,
  0xb4400000,
  0xbf000001,
  0xc1100000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f7fffff,
  0x3f7fffff,
  0x3f7fffff,
  0x3f7fffff,
  0x3f7fffff,
  0x3fbfffff,
  0x3fc00000,
  0x3fc00000,
  0x3fffffff,
  0x40000000,
  0x40000000,
  0x40200000,
  0x41300000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f7fffff,
  0x3f7fffff,
  0x3f7fffff,
  0x3f800000,
  0x3f800000,
  0x3f000000,
  0x3f000000,
  0x3efffffe,
  0x33800000,
  0x00000000,
  0xb4000000,
  0xbf000000,
  0xc1100000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3fc00000,
  0x3fc00000,
  0x3fc00000,
  0x40000000,
  0x40000000,
  0x40000000,
  0x40200000,
  0x41300000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3f800001,
  0x3f800001,
  0x3f000002,
  0x3f000002,
  0x3f000001,
  0x34400000,
  0x34000000,
  0x00000000,
  0xbefffffc,
  0xc1100000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f800001,
  0x3f800001,
  0x3f800001,
  0x3f800001,
  0x3f800001,
  0x3fc00001,
  0x3fc00001,
  0x3fc00002,
  0x40000000,
  0x40000000,
  0x40000001,
  0x40200000,
  0x41300000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f800001,
  0x3f800001,
  0x3f800001,
  0x3fc00000,
  0x3fc00000,
  0x3f800000,
  0x3f800000,
  0x3f7fffff,
  0x3f000001,
  0x3f000000,
  0x3efffffc,
  0x00000000,
  0xc1080000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3fc00000,
  0x3fc00000,
  0x3fc00000,
  0x3fc00000,
  0x3fc00000,
  0x40000000,
  0x40000000,
  0x40000000,
  0x40200000,
  0x40200000,
  0x40200000,
  0x40400000,
  0x41380000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3fc00000,
  0x3fc00000,
  0x3fc00000,
  0x41200000,
  0x41200000,
  0x41180000,
  0x41180000,
  0x41180000,
  0x41100000,
  0x41100000,
  0x41100000,
  0x41080000,
  0x00000000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x41200000,
  0x41200000,
  0x41200000,
  0x41200000,
  0x41200000,
  0x41280000,
  0x41280000,
  0x41280000,
  0x41300000,
  0x41300000,
  0x41300000,
  0x41380000,
  0x41a00000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x41200000,
  0x41200000,
  0x41200000,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x00123456,
  0x806dcbaa,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x00000000,
  0x806dcba9,
  0x00123455,
  0x00123456,
  0x00923456,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x002468ac,
  0x00923455,
  0x00123457,
  0x007fffff,
  0x80000001,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x006dcba9,
  0x00000000,
  0x007ffffe,
  0x007fffff,
  0x00ffffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00923455,
  0x00fffffe,
  0x00800000,
  0x00000001,
  0x807fffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123455,
  0x807ffffe,
  0x00000000,
  0x00000001,
  0x00800001,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123457,
  0x00800000,
  0x00000002,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80800001,
  0x81000000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80923457,
  0x81000000,
  0x80800002,
  0x80800001,
  0x80000001,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x806dcbab,
  0x80000002,
  0x80800000,
  0xbf000000,
  0xbf000000,
  0xbf800000,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xbfc00000,
  0xbfc00001,
  0xc0000000,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xb37fffff,
  0xb2fffffe,
  0x33000001,
  0x3efffffd,
  0x3effffff,
  0x3f000002,
  0x3f800000,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000001,
  0xbf000001,
  0xbf800000,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xbfc00000,
  0xbfc00002,
  0xc0000000,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xb3c00000,
  0xb3800000,
  0x00000000,
  0x3efffffc,
  0x3efffffe,
  0x3f000001,
  0x3f7fffff,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf000002,
  0xbf000002,
  0xbf800001,
  0xbf800001,
  0xbf800002,
  0xbfc00001,
  0xbfc00001,
  0xbfc00002,
  0xc0000001,
  0xc1280000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf000002,
  0xbf000002,
  0xbf000002,
  0xbf000002,
  0xbf000002,
  0xb4200000,
  0xb4000000,
  0xb3800001,
  0x3efffffa,
  0x3efffffc,
  0x3f000000,
  0x3f7ffffe,
  0x41180000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf000002,
  0xbf000002,
  0xbf000002,
  0xbf800000,
  0xbf800000,
  0xbfc00000,
  0xbfc00000,
  0xbfc00001,
  0xc0000000,
  0xc0000000,
  0xc0000001,
  0xc0200000,
  0xc1300000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbf000001,
  0xbf000001,
  0xbf000000,
  0xb3ffffff,
  0xb37ffffe,
  0x33800001,
  0x3efffffe,
  0x41100000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbf800001,
  0xbf800001,
  0xbfc00001,
  0xbfc00001,
  0xbfc00002,
  0xc0000000,
  0xc0000000,
  0xc0000001,
  0xc0200000,
  0xc1300000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf800001,
  0xbf800001,
  0xbf800001,
  0xbf800001,
  0xbf800001,
  0xbf000002,
  0xbf000002,
  0xbf000001,
  0xb4400000,
  0xb4000000,
  0x00000000,
  0x3efffffc,
  0x41100000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf800001,
  0xbf800001,
  0xbf800001,
  0xbf800002,
  0xbf800002,
  0xbfc00002,
  0xbfc00002,
  0xbfc00003,
  0xc0000001,
  0xc0000001,
  0xc0000002,
  0xc0200001,
  0xc1300000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf800002,
  0xbf800002,
  0xbf800002,
  0xbf800002,
  0xbf800002,
  0xbf000005,
  0xbf000004,
  0xbf000003,
  0xb4a00000,
  0xb4800000,
  0xb4000001,
  0x3efffff8,
  0x41100000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf800002,
  0xbf800002,
  0xbf800002,
  0xbfc00002,
  0xbfc00002,
  0xc0000001,
  0xc0000001,
  0xc0000001,
  0xc0200000,
  0xc0200001,
  0xc0200001,
  0xc0400001,
  0xc1380000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbfc00002,
  0xbfc00002,
  0xbfc00002,
  0xbfc00002,
  0xbfc00001,
  0xbf800002,
  0xbf800002,
  0xbf800001,
  0xbf000004,
  0xbf000003,
  0xbf000001,
  0xb4400000,
  0x41080000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbfc00001,
  0xbfc00001,
  0xbfc00001,
  0xc1200001,
  0xc1200001,
  0xc1280001,
  0xc1280001,
  0xc1280001,
  0xc1300001,
  0xc1300001,
  0xc1300001,
  0xc1380001,
  0xc1a00001,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xc1200001,
  0xc1200001,
  0xc1200001,
  0xc1200001,
  0xc1200001,
  0xc1180001,
  0xc1180001,
  0xc1180001,
  0xc1100001,
  0xc1100001,
  0xc1100001,
  0xc1080001,
  0xb5a00000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xc1200001,
  0xc1200001,
  0xc1200001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x80123456,
  0x80923456,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x802468ac,
  0x80923455,
  0x80123457,
  0x80123456,
  0x006dcbaa,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x80000000,
  0x006dcba9,
  0x80123455,
  0x80800000,
  0x81000000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80923456,
  0x80ffffff,
  0x80800001,
  0x80800000,
  0x00000000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x806dcbaa,
  0x80000001,
  0x807fffff,
  0x80000001,
  0x80800001,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123457,
  0x80800000,
  0x80000002,
  0x80000001,
  0x007fffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123455,
  0x007ffffe,
  0x80000000,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00800001,
  0x00000001,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x006dcbab,
  0x00000002,
  0x00800000,
  0x00800001,
  0x01000000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00923457,
  0x01000000,
  0x00800002,
  0x3f000000,
  0x3f000000,
  0x337fffff,
  0x32fffffe,
  0xb3000001,
  0xbefffffd,
  0xbeffffff,
  0xbf000002,
  0xbf800000,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f800000,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x3fc00000,
  0x3fc00001,
  0x40000000,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000001,
  0x3f000001,
  0x33c00000,
  0x33800000,
  0x00000000,
  0xbefffffc,
  0xbefffffe,
  0xbf000001,
  0xbf7fffff,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f800000,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x3fc00000,
  0x3fc00002,
  0x40000000,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f000002,
  0x3f000002,
  0x34200000,
  0x34000000,
  0x33800001,
  0xbefffffa,
  0xbefffffc,
  0xbf000000,
  0xbf7ffffe,
  0xc1180000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f000002,
  0x3f000002,
  0x3f000002,
  0x3f000002,
  0x3f000002,
  0x3f800001,
  0x3f800001,
  0x3f800002,
  0x3fc00001,
  0x3fc00001,
  0x3fc00002,
  0x40000001,
  0x41280000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f000002,
  0x3f000002,
  0x3f000002,
  0x3f800000,
  0x3f800000,
  0x3f000001,
  0x3f000001,
  0x3f000000,
  0x33ffffff,
  0x337ffffe,
  0xb3800001,
  0xbefffffe,
  0xc1100000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3fc00000,
  0x3fc00000,
  0x3fc00001,
  0x40000000,
  0x40000000,
  0x40000001,
  0x40200000,
  0x41300000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3f800001,
  0x3f800001,
  0x3f000002,
  0x3f000002,
  0x3f000001,
  0x34400000,
  0x34000000,
  0x00000000,
  0xbefffffc,
  0xc1100000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f800001,
  0x3f800001,
  0x3f800001,
  0x3f800001,
  0x3f800001,
  0x3fc00001,
  0x3fc00001,
  0x3fc00002,
  0x40000000,
  0x40000000,
  0x40000001,
  0x40200000,
  0x41300000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f800001,
  0x3f800001,
  0x3f800001,
  0x3f800002,
  0x3f800002,
  0x3f000005,
  0x3f000004,
  0x3f000003,
  0x34a00000,
  0x34800000,
  0x34000001,
  0xbefffff8,
  0xc1100000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f800002,
  0x3f800002,
  0x3f800002,
  0x3f800002,
  0x3f800002,
  0x3fc00002,
  0x3fc00002,
  0x3fc00003,
  0x40000001,
  0x40000001,
  0x40000002,
  0x40200001,
  0x41300000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f800002,
  0x3f800002,
  0x3f800002,
  0x3fc00002,
  0x3fc00001,
  0x3f800002,
  0x3f800002,
  0x3f800001,
  0x3f000004,
  0x3f000003,
  0x3f000001,
  0x34400000,
  0xc1080000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3fc00001,
  0x3fc00001,
  0x3fc00001,
  0x3fc00002,
  0x3fc00002,
  0x40000001,
  0x40000001,
  0x40000001,
  0x40200000,
  0x40200001,
  0x40200001,
  0x40400001,
  0x41380000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3fc00002,
  0x3fc00002,
  0x3fc00002,
  0x41200001,
  0x41200001,
  0x41180001,
  0x41180001,
  0x41180001,
  0x41100001,
  0x41100001,
  0x41100001,
  0x41080001,
  0x35a00000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x41200001,
  0x41200001,
  0x41200001,
  0x41200001,
  0x41200001,
  0x41280001,
  0x41280001,
  0x41280001,
  0x41300001,
  0x41300001,
  0x41300001,
  0x41380001,
  0x41a00001,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x41200001,
  0x41200001,
  0x41200001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x00123456,
  0x806dcbaa,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x00000000,
  0x806dcba9,
  0x00123455,
  0x00123456,
  0x00923456,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x002468ac,
  0x00923455,
  0x00123457,
  0x00800000,
  0x80000000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x006dcbaa,
  0x00000001,
  0x007fffff,
  0x00800000,
  0x01000000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00923456,
  0x00ffffff,
  0x00800001,
  0x00000001,
  0x807fffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123455,
  0x807ffffe,
  0x00000000,
  0x00000001,
  0x00800001,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123457,
  0x00800000,
  0x00000002,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80c00000,
  0x81200000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80d23456,
  0x81200000,
  0x80c00001,
  0x80c00000,
  0x80400000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x80adcbaa,
  0x80400001,
  0x80bfffff,
  0xbf3fffff,
  0xbf3fffff,
  0xbf9fffff,
  0xbfa00000,
  0xbfa00000,
  0xbfdfffff,
  0xbfe00000,
  0xbfe00001,
  0xc0100000,
  0xc12c0000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf3fffff,
  0xbf3fffff,
  0xbf3fffff,
  0xbf3fffff,
  0xbf3fffff,
  0xbe7fffff,
  0xbe7ffffd,
  0xbe7ffff9,
  0x3e7fffff,
  0x3e800002,
  0x3e800006,
  0x3f400001,
  0x41140000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf3fffff,
  0xbf3fffff,
  0xbf3fffff,
  0xbf400000,
  0xbf400000,
  0xbfa00000,
  0xbfa00000,
  0xbfa00000,
  0xbfe00000,
  0xbfe00000,
  0xbfe00001,
  0xc0100000,
  0xc12c0000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf400000,
  0xbf400000,
  0xbf400000,
  0xbf400000,
  0xbf400000,
  0xbe800001,
  0xbe800000,
  0xbe7ffffc,
  0x3e7ffffc,
  0x3e800000,
  0x3e800004,
  0x3f400000,
  0x41140000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf400000,
  0xbf400000,
  0xbf400000,
  0xbf400002,
  0xbf400002,
  0xbfa00000,
  0xbfa00001,
  0xbfa00001,
  0xbfe00000,
  0xbfe00001,
  0xbfe00002,
  0xc0100000,
  0xc12c0000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf400002,
  0xbf400002,
  0xbf400002,
  0xbf400002,
  0xbf400001,
  0xbe800004,
  0xbe800003,
  0xbe800001,
  0x3e7ffff6,
  0x3e7ffffa,
  0x3e800001,
  0x3f3ffffe,
  0x41140000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf400001,
  0xbf400001,
  0xbf400001,
  0xbfbfffff,
  0xbfbfffff,
  0xbfffffff,
  0xbfffffff,
  0xc0000000,
  0xc01fffff,
  0xc0200000,
  0xc0200000,
  0xc0400000,
  0xc1380000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbfbfffff,
  0xbfbfffff,
  0xbfbfffff,
  0xbfbfffff,
  0xbfbfffff,
  0xbf7fffff,
  0xbf7ffffe,
  0xbf7ffffe,
  0xbeffffff,
  0xbefffffd,
  0xbefffff9,
  0x33c00000,
  0x41080000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbfbfffff,
  0xbfbfffff,
  0xbfbfffff,
  0xbfc00000,
  0xbfc00000,
  0xc0000000,
  0xc0000000,
  0xc0000000,
  0xc0200000,
  0xc0200000,
  0xc0200000,
  0xc0400000,
  0xc1380000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbfc00000,
  0xbfc00000,
  0xbfc00000,
  0xbfc00000,
  0xbfc00000,
  0xbf800000,
  0xbf800000,
  0xbf7fffff,
  0xbf000001,
  0xbf000000,
  0xbefffffc,
  0x00000000,
  0x41080000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbfc00000,
  0xbfc00000,
  0xbfc00000,
  0xbfc00002,
  0xbfc00002,
  0xc0000001,
  0xc0000001,
  0xc0000001,
  0xc0200000,
  0xc0200001,
  0xc0200001,
  0xc0400001,
  0xc1380000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbfc00002,
  0xbfc00002,
  0xbfc00002,
  0xbfc00002,
  0xbfc00001,
  0xbf800002,
  0xbf800002,
  0xbf800001,
  0xbf000004,
  0xbf000003,
  0xbf000001,
  0xb4400000,
  0x41080000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbfc00001,
  0xbfc00001,
  0xbfc00001,
  0xc0100000,
  0xc0100000,
  0xc0300000,
  0xc0300000,
  0xc0300000,
  0xc0500000,
  0xc0500000,
  0xc0500000,
  0xc0700000,
  0xc1440000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xc0100000,
  0xc0100000,
  0xc0100000,
  0xc0100000,
  0xc0100000,
  0xbfe00000,
  0xbfe00000,
  0xbfe00000,
  0xbfa00000,
  0xbfa00000,
  0xbf9fffff,
  0xbf400000,
  0x40f80000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xc0100000,
  0xc0100000,
  0xc0100000,
  0xc1700000,
  0xc1700000,
  0xc1780000,
  0xc1780000,
  0xc1780000,
  0xc1800000,
  0xc1800000,
  0xc1800000,
  0xc1840000,
  0xc1c80000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xc1700000,
  0xc1700000,
  0xc1700000,
  0xc1700000,
  0xc1700000,
  0xc1680000,
  0xc1680000,
  0xc1680000,
  0xc1600000,
  0xc1600000,
  0xc1600000,
  0xc1580000,
  0xc0a00000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xc1700000,
  0xc1700000,
  0xc1700000,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x801b4e81,
  0x809b4e81,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x802d82d7,
  0x809b4e80,
  0x801b4e82,
  0x801b4e81,
  0x0064b17f,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x80091a2b,
  0x0064b17e,
  0x801b4e80,
  0x80bffffe,
  0x811fffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80d23454,
  0x811fffff,
  0x80c00000,
  0x80bffffe,
  0x803ffffe,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x80adcba8,
  0x80400000,
  0x80bffffe,
  0x80000002,
  0x80800002,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123458,
  0x80800000,
  0x80000002,
  0x80000002,
  0x007ffffe,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123454,
  0x007ffffe,
  0x80000000,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00c00000,
  0x00400000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x00adcbaa,
  0x00400001,
  0x00bfffff,
  0x00c00000,
  0x01200000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00d23456,
  0x01200000,
  0x00c00001,
  0x3f3fffff,
  0x3f3fffff,
  0x3e7fffff,
  0x3e7ffffd,
  0x3e7ffff9,
  0xbe7fffff,
  0xbe800002,
  0xbe800006,
  0xbf400001,
  0xc1140000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f3fffff,
  0x3f3fffff,
  0x3f3fffff,
  0x3f3fffff,
  0x3f3fffff,
  0x3f9fffff,
  0x3fa00000,
  0x3fa00000,
  0x3fdfffff,
  0x3fe00000,
  0x3fe00001,
  0x40100000,
  0x412c0000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f3fffff,
  0x3f3fffff,
  0x3f3fffff,
  0x3f400000,
  0x3f400000,
  0x3e800001,
  0x3e800000,
  0x3e7ffffc,
  0xbe7ffffc,
  0xbe800000,
  0xbe800004,
  0xbf400000,
  0xc1140000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f400000,
  0x3f400000,
  0x3f400000,
  0x3f400000,
  0x3f400000,
  0x3fa00000,
  0x3fa00000,
  0x3fa00000,
  0x3fe00000,
  0x3fe00000,
  0x3fe00001,
  0x40100000,
  0x412c0000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f400000,
  0x3f400000,
  0x3f400000,
  0x3f400002,
  0x3f400001,
  0x3e800004,
  0x3e800003,
  0x3e800001,
  0xbe7ffff6,
  0xbe7ffffa,
  0xbe800001,
  0xbf3ffffe,
  0xc1140000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f400001,
  0x3f400001,
  0x3f400001,
  0x3f400002,
  0x3f400002,
  0x3fa00000,
  0x3fa00001,
  0x3fa00001,
  0x3fe00000,
  0x3fe00001,
  0x3fe00002,
  0x40100000,
  0x412c0000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f400002,
  0x3f400002,
  0x3f400002,
  0x3fbfffff,
  0x3fbfffff,
  0x3f7fffff,
  0x3f7ffffe,
  0x3f7ffffe,
  0x3effffff,
  0x3efffffd,
  0x3efffff9,
  0xb3c00000,
  0xc1080000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3fbfffff,
  0x3fbfffff,
  0x3fbfffff,
  0x3fbfffff,
  0x3fbfffff,
  0x3fffffff,
  0x3fffffff,
  0x40000000,
  0x401fffff,
  0x40200000,
  0x40200000,
  0x40400000,
  0x41380000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3fbfffff,
  0x3fbfffff,
  0x3fbfffff,
  0x3fc00000,
  0x3fc00000,
  0x3f800000,
  0x3f800000,
  0x3f7fffff,
  0x3f000001,
  0x3f000000,
  0x3efffffc,
  0x00000000,
  0xc1080000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3fc00000,
  0x3fc00000,
  0x3fc00000,
  0x3fc00000,
  0x3fc00000,
  0x40000000,
  0x40000000,
  0x40000000,
  0x40200000,
  0x40200000,
  0x40200000,
  0x40400000,
  0x41380000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3fc00000,
  0x3fc00000,
  0x3fc00000,
  0x3fc00002,
  0x3fc00001,
  0x3f800002,
  0x3f800002,
  0x3f800001,
  0x3f000004,
  0x3f000003,
  0x3f000001,
  0x34400000,
  0xc1080000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3fc00001,
  0x3fc00001,
  0x3fc00001,
  0x3fc00002,
  0x3fc00002,
  0x40000001,
  0x40000001,
  0x40000001,
  0x40200000,
  0x40200001,
  0x40200001,
  0x40400001,
  0x41380000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3fc00002,
  0x3fc00002,
  0x3fc00002,
  0x40100000,
  0x40100000,
  0x3fe00000,
  0x3fe00000,
  0x3fe00000,
  0x3fa00000,
  0x3fa00000,
  0x3f9fffff,
  0x3f400000,
  0xc0f80000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x40100000,
  0x40100000,
  0x40100000,
  0x40100000,
  0x40100000,
  0x40300000,
  0x40300000,
  0x40300000,
  0x40500000,
  0x40500000,
  0x40500000,
  0x40700000,
  0x41440000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x40100000,
  0x40100000,
  0x40100000,
  0x41700000,
  0x41700000,
  0x41680000,
  0x41680000,
  0x41680000,
  0x41600000,
  0x41600000,
  0x41600000,
  0x41580000,
  0x40a00000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x41700000,
  0x41700000,
  0x41700000,
  0x41700000,
  0x41700000,
  0x41780000,
  0x41780000,
  0x41780000,
  0x41800000,
  0x41800000,
  0x41800000,
  0x41840000,
  0x41c80000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x41700000,
  0x41700000,
  0x41700000,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x001b4e81,
  0x8064b17f,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x00091a2b,
  0x8064b17e,
  0x001b4e80,
  0x001b4e81,
  0x009b4e81,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x002d82d7,
  0x009b4e80,
  0x001b4e82,
  0x00bffffe,
  0x003ffffe,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x00adcba8,
  0x00400000,
  0x00bffffe,
  0x00bffffe,
  0x011fffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00d23454,
  0x011fffff,
  0x00c00000,
  0x00000002,
  0x807ffffe,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123454,
  0x807ffffe,
  0x00000000,
  0x00000002,
  0x00800002,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123458,
  0x00800000,
  0x00000002,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x82200000,
  0x82300000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x8222468b,
  0x82300000,
  0x82200000,
  0x82200000,
  0x82100000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x821db975,
  0x82100000,
  0x82200000,
  0xc09fffff,
  0xc09fffff,
  0xc0afffff,
  0xc0afffff,
  0xc0b00000,
  0xc0bfffff,
  0xc0bfffff,
  0xc0c00000,
  0xc0cfffff,
  0xc1700000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xc09fffff,
  0xc09fffff,
  0xc09fffff,
  0xc09fffff,
  0xc09fffff,
  0xc08fffff,
  0xc08fffff,
  0xc08fffff,
  0xc07fffff,
  0xc07fffff,
  0xc07ffffe,
  0xc05fffff,
  0x40a00001,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xc09fffff,
  0xc09fffff,
  0xc09fffff,
  0xc0a00000,
  0xc0a00000,
  0xc0b00000,
  0xc0b00000,
  0xc0b00000,
  0xc0c00000,
  0xc0c00000,
  0xc0c00000,
  0xc0d00000,
  0xc1700000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xc0a00000,
  0xc0a00000,
  0xc0a00000,
  0xc0a00000,
  0xc0a00000,
  0xc0900000,
  0xc0900000,
  0xc0900000,
  0xc0800000,
  0xc0800000,
  0xc0800000,
  0xc0600000,
  0x40a00000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xc0a00000,
  0xc0a00000,
  0xc0a00000,
  0xc0a00001,
  0xc0a00001,
  0xc0b00001,
  0xc0b00001,
  0xc0b00001,
  0xc0c00001,
  0xc0c00001,
  0xc0c00002,
  0xc0d00001,
  0xc1700001,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xc0a00001,
  0xc0a00001,
  0xc0a00001,
  0xc0a00001,
  0xc0a00001,
  0xc0900001,
  0xc0900001,
  0xc0900001,
  0xc0800001,
  0xc0800001,
  0xc0800001,
  0xc0600002,
  0x409fffff,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xc0a00001,
  0xc0a00001,
  0xc0a00001,
  0xc11fffff,
  0xc11fffff,
  0xc127ffff,
  0xc127ffff,
  0xc127ffff,
  0xc12fffff,
  0xc12fffff,
  0xc1300000,
  0xc137ffff,
  0xc1a00000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xc11fffff,
  0xc11fffff,
  0xc11fffff,
  0xc11fffff,
  0xc11fffff,
  0xc117ffff,
  0xc117ffff,
  0xc117ffff,
  0xc10fffff,
  0xc10fffff,
  0xc10fffff,
  0xc107ffff,
  0x35200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xc11fffff,
  0xc11fffff,
  0xc11fffff,
  0xc1200000,
  0xc1200000,
  0xc1280000,
  0xc1280000,
  0xc1280000,
  0xc1300000,
  0xc1300000,
  0xc1300000,
  0xc1380000,
  0xc1a00000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xc1200000,
  0xc1200000,
  0xc1200000,
  0xc1200000,
  0xc1200000,
  0xc1180000,
  0xc1180000,
  0xc1180000,
  0xc1100000,
  0xc1100000,
  0xc1100000,
  0xc1080000,
  0x00000000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xc1200000,
  0xc1200000,
  0xc1200000,
  0xc1200001,
  0xc1200001,
  0xc1280001,
  0xc1280001,
  0xc1280001,
  0xc1300001,
  0xc1300001,
  0xc1300001,
  0xc1380001,
  0xc1a00001,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xc1200001,
  0xc1200001,
  0xc1200001,
  0xc1200001,
  0xc1200001,
  0xc1180001,
  0xc1180001,
  0xc1180001,
  0xc1100001,
  0xc1100001,
  0xc1100001,
  0xc1080001,
  0xb5a00000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xc1200001,
  0xc1200001,
  0xc1200001,
  0xc1700000,
  0xc1700000,
  0xc1780000,
  0xc1780000,
  0xc1780000,
  0xc1800000,
  0xc1800000,
  0xc1800000,
  0xc1840000,
  0xc1c80000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xc1700000,
  0xc1700000,
  0xc1700000,
  0xc1700000,
  0xc1700000,
  0xc1680000,
  0xc1680000,
  0xc1680000,
  0xc1600000,
  0xc1600000,
  0xc1600000,
  0xc1580000,
  0xc0a00000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xc1700000,
  0xc1700000,
  0xc1700000,
  0xc2c80000,
  0xc2c80000,
  0xc2c90000,
  0xc2c90000,
  0xc2c90000,
  0xc2ca0000,
  0xc2ca0000,
  0xc2ca0000,
  0xc2cb0000,
  0xc2dc0000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xc2c80000,
  0xc2c80000,
  0xc2c80000,
  0xc2c80000,
  0xc2c80000,
  0xc2c70000,
  0xc2c70000,
  0xc2c70000,
  0xc2c60000,
  0xc2c60000,
  0xc2c60000,
  0xc2c50000,
  0xc2b40000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xc2c80000,
  0xc2c80000,
  0xc2c80000,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x80b60b5c,
  0x811b05ae,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80c83fb2,
  0x811b05ae,
  0x80b60b5d,
  0x80b60b5c,
  0x80360b5c,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x80a3d706,
  0x80360b5d,
  0x80b60b5b,
  0x821fffff,
  0x822fffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x8222468a,
  0x822fffff,
  0x821fffff,
  0x821fffff,
  0x820fffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x821db974,
  0x820fffff,
  0x821fffff,
  0x8000000a,
  0x8080000a,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123460,
  0x80800009,
  0x8000000b,
  0x8000000a,
  0x007ffff6,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x0012344c,
  0x007ffff5,
  0x80000009,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x02200000,
  0x02100000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x021db975,
  0x02100000,
  0x02200000,
  0x02200000,
  0x02300000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x0222468b,
  0x02300000,
  0x02200000,
  0x409fffff,
  0x409fffff,
  0x408fffff,
  0x408fffff,
  0x408fffff,
  0x407fffff,
  0x407fffff,
  0x407ffffe,
  0x405fffff,
  0xc0a00001,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x409fffff,
  0x409fffff,
  0x409fffff,
  0x409fffff,
  0x409fffff,
  0x40afffff,
  0x40afffff,
  0x40b00000,
  0x40bfffff,
  0x40bfffff,
  0x40c00000,
  0x40cfffff,
  0x41700000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x409fffff,
  0x409fffff,
  0x409fffff,
  0x40a00000,
  0x40a00000,
  0x40900000,
  0x40900000,
  0x40900000,
  0x40800000,
  0x40800000,
  0x40800000,
  0x40600000,
  0xc0a00000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x40a00000,
  0x40a00000,
  0x40a00000,
  0x40a00000,
  0x40a00000,
  0x40b00000,
  0x40b00000,
  0x40b00000,
  0x40c00000,
  0x40c00000,
  0x40c00000,
  0x40d00000,
  0x41700000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x40a00000,
  0x40a00000,
  0x40a00000,
  0x40a00001,
  0x40a00001,
  0x40900001,
  0x40900001,
  0x40900001,
  0x40800001,
  0x40800001,
  0x40800001,
  0x40600002,
  0xc09fffff,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x40a00001,
  0x40a00001,
  0x40a00001,
  0x40a00001,
  0x40a00001,
  0x40b00001,
  0x40b00001,
  0x40b00001,
  0x40c00001,
  0x40c00001,
  0x40c00002,
  0x40d00001,
  0x41700001,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x40a00001,
  0x40a00001,
  0x40a00001,
  0x411fffff,
  0x411fffff,
  0x4117ffff,
  0x4117ffff,
  0x4117ffff,
  0x410fffff,
  0x410fffff,
  0x410fffff,
  0x4107ffff,
  0xb5200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x411fffff,
  0x411fffff,
  0x411fffff,
  0x411fffff,
  0x411fffff,
  0x4127ffff,
  0x4127ffff,
  0x4127ffff,
  0x412fffff,
  0x412fffff,
  0x41300000,
  0x4137ffff,
  0x41a00000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x411fffff,
  0x411fffff,
  0x411fffff,
  0x41200000,
  0x41200000,
  0x41180000,
  0x41180000,
  0x41180000,
  0x41100000,
  0x41100000,
  0x41100000,
  0x41080000,
  0x00000000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x41200000,
  0x41200000,
  0x41200000,
  0x41200000,
  0x41200000,
  0x41280000,
  0x41280000,
  0x41280000,
  0x41300000,
  0x41300000,
  0x41300000,
  0x41380000,
  0x41a00000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x41200000,
  0x41200000,
  0x41200000,
  0x41200001,
  0x41200001,
  0x41180001,
  0x41180001,
  0x41180001,
  0x41100001,
  0x41100001,
  0x41100001,
  0x41080001,
  0x35a00000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x41200001,
  0x41200001,
  0x41200001,
  0x41200001,
  0x41200001,
  0x41280001,
  0x41280001,
  0x41280001,
  0x41300001,
  0x41300001,
  0x41300001,
  0x41380001,
  0x41a00001,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x41200001,
  0x41200001,
  0x41200001,
  0x41700000,
  0x41700000,
  0x41680000,
  0x41680000,
  0x41680000,
  0x41600000,
  0x41600000,
  0x41600000,
  0x41580000,
  0x40a00000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x41700000,
  0x41700000,
  0x41700000,
  0x41700000,
  0x41700000,
  0x41780000,
  0x41780000,
  0x41780000,
  0x41800000,
  0x41800000,
  0x41800000,
  0x41840000,
  0x41c80000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x41700000,
  0x41700000,
  0x41700000,
  0x42c80000,
  0x42c80000,
  0x42c70000,
  0x42c70000,
  0x42c70000,
  0x42c60000,
  0x42c60000,
  0x42c60000,
  0x42c50000,
  0x42b40000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x42c80000,
  0x42c80000,
  0x42c80000,
  0x42c80000,
  0x42c80000,
  0x42c90000,
  0x42c90000,
  0x42c90000,
  0x42ca0000,
  0x42ca0000,
  0x42ca0000,
  0x42cb0000,
  0x42dc0000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x42c80000,
  0x42c80000,
  0x42c80000,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x00b60b5c,
  0x00360b5c,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x00a3d706,
  0x00360b5d,
  0x00b60b5b,
  0x00b60b5c,
  0x011b05ae,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00c83fb2,
  0x011b05ae,
  0x00b60b5d,
  0x021fffff,
  0x020fffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x021db974,
  0x020fffff,
  0x021fffff,
  0x021fffff,
  0x022fffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x0222468a,
  0x022fffff,
  0x021fffff,
  0x0000000a,
  0x807ffff6,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x8012344c,
  0x807ffff5,
  0x00000009,
  0x0000000a,
  0x0080000a,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123460,
  0x00800009,
  0x0000000b,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80091a2b,
  0x80891a2b,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x801b4e81,
  0x80891a2a,
  0x80091a2c,
  0x80091a2b,
  0x0076e5d5,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00091a2b,
  0x0076e5d4,
  0x80091a2a,
  0x80091a2b,
  0x80891a2b,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x801b4e81,
  0x80891a2a,
  0x80091a2c,
  0x80091a2b,
  0x0076e5d5,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00091a2b,
  0x0076e5d4,
  0x80091a2a,
  0x80091a2b,
  0x80891a2b,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x801b4e81,
  0x80891a2a,
  0x80091a2c,
  0x80091a2b,
  0x0076e5d5,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00091a2b,
  0x0076e5d4,
  0x80091a2a,
  0x80123456,
  0x80923456,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x802468ac,
  0x80923455,
  0x80123457,
  0x80123456,
  0x006dcbaa,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00000000,
  0x006dcba9,
  0x80123455,
  0x80123456,
  0x80923456,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x802468ac,
  0x80923455,
  0x80123457,
  0x80123456,
  0x006dcbaa,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00000000,
  0x006dcba9,
  0x80123455,
  0x80123456,
  0x80923456,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x802468ac,
  0x80923455,
  0x80123457,
  0x80123456,
  0x006dcbaa,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x80000000,
  0x006dcba9,
  0x80123455,
  0x801b4e81,
  0x809b4e81,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x802d82d7,
  0x809b4e80,
  0x801b4e82,
  0x801b4e81,
  0x0064b17f,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x80091a2b,
  0x0064b17e,
  0x801b4e80,
  0x80b60b5c,
  0x811b05ae,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80c83fb2,
  0x811b05ae,
  0x80b60b5d,
  0x80b60b5c,
  0x80360b5c,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x80a3d706,
  0x80360b5d,
  0x80b60b5b,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00091a2b,
  0x8076e5d5,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80091a2b,
  0x8076e5d4,
  0x00091a2a,
  0x00091a2b,
  0x00891a2b,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x001b4e81,
  0x00891a2a,
  0x00091a2c,
  0x00091a2b,
  0x8076e5d5,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80091a2b,
  0x8076e5d4,
  0x00091a2a,
  0x00091a2b,
  0x00891a2b,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x001b4e81,
  0x00891a2a,
  0x00091a2c,
  0x00091a2b,
  0x8076e5d5,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80091a2b,
  0x8076e5d4,
  0x00091a2a,
  0x00091a2b,
  0x00891a2b,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x001b4e81,
  0x00891a2a,
  0x00091a2c,
  0x00123456,
  0x806dcbaa,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80000000,
  0x806dcba9,
  0x00123455,
  0x00123456,
  0x00923456,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x002468ac,
  0x00923455,
  0x00123457,
  0x00123456,
  0x806dcbaa,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x00000000,
  0x806dcba9,
  0x00123455,
  0x00123456,
  0x00923456,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x002468ac,
  0x00923455,
  0x00123457,
  0x00123456,
  0x806dcbaa,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x00000000,
  0x806dcba9,
  0x00123455,
  0x00123456,
  0x00923456,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x002468ac,
  0x00923455,
  0x00123457,
  0x001b4e81,
  0x8064b17f,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x00091a2b,
  0x8064b17e,
  0x001b4e80,
  0x001b4e81,
  0x009b4e81,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x002d82d7,
  0x009b4e80,
  0x001b4e82,
  0x00b60b5c,
  0x00360b5c,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x00a3d706,
  0x00360b5d,
  0x00b60b5b,
  0x00b60b5c,
  0x011b05ae,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00c83fb2,
  0x011b05ae,
  0x00b60b5d,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x803fffff,
  0x80bfffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80523455,
  0x80bffffe,
  0x80400000,
  0x803fffff,
  0x00400001,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x802dcba9,
  0x00400000,
  0x803ffffe,
  0x80400000,
  0x80c00000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80523456,
  0x80bffffe,
  0x80400000,
  0x80400000,
  0x00400000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x802dcbaa,
  0x00400000,
  0x803ffffe,
  0x80400000,
  0x80c00000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80523456,
  0x80bfffff,
  0x80400001,
  0x80400000,
  0x00400000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x802dcbaa,
  0x003fffff,
  0x803fffff,
  0x807fffff,
  0x80ffffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80923455,
  0x80fffffe,
  0x80800000,
  0x807fffff,
  0x00000001,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x806dcba9,
  0x00000000,
  0x807ffffe,
  0x807fffff,
  0x80ffffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80923455,
  0x80fffffe,
  0x80800000,
  0x807fffff,
  0x00000001,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x806dcba9,
  0x00000000,
  0x807ffffe,
  0x80800000,
  0x81000000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80923456,
  0x80ffffff,
  0x80800001,
  0x80800000,
  0x00000000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x806dcbaa,
  0x80000001,
  0x807fffff,
  0x80bffffe,
  0x811fffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80d23454,
  0x811fffff,
  0x80c00000,
  0x80bffffe,
  0x803ffffe,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x80adcba8,
  0x80400000,
  0x80bffffe,
  0x821fffff,
  0x822fffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x8222468a,
  0x822fffff,
  0x821fffff,
  0x821fffff,
  0x820fffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x821db974,
  0x820fffff,
  0x821fffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x003fffff,
  0x80400001,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x002dcba9,
  0x80400000,
  0x003ffffe,
  0x003fffff,
  0x00bfffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00523455,
  0x00bffffe,
  0x00400000,
  0x00400000,
  0x80400000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x002dcbaa,
  0x80400000,
  0x003ffffe,
  0x00400000,
  0x00c00000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00523456,
  0x00bffffe,
  0x00400000,
  0x00400000,
  0x80400000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x002dcbaa,
  0x803fffff,
  0x003fffff,
  0x00400000,
  0x00c00000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00523456,
  0x00bfffff,
  0x00400001,
  0x007fffff,
  0x80000001,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x006dcba9,
  0x80000000,
  0x007ffffe,
  0x007fffff,
  0x00ffffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00923455,
  0x00fffffe,
  0x00800000,
  0x007fffff,
  0x80000001,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x006dcba9,
  0x00000000,
  0x007ffffe,
  0x007fffff,
  0x00ffffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00923455,
  0x00fffffe,
  0x00800000,
  0x00800000,
  0x80000000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x006dcbaa,
  0x00000001,
  0x007fffff,
  0x00800000,
  0x01000000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00923456,
  0x00ffffff,
  0x00800001,
  0x00bffffe,
  0x003ffffe,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x00adcba8,
  0x00400000,
  0x00bffffe,
  0x00bffffe,
  0x011fffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00d23454,
  0x011fffff,
  0x00c00000,
  0x021fffff,
  0x020fffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x021db974,
  0x020fffff,
  0x021fffff,
  0x021fffff,
  0x022fffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x0222468a,
  0x022fffff,
  0x021fffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x80800000,
  0x80000002,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007ffffe,
  0x00000000,
  0x80000001,
  0x80800001,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123457,
  0x80800000,
  0x80000002,
  0x80000001,
  0x007fffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123455,
  0x007ffffe,
  0x00000000,
  0x80000001,
  0x80800001,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123457,
  0x80800000,
  0x80000002,
  0x80000001,
  0x007fffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123455,
  0x007ffffe,
  0x00000000,
  0x80000001,
  0x80800001,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123457,
  0x80800000,
  0x80000002,
  0x80000001,
  0x007fffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123455,
  0x007ffffe,
  0x00000000,
  0x80000001,
  0x80800001,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123457,
  0x80800000,
  0x80000002,
  0x80000001,
  0x007fffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123455,
  0x007ffffe,
  0x80000000,
  0x80000002,
  0x80800002,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123458,
  0x80800000,
  0x80000002,
  0x80000002,
  0x007ffffe,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123454,
  0x007ffffe,
  0x80000000,
  0x8000000a,
  0x8080000a,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123460,
  0x80800009,
  0x8000000b,
  0x8000000a,
  0x007ffff6,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x0012344c,
  0x007ffff5,
  0x80000009,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xffd23456,
  0xffc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fd23456,
  0x7fc00001,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0xffd23456,
  0xffc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fcfffff,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x80000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807ffffe,
  0x80000000,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x00800000,
  0x00000002,
  0x00000001,
  0x807fffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123455,
  0x807ffffe,
  0x80000000,
  0x00000001,
  0x00800001,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123457,
  0x00800000,
  0x00000002,
  0x00000001,
  0x807fffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123455,
  0x807ffffe,
  0x80000000,
  0x00000001,
  0x00800001,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123457,
  0x00800000,
  0x00000002,
  0x00000001,
  0x807fffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123455,
  0x807ffffe,
  0x00000000,
  0x00000001,
  0x00800001,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123457,
  0x00800000,
  0x00000002,
  0x00000001,
  0x807fffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123455,
  0x807ffffe,
  0x00000000,
  0x00000001,
  0x00800001,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123457,
  0x00800000,
  0x00000002,
  0x00000002,
  0x807ffffe,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123454,
  0x807ffffe,
  0x00000000,
  0x00000002,
  0x00800002,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123458,
  0x00800000,
  0x00000002,
  0x0000000a,
  0x807ffff6,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x8012344c,
  0x807ffff5,
  0x00000009,
  0x0000000a,
  0x0080000a,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123460,
  0x00800009,
  0x0000000b,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffd23456,
  0xffc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7fd23456,
  0x7fc00001,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fcfffff,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x7fd23456,
  0x7fc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
};
const unsigned kExpectedCount_fnmsub_s = 54872;

const uint64_t kExpected_frinta_d[] = {
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x4000000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xc000000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x47efffff00000000,
  0x0000000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x47efffffefffffff,
  0x47f0000000000000,
  0x47effffff0000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0xc7efffff00000000,
  0x8000000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xc7efffffefffffff,
  0xc7f0000000000000,
  0xc7effffff0000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x4330000000000000,
  0x4330000000000001,
  0x4330000000000002,
  0x4330000000000003,
  0x433fedcba9876543,
  0x433ffffffffffffc,
  0x433ffffffffffffd,
  0x433ffffffffffffe,
  0x433fffffffffffff,
  0x4320000000000000,
  0x4320000000000002,
  0x4320000000000002,
  0x4320000000000004,
  0x432fedcba9876544,
  0x432ffffffffffffc,
  0x432ffffffffffffe,
  0x432ffffffffffffe,
  0x4330000000000000,
  0x4310000000000000,
  0x4310000000000000,
  0x4310000000000004,
  0x4310000000000004,
  0x431fedcba9876544,
  0x431ffffffffffffc,
  0x431ffffffffffffc,
  0x4320000000000000,
  0x4320000000000000,
  0xc330000000000000,
  0xc330000000000001,
  0xc330000000000002,
  0xc330000000000003,
  0xc33fedcba9876543,
  0xc33ffffffffffffc,
  0xc33ffffffffffffd,
  0xc33ffffffffffffe,
  0xc33fffffffffffff,
  0xc320000000000000,
  0xc320000000000002,
  0xc320000000000002,
  0xc320000000000004,
  0xc32fedcba9876544,
  0xc32ffffffffffffc,
  0xc32ffffffffffffe,
  0xc32ffffffffffffe,
  0xc330000000000000,
  0xc310000000000000,
  0xc310000000000000,
  0xc310000000000004,
  0xc310000000000004,
  0xc31fedcba9876544,
  0xc31ffffffffffffc,
  0xc31ffffffffffffc,
  0xc320000000000000,
  0xc320000000000000,
  0xc3e0000000000001,
  0xc3e0000000000000,
  0xc3dfffffffffffff,
  0x43dfffffffffffff,
  0x43e0000000000000,
  0x43efffffffffffff,
  0x43f0000000000000,
  0xc1e0000000200000,
  0xc1e0000000200000,
  0xc1e0000000200000,
  0xc1e0000000200000,
  0xc1e0000000200000,
  0xc1e0000000000000,
  0xc1e0000000000000,
  0xc1e0000000000000,
  0xc1e0000000000000,
  0xc1e0000000000000,
  0xc1e0000000000000,
  0xc1dfffffffc00000,
  0x41dfffffff800000,
  0x41dfffffff800000,
  0x41dfffffff800000,
  0x41dfffffff800000,
  0x41dfffffffc00000,
  0x41dfffffffc00000,
  0x41dfffffffc00000,
  0x41dfffffffc00000,
  0x41dfffffffc00000,
  0x41dfffffffc00000,
  0x41e0000000000000,
  0x41e0000000000000,
  0x41efffffffc00000,
  0x41efffffffc00000,
  0x41efffffffc00000,
  0x41efffffffc00000,
  0x41efffffffe00000,
  0x41efffffffe00000,
  0x41efffffffe00000,
  0x41efffffffe00000,
  0x41efffffffe00000,
  0x41efffffffe00000,
  0x41f0000000000000,
  0x41f0000000000000,
};
const unsigned kExpectedCount_frinta_d = 207;

const uint32_t kExpected_frinta_s[] = {
  0x00000000,
  0x00000000,
  0x00000000,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x40000000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00000000,
  0x00000000,
  0x00000000,
  0x80000000,
  0x80000000,
  0x80000000,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xc0000000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80000000,
  0x80000000,
  0x80000000,
  0x4b000000,
  0x4b000001,
  0x4b000002,
  0x4b000003,
  0x4b765432,
  0x4b7ffffc,
  0x4b7ffffd,
  0x4b7ffffe,
  0x4b7fffff,
  0x4a800000,
  0x4a800002,
  0x4a800002,
  0x4a800004,
  0x4af65432,
  0x4afffffc,
  0x4afffffe,
  0x4afffffe,
  0x4b000000,
  0x4a000000,
  0x4a000000,
  0x4a000004,
  0x4a000004,
  0x4a765434,
  0x4a7ffffc,
  0x4a7ffffc,
  0x4a800000,
  0x4a800000,
  0xcb000000,
  0xcb000001,
  0xcb000002,
  0xcb000003,
  0xcb765432,
  0xcb7ffffc,
  0xcb7ffffd,
  0xcb7ffffe,
  0xcb7fffff,
  0xca800000,
  0xca800002,
  0xca800002,
  0xca800004,
  0xcaf65432,
  0xcafffffc,
  0xcafffffe,
  0xcafffffe,
  0xcb000000,
  0xca000000,
  0xca000000,
  0xca000004,
  0xca000004,
  0xca765434,
  0xca7ffffc,
  0xca7ffffc,
  0xca800000,
  0xca800000,
  0xdf000001,
  0xdf000000,
  0xdeffffff,
  0x5effffff,
  0x5f000000,
  0x5f7fffff,
  0x5f800000,
  0xcf000001,
  0xcf000000,
  0xceffffff,
  0x4effffff,
  0x4f000000,
};
const unsigned kExpectedCount_frinta_s = 104;

const uint64_t kExpected_frintn_d[] = {
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x4000000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xc000000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x47efffff00000000,
  0x0000000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x47efffffefffffff,
  0x47f0000000000000,
  0x47effffff0000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0xc7efffff00000000,
  0x8000000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xc7efffffefffffff,
  0xc7f0000000000000,
  0xc7effffff0000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x4330000000000000,
  0x4330000000000001,
  0x4330000000000002,
  0x4330000000000003,
  0x433fedcba9876543,
  0x433ffffffffffffc,
  0x433ffffffffffffd,
  0x433ffffffffffffe,
  0x433fffffffffffff,
  0x4320000000000000,
  0x4320000000000000,
  0x4320000000000002,
  0x4320000000000004,
  0x432fedcba9876544,
  0x432ffffffffffffc,
  0x432ffffffffffffc,
  0x432ffffffffffffe,
  0x4330000000000000,
  0x4310000000000000,
  0x4310000000000000,
  0x4310000000000000,
  0x4310000000000004,
  0x431fedcba9876544,
  0x431ffffffffffffc,
  0x431ffffffffffffc,
  0x4320000000000000,
  0x4320000000000000,
  0xc330000000000000,
  0xc330000000000001,
  0xc330000000000002,
  0xc330000000000003,
  0xc33fedcba9876543,
  0xc33ffffffffffffc,
  0xc33ffffffffffffd,
  0xc33ffffffffffffe,
  0xc33fffffffffffff,
  0xc320000000000000,
  0xc320000000000000,
  0xc320000000000002,
  0xc320000000000004,
  0xc32fedcba9876544,
  0xc32ffffffffffffc,
  0xc32ffffffffffffc,
  0xc32ffffffffffffe,
  0xc330000000000000,
  0xc310000000000000,
  0xc310000000000000,
  0xc310000000000000,
  0xc310000000000004,
  0xc31fedcba9876544,
  0xc31ffffffffffffc,
  0xc31ffffffffffffc,
  0xc320000000000000,
  0xc320000000000000,
  0xc3e0000000000001,
  0xc3e0000000000000,
  0xc3dfffffffffffff,
  0x43dfffffffffffff,
  0x43e0000000000000,
  0x43efffffffffffff,
  0x43f0000000000000,
  0xc1e0000000200000,
  0xc1e0000000200000,
  0xc1e0000000200000,
  0xc1e0000000200000,
  0xc1e0000000000000,
  0xc1e0000000000000,
  0xc1e0000000000000,
  0xc1e0000000000000,
  0xc1e0000000000000,
  0xc1e0000000000000,
  0xc1e0000000000000,
  0xc1dfffffffc00000,
  0x41dfffffff800000,
  0x41dfffffff800000,
  0x41dfffffff800000,
  0x41dfffffff800000,
  0x41dfffffff800000,
  0x41dfffffffc00000,
  0x41dfffffffc00000,
  0x41dfffffffc00000,
  0x41dfffffffc00000,
  0x41dfffffffc00000,
  0x41e0000000000000,
  0x41e0000000000000,
  0x41efffffffc00000,
  0x41efffffffc00000,
  0x41efffffffc00000,
  0x41efffffffc00000,
  0x41efffffffc00000,
  0x41efffffffe00000,
  0x41efffffffe00000,
  0x41efffffffe00000,
  0x41efffffffe00000,
  0x41efffffffe00000,
  0x41f0000000000000,
  0x41f0000000000000,
};
const unsigned kExpectedCount_frintn_d = 207;

const uint32_t kExpected_frintn_s[] = {
  0x00000000,
  0x00000000,
  0x00000000,
  0x00000000,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x40000000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00000000,
  0x00000000,
  0x00000000,
  0x80000000,
  0x80000000,
  0x80000000,
  0x80000000,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xc0000000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80000000,
  0x80000000,
  0x80000000,
  0x4b000000,
  0x4b000001,
  0x4b000002,
  0x4b000003,
  0x4b765432,
  0x4b7ffffc,
  0x4b7ffffd,
  0x4b7ffffe,
  0x4b7fffff,
  0x4a800000,
  0x4a800000,
  0x4a800002,
  0x4a800004,
  0x4af65432,
  0x4afffffc,
  0x4afffffc,
  0x4afffffe,
  0x4b000000,
  0x4a000000,
  0x4a000000,
  0x4a000000,
  0x4a000004,
  0x4a765430,
  0x4a7ffffc,
  0x4a7ffffc,
  0x4a800000,
  0x4a800000,
  0xcb000000,
  0xcb000001,
  0xcb000002,
  0xcb000003,
  0xcb765432,
  0xcb7ffffc,
  0xcb7ffffd,
  0xcb7ffffe,
  0xcb7fffff,
  0xca800000,
  0xca800000,
  0xca800002,
  0xca800004,
  0xcaf65432,
  0xcafffffc,
  0xcafffffc,
  0xcafffffe,
  0xcb000000,
  0xca000000,
  0xca000000,
  0xca000000,
  0xca000004,
  0xca765430,
  0xca7ffffc,
  0xca7ffffc,
  0xca800000,
  0xca800000,
  0xdf000001,
  0xdf000000,
  0xdeffffff,
  0x5effffff,
  0x5f000000,
  0x5f7fffff,
  0x5f800000,
  0xcf000001,
  0xcf000000,
  0xceffffff,
  0x4effffff,
  0x4f000000,
};
const unsigned kExpectedCount_frintn_s = 104;

const uint64_t kExpected_frintz_d[] = {
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff0000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x47efffff00000000,
  0x0000000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x0000000000000000,
  0x47efffffefffffff,
  0x47f0000000000000,
  0x47effffff0000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0x0000000000000000,
  0xc7efffff00000000,
  0x8000000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0x8000000000000000,
  0xc7efffffefffffff,
  0xc7f0000000000000,
  0xc7effffff0000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x8000000000000000,
  0x4330000000000000,
  0x4330000000000001,
  0x4330000000000002,
  0x4330000000000003,
  0x433fedcba9876543,
  0x433ffffffffffffc,
  0x433ffffffffffffd,
  0x433ffffffffffffe,
  0x433fffffffffffff,
  0x4320000000000000,
  0x4320000000000000,
  0x4320000000000002,
  0x4320000000000002,
  0x432fedcba9876542,
  0x432ffffffffffffc,
  0x432ffffffffffffc,
  0x432ffffffffffffe,
  0x432ffffffffffffe,
  0x4310000000000000,
  0x4310000000000000,
  0x4310000000000000,
  0x4310000000000000,
  0x431fedcba9876540,
  0x431ffffffffffffc,
  0x431ffffffffffffc,
  0x431ffffffffffffc,
  0x431ffffffffffffc,
  0xc330000000000000,
  0xc330000000000001,
  0xc330000000000002,
  0xc330000000000003,
  0xc33fedcba9876543,
  0xc33ffffffffffffc,
  0xc33ffffffffffffd,
  0xc33ffffffffffffe,
  0xc33fffffffffffff,
  0xc320000000000000,
  0xc320000000000000,
  0xc320000000000002,
  0xc320000000000002,
  0xc32fedcba9876542,
  0xc32ffffffffffffc,
  0xc32ffffffffffffc,
  0xc32ffffffffffffe,
  0xc32ffffffffffffe,
  0xc310000000000000,
  0xc310000000000000,
  0xc310000000000000,
  0xc310000000000000,
  0xc31fedcba9876540,
  0xc31ffffffffffffc,
  0xc31ffffffffffffc,
  0xc31ffffffffffffc,
  0xc31ffffffffffffc,
  0xc3e0000000000001,
  0xc3e0000000000000,
  0xc3dfffffffffffff,
  0x43dfffffffffffff,
  0x43e0000000000000,
  0x43efffffffffffff,
  0x43f0000000000000,
  0xc1e0000000200000,
  0xc1e0000000200000,
  0xc1e0000000000000,
  0xc1e0000000000000,
  0xc1e0000000000000,
  0xc1e0000000000000,
  0xc1e0000000000000,
  0xc1e0000000000000,
  0xc1dfffffffc00000,
  0xc1dfffffffc00000,
  0xc1dfffffffc00000,
  0xc1dfffffffc00000,
  0x41dfffffff400000,
  0x41dfffffff800000,
  0x41dfffffff800000,
  0x41dfffffff800000,
  0x41dfffffff800000,
  0x41dfffffff800000,
  0x41dfffffff800000,
  0x41dfffffffc00000,
  0x41dfffffffc00000,
  0x41dfffffffc00000,
  0x41dfffffffc00000,
  0x41dfffffffc00000,
  0x41efffffffa00000,
  0x41efffffffc00000,
  0x41efffffffc00000,
  0x41efffffffc00000,
  0x41efffffffc00000,
  0x41efffffffc00000,
  0x41efffffffc00000,
  0x41efffffffe00000,
  0x41efffffffe00000,
  0x41efffffffe00000,
  0x41efffffffe00000,
  0x41efffffffe00000,
};
const unsigned kExpectedCount_frintz_d = 207;

const uint32_t kExpected_frintz_s[] = {
  0x00000000,
  0x00000000,
  0x00000000,
  0x00000000,
  0x00000000,
  0x00000000,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x41200000,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00000000,
  0x00000000,
  0x00000000,
  0x80000000,
  0x80000000,
  0x80000000,
  0x80000000,
  0x80000000,
  0x80000000,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xc1200000,
  0xffcfffff,
  0xff800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x80000000,
  0x80000000,
  0x80000000,
  0x4b000000,
  0x4b000001,
  0x4b000002,
  0x4b000003,
  0x4b765432,
  0x4b7ffffc,
  0x4b7ffffd,
  0x4b7ffffe,
  0x4b7fffff,
  0x4a800000,
  0x4a800000,
  0x4a800002,
  0x4a800002,
  0x4af65432,
  0x4afffffc,
  0x4afffffc,
  0x4afffffe,
  0x4afffffe,
  0x4a000000,
  0x4a000000,
  0x4a000000,
  0x4a000000,
  0x4a765430,
  0x4a7ffffc,
  0x4a7ffffc,
  0x4a7ffffc,
  0x4a7ffffc,
  0xcb000000,
  0xcb000001,
  0xcb000002,
  0xcb000003,
  0xcb765432,
  0xcb7ffffc,
  0xcb7ffffd,
  0xcb7ffffe,
  0xcb7fffff,
  0xca800000,
  0xca800000,
  0xca800002,
  0xca800002,
  0xcaf65432,
  0xcafffffc,
  0xcafffffc,
  0xcafffffe,
  0xcafffffe,
  0xca000000,
  0xca000000,
  0xca000000,
  0xca000000,
  0xca765430,
  0xca7ffffc,
  0xca7ffffc,
  0xca7ffffc,
  0xca7ffffc,
  0xdf000001,
  0xdf000000,
  0xdeffffff,
  0x5effffff,
  0x5f000000,
  0x5f7fffff,
  0x5f800000,
  0xcf000001,
  0xcf000000,
  0xceffffff,
  0x4effffff,
  0x4f000000,
};
const unsigned kExpectedCount_frintz_s = 104;

const uint64_t kExpected_fsqrt_d[] = {
  0x0000000000000000,
  0x2000000000000000,
  0x3fe6a09e667f3bcc,
  0x3fe6a09e667f3bcd,
  0x3fe6a09e667f3bcd,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff3988e1409212e,
  0x40094c583ada5b53,
  0x5fefffffffffffff,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x1fe111111111110a,
  0x1fffffffffffffff,
  0x1e60000000000000,
  0x8000000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
};
const unsigned kExpectedCount_fsqrt_d = 38;

const uint32_t kExpected_fsqrt_s[] = {
  0x00000000,
  0x20000000,
  0x3f3504f3,
  0x3f3504f3,
  0x3f3504f4,
  0x3f7fffff,
  0x3f800000,
  0x3f800000,
  0x3f9cc471,
  0x404a62c2,
  0x7fcfffff,
  0x7f800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x1f411656,
  0x1fffffff,
  0x1a3504f3,
  0x80000000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
};
const unsigned kExpectedCount_fsqrt_s = 38;

const uint64_t kExpected_fsub_d[] = {
  0x0000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x0010000000000000,
  0x0000000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff0000000000000,
  0x000edcba98765433,
  0x0000000000000001,
  0x000fffffffffffff,
  0x0010000000000000,
  0x0020000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff0000000000000,
  0x001123456789abcd,
  0x001fffffffffffff,
  0x0010000000000001,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x0000000000000000,
  0xbc90000000000000,
  0xbca8000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000002,
  0xbff0000000000000,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff0000000000000,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff7ffffffffffff,
  0x3ff8000000000000,
  0x3ff8000000000001,
  0x4000000000000000,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff0000000000000,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3c90000000000000,
  0x0000000000000000,
  0xbca0000000000000,
  0xbfdffffffffffffe,
  0xbfe0000000000000,
  0xbfe0000000000002,
  0xbff0000000000000,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000001,
  0x4000000000000000,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3ca8000000000000,
  0x3ca0000000000000,
  0x0000000000000000,
  0xbfdffffffffffffc,
  0xbfdffffffffffffe,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xc023000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000002,
  0x4000000000000000,
  0x4025000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff0000000000000,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fdfffffffffffff,
  0x3fdffffffffffffe,
  0x3fdffffffffffffc,
  0x0000000000000000,
  0xbca0000000000000,
  0xbcb8000000000000,
  0xbfe0000000000001,
  0xc022000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff0000000000000,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3ff7ffffffffffff,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3fffffffffffffff,
  0x4000000000000000,
  0x4000000000000000,
  0x4004000000000000,
  0x4026000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff0000000000000,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3fe0000000000000,
  0x3fe0000000000000,
  0x3fdffffffffffffe,
  0x3ca0000000000000,
  0x0000000000000000,
  0xbcb0000000000000,
  0xbfe0000000000000,
  0xc022000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x4000000000000000,
  0x4000000000000000,
  0x4000000000000000,
  0x4004000000000000,
  0x4026000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3fe0000000000002,
  0x3fe0000000000002,
  0x3fe0000000000001,
  0x3cb8000000000000,
  0x3cb0000000000000,
  0x0000000000000000,
  0xbfdffffffffffffc,
  0xc022000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff0000000000000,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff8000000000001,
  0x3ff8000000000001,
  0x3ff8000000000002,
  0x4000000000000000,
  0x4000000000000000,
  0x4000000000000001,
  0x4004000000000000,
  0x4026000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff0000000000000,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff0000000000000,
  0x3ff0000000000000,
  0x3fefffffffffffff,
  0x3fe0000000000001,
  0x3fe0000000000000,
  0x3fdffffffffffffc,
  0x0000000000000000,
  0xc021000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff0000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x4000000000000000,
  0x4000000000000000,
  0x4000000000000000,
  0x4004000000000000,
  0x4004000000000000,
  0x4004000000000000,
  0x4008000000000000,
  0x4027000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff0000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x3ff8000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4023000000000000,
  0x4023000000000000,
  0x4023000000000000,
  0x4022000000000000,
  0x4022000000000000,
  0x4022000000000000,
  0x4021000000000000,
  0x0000000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff0000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4025000000000000,
  0x4025000000000000,
  0x4025000000000000,
  0x4026000000000000,
  0x4026000000000000,
  0x4026000000000000,
  0x4027000000000000,
  0x4034000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff0000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x0000000000000000,
  0xfff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff0000000000000,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff0000000000000,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x800edcba98765433,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff0000000000000,
  0x0000000000000000,
  0x800edcba98765432,
  0x000123456789abcc,
  0x000123456789abcd,
  0x001123456789abcd,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff0000000000000,
  0x0002468acf13579a,
  0x001123456789abcc,
  0x000123456789abce,
  0x000fffffffffffff,
  0x8000000000000001,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff0000000000000,
  0x000edcba98765432,
  0x0000000000000000,
  0x000ffffffffffffe,
  0x000fffffffffffff,
  0x001fffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff0000000000000,
  0x001123456789abcc,
  0x001ffffffffffffe,
  0x0010000000000000,
  0x0000000000000001,
  0x800fffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcc,
  0x800ffffffffffffe,
  0x0000000000000000,
  0x0000000000000001,
  0x0010000000000001,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abce,
  0x0010000000000000,
  0x0000000000000002,
  0x8000000000000000,
  0x8010000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff0000000000000,
  0x800123456789abcd,
  0x800fffffffffffff,
  0x8000000000000001,
  0x0000000000000000,
  0x0010000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcd,
  0x000fffffffffffff,
  0x0000000000000001,
  0x8010000000000000,
  0x8020000000000000,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff0000000000000,
  0x801123456789abcd,
  0x801fffffffffffff,
  0x8010000000000001,
  0x8010000000000000,
  0x0000000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff0000000000000,
  0x800edcba98765433,
  0x8000000000000001,
  0x800fffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff7ffffffffffff,
  0xbff8000000000000,
  0xbff8000000000001,
  0xc000000000000000,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff0000000000000,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0x0000000000000000,
  0x3c90000000000000,
  0x3ca8000000000000,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000002,
  0x3ff0000000000000,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff0000000000000,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000001,
  0xc000000000000000,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbc90000000000000,
  0x0000000000000000,
  0x3ca0000000000000,
  0x3fdffffffffffffe,
  0x3fe0000000000000,
  0x3fe0000000000002,
  0x3ff0000000000000,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000002,
  0xc000000000000000,
  0xc025000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbca8000000000000,
  0xbca0000000000000,
  0x0000000000000000,
  0x3fdffffffffffffc,
  0x3fdffffffffffffe,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x4023000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff0000000000000,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbff7ffffffffffff,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbfffffffffffffff,
  0xc000000000000000,
  0xc000000000000000,
  0xc004000000000000,
  0xc026000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff0000000000000,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfdfffffffffffff,
  0xbfdffffffffffffe,
  0xbfdffffffffffffc,
  0x0000000000000000,
  0x3ca0000000000000,
  0x3cb8000000000000,
  0x3fe0000000000001,
  0x4022000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff0000000000000,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xc000000000000000,
  0xc000000000000000,
  0xc000000000000000,
  0xc004000000000000,
  0xc026000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbfe0000000000000,
  0xbfe0000000000000,
  0xbfdffffffffffffe,
  0xbca0000000000000,
  0x0000000000000000,
  0x3cb0000000000000,
  0x3fe0000000000000,
  0x4022000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff8000000000001,
  0xbff8000000000001,
  0xbff8000000000002,
  0xc000000000000000,
  0xc000000000000000,
  0xc000000000000001,
  0xc004000000000000,
  0xc026000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff0000000000000,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbfe0000000000002,
  0xbfe0000000000002,
  0xbfe0000000000001,
  0xbcb8000000000000,
  0xbcb0000000000000,
  0x0000000000000000,
  0x3fdffffffffffffc,
  0x4022000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff0000000000000,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff0000000000001,
  0xbff8000000000000,
  0xbff8000000000000,
  0xc000000000000000,
  0xc000000000000000,
  0xc000000000000000,
  0xc004000000000000,
  0xc004000000000000,
  0xc004000000000000,
  0xc008000000000000,
  0xc027000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff0000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff0000000000000,
  0xbff0000000000000,
  0xbfefffffffffffff,
  0xbfe0000000000001,
  0xbfe0000000000000,
  0xbfdffffffffffffc,
  0x0000000000000000,
  0x4021000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff0000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xbff8000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc025000000000000,
  0xc025000000000000,
  0xc025000000000000,
  0xc026000000000000,
  0xc026000000000000,
  0xc026000000000000,
  0xc027000000000000,
  0xc034000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff0000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc023000000000000,
  0xc023000000000000,
  0xc023000000000000,
  0xc022000000000000,
  0xc022000000000000,
  0xc022000000000000,
  0xc021000000000000,
  0x0000000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff0000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff0000000000000,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0x0000000000000000,
  0x7ff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff0000000000000,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xffefffffffffffff,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0x7ff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0x7ff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff8000000000000,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x7ff8000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff8000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0xfff0000000000000,
  0x800123456789abcd,
  0x801123456789abcd,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff0000000000000,
  0x8002468acf13579a,
  0x801123456789abcc,
  0x800123456789abce,
  0x800123456789abcd,
  0x000edcba98765433,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff0000000000000,
  0x0000000000000000,
  0x000edcba98765432,
  0x800123456789abcc,
  0x800fffffffffffff,
  0x801fffffffffffff,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff0000000000000,
  0x801123456789abcc,
  0x801ffffffffffffe,
  0x8010000000000000,
  0x800fffffffffffff,
  0x0000000000000001,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff0000000000000,
  0x800edcba98765432,
  0x0000000000000000,
  0x800ffffffffffffe,
  0x8000000000000001,
  0x8010000000000001,
  0xbfdfffffffffffff,
  0xbfe0000000000000,
  0xbfe0000000000001,
  0xbfefffffffffffff,
  0xbff0000000000000,
  0xbff0000000000001,
  0xbff8000000000000,
  0xc024000000000000,
  0xffefffffffffffff,
  0xfff0000000000000,
  0x7ff923456789abcd,
  0x7ff8000000000000,
  0x7ff923456789abcd,
  0xfff0000000000000,
  0x800123456789abce,
  0x8010000000000000,
  0x8000000000000002,
  0x8000000000000001,
  0x000fffffffffffff,
  0x3fdfffffffffffff,
  0x3fe0000000000000,
  0x3fe0000000000001,
  0x3fefffffffffffff,
  0x3ff0000000000000,
  0x3ff0000000000001,
  0x3ff8000000000000,
  0x4024000000000000,
  0x7fefffffffffffff,
  0x7ff0000000000000,
  0xfff923456789abcd,
  0xfff8000000000000,
  0xfff923456789abcd,
  0x7ff0000000000000,
  0x000123456789abcc,
  0x000ffffffffffffe,
  0x0000000000000000,
};
const unsigned kExpectedCount_fsub_d = 1444;

const uint32_t kExpected_fsub_s[] = {
  0x00000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0x7fcfffff,
  0xff800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0xffcfffff,
  0x7f800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x00800000,
  0x00000000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0x7fcfffff,
  0xff800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x006dcbaa,
  0x00000001,
  0x007fffff,
  0x00800000,
  0x01000000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0xffcfffff,
  0x7f800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x00923456,
  0x00ffffff,
  0x00800001,
  0x3effffff,
  0x3effffff,
  0x00000000,
  0xb3000000,
  0xb3c00000,
  0xbeffffff,
  0xbf000000,
  0xbf000002,
  0xbf800000,
  0xc1180000,
  0x7fcfffff,
  0xff800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3f7fffff,
  0x3f800000,
  0x3f800000,
  0x3fbfffff,
  0x3fc00000,
  0x3fc00001,
  0x40000000,
  0x41280000,
  0xffcfffff,
  0x7f800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3effffff,
  0x3effffff,
  0x3effffff,
  0x3f000000,
  0x3f000000,
  0x33000000,
  0x00000000,
  0xb3800000,
  0xbefffffe,
  0xbf000000,
  0xbf000002,
  0xbf800000,
  0xc1180000,
  0x7fcfffff,
  0xff800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3fc00000,
  0x3fc00000,
  0x3fc00001,
  0x40000000,
  0x41280000,
  0xffcfffff,
  0x7f800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f000000,
  0x3f000000,
  0x3f000000,
  0x3f000001,
  0x3f000001,
  0x33c00000,
  0x33800000,
  0x00000000,
  0xbefffffc,
  0xbefffffe,
  0xbf000001,
  0xbf7fffff,
  0xc1180000,
  0x7fcfffff,
  0xff800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f800000,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x3fc00000,
  0x3fc00002,
  0x40000000,
  0x41280000,
  0xffcfffff,
  0x7f800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f000001,
  0x3f000001,
  0x3f000001,
  0x3f7fffff,
  0x3f7fffff,
  0x3effffff,
  0x3efffffe,
  0x3efffffc,
  0x00000000,
  0xb3800000,
  0xb4400000,
  0xbf000001,
  0xc1100000,
  0x7fcfffff,
  0xff800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f7fffff,
  0x3f7fffff,
  0x3f7fffff,
  0x3f7fffff,
  0x3f7fffff,
  0x3fbfffff,
  0x3fc00000,
  0x3fc00000,
  0x3fffffff,
  0x40000000,
  0x40000000,
  0x40200000,
  0x41300000,
  0xffcfffff,
  0x7f800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f7fffff,
  0x3f7fffff,
  0x3f7fffff,
  0x3f800000,
  0x3f800000,
  0x3f000000,
  0x3f000000,
  0x3efffffe,
  0x33800000,
  0x00000000,
  0xb4000000,
  0xbf000000,
  0xc1100000,
  0x7fcfffff,
  0xff800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3fc00000,
  0x3fc00000,
  0x3fc00000,
  0x40000000,
  0x40000000,
  0x40000000,
  0x40200000,
  0x41300000,
  0xffcfffff,
  0x7f800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f800000,
  0x3f800000,
  0x3f800000,
  0x3f800001,
  0x3f800001,
  0x3f000002,
  0x3f000002,
  0x3f000001,
  0x34400000,
  0x34000000,
  0x00000000,
  0xbefffffc,
  0xc1100000,
  0x7fcfffff,
  0xff800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3f800001,
  0x3f800001,
  0x3f800001,
  0x3f800001,
  0x3f800001,
  0x3fc00001,
  0x3fc00001,
  0x3fc00002,
  0x40000000,
  0x40000000,
  0x40000001,
  0x40200000,
  0x41300000,
  0xffcfffff,
  0x7f800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3f800001,
  0x3f800001,
  0x3f800001,
  0x3fc00000,
  0x3fc00000,
  0x3f800000,
  0x3f800000,
  0x3f7fffff,
  0x3f000001,
  0x3f000000,
  0x3efffffc,
  0x00000000,
  0xc1080000,
  0x7fcfffff,
  0xff800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x3fc00000,
  0x3fc00000,
  0x3fc00000,
  0x3fc00000,
  0x3fc00000,
  0x40000000,
  0x40000000,
  0x40000000,
  0x40200000,
  0x40200000,
  0x40200000,
  0x40400000,
  0x41380000,
  0xffcfffff,
  0x7f800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x3fc00000,
  0x3fc00000,
  0x3fc00000,
  0x41200000,
  0x41200000,
  0x41180000,
  0x41180000,
  0x41180000,
  0x41100000,
  0x41100000,
  0x41100000,
  0x41080000,
  0x00000000,
  0x7fcfffff,
  0xff800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x41200000,
  0x41200000,
  0x41200000,
  0x41200000,
  0x41200000,
  0x41280000,
  0x41280000,
  0x41280000,
  0x41300000,
  0x41300000,
  0x41300000,
  0x41380000,
  0x41a00000,
  0xffcfffff,
  0x7f800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x41200000,
  0x41200000,
  0x41200000,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7fcfffff,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fcfffff,
  0x7fc00000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0xffcfffff,
  0x7f800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x7f800000,
  0x7f800000,
  0x7f800000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffcfffff,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0xffd23456,
  0xffc00001,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fcfffff,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffcfffff,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0xffd23456,
  0xffc00001,
  0x7fc00000,
  0x7fc00000,
  0x7fc00000,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fd23456,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x7fc00001,
  0x00123456,
  0x806dcbaa,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0x7fcfffff,
  0xff800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x00000000,
  0x806dcba9,
  0x00123455,
  0x00123456,
  0x00923456,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0xffcfffff,
  0x7f800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x002468ac,
  0x00923455,
  0x00123457,
  0x007fffff,
  0x80000001,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0x7fcfffff,
  0xff800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x006dcba9,
  0x00000000,
  0x007ffffe,
  0x007fffff,
  0x00ffffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0xffcfffff,
  0x7f800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x00923455,
  0x00fffffe,
  0x00800000,
  0x00000001,
  0x807fffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0x7fcfffff,
  0xff800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x80123455,
  0x807ffffe,
  0x00000000,
  0x00000001,
  0x00800001,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0xffcfffff,
  0x7f800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x00123457,
  0x00800000,
  0x00000002,
  0x80000000,
  0x80800000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0x7fcfffff,
  0xff800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x80123456,
  0x807fffff,
  0x80000001,
  0x00000000,
  0x00800000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0xffcfffff,
  0x7f800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x00123456,
  0x007fffff,
  0x00000001,
  0x80800000,
  0x81000000,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0x7fcfffff,
  0xff800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x80923456,
  0x80ffffff,
  0x80800001,
  0x80800000,
  0x00000000,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0xffcfffff,
  0x7f800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x806dcbaa,
  0x80000001,
  0x807fffff,
  0xbeffffff,
  0xbeffffff,
  0xbf7fffff,
  0xbf800000,
  0xbf800000,
  0xbfbfffff,
  0xbfc00000,
  0xbfc00001,
  0xc0000000,
  0xc1280000,
  0x7fcfffff,
  0xff800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0x00000000,
  0x33000000,
  0x33c00000,
  0x3effffff,
  0x3f000000,
  0x3f000002,
  0x3f800000,
  0x41180000,
  0xffcfffff,
  0x7f800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbeffffff,
  0xbeffffff,
  0xbeffffff,
  0xbf000000,
  0xbf000000,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbfc00000,
  0xbfc00000,
  0xbfc00001,
  0xc0000000,
  0xc1280000,
  0x7fcfffff,
  0xff800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xb3000000,
  0x00000000,
  0x33800000,
  0x3efffffe,
  0x3f000000,
  0x3f000002,
  0x3f800000,
  0x41180000,
  0xffcfffff,
  0x7f800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf000000,
  0xbf000000,
  0xbf000000,
  0xbf000001,
  0xbf000001,
  0xbf800000,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xbfc00000,
  0xbfc00002,
  0xc0000000,
  0xc1280000,
  0x7fcfffff,
  0xff800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xb3c00000,
  0xb3800000,
  0x00000000,
  0x3efffffc,
  0x3efffffe,
  0x3f000001,
  0x3f7fffff,
  0x41180000,
  0xffcfffff,
  0x7f800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf000001,
  0xbf000001,
  0xbf000001,
  0xbf7fffff,
  0xbf7fffff,
  0xbfbfffff,
  0xbfc00000,
  0xbfc00000,
  0xbfffffff,
  0xc0000000,
  0xc0000000,
  0xc0200000,
  0xc1300000,
  0x7fcfffff,
  0xff800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf7fffff,
  0xbf7fffff,
  0xbf7fffff,
  0xbf7fffff,
  0xbf7fffff,
  0xbeffffff,
  0xbefffffe,
  0xbefffffc,
  0x00000000,
  0x33800000,
  0x34400000,
  0x3f000001,
  0x41100000,
  0xffcfffff,
  0x7f800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf7fffff,
  0xbf7fffff,
  0xbf7fffff,
  0xbf800000,
  0xbf800000,
  0xbfc00000,
  0xbfc00000,
  0xbfc00000,
  0xc0000000,
  0xc0000000,
  0xc0000000,
  0xc0200000,
  0xc1300000,
  0x7fcfffff,
  0xff800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbf000000,
  0xbf000000,
  0xbefffffe,
  0xb3800000,
  0x00000000,
  0x34000000,
  0x3f000000,
  0x41100000,
  0xffcfffff,
  0x7f800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf800000,
  0xbf800000,
  0xbf800000,
  0xbf800001,
  0xbf800001,
  0xbfc00001,
  0xbfc00001,
  0xbfc00002,
  0xc0000000,
  0xc0000000,
  0xc0000001,
  0xc0200000,
  0xc1300000,
  0x7fcfffff,
  0xff800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbf800001,
  0xbf800001,
  0xbf800001,
  0xbf800001,
  0xbf800001,
  0xbf000002,
  0xbf000002,
  0xbf000001,
  0xb4400000,
  0xb4000000,
  0x00000000,
  0x3efffffc,
  0x41100000,
  0xffcfffff,
  0x7f800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbf800001,
  0xbf800001,
  0xbf800001,
  0xbfc00000,
  0xbfc00000,
  0xc0000000,
  0xc0000000,
  0xc0000000,
  0xc0200000,
  0xc0200000,
  0xc0200000,
  0xc0400000,
  0xc1380000,
  0x7fcfffff,
  0xff800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xbfc00000,
  0xbfc00000,
  0xbfc00000,
  0xbfc00000,
  0xbfc00000,
  0xbf800000,
  0xbf800000,
  0xbf7fffff,
  0xbf000001,
  0xbf000000,
  0xbefffffc,
  0x00000000,
  0x41080000,
  0xffcfffff,
  0x7f800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xbfc00000,
  0xbfc00000,
  0xbfc00000,
  0xc1200000,
  0xc1200000,
  0xc1280000,
  0xc1280000,
  0xc1280000,
  0xc1300000,
  0xc1300000,
  0xc1300000,
  0xc1380000,
  0xc1a00000,
  0x7fcfffff,
  0xff800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xc1200000,
  0xc1200000,
  0xc1200000,
  0xc1200000,
  0xc1200000,
  0xc1180000,
  0xc1180000,
  0xc1180000,
  0xc1100000,
  0xc1100000,
  0xc1100000,
  0xc1080000,
  0x00000000,
  0xffcfffff,
  0x7f800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xc1200000,
  0xc1200000,
  0xc1200000,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xffcfffff,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0x7fcfffff,
  0xff800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffcfffff,
  0x7fc00000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xff800000,
  0xff800000,
  0xff800000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0x7fd23456,
  0x7fc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffcfffff,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fcfffff,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0x7fd23456,
  0x7fc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffcfffff,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0xffc00000,
  0xffc00000,
  0xffc00000,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffd23456,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0xffc00001,
  0x80123456,
  0x80923456,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0x7fcfffff,
  0xff800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x802468ac,
  0x80923455,
  0x80123457,
  0x80123456,
  0x006dcbaa,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0xffcfffff,
  0x7f800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x00000000,
  0x006dcba9,
  0x80123455,
  0x807fffff,
  0x80ffffff,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0x7fcfffff,
  0xff800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x80923455,
  0x80fffffe,
  0x80800000,
  0x807fffff,
  0x00000001,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0xffcfffff,
  0x7f800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x806dcba9,
  0x00000000,
  0x807ffffe,
  0x80000001,
  0x80800001,
  0xbeffffff,
  0xbf000000,
  0xbf000001,
  0xbf7fffff,
  0xbf800000,
  0xbf800001,
  0xbfc00000,
  0xc1200000,
  0x7fcfffff,
  0xff800000,
  0x7fd23456,
  0x7fc00000,
  0x7fd23456,
  0x7fc00001,
  0x80123457,
  0x80800000,
  0x80000002,
  0x80000001,
  0x007fffff,
  0x3effffff,
  0x3f000000,
  0x3f000001,
  0x3f7fffff,
  0x3f800000,
  0x3f800001,
  0x3fc00000,
  0x41200000,
  0xffcfffff,
  0x7f800000,
  0xffd23456,
  0xffc00000,
  0xffd23456,
  0xffc00001,
  0x00123455,
  0x007ffffe,
  0x00000000,
};
const unsigned kExpectedCount_fsub_s = 1444;

